#
# =================================================================
#
#   1. Example with input MTZ file of structure factors
#      Fobs : test.mtz
#      Model: test_mod.pdb 
# 
# =================================================================
# --------------------------------
molrep -doc A -i <<stop
# --------------------------------
# first line :   "_DOC  <N>,Y,A "
#   N - means without DOC-file: "molrep.doc"
#   Y - create new file or rewrite if it is old file
#   A - means to keep old contents and add new information
#
_DOC  Y
#
#
#
_FILE_F test.mtz
#F:        < >       - label of F or F(+)
#SIGF:     < >       - label of sigma F or sigma F(+)
#F-:       < >       - label of F(+)
#SIGF-:    < >       - label of sigma F(-)
#I:        < >       - label of I or I(+)
#SIGI:     < >       - label of sigma I or  sigma I(+)
#I-:       < >       - label of I(-)
#SIGI-:    < >       - label of sigma I(-)
_F    F
_SIGF    SIGF
_END    <--- end of MTZ block
_FILE_M test_mod.pdb
#
#
_NP     3
_NPT    10
_END
stop
#
# =================================================================
#
#   2. Example with input CIFile of structure factors
#      Fobs : test.cif
#      Model: test_mod.pdb 
#
# =================================================================
# --------------------------------
molrep -doc A -i <<stop
# --------------------------------
# first line :   "_DOC  <N>,Y,A "
#   N - means without DOC-file: "molrep.doc"
#   Y - create new file or rewrite if it is old file
#   A - means to keep old contents and add new information
#
_DOC  A
#
#
#
_FILE_F test.cif
_FILE_M test_mod.pdb
#
#
_NP     2
_NPT    3
_nmon   2
_mode   s
_COMPL  .5
_SIM    .7
_END
stop
#
# =================================================================
#
#   3. Example with input CIFile of structure factors and second model
#      which is solution for first peak of Rotation Function.
# 
#      Fobs   : test.cif
#      Model  : test_mod.pdb 
#      Model_2: test_mod2.pdb
#
#      Solution is "molrep.pdb" which contains two molecules:
#      first is "test_mod2.pdb", second is solution for second peak of 
#      Rotation Function. 
#
# =================================================================
# --------------------------------
molrep -doc A -i <<stop
# --------------------------------
# first line :   "_DOC  <N>,Y,A "
#   N - means without DOC-file: "molrep.doc"
#   Y - create new file or rewrite if it is old file
#   A - means to keep old contents and add new information
#
_DOC  A
#
#
#
_FILE_F test.cif
_FILE_M test_mod.pdb
#
#
_MODEL_2    test_mod2.pdb
_NP    3
_NPT   10
_END
stop
#
# =================================================================
#
#   4. Example to use NMON keyword with input CIFile of structure 
#      factors. In this case program will find two molecules related
#      by non-crystallographical symmetry.
# 
#      Fobs   : test.cif
#      Model  : test_mod.pdb 
#   
#
#      Solution is "molrep.pdb" which contains two molecules:
#
# =================================================================
# --------------------------------
molrep -doc A -i <<stop
# --------------------------------
# first line :   "_DOC  <N>,Y,A "
#   N - means without DOC-file: "molrep.doc"
#   Y - create new file or rewrite if it is old file
#   A - means to keep old contents and add new information
#
_DOC  A
#
#
#
_FILE_F test.cif
_FILE_M test_mod.pdb
#
#
_NMON   2
_NP     3
_NPT   10
_END
stop
#
# =================================================================
#
#   5. Example for Dyad search.
#      Fobs : test.cif
#      Model: test_mod.pdb 
#
# =================================================================
# --------------------------------
molrep -doc A -i <<stop
# --------------------------------
# first line :   "_DOC  <N>,Y,A "
#   N - means without DOC-file: "molrep.doc"
#   Y - create new file or rewrite if it is old file
#   A - means to keep old contents and add new information
#
_DOC  A
#
#
#
_FILE_F test.cif
_FILE_M test_mod.pdb
#
_RESMAX 3
_NMON   2
_NP     2
_NPT    3
_NPTD   3
_DYAD   Y
_END
stop
#
# =================================================================
#
#   6. Example for NMR model.
#      Fobs : test.cif
#      Model: nmr.pdb  - contains 3 models: 2sar,1rsn,1ay7 
# 
# =================================================================
# --------------------------------
molrep -doc A -i <<stop
# --------------------------------
# first line :   "_DOC  <N>,Y,A "
#   N - means without DOC-file: "molrep.doc"
#   Y - create new file or rewrite if it is old file
#   A - means to keep old contents and add new information
#
_DOC  A
#
#
#
_FILE_F test.cif
_FILE_M nmr.pdb
#
_NMON   2
_COMPL .5
_SIM   .5
_NP    3
_NPT   10
_NMR   3
_END
stop
#
# =================================================================
#
#   7. Example for model fitting.
#      Model   : test_mod.pdb - searching model
#      Model_2 : 2rnt.pdb     - target model
# 
# =================================================================
# --------------------------------
molrep -doc A -i <<stop
# --------------------------------
# first line :   "_DOC  <N>,Y,A "
#   N - means without DOC-file: "molrep.doc"
#   Y - create new file or rewrite if it is old file
#   A - means to keep old contents and add new information
#
_DOC  A
#
#
#
_FILE_F 
_FILE_M test_fit.pdb
#
_PRF Y
_compl 1.
_sim   .2
_MODEL_2 2rnt.pdb
_END
stop
#
# =================================================================
#
#   8. Example for searching a model in elecron density map.
#      Fobs    : mtz.mtz   - Phases for 1 derivative (FOM = 0.31)
#      Model   : model.pdb - searching model
# 
# =================================================================
# --------------------------------
molrep -doc A -i <<stop 
# --------------------------------
# first line :   "_DOC  <N>,Y,A "
#   N - means without DOC-file: "molrep.doc"
#   Y - create new file or rewrite if it is old file
#   A - means to keep old contents and add new information
#
_DOC  A
#
_FILE_F mtz.mtz
_f    FP
_sigf SIGFP
_ph   PH
_fom  FOM
_end         <--- end of MTZ block
#
_FILE_M model.pdb
#
#
_PRF    y
_compl 1.
_sim   .2
_END
stop
# ==========================================================
#  
#   9. Example for finding HA position by MR solution.
#      Fobs    : test_ha.mtz   - Fobs and derivative
#      Model2  : model.pdb    - MR solution
#   
# ==========================================================
molrep -doc A -i <<stop
# --------------------------------
# first line :   "_DOC  <N>,Y,A "
#   N - means without DOC-file: "molrep.doc"
#   Y - create new file or rewrite if it is old file
#   A - means to keep old contents and add new information
#
_DOC  A
#
#
#
_FILE_F test_ha.mtz
#
_F      FP
_SIGF   SIGFP
_FD     FD3
_SIGFD  SIGFD3
_END    <--- end of MTZ block
_FILE_M
#
_FUN   d
_res_t 8
_model_2 model.pdb
_end
stop
# ==========================================================
#  
#  10. Example for HA search by multi-copy search
#      Fobs    : test_ha.mtz   - Fobs and derivative
#
# ==========================================================
molrep -doc A -i <<stop
# --------------------------------
# first line :   "_DOC  <N>,Y,A "
#   N - means without DOC-file: "molrep.doc"
#   Y - create new file or rewrite if it is old file
#   A - means to keep old contents and add new information
#
_DOC  A
#
#
#
_FILE_F test_ha.mtz
#
_F      FP
_SIGF   SIGFP
_FD     FD3
_SIGFD  SIGFD3
_END    <--- end of MTZ block
_FILE_M
#
_FUN t
_diff h
_dyad y
_res_t 8
_nmon 4
_end
stop
# ==========================================================
#  
#  11. Example HA for search by translation function
#      Fobs    : test_ha.mtz   - Fobs and derivative
#
# ==========================================================
molrep -doc A -i <<stop
# --------------------------------
# first line :   "_DOC  <N>,Y,A "
#   N - means without DOC-file: "molrep.doc"
#   Y - create new file or rewrite if it is old file
#   A - means to keep old contents and add new information
#
# --------------------------------
#
_DOC  A
#
#
#
_FILE_F test_ha.mtz
#
_F      FP
_SIGF   SIGFP
_FD     FD3
_SIGFD  SIGFD3
_END    <--- end of MTZ block
_FILE_M
#
_FUN  t
_diff  h
_res_t 8
_nmon  4
_end
stop
# ==========================================================
#  
#  12. Example for Self RF for Heavy Atom structure in derivative.
#      Fobs    : test_ha.mtz   - Fobs and derivative
#
# ==========================================================
molrep -doc A -i <<stop
# --------------------------------
# first line :   "_DOC  <N>,Y,A "
#   N - means without DOC-file: "molrep.doc"
#   Y - create new file or rewrite if it is old file
#   A - means to keep old contents and add new information
#
# --------------------------------
#
_DOC  A
#
#
#
_FILE_F test_ha.mtz
#
_F      FP
_SIGF   SIGFP
_FD     FD3
_SIGFD  SIGFD3
_END    <--- end of MTZ block
_FILE_M
#
_FUN  r
_diff  h
_res_t 8
_end
stop
# ==========================================================
