#
# =================================================================
#
#   1. Example with input MTZ file of structure factors
#      Fobs : test.mtz
#      Model: test_mod.pdb 
# 
# =================================================================
# --------------------------------
$MR_TEST/molrep -f ../data/test.mtz -m ../data/test_mod.pdb -po out/ -ps scr/ -i <<stop
# --------------------------------
stop
#
# =================================================================
#
#   2. Example with input CIFile of structure factors
#      Fobs : test.cif
#      Model: test_mod.pdb 
#
# =================================================================
# --------------------------------
$MR_TEST/molrep -f ../data/test.cif -m ../data/test_mod.pdb -po out/ -ps scr/ -i <<stop
# --------------------------------
_NP     2
_nmon   2
_COMPL  .5
_SIM    .7
stop
#
# =================================================================
#
#   3. Example with input CIFile of structure factors and second model
#      which is solution for first peak of Rotation Function.
# 
#      Fobs   : test.cif
#      Model  : test_mod.pdb 
#      Model_2: test_mod2.pdb
#
#      Solution is "molrep.pdb" which contains two molecules:
#      first is "test_mod2.pdb", second is solution for second peak of 
#      Rotation Function. 
#
# =================================================================
# --------------------------------
$MR_TEST/molrep -f ../data/test.cif -m ../data/test_mod.pdb -mx ../data/test_mod2.pdb -po out/ -ps scr/ -i <<stop
# --------------------------------
_NP    3
stop
#
# =================================================================
#
#   4. Example to use NMON keyword with input CIFile of structure 
#      factors. In this case program will find two molecules related
#      by non-crystallographical symmetry.
# 
#      Fobs   : test.cif
#      Model  : test_mod.pdb 
#   
#
#      Solution is "molrep.pdb" which contains two molecules:
#
# =================================================================
# --------------------------------
$MR_TEST/molrep -f ../data/test.cif -m ../data/test_mod.pdb -po out/ -ps scr/ -i <<stop
# --------------------------------
#
_NMON   2
_NP     3
stop
#
# =================================================================
#
#   5. Example for Dyad search.
#      Fobs : test.cif
#      Model: test_mod.pdb 
#
# =================================================================
# --------------------------------
$MR_TEST/molrep -f ../data/test.cif -m ../data/test_mod.pdb  -m2 ../data/test_mod.pdb -po out/ -ps scr/ -i <<stop
# --------------------------------
_RESMAX 3
_NMON   2
_NP     2
_NPT    3
_NPTD   3
_DYAD   D
stop
#
# =================================================================
#
#   6. Example for NMR model.
#      Fobs : test.cif
#      Model: nmr.pdb  - contains 3 models: 2sar,1rsn,1ay7 
#      keyword NMR = 3
# =================================================================
# --------------------------------
$MR_TEST/molrep -f ../data/test.cif -m ../data/nmr.pdb -po out/ -ps scr/ -i <<stop
# --------------------------------
_NMON   2
_COMPL .5
_SIM   .5
_NP    3
_NPT   10
_NMR   3
stop
#
# =================================================================
#
#   7. Example for model fitting. (using SAPTF )
#      Model   : test_mod.pdb - searching model
#      Model_2 : 2rnt.pdb     - target model
#      PRF = 'Y' means to use SAPTF+PRF+PTF instead RF+PTF
# =================================================================
# --------------------------------
$MR_TEST/molrep -m ../data/test_fit.pdb -mx ../data/2rnt.pdb -po out/ -ps scr/ -i <<stop
# --------------------------------
_PRF Y
_compl 1.
_sim   .2
stop
#
# =================================================================
#
#   8. Example for searching a model in elecron density map.
#      Fobs    : mtz.mtz   - Phases for 1 derivative (FOM = 0.31)
#      Model   : model.pdb - searching model
# 
# =================================================================
# -------------------------------- 
$MR_TEST/molrep -f ../data/mtz.mtz -m ../data/model.pdb -po out/ -ps scr/ -i <<stop 
# --------------------------------
#
_f    FP
_sigf SIGFP
_ph   PH
_fom  FOM
#
stop
# =================================================================
#
#   9. use sequence
# 
# =================================================================
# --------------------------------
$MR_TEST/molrep -f ../data/s100.mtz -m ../data/monomer.pdb -s ../data/s100.seq -po out/ -ps scr/ -i <<stop 
# --------------------------------
stop
# =================================================================
#
#   10. Locked RF
# 
# =================================================================
# --------------------------------
$MR_TEST/molrep -f ../data/s100.mtz -m ../data/monomer.pdb -s ../data/s100.seq -po out/ -ps scr/ -i <<stop 
# --------------------------------
_lock y
_file_tsrf ../data/srf.tab
_nsrf 1
stop
# =================================================================
#
#   11. Multi-monomer search using NCS, SELF = 'A' means to compute Self RF and 
#                                                        to use related RF peaks only 
# 
# =================================================================
# --------------------------------
$MR_TEST/molrep -f ../data/s100.mtz -m ../data/monomer.pdb -m2 ../data/monomer.pdb -s ../data/s100.seq -po out/ -ps scr/ -i <<stop 
# --------------------------------
_self a
_nsrf 1
stop
# =================================================================
#
#   12.  use pst
# 
# =================================================================
# --------------------------------
$MR_TEST/molrep -f ../data/pst.mtz -m ../data/model_pst.pdb -po out/ -ps scr/ -i <<stop 
# --------------------------------
#
stop
# =================================================================
#
#   13. space group check
# 
# =================================================================
# --------------------------------
$MR_TEST/molrep -f ../data/test.mtz -m ../data/test_mod.pdb -po out/ -ps scr/ -i <<stop
# --------------------------------
_sg all
#
stop
# ==========================================================
#  
#  14. Example for finding HA position by MR solution.
#      Fobs    : test_ha.mtz   - Fobs and derivative
#      Model2  : model.pdb    - MR solution
#   
# ==========================================================
$MR_TEST/molrep -f ../data/test_ha.mtz -mx ../data/model.pdb -po out/ -ps scr/ -i <<stop
# --------------------------------
_F      FP
_SIGF   SIGFP
_FD     FD3
_SIGFD  SIGFD3
#
_FUN   d
stop
# ==========================================================
#  
#  15. Example for HA search by multi-copy search
#      Fobs    : test_ha.mtz   - Fobs and derivative
#
# ==========================================================
$MR_TEST/molrep -f ../data/test_ha.mtz -po out/ -ps scr/ -i <<stop
# --------------------------------
#
_F      FP
_SIGF   SIGFP
_FD     FD3
_SIGFD  SIGFD3
#
_FUN t
_diff h
_dyad y
_nmon 4
stop
# ==========================================================
#  
#  16. Example HA for search by translation function
#      Fobs    : test_ha.mtz   - Fobs and derivative
#
# ==========================================================
$MR_TEST/molrep -f ../data/test_ha.mtz -po out/ -ps scr/ -i <<stop
# --------------------------------
_F      FP
_SIGF   SIGFP
_FD     FD3
_SIGFD  SIGFD3
#
_FUN  t
_diff  h
_nmon  4
stop
# ==========================================================
#  
#  17. Example for Self RF for Heavy Atom structure in derivative.
#      Fobs    : test_ha.mtz   - Fobs and derivative
#
# ==========================================================
$MR_TEST/molrep -f ../data/test_ha.mtz -po out/ -ps scr/ -i <<stop
# --------------------------------
_F      FP
_SIGF   SIGFP
_FD     FD3
_SIGFD  SIGFD3
#
_FUN  r
_diff  h
stop
# ==========================================================
