C
C     MOLREP molecular replacement program
C     Copyright (C) 1999-2006 Alexei Vagin
C
C     This code is distributed under the terms and conditions of the
C     CCP4 Program Suite Licence Agreement as a CCP4 Application.
C     A copy of the CCP4 licence can be obtained by writing to the
C     CCP4 Secretary, Daresbury Laboratory, Warrington WA4 4AD, UK.
C
C -I-
      SUBROUTINE FFT(MDOC,NX,NY,NZ,IZMIN,IZMAX,F000,NAMEC
     * ,NAMED,ISYM,IPRSYM,IERR)
C ---------------------------------------------
C -P- FFT  : fast fourie transform: complex --> real.
C            Program applies coefficients supplied by COEF or TRPACK
C            to produce density map. For all space groups.
C -S-
C      Dialog and Batch:
C    
C    FILE_C:  name of input coef-file.
C    FILE_D:  name of output dens-file.
C    GRID:    NX,NY,NZ  - grid spacing. Default are the values 
C                 suitable for calculation of structure factors.
C    LIMZ:    MIN MAX numbers of Z-section /default for SF calculation/
C    F000:    <0.0>  - don"t use F000
C              > 0   - use this value
C              < 0   - use value from FILE_coef
C
C      SUBROUTINE FFT(MDOC,POOL,NX,NY,NZ,IZMIN,IZMAX,F000,NAMEC
C     *              ,NAMED,MEMORY,ISYM,IPRSYM,IERR)
C
C      Parameters of subroutine FFT:
C
C      MDOC     - mode of writting messages to DOC-file
C                0 - only terminal , < - 0 only file, 0 < < 99 - both
C                >= 99 - don't write  
C      NAMEC    - name of input coef-file.
C      NAMED    - name of output dens-file.
C      NX,NY,NZ - numbers of points of grid corresponding axises X,Y,Z
C                 if NX=NY=NZ=0 program will define minimal values 
C                 suitable for calculation structure factors.
C      IZMIN,IZMAX - serial numbers for first and last Z-section
C                    of electron density.
C                    <0,-1> mean default for SF calculation.
C      F000:  <0.0>   - value of F(0,0,0)
C               > 0   - use this value
C               < 0   - use value from input coef_file.
C      POOL   - real array POOL(MEMORY) for
C               one Z-section of electron density NX x NY < MEMORY.
C      MEMORY - dimension of real array POOL.
C      ISYM   - integer*2 array for cryst.symmetry operators 
C      IPRSYM - dimension of integer*2 array ISYM(5,3,IPRSYM)
C               We need not to define contents of array ISYM
C               Here is only reservation of memory.
C      IERR   - signal of error / =1 -error , =o - OK / 
C -I-
C ---------------------------------------------
      INTEGER*2 ISYM(5,3,IPRSYM)
      INTEGER   MDOC,IPRSYM,IERR
      CHARACTER NAMEC*(*),NAMED*(*)
      REAL      F000
      INTEGER   NX,NY,NZ,IZMIN,IZMAX

c     INTEGER   IH(IPRSYM),IK(IPRSYM),IL(IPRSYM)
c     REAL      FA(IPRSYM),FB(IPRSYM)

      integer,   allocatable :: IH(:)
      integer,   allocatable :: IK(:)
      integer,   allocatable :: IL(:)
      real,      allocatable :: FA(:)
      real,      allocatable :: FB(:)

C --------------
C !   IERR  = 0
C !
C V
c      NCRES=MEMORY-IPRSYM*5
c      IF(NCRES.LE.1) THEN
c        CALL MSGERR(MDOC,' ERR: FFT: NOT MEMORY')
c        IERR=1
c      ENDIF
c      I0     = NCRES+1
c      NCRES2 = NCRES/2

      IT = 0
      allocate(IH(1:IPRSYM),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(IK(1:IPRSYM),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(IL(1:IPRSYM),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(FA(1:IPRSYM),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(FB(1:IPRSYM),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      IF(IT.NE.0) THEN
        IERR = 1
        CALL MSGERR(MDOC,
     *    ' ERROR: in FFT : problem with memory allocation')
        CALL MSGERR(MDOC,
     *    '                 try to change resolution')
        RETURN
      ENDIF
C -----------
      CALL SFFT(MDOC,NX,NY,NZ,IZMIN,IZMAX,F000,NAMEC
     * ,NAMED,ISYM,IH,IK,IL,FA,FB,IPRSYM,IERR)
C -----------

      deallocate(IH,STAT=ISTAT)
      deallocate(IK,STAT=ISTAT)
      deallocate(IL,STAT=ISTAT)
      deallocate(FA,STAT=ISTAT)
      deallocate(FB,STAT=ISTAT)

      RETURN
      END
      

      SUBROUTINE INDENS(MTIN,NAMED,NSYM,ISYM,IPRSYM
     *  ,NZ1,NXY,POOLA,POOLB,POOL8,CSAN,SNAN,
     *             DELCS,DELSN,MDOC,IERR)
C --------------------------------------------------------
CMS     : POOL8,POOLA,POOLB
      COMPLEX   POOL8(*)
      REAL      POOLA(*),POOLB(*)
      INTEGER*2 ISYM(5,3,IPRSYM)
C --------------------------------
      REAL      RLINE(20)
      INTEGER*2 IBLOCK(1024)
      COMPLEX   DM
      CHARACTER NAMED*(*),TYPE*4
      DATA      NRMAX/1024/,NW4/4/,NW20/20/
C -------------------------------------------------------------
      IERR=0
      REWIND MTIN
      ZERO    =0.0
      DM      =CMPLX(ZERO,ZERO)
      POOLA(1)=0.0
      DO     I=1,NXY
        POOL8(I)=DM
      ENDDO
      CSZL=1.
      SNZL=0.
C-------------
C      CALL RBLOCK(MTIN,RLINE,NW20,IERR)
C      IF(IERR.NE.0) THEN
C        CALL MSGDOC(MDOC,' ERR: READ FILE-DENS')
C        RETURN
C      ENDIF
C      CALL RBLOCK(MTIN,RLINE,NW20,IERR)
C      IF(IERR.NE.0) THEN
C        CALL MSGERR(MDOC,' ERR: READ FILE-DENS')
C        RETURN
C      ENDIF
      TYPE='RI  '
      MD=99
      CALL OPFILE(MD,MTIN,NAMED,TYPE,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.GT.0) THEN
        IERR=4
        CALL MSGERR(MDOC,' ERR: RFT: READ FILE-DENS')
        MTIN=0
        RETURN
      ENDIF
C-------------
      DO     IZ=1,NZ1
        CALL RBLOCK(MTIN,RLINE,NW4,IERR)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MDOC,' ERR: RFT: READ FILE-DENS')
          RETURN
        ENDIF
C ::::::
C ----- CALL RBLOCK(MTIN,IPOOL,NXY2,IERR)
C ::::::
        IXY=0
        NR0=0
        NR1=1
77710   NR2=NR0+NRMAX
        IF(NR2.GT.NXY) THEN
          NRR=NXY-NR0
        ELSE
          NRR=NRMAX
        ENDIF
        NRR2=NRR/2
        READ(MTIN,ERR=9) (IBLOCK(II),II=1,NRR)
        DO     I=1,NRR
          IXY=IXY+2
          POOLA(IXY)=POOLA(IXY)+IBLOCK(I)*CSZL/RLINE(2)
          POOLB(IXY)=POOLB(IXY)-IBLOCK(I)*SNZL/RLINE(2)
        ENDDO
C:::::::::
        NR0=NR0+NRR
        NR1=NR1+NRR
        IF(NR1.LE.NXY) GO TO 77710
C:::::::::
        STOR=SNZL*CSAN+CSZL*SNAN
        CSZL=CSZL*CSAN-SNZL*SNAN
        SNZL=STOR
      ENDDO
      STOR=SNAN*DELCS+CSAN*DELSN
      CSAN=CSAN*DELCS-SNAN*DELSN
      SNAN=STOR
      RETURN
C --------------------------------------------------
    9 CALL MSGERR(MDOC,' ERR: RFT: READ INPUT-FILE-DENS')
      IERR=1
      RETURN
      END

      SUBROUTINE RDINDX(IH,IK,IL,IHMAX,IKMAX,ILMAX
     * ,RSMIN,RSMAX,NSYM,ISYM,IPRSYM,IEND)
C ----------------------------------------------------
      INTEGER*2 ISYM(5,3,IPRSYM)
C ----------------------------------------------------
 100  CONTINUE
      IF(IEND.EQ.-1) THEN
        IL=0
        IK=-IKMAX
        IH=-IHMAX-1
        IEND=0
      ENDIF
      IH=IH+1
      IF(IH.GT.IHMAX) THEN
        IH=-IHMAX
        IK=IK+1
        IF(IK.GT.IKMAX) THEN
          IK=-IKMAX
          IL=IL+1
          IF(IL.GT.ILMAX) THEN
            IEND=1
            RETURN
          ENDIF
        ENDIF
      ENDIF
      IF(IH.EQ.0.AND.IK.EQ.0.AND.IL.EQ.0) GO TO 100
      CALL DSTAR(IH,IK,IL,RS)
      RS=SQRT(RS)
      IF(RS.GT.RSMAX)      GO TO 100
      CALL SYSABS_BL(IH,IK,IL,NSYM,ISYM,ICND)
      IF(ICND.NE.0) GO TO 100
      NH=IH
      NK=IK
      NL=IL
      CALL ANOMSC(NH,NK,NL,KANOM,JJSYM,NSYM,ISYM)
      IF(JJSYM.NE.1.OR.KANOM.NE.1) GO TO 100
      IF(RS.LT.RSMIN) RSMIN=RS
      RETURN
      END

      SUBROUTINE RFT2(MDOC,POOL8,POOLA,POOLB,NCRES,RESMAX
     * ,NAMED,NAMEF,NAMEPH,NAME,IPRSYM
     * ,SFA,SFB,SYM,JHS,JKS,JLS,LSYM,ISYM
     * ,POOLC,IPOOL,NCRESF  
     * ,RESULT,IERR)
C ---------------------------------------------
      INTEGER*2 ISYM(5,3,IPRSYM)
      INTEGER   ID(3),IDT(7)
CMS     : POOL8,POOLA,POOLB
      REAL      RESULT(11)
      COMPLEX   POOL8(*)
      REAL      POOLA(*),POOLB(*),POOLC(*)
      INTEGER   IPOOL(*)
      REAL      RLATT(6)
      REAL      SFA(IPRSYM),SFB(IPRSYM)
      INTEGER   JHS(IPRSYM),JKS(IPRSYM),JLS(IPRSYM),LSYM(IPRSYM)
      REAL      SYM(3,IPRSYM)
      CHARACTER LINE*80
      CHARACTER NAMED*(*),NAMEF*(*),NAMEPH*(*),NAME*(*)
      CHARACTER TITLE*80,ITYPE*4,PATH*1,EXT*1,PATT*1
      EXTERNAL  PACK,UNPACK
C--------------------------------------------------------------
      TWOPI =8.0*ATAN(1.0)
      IERR=0
C --------------------
      MTIN  =40
      ITYPE ='RI  '
      MD=-ABS(MDOC)-1
      M=99
C     WRITE(*,*) '       INPUT-FILE /DENS/'
      ITYP  =0
      CALL IRDENS(MTIN,NAMED,MD,ITYP,ICNTZ,NX,NY,NZ,IZM,
     * IZN,RMAX,RMIN,POOLA,SCALE,A,B,C,AL,BE,GA,DRMS,
     * RAVER,RESOL,IX0,IY0,IZ0,ITR,TITLE
     * ,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERR: RFT: FILE--DENS')
        CLOSE(MTIN)
        IERR=1
        RETURN
      ENDIF
C      CALL ORFILE(M,MTIN,NAMED,ITYPE,NSYM,ISYM,IPRSYM,IERR)
C      IF(IERR.NE.0) THEN
C        CALL MSGERR(MDOC,' ERR: RFT: OPEN FILE---DENS')
C        RETURN
C      ENDIF
C      CALL GET_TITLE(M,A,B,C,AL,BE,GA
C     *  ,F1,F2,F3,F4,NX,NY,NZ,IZN,IZM,TITLE,IERR)
      NXY=NX*NY
      IF(IZN.NE.0) THEN
        CALL MSGERR(MDOC,' ERR: RFT: IZMIN # 0')
        IERR=1
        RETURN
      ENDIF
      CALL C_RD_CR
      IF(NXY.GT.NCRES) THEN
        WRITE(LINE,
     *  '('' ERR: RFT: not memory '',I4,'' x'',I4,'' >'',I8)')
     *             NX,NY,NCRES
        CALL MSGERR(MDOC,LINE)
        IERR=1
        RETURN
      ENDIF
      IF(TITLE(1:4).EQ.'PATT') THEN
        PATT='Y'
      ELSE
        PATT='N'
      ENDIF
C  ------------------------------------
      RLATT(1)=A
      RLATT(2)=B
      RLATT(3)=C
      RLATT(4)=AL
      RLATT(5)=BE
      RLATT(6)=GA
      CALL DSTARF(RLATT,AST,BST,CST,COALST,COBEST,COGAST,VOL)
      M=99
      CALL ANOMF(M,NSYM,ISYM)
      RESMIN=1000.
      IF(RESMAX.LT.1.E-4) RESMAX=RESOL
      DO     I=1,NSYM
        DO     J=1,3
          SYM(J,I)=(TWOPI*ISYM(4,J,I))/REAL(ISYM(5,J,I))
        ENDDO
      ENDDO
C ---------------------------------------------------
C     WRITE(*,*) '      OUTPUT FILE-FMOD'
      MTF=30
      TITLE(1:4)='FOUR'
      ITYPE='COEF'
      TITLE(5:8)='RFT '
      F1   =1.0
      F2   =0.0
      CALL C_CR_WR
      CALL SET_TITLE(M,A,B,C,
     *  AL,BE,GA,F1,F2,RESMIN,RESMAX,
     *  IDM,IDM,IDM,IDM,IDM,TITLE,IERR)

C     NAME='scratch_rft'

      CALL OWFILE(M,MTF,NAMEF,ITYPE,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERR: RFT: FILE-F')
        CLOSE(MTIN)
        RETURN
      ENDIF
C      WRITE(*,*) '      OUTPUT FILE-PHAS'
      MTPH=33
      TITLE(1:4)='PH  '
      TITLE(5:8)='RFT '
      ITYPE='PH  '
      CALL SET_TITLE(M,A,B,C,
     *  AL,BE,GA,F1,F2,RESMIN,RESMAX,
     *  IDM,IDM,IDM,IDM,IDM,TITLE,IERR)
      CALL OWFILE(M,MTPH,NAMEPH,ITYPE,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERR: RFT: FILE-PH')
        CLOSE(MTIN)
        CLOSE(MTF)
        RETURN
      ENDIF
      CLOSE(MTPH)
      CLOSE(MTF)
C -----------------------------------------------------
      PATH=' '
      EXT =' '
      M   =99
      CALL OPENUW(MTF,M,PATH,NAME,EXT,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERR: RFT: OPEN SCRATCH_FILE')
        RETURN
      ENDIF
C -------------------------------------------------------
      RHMIN=1000.0
      RHMAX=1./RESMAX
      WRITE(LINE,'('' RESOLUTION:'',F7.3)') RESMAX
      CALL MSGDOC(MDOC,LINE)
      CALL LIMHKL(RESMAX,IHMAX,IKMAX,LMAX,NXMIN,NYMIN,NZMIN)
      CALL MSGDOC(MDOC,' For this resolution:')
      WRITE(LINE,1020) IHMAX,IKMAX,LMAX
 1020 FORMAT(' Hmax,Kmax,Lmax :',3I4)
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,1021) NXMIN,NYMIN,NZMIN
 1021 FORMAT(' NXmin,NYmin,NZmin :',3I4)
      CALL MSGDOC(MDOC,LINE)
c      IHMAX  =(NX+2)/2
c      IKMAX  =(NY+2)/2
c      LMAX   =(NZ+2)/2
c      WRITE(LINE,1022) IHMAX,IKMAX,LMAX
c 1022 FORMAT(
c     * ' From NX,NY,NZ of dens-file Hmax,Kmax,Lmax are :',3I4)
c      CALL MSGDOC(MDOC,LINE)
      LMAX1 =LMAX+1
      NZ1   =IZM+1
      NX1   =NX+1
      NX2   =NX+2
      NXB2  =NX/2
      NYB2  =NY/2
      ZER   =0.0
      COEF  =(NX*NY*NZ)/(VOL)
      FMIN =0.0
C ------
      DELANG=TWOPI/FLOAT(NZ)
      DELSN =SIN(DELANG)
      DELCS =COS(DELANG)
      CSAN  =1.0
      SNAN  =0.0
C ------
      NBL  =0
      NBL11=0
      IENDN=-1
      IEND =-1
      IEND1=-1
      NUMB =0
      NUMBS=0
C ---
      SUMF =0.
      SF2C =0.
C ---
      ID(1)=NX
      ID(2)=NY
      ID(3)=0
C ---
      N000 =0
C ==============================================
      LINE=' '
      CALL MSGDOC(MDOC,LINE)
      DO     IL=1,LMAX1
C -------------------------------------
        CALL CLOCK(IDT)
        ILR=IL-1
        WRITE(LINE,'(''    L='',I5,10X,I2,''.'',I2,''.'',I2)')
     .           ILR,IDT(4),IDT(3),IDT(2)
        MM=99         
        IF(MDOC.GE.0.AND.MDOC.LT.99) MM=0
        CALL MSGDOC(MM,LINE)
C ----------------------------
        CALL INDENS(MTIN,NAMED,NSYM,ISYM,IPRSYM
     *    ,NZ1,NXY,POOLA,POOLB,POOL8,CSAN,SNAN,
     *             DELCS,DELSN,MDOC,IERR)
        IF(IERR.GT.0) THEN
          CLOSE(MTIN)
          CLOSE(MTF)
          RETURN
        ENDIF
C  ---------------------------
        CALL MDCFT2(POOL8,ID,IERR)
        IF(IERR.GT.0) THEN
          CALL MSGERR(MDOC,' ERR: RFT: IN MDCFT2')
          CLOSE(MTIN)
          CLOSE(MTF)
          RETURN
        ENDIF
C -----------------------------------------------------
        IF(ILR.EQ.0) THEN
          F000=(POOLA(2)*NSYM)/(COEF)
          FMIN=F000*0.000001
          IF0=0
          MH=0
          MK=0
          ML=0
          FA=1.
          FB=0.
C         CALL WRT (MTF ,MH,MK,ML,F000,ZER,NBL  ,IEND )
C         WRITE(MTF) MH,MK,ML,F000,ZER
          CALL PACK(INDX,MH,MK,ML)
          WRITE(MTF) INDX,F000,ZER
          N000=1
        ENDIF
        ILN=ILR
C---------------
        DO IKN=-IKMAX,IKMAX
        DO IHN=-IHMAX,IHMAX
          IF(IHN.EQ.0.AND.IKN.EQ.0.AND.ILN.EQ.0)     GO TO 400
          IF(IABS(IHN).GE.NXB2.OR.IABS(IKN).GE.NYB2) GO TO 400
          MH=IHN
          MK=IKN
          ML=ILN
          CALL SYSABS_BL(MH,MK,ML,NSYM,ISYM,ICND)
          IF(ICND.NE.0) GO TO 400
          CALL ANOMSC(MH,MK,ML,KANOM,JJSYM,NSYM,ISYM)
          CALL DSTAR(MH,MK,ML,RH)
          RH=SQRT(RH)
          IF(RH.GT.RHMAX)      GO TO 400
          IF(RH.LT.RHMIN) RHMIN=RH
          IKNN=IKN
          IF(IKNN.LT.0) IKNN=IKNN+NY
          IKNIND =IKNN*NX
          IHNN=IHN
          IF(IHNN.LT.0) IHNN=IHNN+NX
          IND1=IKNIND+IHNN+1
          IND =IND1*2
          FAI= POOLA(IND)/COEF
          FBI=-POOLB(IND)/COEF
          JHN= IHN
          JKN= IKN
          JLN= ILN
          FAT= FAI
          FBT= FBI
          FA=0.0
          FB=0.0
          IWRITE=0
          IF(KANOM.EQ.1) THEN
CD            WRITE(*,'('' --- M H,K,L,FNOM:'',5I5)') 
CD     *      MH,MK,ML,KANOM,JJSYM
CD            WRITE(*,'(''    N H,K,L,FA,FB:'',3I5,2X,2F12.3)')
CD     *      JHN,JKN,JLN,FAT,FBT

C----
            DO     I=1,NSYM
C              FA=0.0
C              FB=0.0
              IHS=ISYM(1,1,I)*MH+ISYM(1,2,I)*MK+ISYM(1,3,I)*ML
              IKS=ISYM(2,1,I)*MH+ISYM(2,2,I)*MK+ISYM(2,3,I)*ML
              ILS=ISYM(3,1,I)*MH+ISYM(3,2,I)*MK+ISYM(3,3,I)*ML
              IF(IHS.EQ.JHN.AND.IKS.EQ.JKN.AND.ILS.EQ.JLN) THEN
                FFAT=FAT
                FFBT=FBT
c                LSS=LS*KANOM
c                IF(LS.NE.1) FFBT=-FFBT
                ARG   =MH*SYM(1,I)+MK*SYM(2,I)+ML*SYM(3,I)
                COSD  =COS(ARG)
                SIND  =SIN(ARG)
                FA=FA+FFAT*COSD-FFBT*SIND
                FB=FB+FFBT*COSD+FFAT*SIND
                IWRITE=1
CD                WRITE(*,'(''      I H,K,:'',5I5,2F12.3)') 
CD     *          I,IHS,IKS,ILS,LS,FA,FB
CD                NUMBS=NUMBS+1
CD                WRITE(MTF) MH,MK,ML,FA,FB
              ENDIF
            ENDDO
          ENDIF

C         ARG   =MH*SYM(1,JJSYM)+MK*SYM(2,JJSYM)+ML*SYM(3,JJSYM)
C         COSD  =COS(ARG)
C         SIND  =SIN(ARG)
C         STOR  =FA*COSD-FB*SIND
C         FB    =FB*COSD+FA*SIND
C         FA    =STOR
C         NUMBS=NUMBS+1
C         CALL WRT(MTF,MH,MK,ML,FA,FB,NBL,IEND )
c         WRITE(MTF) MH,MK,ML,FA,FB

          IF(ILN.GT.0) THEN
            MMH=-IHN
            MMK=-IKN
            MML=-ILN
            CALL ANOMSC(MMH,MMK,MML,KANOM,JJSYM,NSYM,ISYM)
            IF(MMH.EQ.MH.AND.MMK.EQ.MK.AND.MML.EQ.ML.AND.KANOM.EQ.1)
     *      THEN
              JHN=-IHN
              JKN=-IKN
              JLN=-ILN
              FAT= FAI
              FBT=-FBI
CD              WRITE(*,'('' --- M H,K,L,FNOM:'',5I5)') 
CD     *        MH,MK,ML,KANOM,JJSYM
CD              WRITE(*,'(''    N H,K,L,FA,FB:'',3I5,2X,2F12.3)')
CD     *        JHN,JKN,JLN,FAT,FBT

C----
              DO     I=1,NSYM
CD                FA=0.0
CD                FB=0.0
                IHS=ISYM(1,1,I)*MH+ISYM(1,2,I)*MK+ISYM(1,3,I)*ML
                IKS=ISYM(2,1,I)*MH+ISYM(2,2,I)*MK+ISYM(2,3,I)*ML
                ILS=ISYM(3,1,I)*MH+ISYM(3,2,I)*MK+ISYM(3,3,I)*ML
                IF(IHS.EQ.JHN.AND.IKS.EQ.JKN.AND.ILS.EQ.JLN) THEN
                  FFAT=FAT
                  FFBT=FBT
                  ARG   =
     *            MH*SYM(1,I)+MK*SYM(2,I)+ML*SYM(3,I)
                  COSD  =COS(ARG)
                  SIND  =SIN(ARG)
                  FA=FA+FFAT*COSD-FFBT*SIND
                  FB=FB+FFBT*COSD+FFAT*SIND
                  IWRITE=1 
CD                  WRITE(*,'(''      I H,K,:'',5I5,2F12.3)') 
CD     *            I,IHS,IKS,ILS,LS,FA,FB
CD                  NUMBS=NUMBS+1
CD                  WRITE(MTF) MH,MK,ML,FA,FB
                ENDIF

              ENDDO
            ENDIF
          ENDIF
          IF(IWRITE.EQ.1) THEN
            NUMBS=NUMBS+1
C           WRITE(MTF) MH,MK,ML,FA,FB
            CALL PACK(INDX,MH,MK,ML)
            WRITE(MTF) INDX,FA,FB
          ENDIF
  400     CONTINUE
        ENDDO
        ENDDO
      ENDDO

C  ===============================================
      RESMIN=1./RHMIN
      IEND =2
C      CALL WRT (MTF ,MH,MK,ML,FD,ZER,NBL  ,IEND )
      END FILE MTF
      CLOSE(MTF)
      CLOSE(MTIN)
C -----------------------------------------------
      PATH=' '
      EXT =' '
      M   =99
      MTN =41
      CALL OPENUR(MTN,M,PATH,NAME,EXT,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERR: RFT: OPEN SCRATCH-FILE')
        RETURN
      ENDIF

C      M=99
C      MTN=41
C      ITYPE='COEF'
C      CALL ORFILE(M,MTN,NAME,ITYPE,NSYM,ISYM,IPRSYM,IERR)
C      IF(IERR.NE.0) THEN
C        CALL MSGERR(MDOC,' ERR: RFT: OPEN FILE-F')
C        RETURN
C      ENDIF
C ----
      IENDN=-1
      NUMBS=0
 600  CONTINUE
C      CALL RD1(MTN,IH,IK,IL,FA,FB,NBLN,IENDN)
C     READ(MTN,END=700) IH,IK,IL,FA,FB
      READ(MTN,END=700) IND,FA,FB
      IF(MTN.LE.0) THEN
        CALL MSGERR(MDOC,' ERR: RFT: READ SCRATCH_FILE')
        IERR=1
        RETURN
      ENDIF
      IF(IENDN.GT.0) GO TO 700
       

      IF(NUMBS.GE.NCRESF) THEN
        CALL RFT_SUM(MDOC,NUMBS,IPOOL,POOLA,POOLC)        
        IF(NUMBS.GE.NCRESF) THEN
          WRITE(LINE
     *    ,'('' ERR: RFT: not memory for scratch_F >'',I8)') NCRESF
          CALL MSGERR(MDOC,LINE)
          IERR=1
          CLOSE(MTN)
          RETURN
        ENDIF
      ENDIF

      NUMBS=NUMBS+1
C     CALL PACK(IND,IH,IK,IL)
      IPOOL(NUMBS)=IND
      POOLA(NUMBS)=FA
      POOLC(NUMBS)=FB
      GO TO 600

 700  CONTINUE
      IF(NUMBS.LE.0) THEN
        CALL MSGERR(MDOC,' ERR: RFT: NUMBER OF REFLS = 0')
        IERR=1
        CLOSE(MTN)
        RETURN
      ENDIF
      CLOSE(MTN)
C -----------------------
      CALL RFT_SUM(MDOC,NUMBS,IPOOL,POOLA,POOLC)        
C -----------------------
C     WRITE(*,*) '      OUTPUT FILE-FMOD'
      MTF=30
      TITLE(1:4)='F   '
      ITYPE='F   '
      TITLE(5:8)='RFT '
      F1   =1.0
      F2   =0.0
      CALL C_CR_WR
      CALL SET_TITLE(MD,A,B,C,
     *AL,BE,GA,F1,F2,RESMIN,RESMAX,
     *IDM,IDM,IDM,IDM,IDM,TITLE,IERR)
      CALL OWFILE(MD,MTF,NAMEF,ITYPE,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERR: RFT: OPEN FILE-F')
        RETURN
      ENDIF
C      WRITE(*,*) '      OUTPUT FILE-PHAS'
      MTPH=33
      TITLE(1:4)='PH  '
      TITLE(5:8)='RFT '
      ITYPE='PH  '
      CALL SET_TITLE(MD,A,B,C,
     *  AL,BE,GA,F1,F2,RESMIN,RESMAX,
     *  IDM,IDM,IDM,IDM,IDM,TITLE,IERR)
      CALL OWFILE(MD,MTPH,NAMEPH,ITYPE,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERR: RFT: OPEN FILE-PH')
        CLOSE(MTF)
        RETURN
      ENDIF
C-----------------------
      N000=0
      NUMB=0
      SF2C=0.0
      SUMF=0.0
      IEND = -1
      IEND1= -1
      NBL  =0
      NBL11=0
      DO     I=1,NUMBS
        IND=IPOOL(I)
        SA =POOLA(I)
        SB =POOLC(I)
        CALL UNPACK(IND,IH,IK,IL)
        IF(IH.EQ.0.AND.IK.EQ.0.AND.IL.EQ.0) THEN
          N000=1
          F000=SA
          CALL WRT(MTF  ,IH,IK,IL,SA,ZER,NBL  ,IEND )
          IF(MTF.LE.0) THEN
            CALL MSGERR(MDOC,' ERR: RFT: WRITE TO FILE-F')
            CLOSE(MTPH)
            IERR=1
            RETURN
          ENDIF
          SA=1.
          SB=0.
          CALL WRT1(MTPH,IH,IK,IL,SA ,SB ,NBL11,IEND1)
          IF(MTPH.LE.0) THEN
            CALL MSGERR(MDOC,' ERR: RFT: WRITE TO FILE-PH')
            IERR=1
            CLOSE(MTF)
            RETURN
          ENDIF
        ELSE
          FD =SA*SA+SB*SB
          FD2=FD
          FD =SQRT(FD)
          FDD=FD
          IF(FDD.GE.FMIN) THEN
            SF2C=SF2C+FD2
            SUMF=SUMF+FDD
            SA  =SA/FD
            SB  =SB/FD
            NUMB=NUMB+1
            IF(PATT.EQ.'Y') THEN
              FDD=SQRT(FDD)
            ENDIF
            CALL WRT(MTF  ,IH,IK,IL,FDD,ZER,NBL  ,IEND )
            IF(MTF.LE.0) THEN
              CALL MSGERR(MDOC,' ERR: RFT: WRITE TO FILE_F')
              CLOSE(MTPH)
              IERR=1
              RETURN
            ENDIF
            CALL WRT1(MTPH,IH,IK,IL,SA ,SB ,NBL11,IEND1)
            IF(MTPH.LE.0) THEN
              CALL MSGERR(MDOC,' ERR: RFT: WRITE TO FILE_PH')
              CLOSE(MTF)
              IERR=1
              RETURN
            ENDIF
          ENDIF
        ENDIF
      ENDDO     
C     CLOSE(MTN)
C --------------------------------------------
CC
C
C      N000=0
C      SA=0.0
C      SB=0.0
C      INDOLD=-1
C      NUMB=0
C      SF2C=0.0
C      SUMF=0.0
C      IEND = -1
C      DO     I=1,NUMBS
C        IND=IPOOL(I)
C        FA =POOLA(I)
C        FB =POOLC(I)
C        CALL UNPACK(IND,IH,IK,IL)
C        IF(I.NE.1.AND.IND.NE.INDOLD) THEN
C
C          CALL UNPACK(INDOLD,IHO,IKO,ILO)
C          IF(IHO.EQ.0.AND.IKO.EQ.0.AND.ILO.EQ.0) THEN
C            N000=1
C            F000=SA
C            CALL WRT(MTF  ,IHO,IKO,ILO,SA,ZER,NBL  ,IEND )
C            SA=1.
C            SB=0.
C            CALL WRT1(MTPH,IHO,IKO,ILO,SA ,SB ,NBL11,IEND1)
C            WRITE(*,'('' ->'',4I5,3F16.3)') 
C     *      NUMB,IHO,IKO,ILO,FDD,SA,SB
C          ELSE
C            FD =SA*SA+SB*SB
C            FD2=FD
C            FD =SQRT(FD)
C            FDD=FD
C            IF(FDD.GE.FMIN) THEN
C              SF2C=SF2C+FD2
C              SUMF=SUMF+FDD
C              SA  =SA/FD
C              SB  =SB/FD
C              NUMB=NUMB+1
C              WRITE(*,'('' ->'',4I5,3F16.3)') 
C     *        NUMB,IHO,IKO,ILO,FDD,SA,SB
C              CALL WRT(MTF  ,IHO,IKO,ILO,FDD,ZER,NBL  ,IEND )
C              CALL WRT1(MTPH,IHO,IKO,ILO,SA ,SB ,NBL11,IEND1)
C            ENDIF
C          ENDIF
C          WRITE(*,'(''   '',4I5,2F16.3)') I,IH,IK,IL,FA,FB
C          SA=FA
C          SB=FB
C        ELSE
C          WRITE(*,'(''   '',4I5,2F16.3)') I,IH,IK,IL,FA,FB
C          SA=SA+FA
C          SB=SB+FB
C        ENDIF
C        INDOLD=IND
C        IF(I.EQ.NUMBS) THEN
C          CALL UNPACK(INDOLD,IHO,IKO,ILO)
C          IF(IHO.EQ.0.AND.IKO.EQ.0.AND.ILO.EQ.0) THEN
C            N000=1
C            F000=SA
C            CALL WRT(MTF  ,IHO,IKO,ILO,SA,ZER,NBL  ,IEND )
C            SA=1.
C            SB=0.
C            CALL WRT1(MTPH,IHO,IKO,ILO,SA ,SB ,NBL11,IEND1)
C            WRITE(*,'('' ->'',4I5,3F16.3)') 
C     *      NUMB,IHO,IKO,ILO,FDD,SA,SB
C          ELSE
C            FD =SA*SA+SB*SB
C            FD2=FD
C            FD =SQRT(FD)
C            FDD=FD
C            IF(FDD.GE.FMIN) THEN
C              SF2C=SF2C+FD2
C              SUMF=SUMF+FDD
C              SA  =SA/FD
C              SB  =SB/FD
C              NUMB=NUMB+1
C              CALL WRT(MTF  ,IHO,IKO,ILO,FDD,ZER,NBL  ,IEND )
C              CALL WRT1(MTPH,IHO,IKO,ILO,SA ,SB ,NBL11,IEND1)
C              WRITE(*,'('' ->'',4I5,3F16.3)') 
C     *        NUMB,IHO,IKO,ILO,FDD,SA,SB
C            ENDIF
C          ENDIF
C        ENDIF
C      ENDDO     
C      CLOSE(MTN)
C --------------------------------------------
      IEND =2
      IEND1=2
      CALL WRT (MTF ,MH,MK,ML,FD,ZER,NBL  ,IEND )
      CALL WRT1(MTPH,MH,MK,ML,FA,FB ,NBL11,IEND1)
      CLOSE(MTF)
      CLOSE(MTPH)
C------------------------
      IF(NUMB.GT.0) THEN
        SUMF=SUMF/NUMB
        SF2C=SF2C/NUMB
      ENDIF
      SUMF=SQRT(SF2C)  
      NUMB=NUMB+N000
      WRITE(LINE,1010) NUMB,SUMF,SF2C
 1010 FORMAT(' WRITE NUMB OF REFLS=',I8,' <F-MOD>=',G15.4,
     * ' <F**2>=',G15.4)
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,'('' F000,VOL :'',2G15.4)') F000,VOL
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,'('' RESOLUTION:'',2F7.3)') RESMIN,RESMAX
      CALL MSGDOC(MDOC,LINE)
C -------------------------------------------------
      RESULT(1)=NUMB
      RESULT(2)=RESMIN
      RESULT(3)=RESMAX
      RESULT(4)=F000
      RESULT(5)=SUMF
      RESULT(6)=SF2C
      IF(NUMB.LE.0) THEN
        CALL MSGERR(MDOC,' ERR: RFT: Number of reflections = 0')
        IERR=1
      ENDIF
      RETURN
      END

      SUBROUTINE RFT_SUM(MDOC,NUMBS,IPOOL,POOLA,POOLC)
      INTEGER IPOOL(*)
      REAL POOLA(*),POOLC(*)
      CHARACTER LINE*80
C -----------------------
      M=99
      CALL MSGDOC(M,' --- SORT ---')
      WRITE(LINE,'('' Number of refls for sort   :'',I12)') NUMBS
      CALL MSGDOC(M,LINE)
      CALL ISORT2(IPOOL,NUMBS,POOLA,POOLC)
      WRITE(LINE,'('' Number of refls after sort :'',I12)') NUMBS
      CALL MSGDOC(M,LINE)
      CALL MSGDOC(M,' ------------')
C -----------------------
      SA=0.0
      SB=0.0
      INDOLD=-1
      NUMB=0
      DO     I=1,NUMBS
        IND=IPOOL(I)
        FA =POOLA(I)
        FB =POOLC(I)
        IF(I.NE.1.AND.IND.NE.INDOLD) THEN
          NUMB=NUMB+1
          IPOOL(NUMB)=INDOLD
          POOLA(NUMB)=SA
          POOLC(NUMB)=SB
          SA=FA
          SB=FB
        ELSE
          SA=SA+FA
          SB=SB+FB
        ENDIF
        INDOLD=IND
        IF(I.EQ.NUMBS) THEN
          NUMB=NUMB+1
          IPOOL(NUMB)=INDOLD
          POOLA(NUMB)=SA
          POOLC(NUMB)=SB
        ENDIF
      ENDDO     
      NUMBS=NUMB
      RETURN
      END


      SUBROUTINE REDCT1(MDOC,NAME1,NAMEW,RESULT
     *    ,POOLC,IPOOLA,NCRES
     *    ,MODE,ISYM,IPRSYM,IERR)
C ----------------------------------------------------------
      INTEGER*2 IPOOLA(NCRES)
      REAL      POOLC(NCRES)
      REAL RESULT(*)
      INTEGER*2 ISYM(5,3,IPRSYM)
      REAL      XS(3),XT(3),AX(3)
      CHARACTER NAME1*(*),NAMEW*(*),MODE*1
      CHARACTER TTT1*80
      CHARACTER TTTW*80,TYPE*4
      CHARACTER LINE*80
      EQUIVALENCE (X,XS(1)),(Y,XS(2)),(Z,XS(3))
C ----------------------------------------------------------------------
      IERR=0
      NSYM=1
C--------------------------------------
      ITYPE  = 0
      MTIN1  =40
      M=-ABS(MDOC)-1
      CALL IRDENS(MTIN1,NAME1,M,ITYPE,ICNTZ1,NX1,NY1,NZ1,IZMAX1,
     * IZMIN1,RMAX1,RMIN1,IPOOLA,SCALE1,A1,B1,C1,AL1,BE1,GA1,DRMS,
     * RAVER,RESOL,IX01,IY01,IZ01,ITR1,TTT1
     * ,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.GT.0) THEN
        CALL MSGERR(MDOC,' ERR: REDUCT: INPUT-DENS-FILE')
        IERR=1
        RETURN
      ENDIF
c      CLOSE(MTIN1)
C ---
      IF(MODE.EQ.'R') THEN
        IF(NSYM.EQ.2) THEN
          IF(ISYM(1,2,2).EQ.0.AND.
     *       ISYM(2,2,2).EQ.1.AND.
     *       ISYM(3,2,2).EQ.0     ) THEN
            MODE = 'B'
            WRITE(LINE,*) ' NOW MODE:',MODE
            CALL MSGDOC(MDOC,LINE)
          ENDIF
        ENDIF
      ENDIF

      CALL C_RD_CR
      CALL C_CR_WR
      NXY1=NX1*NY1
      IXMIN1=0
      IXMAX1=NX1-1
      IYMIN1=0
      IYMAX1=NY1-1
      IX0W=IX01
      IY0W=IY01
      IZ0W=IZ01
      DO I=1,80
        TTTW(I:I)=' '
      ENDDO
      TTTW=TTT1
C--------------------------------------------------------
      ALW=AL1
      BEW=BE1
      GAW=GA1
      AW =A1
      BW =B1
      CW =C1
      NXW=NX1
      NYW=NY1
      NZW=NZ1
      IXMINW=0
      IXMAXW=NXW-1
      IYMINW=0
      IYMAXW=NYW-1
      IZMINW=IZMIN1
      IZMAXW=IZMAX1
C--------------------------------------------------------
      MD=-ABS(MDOC)-1
      MTS      = 0
      TTTW(1:4)='REDU'
      TTTW(5:8)='    '
      TYPE     ='RI  '
      CALL LENSTR_BL(NAMEW,LEN)
      IF(LEN.GT.0.AND.NAMEW(1:1).NE.','.AND.NAMEW(1:1).NE.' ') THEN 
        MTS      =43
        CALL SET_TITLE(MD,AW,BW,CW,ALW,BEW,GAW
     *  ,F1,F2,F3,F4,NXW,NYW,NZW,IZMINW,IZMAXW,TTTW,IERR)
        CALL OWFILE(MD,MTS,NAMEW,TYPE,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.GT.0) THEN
          CALL MSGERR(MDOC,' ERR: REDUCT: OUTPUT-DENS-FILE')
          CLOSE(MTIN1)
          RETURN
        ENDIF
      ENDIF
C ----------------------
C---------------------------------------------------------------
      ICNTZ3=-999
      ITYPE=-1
C---------------------------------------------------------------
      NXMAX=0
      NYMAX=0
      NZMAX=0
      DSUM1=0.0
      DSUM2=0.0
      DSUMO=0.0
      DSUMP=0.0
      DSUMN=0.0
      DSUMO2=0.0
      NUMB=0
      IERR=0
      DO     IZ=IZMIN1,IZMAX1
        Z=IZ/FLOAT(NZ1)
C-----------------------
        CALL IRDENS(MTIN1,NAME1,MDOC,ITYPE,ICNTZ1,NX1,NY1,NZ1,IZMAX1,
     *  IZMIN1,RMAX1,RMIN1,IPOOLA,SCALE1,A1,B1,C1,AL1,BE1,GA1,DRMS,
     *  RAVER,RESOL,IX01,IY01,IZ01,ITR1,TTT1
     *  ,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.GT.0) THEN
          CALL MSGERR(MDOC,' ERR: REDUCT: INPUT-DENS-FILE')
          IERR=1
          CLOSE(MTS)
          RETURN
        ENDIF
C-----------------------
        N=0
        DO     IY=1,NY1
          Y=(IY-1)/FLOAT(NY1)
          IND0 =(IY-1)*NX1
          DO     IX=1,NX1
            X=(IX-1)/FLOAT(NX1)
            IND =IND0+IX
            D1=IPOOLA(IND)/SCALE1
            IFLAG=0
C              -------  GENERAL ----------
            IF(MODE.EQ.'R') THEN
              IT=1
              NN=1
              IF(NSYM.GT.1) THEN
              DO     I=2,NSYM
                DO     J=1,3
                  IF(ISYM(5,J,I).EQ. 0) ISYM(5,J,I)=1
                  XT(J)=ISYM(4,J,I)/REAL(ISYM(5,J,I))
                  DO     K=1,3
                    XT(J)=XT(J)+ISYM(K,J,I)*XS(K)
                  ENDDO
                ENDDO
                DO     J=1,3
                  T=ABS(XT(J))
                  IAX=T
                  AX(J)=T-IAX
                  IF(XT(J).LT.0) AX(J)=1.-AX(J)
                  IF(AX(J).GE.1.0) AX(J)=0.
                  AX(J)=XS(J)-AX(J)
                  IF(ABS(AX(J)).LT.1.E-5) AX(J)=0.
                ENDDO

C                IF(AX(3)) 160,150,140
C 150            IF(AX(2)) 160,151,140
C 151            IF(AX(1)) 160,152,140

                IF(AX(3).LT.0.0) GO TO 160
                IF(AX(3).EQ.0.0) GO TO 150
                IF(AX(3).GT.0.0) GO TO 140
 150            IF(AX(2).LT.0.0) GO TO 160
                IF(AX(2).EQ.0.0) GO TO 151
                IF(AX(2).GT.0.0) GO TO 140
 151            IF(AX(1).LT.0.0) GO TO 160
                IF(AX(1).EQ.0.0) GO TO 152
                IF(AX(1).GT.0.0) GO TO 140

 152            CONTINUE
                NN=NN+1
                GO TO 160
 140            CONTINUE
                IT=0
                GO TO 170
 160            CONTINUE
              ENDDO
 170          CONTINUE
              ENDIF
              IF(IT.GE.1) THEN
                N=N+1
                DOUT=D1/FLOAT(NN)
                IFLAG=1
              ELSE
                DOUT=0.
              ENDIF
C              -------  P1 21 1 or P 1 2 1 ----------
            ELSE IF(MODE.EQ.'B') THEN
              IDT=1
              DOUT=D1
              IF(X.LE.0.5) THEN
                IF(X.EQ.0.0) THEN
                  IF(Z.GT.0.5) THEN
                    IDT=0
                  ELSE
                    IF(Y.EQ.0.0.OR.Y.EQ.0.5) DOUT=DOUT/2.
                  ENDIF
                ELSE IF(X.EQ.0.5) THEN
                  IF(Z.GT.0.5) THEN
                    IDT=0
                  ELSE
                    IF(Y.EQ.0.0.OR.Y.EQ.0.5) DOUT=DOUT/2.
                  ENDIF
                ENDIF
              ELSE
                IDT=0
              ENDIF
              IF(IDT.EQ.0) THEN
                DOUT=0.0
              ELSE
                IFLAG=1
                N=N+1
              ENDIF
C              -------  P212121 ----------
            ELSE IF(MODE.EQ.'P') THEN
              IDT=1
              DOUT=D1
              IF(Z.LE.0.25) THEN
                IF(Z.EQ.0.0) THEN
                  IF(Y.GE.0.0.AND.Y.LE.0.25) THEN
                    IF(Y.EQ.0.25.AND.X.GE.0.5) IDT=0
                  ELSE IF(Y.GT.0.5.AND.Y.LE.0.75) THEN
                    IF(Y.EQ.0.75.AND.X.GE.0.5) IDT=0
                  ELSE
                    IDT=0
                  ENDIF
                ELSE IF(Z.EQ.0.25) THEN
                  IF(X.GE.0.0.AND.X.LE.0.5) THEN
                    IF(X.EQ.0.0.AND.Y.GE.0.5) IDT=0
                    IF(X.EQ.0.5.AND.Y.GE.0.5) IDT=0
                  ELSE
                    IDT=0
                  ENDIF
                ENDIF
              ELSE
                IDT=0
              ENDIF
              IF(IDT.EQ.0) THEN
                DOUT=0.0
              ELSE
                IFLAG=1
                N=N+1
              ENDIF
C              -------  P43212 ----------
            ELSE IF(MODE.EQ.'4') THEN
                IDT=1
                DOUT=D1
                IF(Z.LE.0.125) THEN
                  IF(Z.EQ.0.0) THEN
                    IF(Y.EQ.X) DOUT=DOUT/2.
                    IF(Y.GT.X) IDT=0
                  ELSE IF(Z.EQ.0.125) THEN
                    IF(Y.GE.0.0.AND.Y.LE.0.25) THEN
                      IF(Y.EQ.0.0 .AND.X.GE.0.5) IDT=0
                      IF(Y.EQ.0.25.AND.X.GE.0.5) IDT=0
                    ELSE IF(Y.GT.0.5.AND.Y.LE.0.75) THEN
                      IF(Y.EQ.0.5 .AND.X.GE.0.5) IDT=0
                      IF(Y.EQ.0.75.AND.X.GE.0.5) IDT=0
                    ELSE
                      IDT=0
                    ENDIF
                  ENDIF
                ELSE
                  IDT=0
                ENDIF
                IF(IDT.EQ.0) THEN
                  DOUT=0.0
                ELSE
                  IFLAG=1
                  N=N+1
                ENDIF
C              -------  C2221 ----------
            ELSE IF(MODE.EQ.'C') THEN
                IDT=1
                DOUT=D1
                IF(Y.LE.0.5) THEN
                  IF(Z.EQ.0.0) THEN
                    IF(Y.EQ.0.0) DOUT=DOUT/2.
                    IF(Y.LE.0.25) THEN
                      IF(Y.EQ.0.25.AND.X.LE.0.5) IDT=0
                    ELSE
                      IDT=0
                    ENDIF
                  ELSE IF(Z.EQ.0.25) THEN
                    IF(X.LE.0.5) THEN
                      IF(X.EQ.0.0) DOUT=DOUT/2.
                      IF(X.EQ.0.5) DOUT=DOUT/2.
                      IF(Y.EQ.0.25) IDT=0
                    ELSE
                      IDT=0
                    ENDIF
                  ELSE IF(Z.GT.0.25) THEN
                    IDT=0
                  ELSE
                    IF(Y.EQ.0.5) IDT=0
                  ENDIF
                ELSE
                  IDT=0
                ENDIF
                IF(IDT.EQ.0) THEN
                  DOUT=0.0
                ELSE
                  IFLAG=1
                  N=N+1
                ENDIF
C              -------  I4 ----------
            ELSE IF(MODE.EQ.'I') THEN
                DOUT=D1
                XN=1.-X
                IFLAG=1
                IF(((Y.GT.X).OR.(Y.GE.XN)).OR.
     *             (X.GT.0.5.AND.Y.EQ.0.0).OR.(Z.GE.0.5)) THEN
                  DOUT=0.0
                  IFLAG=0
                ELSE
                  IF(Y.EQ.0.0.AND.X.EQ.0.0) DOUT=DOUT/4.
                  IF(Y.EQ.0.5.AND.X.EQ.0.5) DOUT=DOUT/4.
                  IF(Y.EQ.0.0.AND.X.EQ.0.5) DOUT=DOUT/2.
                  N=N+1
                ENDIF
            ENDIF
            
            POOLC(IND)=DOUT
            IF(IFLAG.EQ.1) THEN
              DSUM1 =DSUM1+D1
              DSUMO =DSUMO+DOUT
              DSUMO2=DSUMO2+DOUT*DOUT
              NUMB=NUMB+1
              IF((IX-1).GT.NXMAX) NXMAX=IX-1
              IF((IY-1).GT.NYMAX) NYMAX=IY-1
              IF( IZ   .GT.NZMAX) NZMAX=IZ
            ENDIF
C----XXXX---YYYY-------
  500       CONTINUE
          ENDDO
  400     CONTINUE
        ENDDO
        IF(N.GT.0) NZN=IZ
C---------------------
        IF(MTS.GT.0) THEN
          CALL WDENS(MTS,MDOC,ICNTZ3,NXW,NYW,NZW,IZMINW,IZMAXW,
     *             RMAXD,RMIND,POOLC,RESOL,IX01,IY01,IZ01,ITR1)
          IF(MTS.LE.0) THEN
            CALL MSGERR(MDOC,' ERR: REDUCT: OUTPUT-DENS-FILE')
            IERR=1
            CLOSE(MTIN1)
            RETURN
          ENDIF
        ENDIF
  300 CONTINUE
C---ZZZZZZZZZ----------
      ENDDO
C----------------------
  100 CONTINUE
      AVER=0.0
      RMS=0.0
      NTOT=NX1*NY1*(IZMAX1-IZMIN1+1)
      IF(NUMB.GT.0) THEN
        AVER=DSUMO/NUMB
        RMS=SQRT((DSUMO2+NUMB*AVER*AVER-2.0*AVER*DSUMO)/NUMB)
      ENDIF
      WRITE(LINE,'('' <D>,RMS(D),N,Ntot ='',2G16.4,2I10)') 
     * AVER,RMS,NUMB,NTOT
      CALL MSGDOC(MDOC,LINE)
      M=-ABS(MDOC)-1
      WRITE(LINE,40) DSUMO,DSUMO2
   40 FORMAT(' SUM-R, SUM-R**2 :',2G18.5)
      CALL MSGDOC(M,LINE)

      IF(NXMAX.GT.0) NXMAX=NX1/NXMAX
      IF(NYMAX.GT.0) NYMAX=NY1/NYMAX
      IF(NZMAX.GT.0) NZMAX=NZ1/NZMAX

      WRITE(LINE,'(''Asymm.part N/Na.p (x,y,z) :'',3I6)') 
     * NXMAX,NYMAX,NZMAX
      CALL MSGDOC(MDOC,LINE)
      RESULT(7) = NTOT
      RESULT(8) = NUMB
      RESULT(9) = NXMAX  
      RESULT(10) = NYMAX
      RESULT(11) = NZMAX
C---------------------
      CLOSE(MTIN1)
      IF(MTS.GT.0) CLOSE(MTS)
      RETURN
      END

      SUBROUTINE VLD_SECT(MDOC,MTOUT
     * ,IPATT,ASYM,POOL1,NX1,NY1,NZ1,IZ,NSYM,ISYM,IERR)
C --------------------------------------------------------------------
CMS     : POOL1
      REAL POOL1(*)
      INTEGER*2 ISYM(5,3,*)
C --------------------------------------------------------------
      CHARACTER LINE*80,ASYM*1
C ----------------------------------------------------------------------
      COMMON/COM_VLD/ DMAX1T,DMIN1T,SUM1,SUM21,NUMB1,NPOS,NNEG,NZER
     * ,SUMP,SUMN,SUMP2,SUMN2,SUM31,SUM41,P000
C ----------------------------------------------------------------------
      REAL      XS(3),XT(3),AX(3)
      EQUIVALENCE (X,XS(1)),(Y,XS(2)),(Z,XS(3))
C-----------------------------------------------
        DMAX1 = -1.E30
        DMIN1 =  1.E30
        IXN   = 0
        IYN   = 0
        IXM   = 0
        IYM   = 0
        Z = IZ/FLOAT(NZ1)
        DO     IY=1,NY1
          Y = (IY-1)/FLOAT(NY1)
          IND0 = (IY-1)*NX1
          DO     IX=1,NX1
            X = (IX-1)/FLOAT(NX1)
            IND = IND0+IX
            D1  = POOL1(IND)
            IT  = 1
            NN  = 1
C ---
            IF(ASYM.EQ.'Y') THEN
              IF(IPATT.NE.1) THEN
                DO     I=2,NSYM
                  DO     J=1,3
                    IF(ISYM(5,J,I).EQ. 0) ISYM(5,J,I)=1
                    XT(J)=ISYM(4,J,I)/REAL(ISYM(5,J,I))
                    DO     K=1,3
                      XT(J)=XT(J)+ISYM(K,J,I)*XS(K)
                    ENDDO
                  ENDDO
                  DO     J=1,3
                    T     = ABS(XT(J))
                    IAX   = T
                    AX(J) = T-IAX
                    IF(XT(J).LT.  0) AX(J) = 1.-AX(J)
                    IF(AX(J).GE.1.0) AX(J) = 0.0
                    AX(J) = XS(J)-AX(J)
                    IF(ABS(AX(J)).LT.1.E-5) AX(J) = 0.0
                  ENDDO

C                  IF(AX(3)) 160,150,140
C 150              IF(AX(2)) 160,151,140
C 151              IF(AX(1)) 160,152,140

                  IF(AX(3).LT.0) GO TO  160
                  IF(AX(3).EQ.0) GO TO  150
                  IF(AX(3).GT.0) GO TO  140
 150              IF(AX(2).LT.0) GO TO  160
                  IF(AX(2).EQ.0) GO TO  151
                  IF(AX(2).GT.0) GO TO  140
 151              IF(AX(1).LT.0) GO TO  160
                  IF(AX(1).EQ.0) GO TO  152
                  IF(AX(1).GT.0) GO TO  140

 152              CONTINUE
                  NN = NN + 1
                  GO TO 160
 140              CONTINUE
                  IT = 0
                  GO TO 170
 160              CONTINUE
                ENDDO
 170            CONTINUE
              ELSE
                DO     I=2,NSYM
                  DO     J=1,3
                    XT(J)=0.0
                    DO     K=1,3
                      XT(J)=XT(J)+ISYM(K,J,I)*XS(K)
                    ENDDO
                  ENDDO
                  DO     J=1,3
                    T     = ABS(XT(J))
                    IAX   = T
                    AX(J) = T-IAX
                    IF(XT(J).LT.  0) AX(J) = 1.-AX(J)
                    IF(AX(J).GE.1.0) AX(J) = 0.0
                    AX(J) = XS(J)-AX(J)
                    IF(ABS(AX(J)).LT.1.E-5) AX(J) = 0.0
                  ENDDO

C                  IF(AX(3)) 260,250,240
C 250              IF(AX(2)) 260,251,240
C 251              IF(AX(1)) 260,252,240

                  IF(AX(3).LT.0) GO TO  260
                  IF(AX(3).EQ.0) GO TO  250
                  IF(AX(3).GT.0) GO TO  240
 250              IF(AX(2).LT.0) GO TO  260
                  IF(AX(2).EQ.0) GO TO  251
                  IF(AX(2).GT.0) GO TO  240
 251              IF(AX(1).LT.0) GO TO  260
                  IF(AX(1).EQ.0) GO TO  252
                  IF(AX(1).GT.0) GO TO  240

 252              CONTINUE
                  NN = NN + 1
                  GO TO 260
 240              CONTINUE
                  IT = 0
                  GO TO 270
 260              CONTINUE
                ENDDO
 270            CONTINUE
              ENDIF
            ENDIF
C ---
            IF(IT.LE.0) GO TO 100
            D1 = D1/FLOAT(NN)
            IF(IZ.EQ.0.AND.(IX-1).EQ.0.AND.(IY-1).EQ.0) THEN
              P000 = D1
            ENDIF
            IF(DMAX1.LE.D1) THEN
              DMAX1 = D1
              IXM   = IX-1
              IYM   = IY-1
            ENDIF
            IF(DMIN1.GE.D1) THEN
              DMIN1 = D1
              IXN   = IX-1
              IYN   = IY-1
            ENDIF
            IF(DMAX1T.LE.D1) DMAX1T=D1
            IF(DMIN1T.GE.D1) DMIN1T=D1
            NUMB1 = NUMB1 + 1
            SUM1  = SUM1  + D1
            SUM21 = SUM21 + D1*D1
            SUM31 = SUM31 + D1*D1*D1
            SUM41 = SUM41 + D1*D1*D1*D1
            IF(D1.GT.0.0) THEN
              NPOS  = NPOS  + 1
              SUMP  = SUMP  + D1
              SUMP2 = SUMP2 + D1*D1
            ELSE IF(D1.LT.0.0) THEN
              NNEG  = NNEG  + 1
              SUMN  = SUMN  + D1
              SUMN2 = SUMN2 + D1*D1
            ELSE
              NZER = NZER+1
            ENDIF
 100        CONTINUE
          ENDDO
        ENDDO
        IF(MTOUT.LE.0) THEN
          WRITE(LINE,10) IXM,IYM,IZ,DMAX1,IXN,IYN,IZ,DMIN1
          CALL MSGDOC(MDOC,LINE)
   10     FORMAT(1X,3I4,1X,G12.4,' , ',3I4,1X,G12.4)
        ENDIF
C ----------------------------------------------------------
      RETURN
      END

      SUBROUTINE SET_DINF(MDOC,IPATT,VOL,NX,NY,NZ,RESULT,IPRROW,IERR)
C --------------------------------------------------------------------
      REAL      RESULT(IPRROW,51)
C --------------------------------------------------------------
      CHARACTER LINE*80,ITP*4
C ----------------------------------------------------------------------
      COMMON/COM_VLD/ DMAX1T,DMIN1T,SUM1,SUM21,NUMB1,NPOS,NNEG,NZER
     * ,SUMP,SUMN,SUMP2,SUMN2,SUM31,SUM41,P000
C ----------------------------------------------------------------------
      COEF=(VOL)/(NX*NY*NZ)

      SUM1  = SUM1 *COEF
      SUM21 = SUM21*COEF
      SUMP  = SUMP *COEF
      SUMN  = SUMN *COEF
      SUMP2 = SUMP2*COEF
      SUMN2 = SUMN2*COEF
      SUM31 = SUM31*COEF
      SUM41 = SUM41*COEF
      CFVOL = (VOL*NUMB1)/(NX*NY*NZ)

      AVER1 =SUM1 /CFVOL
      AVER21=SUM21/CFVOL
      RMS1  =SQRT((AVER21-AVER1*AVER1))
      AMOM31=SUM31/(CFVOL*RMS1*RMS1*RMS1)
      AMOM41=SUM41/(CFVOL*RMS1*RMS1*RMS1*RMS1)

c      AVER1=SUM1/NUMB1
c      RMS1=SQRT((SUM21+NUMB1*AVER1*AVER1-2.0*AVER1*SUM1)/NUMB1)
c      AMOM31=SUM31/(NUMB1*RMS1*RMS1*RMS1)
c      AMOM41=SUM41/(NUMB1*RMS1*RMS1*RMS1*RMS1)

      WRITE(LINE,20)
   20 FORMAT(' ---------------------')
      CALL MSGDOC(MDOC,LINE)


      WRITE(LINE,50) NUMB1,RMS1
   50 FORMAT(' NUMB, RMS:',I12,G18.5)
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,30) AVER1,DMAX1T,DMIN1T
   30 FORMAT(' <D>,RMAX,RMIN:',3G18.5)
      CALL MSGDOC(MDOC,LINE)

      IF(IPATT.EQ.1) THEN
        WRITE(LINE,31) P000
 31     FORMAT(' Patterson(000) :',G18.5)
        CALL MSGDOC(MDOC,LINE)
      ENDIF

      WRITE(LINE,55) AMOM31,AMOM41
 55   FORMAT(' Moment_3, Moment_4:',2G18.5)
      CALL MSGDOC(MDOC,LINE)

      AVERP=0.0
      IF(NPOS.GT.0) THEN
        CF=(VOL*NPOS)/(NX*NY*NZ)
        AVERP=SUMP/CF
      ENDIF
      WRITE(LINE,80) NPOS,AVERP
   80 FORMAT(' NUMB D>0 , <D> :',I10,G18.5)
      CALL MSGDOC(MDOC,LINE)
      AVERN=0.0
      IF(NNEG.GT.0) THEN
        CF=(VOL*NNEG)/(NX*NY*NZ)
        AVERN=SUMN/CF
      ENDIF
      WRITE(LINE,82) NNEG,AVERN
   82 FORMAT(' NUMB D<0 , <D> :',I10,G18.5)
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,84) NZER
   84 FORMAT(' NUMB D=0 :',I10)
      CALL MSGDOC(MDOC,LINE)
      NUMB1P=NPOS+NZER
      RMSP =0.0
      RMSN =0.0
      AVERN0=0.0
      AVERP0=0.0
      IF(NUMB1P.GT.0) THEN
        CF=(VOL*NUMB1P)/(NX*NY*NZ)
        AVERP0=SUMP /CF
        SUMP2 =SUMP2/CF
        RMSP =
     *  SQRT((SUMP2-AVERP0*AVERP0))
      ENDIF
      NUMB1N=NNEG+NZER
      IF(NUMB1N.GT.0) THEN
        CF=(VOL*NUMB1N)/(NX*NY*NZ)
        AVERN0=SUMN/CF
        SUMN2=SUMN2/CF
        RMSN =
     *  SQRT((SUMN2-AVERN0*AVERN0))
      ENDIF
      IF(RMSN.GT.0.0) THEN
        RPN=RMSP/RMSN
      ELSE
        RPN=0.0
      ENDIF
      WRITE(LINE,90) RMSP,AVERP0,RPN
   90 FORMAT(' for D >= 0 : RMS,<D> :',3G14.5)
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,92) RMSN,AVERN0
   92 FORMAT(' for D = <0 : RMS,<D> :',2G14.5)
      CALL MSGDOC(MDOC,LINE)

      RESULT(1,1) = NUMB1
      RESULT(2,1) = DMAX1T
      RESULT(3,1) = DMIN1T
      RESULT(4,1) = RMS1
      RESULT(5,1) = AVER1
      RESULT(6,1) = NPOS
      RESULT(7,1) = NNEG
      RESULT(8,1) = RMSP
      RESULT(9,1) = RMSN
      RESULT(10,1) = AVERP0
      RESULT(11,1) = AVERN0
      IF(IPRROW.GE.15) THEN
        RESULT(12,1) = AMOM31
        RESULT(13,1) = AMOM41
        RESULT(14,1) = P000
        RESULT(15,1) = NZER
      ENDIF    
      RETURN
      END


C -I-
      SUBROUTINE RFFT(MDOC,RESMAX
     * ,NAMED,NAMEF,NAMEPH,PATH_SCR,ISYM,IPRSYM,RESULT,IERR)
C ---------------------------------------------
C -P- RFFT : REDUCT + RFT : fast fourie transform: real --> complex.
C            If space group isn't P1 program creates the scratch file 
C                                                      "scratch_rdc"
C -S-
C      Dialog and Batch:
C
C      FILE_D:  -  name of input dens-file.
C      FILE_F:  -  name of output file of modules of SF
C      FILE_PH: -  name of output file of phases  of SF
C      RESOL:  MAX <default from DENS-file> resolution
C
C      It possible to use subroutine RFFT by program:
C
C      SUBROUTINE RFFT(MDOC,POOL,MEMORY,RESMAX
C     * ,NAMED,NAMEF,NAMEPH,ISYM,IPRSYM,RESULT,IERR)
C
C      Parameters:
C
C      MDOC  - mode of writting messages to DOC-file
C             0 - only terminal , < - 0 only file, 0 < < 99 - both
C             >= 99 - don't write  
C      NAMED - name of input dens-file.
C              Symmetry operators will be taken from this file.
C      NAMEF - name of output file of modules of SF
C      NAMEPH- name of output file of phases  of SF
C      RESMAX - resolution. Default values from DENS-file.
C      POOL   -  real array POOL(MEMORY).
C      MEMORY -  (MEMORY*2)/3 is memory for one Z-section of electron
C                density NX x NY.
C                     or
C                NCRES= (MEMORY-IPRSYM*9-2)/2 is memory for
C                the one Z-section of electron density NX x NY < NCRES.
C      ISYM  - integer*2 array for cryst.symmetry operators 
C      IPRSYM- dimension of integer*2 array ISYM(5,3,IPRSYM)
C      IERR  - signal of error / =1 -error , =o - OK / 
C
C      RESULT /real RESULT(11)/ - array for output information:
C
C      RESULT(1) - number of refls
C      RESULT(2) - min resolution
C      RESULT(3) - max resolution
C      RESULT(4) - F(0,0,0)
C      RESULT(5) - <!F!> = sqrt(<I>)
C      RESULT(6) - < I > 
C      RESULT(7) - number of points of density.
C      RESULT(8) - number of points of asymm. part
C      RESULT(9) - asymm. part for X : NX / NXasym.part  
C      RESULT(10) - asymm. part for Y : NY / NYasym.part
C      RESULT(11) - asymm. part for Z : NZ / NZasym.part
C -I-
C -------------------------------------------------------------
      REAL RESULT(*)
      INTEGER*2 ISYM(5,3,IPRSYM)
      CHARACTER NAMED*(*),NAMEF*(*),NAMEPH*(*),NAME*256
      CHARACTER PATH_SCR*(*)

      CHARACTER LINE*80,TYPE*4,MODE*1,PATH*1,EXT*3,TITLE*80
C--------------------------------------------------------------
C      NCRESTR=MEMORY*2
C      NCRESR =NCREST/3
C ---
C      IPRSM = IPRSYM*9
C      IPRSM0= MEMORY-IPRSM+1
C      NCRES = (MEMORY-IPRSM-2)/2
C      NCRESF= (MEMORY-IPRSM-2)/3
C -----------------------------------------------------
      MTIN  =40
      TYPE ='RI  '
      M=99
      CALL ORFILE(M,MTIN,NAMED,TYPE,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERR: RFFT: OPEN INPUT FILE--DENS')
        CLOSE(MTIN)
        RETURN
      ENDIF
      CLOSE(MTIN)
      CALL GET_TITLE(M,A,B,C,AL,BE,GA
     *        ,F1,F2,F3,F4,NX,NY,NZ,IZMIN,IZMAX,TITLE,IERR)
C ----------------------------------------   
      NAME=NAMED
      IF(NSYM.GT.1) THEN

        NAME='molrp_scratch_rdc'
        CALL ADD_PATH(PATH_SCR,NAME)

        PATH=' '
        EXT ='dat'
        M   = 99
        MTF = 43
        CALL OPENUW(MTF,M,PATH,NAME,EXT,IERR)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MDOC,' ERR: RFFT: OPEN SCRATCH_FILE')
          RETURN
        ENDIF
C?
        CLOSE(MTF)
        MODE='R'
C ----
        NXY = NX*NY
        CALL REDUCT(MDOC,NAMED,NAME,RESULT
     *    ,NXY,MODE,ISYM,IPRSYM,IERR)
        IF(IERR.GT.0) RETURN  
C ----
      ENDIF
C ----
      CALL RFT(MDOC,RESMAX
     * ,NAME,NAMEF,NAMEPH,PATH_SCR,ISYM,IPRSYM,RESULT,IERR)
C ----
       NAME = 'molrp_scratch_rdc.dat'
       CALL DELETE_FILE(PATH_SCR,NAME)

      RETURN
      END

      SUBROUTINE SGENDEN(MDOC,NAMEC,NAMED,TITLE
     * ,RX,NX,NY,NZ,IZMIN,IZMAX,MODE,RADR,H2OBG,BADDR,P1,ZFADD
     * ,RESULT,IPRROW,ISYM,IPRSYM,IERR)
C ----------------------------------------------------------
      REAL RESULT(IPRROW)
C ----------------------------------------------------------

      COMMON/CELLL/ A,B,C,ALPHA,BETA,GAMMA,ISPHR,DLIM,HH2OBG,ICELL
C ---
      COMMON/COMINFF/ NDENSP,NDENSM,NZERO,SUMRP,SUMRM

      COMMON/DIMM/  DMAX,NNX,NNY,NNZ,IIZMIN,IIZMAX,IHMAX,IKMAX,ILMAX
C ---------------------------------------
      COMMON/GENDEN_LIM/ BTEMP_LIM 
C ---------------------------------------
C ---
C      INTEGER*2        IBFACT(NCOORM),IZMOCC(NCOORM)
C     *                ,IXC(NCOORM),IYC(NCOORM),IZC(NCOORM)

      integer    , allocatable :: IBFACT(:)
      integer    , allocatable :: IZMOCC(:)
      integer    , allocatable :: IXC(:)
      integer    , allocatable :: IYC(:)
      integer    , allocatable :: IZC(:)

C      INTEGER          NCOORD,NCOORM
C --
C      REAL             X(IPRMAP)

      real,        allocatable :: X(:)

C --
      INTEGER*2        ISYM(5,3,IPRSYM)
C --------------------------------------------------------------
      CHARACTER NAMEC*(*),NAMED*(*),TITLE*(*),MODE*1,P1*1
      CHARACTER LINE*80,STR*80,PATH*1,EXT*3
C==================================================================
      MODEL = IERR
      X0 = 0.0
      Y0 = 0.0
      Z0 = 0.0
      IF(MODEL.LT.0) THEN
        X0 = RESULT(1)
        Y0 = RESULT(2)
        Z0 = RESULT(3)
        RESULT(1) = 0.0
        RESULT(2) = 0.0
        RESULT(3) = 0.0
      ENDIF
      IERR = 0
      MD   = -ABS(MDOC)-1
C ----
      MT   = 10
      CALL ORCRD(MD,MT,NAMEC,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERR: GENDEN: OPEN COORD_FILE')
        GO TO 500
      ENDIF
      CALL C_AT_CR
      CLOSE(MT)
C -------------------------------------------
      BTEMP_LIM = 0.0
      NMODEL = 0
      STR = TITLE
      CALL LENSTR_BL(STR,LEN)
      IF(LEN.LE.0) THEN
        LEN=1
        STR=' '
      ENDIF
      IF(STR(1:3).EQ.',,,') THEN
        STR=' ---'
        LEN=4
      ENDIF
      IF(LEN.GT.60) LEN=60
      TITLE = 'GEN-DEN '//STR(1:LEN)
      LEN=LEN+8
      IF(LEN.LT.68) THEN
        DO I=LEN+1,68
          TITLE(I:I)=' '
        ENDDO
      ENDIF
      IF(P1.EQ.'y') P1='Y'
      IF(P1.EQ.'s') P1='S'
      IF(P1.NE.'Y'.AND.P1.NE.'S') P1='N'
C ---------------------------------------------
      IF(RX.LE.0.0) RX=3.0 
      DMAX = RX
C ----
      CALL LIMHKL(RX,IHMAX,IKMAX,ILMAX,NXMIN,NYMIN,NZMIN)
      WRITE(LINE,1020) IHMAX,IKMAX,ILMAX
 1020 FORMAT(' Hmax,Kmax,Lmax :',3I4)
      CALL MSGDOC(MD,LINE)
      CALL MSGDOC(MD,
     * 'Defaults are minimal grid spacing for calculation SF')
C ----
      WRITE(LINE,1030) NXMIN,NYMIN,NZMIN
 1030 FORMAT('DEFAULT_GRID: NX,NY,NZ <',I3,',',I3,',',I3,'>') 
      CALL MSGDOC(MD,LINE)
      NNX = NX
      NNY = NY
      NNZ = NZ
      IF(NX.LE.0) NNX = NXMIN
      IF(NY.LE.0) NNY = NYMIN
      IF(NZ.LE.0) NNZ = NZMIN
      NNX = (NNX/2)*2
      NNY = (NNY/2)*2
      NNZ = (NNZ/2)*2
      
      IF(NNX.LT.2*IHMAX+1) 
     * CALL MSGDOC(MDOC,'!!! Warning : Nx < 2Hmax+1')
      IF(NNY.LT.2*IKMAX+1) 
     * CALL MSGDOC(MDOC,'!!! Warning : Ny < 2Kmax+1')
      IF(NNZ.LT.2*ILMAX+1) 
     * CALL MSGDOC(MDOC,'!!! Warning : Nz < 2Lmax+1')
      NXY=NNX*NNY

C      IF(NXY.GT.IPRMAP) THEN
C        CALL MSGERR(MDOC,
C     * ' ERROR: GENDEN: not enough memory for one section of dens.')
C        WRITE(LINE,'('' NX='',I4,'' NY='',I4,'' MEMORY-SIZE='',I6)')
C     *                  NNX,NNY,IPRMAP
C        CALL MSGERR(MDOC,LINE)
C        WRITE(LINE,'('' must by: NX x NY < '',I6)') IPRMAP
C        CALL MSGERR(MDOC,LINE)
C        GO TO 500
C      ENDIF
C ---
      IIZMIN = 0
      IIZMAX = 0
      N_SYM  = NSYM
      IF(P1.EQ.'Y'.OR.P1.EQ.'S') N_SYM=1
      CALL SET_LIMZ(N_SYM,ISYM,NNZ,IZMAXD)
      IF(IZMIN.EQ.0.AND.IZMAX.LT.0) THEN
        IIZMIN = 0
        IIZMAX = IZMAXD
        IF(NSYM.EQ.2) THEN
          IF(ISYM(1,2,2).EQ.0.AND.
     *       ISYM(2,2,2).EQ.1.AND.
     *       ISYM(3,2,2).EQ.0     ) IIZMAX = NNZ - 1
        ENDIF
      ELSE
        IIZMAX = IZMAX
        IIZMIN = IZMIN
        IF(IIZMAX.LT.IIZMIN) THEN
          T      = IIZMAX
          IIZMAX = IIZMIN
          IIZMIN = T
        ENDIF
      ENDIF
C ----
      NNXY = NNX * NNY 
      NNZZ = IIZMAX - IIZMIN + 1
      IPRMAP = NNXY * NNZZ

      allocate(X(1:IPRMAP),STAT=ISTAT)
      IF(ISTAT.NE.0) THEN
        IERR = 1
        CALL MSGERR(MDOC,
     *    ' ERROR: in GENDEN_ANISO : problem with memory allocation')
        CALL MSGERR(MDOC,
     *    '                          try to change resolution')
        RETURN
      ENDIF
C ------------------------------------------------
      BADD  = BADDR
      RAD   = RADR
      ISPHR = 0
      ICELL = 0

      IF(MODE.EQ.'u') MODE  = 'U'
      IF(MODE.EQ.'s') MODE  = 'S'
      IF(MODE.EQ.'c') MODE  = 'C'
      IF(MODE.EQ.'b') MODE  = 'B'

      IF(MODE.EQ.'U') ISPHR = 3
      IF(MODE.EQ.'S') ISPHR = 2
C      IF(MODE.EQ.'C') ISPHR = 1

C      IF(MODE.EQ.'C') THEN
C        MODE = 'S'        
C      ENDIF

C      IF(MODE.EQ.'B') THEN
C        BTEMP_LIM = RAD              
C      ENDIF

      IF(MODE.EQ.'S'.OR.MODE.EQ.'C') THEN
        BTEMP_LIM = RAD              
      ENDIF
      IF(ISPHR.GE.2) THEN
        DLIM   = 0.0
        RAD    = 0.0
        BADD   = 0.0
        HH2OBG = 0.0
        IF(ISPHR.GT.2) THEN
          ICELL = 1
          ISPHR = 2
          BADD  = 0.0
        ENDIF
        IF(DLIM.EQ.0.0) THEN
          DLIM  = 2.8
          ISPHR = 3
        ELSE IF(DLIM.LT.0.0) THEN
          DLIM = ABS(DLIM)
          IF(DLIM.GT.32.0) DLIM=32.0
          ISPHR = 4
        ELSE
          ISPHR = 2
          IF(DLIM.GT.32.0) DLIM=32.0
        ENDIF
      ELSE IF(ISPHR.EQ.1) THEN
        DLIM   = 2.8
        BADD   = 0.0
        HH2OBG = 0.0
      ELSE
        DLIM   = 2.8
        HH2OBG = H2OBG
        BADD   = 0.0
        RAD    = 0.0
      ENDIF

C     IF(MDOC.GT.0) THEN
        MD =-ABS(MDOC)-1
        IF(ISPHR.EQ.0) WRITE(LINE,*) ' --- GENERATE ATOM  -DENS ---'
        IF(ISPHR.EQ.1) WRITE(LINE,*) ' --- GENERATE CHARGE-DENS ---'
        IF(ISPHR.GE.2) WRITE(LINE,*) ' --- GENERATE SPHERE-DENS ---'
        CALL MSGDOC(MD,LINE)
        WRITE(LINE,*) ' NX,NY,NZ   :',NNX,NNY,NNZ
        CALL MSGDOC(MD,LINE)
        WRITE(LINE,*) ' IZMIN,IZMAX:',IIZMIN,IIZMAX
        CALL MSGDOC(MD,LINE)
        IF(ISPHR.EQ.2) THEN
          WRITE(LINE,*) ' RADIUS OF SPHERE  :',DLIM
          CALL MSGDOC(MD,LINE)
        ELSE IF(ISPHR.EQ.3) THEN
          WRITE(LINE,*) ' RADIUS OF SPHERE = RAD-Van-der-Waals'
          CALL MSGDOC(MD,LINE)
        ELSE IF(ISPHR.EQ.4) THEN
          WRITE(LINE,*) ' IF SURFACE-AREA=0 THEN RAD :',DLIM
          CALL MSGDOC(MD,LINE)
          WRITE(LINE,*) '             ELSE       RAD =R-Van-der-Waals'
          CALL MSGDOC(MD,LINE)
        ELSE
C          WRITE(LINE,*) ' ADDITIONAL B-FACTOR :',BADD
C          CALL MSGDOC(MD,LINE)
        ENDIF
        IF(ISPHR.EQ.0) THEN
          WRITE(LINE,*) ' DENSITY OF SOLVENT :',HH2OBG
          CALL MSGDOC(MD,LINE)
        ENDIF
C      ENDIF
C --------------------------------------
C
C      write(*,*) 'GD:',ISPHR,dlim,badd
C
C
      NCOORM = 10 
      allocate(IBFACT(1:NCOORM),STAT=ISTAT)
      allocate(IZMOCC(1:NCOORM),STAT=ISTAT)
      allocate(IXC(1:NCOORM),STAT=ISTAT)
      allocate(IYC(1:NCOORM),STAT=ISTAT)
      allocate(IZC(1:NCOORM),STAT=ISTAT)
      IMEM_TEST = 1
      CALL ATSORT(MDOC,NAMEC,BAVER,BMAX,BMIN,BAVERW,BAVERF,BADD
     *  ,NEL,SUMFI2,X0,Y0,Z0,ZFADD
     *  ,NCOORD,NCOORM,IBFACT,IZMOCC,IXC,IYC,IZC
     *  ,MODEL,NMODEL,P1,NSYM,ISYM,IPRSYM,IMEM_TEST,IERR)

      deallocate(IBFACT,STAT=ISTAT)
      deallocate(IZMOCC,STAT=ISTAT)
      deallocate(IXC,STAT=ISTAT)
      deallocate(IYC,STAT=ISTAT)
      deallocate(IZC,STAT=ISTAT)

      IF(IERR.GT.0) THEN
        deallocate(X,STAT=ISTAT)
        RETURN
      ENDIF

      NCOORM = NCOORD

      IT = 0
      allocate(IBFACT(1:NCOORM),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(IZMOCC(1:NCOORM),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(IXC(1:NCOORM),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(IYC(1:NCOORM),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(IZC(1:NCOORM),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      IF(IT.GT.0) THEN
        deallocate(X,STAT=ISTAT)
        IERR = 1
        CALL MSGERR(MDOC,
     *    ' ERROR: in GENDEN: problem with memory allocation')
        CALL MSGERR(MDOC,
     *    '                   try to change resolution')
        RETURN
      ENDIF
      IMEM_TEST = 0
      CALL ATSORT(MDOC,NAMEC,BAVER,BMAX,BMIN,BAVERW,BAVERF,BADD
     *  ,NEL,SUMFI2,X0,Y0,Z0,ZFADD
     *  ,NCOORD,NCOORM,IBFACT,IZMOCC,IXC,IYC,IZC
     *  ,MODEL,NMODEL,P1,NSYM,ISYM,IPRSYM,IMEM_TEST,IERR)
      IF(IERR.GT.0) GO TO 500
      IF(ISPHR.LT.1) THEN
        WRITE(LINE,*) 'ADDITIONAL B-FACTOR :',BADD
        CALL MSGDOC(MDOC,LINE)
      ENDIF
C ---------------------------------------
      NXY=NNX*NNY
      CALL ATMDEN(MDOC,NAMED,TITLE,BADD,SOLV,X,NXY,IPRMAP
     *  ,NCOORD,NCOORM,IBFACT,IZMOCC,IXC,IYC,IZC
     *  ,SUMDEN,P1,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) GO TO 500
C ---------------------------------------
      IF(ISPHR.EQ.0) THEN
        WRITE(LINE,*) ' DENSITY OF SOLVENT :',HH2OBG
        CALL MSGDOC(MD,LINE)
      ENDIF
      NX    = NNX
      NX    = NNY
      NZ    = NNZ
      IZMAX = IIZMAX
      IZMIN = IIZMIN
C     H2OBG = HH2OBG
      RAD   = DLIM

      RESULT(1)  = NEL
      RESULT(2)  = SUMFI2
      RESULT(3)  = BAVER
      RESULT(4)  = BMAX
      RESULT(5)  = BMIN
      RESULT(6)  = BAVERW
      RESULT(7)  = BAVERF
      RESULT(8)  = SUMDEN
      RESULT(9)  = HH2OBG
      RESULT(10) = SOLV
      RESULT(11) = BADD
      RESULT(12) = NMODEL
      RESULT(13) = MODEL
      RESULT(14) = NSYM

      RESULT(18) = NDENSP
      RESULT(19) = NZERO
      RESULT(20) = NDENSM

      WRITE(LINE,*) ' Model,Number of models:',MODEL,NMODEL
      CALL MSGDOC(MDOC,LINE)
 510  CONTINUE

      deallocate(X,STAT=ISTAT)

      deallocate(IBFACT,STAT=ISTAT)
      deallocate(IZMOCC,STAT=ISTAT)
      deallocate(IXC,STAT=ISTAT)
      deallocate(IYC,STAT=ISTAT)
      deallocate(IZC,STAT=ISTAT)

      RETURN
 500  CONTINUE
      IERR=1
      GO TO 510
      END

      SUBROUTINE ATMDEN(MDOC,NAME,TITLE,BADD,SOLV,X,NXY,ISIZE
     *  ,NCOORD,NCOORM,IBFACT,IZMOCC,IXC,IYC,IZC,SUMD
     *  ,P1,NSYM,ISYM,IPRSYM,IERR)
C -----------------------------------------------------
      REAL             X(NXY,*)
C --- integer*2 version
C     INTEGER*2        IBFACT(NCOORM),IZMOCC(NCOORM)
C    *                ,IXC(NCOORM),IYC(NCOORM),IZC(NCOORM)
C --- integer*4 version
      INTEGER          IBFACT(NCOORM),IZMOCC(NCOORM)
     *                ,IXC(NCOORM),IYC(NCOORM),IZC(NCOORM)
C ---
      INTEGER          NCOORD,NCOORM
      CHARACTER        NAME*(*),TITLE*(*),P1*1
      INTEGER*2        ISYM(5,3,IPRSYM)
      INTEGER*4        NSYM,IPRSYM
C --------------------------------------
      COMMON/COMINFF/ NDENSP,NDENSM,NZERO,SUMRP,SUMRM
      COMMON/CELLL/   A,B,C,ALPHA,BETA,GAMMA,ISPHR,DLIM,H2OBG,ICELL
      COMMON/DIMM/    DMAX,NX,NY,NZ,IZMIN,IZMAX,IHMAX,IKMAX,ILMAX
C ---------------------------------------
      CHARACTER LINE*80
      CHARACTER TYPE*4

      REAL      RLATT(6)
      CHARACTER CODEPDB*4,NAMEPDB*40,DATEPDB*9,SPGR*24,TITLEPDB*80 
C-----------------------------------------------
      IERR = 0
      M    = 99
      MD   = -ABS(MDOC)-1
C ---
      MT     = 11
      TYPE   = 'RI  '
      IPRINT = 1
      CALL C_CR_WR

      CALL SET_TITLE(MD,A,B,C,ALPHA,BETA,GAMMA
     *        ,F1,F2,F3,F4,NX,NY,NZ,IZMIN,IZMAX,TITLE,IERR)

      N_SYM=NSYM

      IF(P1.EQ.'Y') THEN

        N_SYM=1

        CALL GET_CELL(RLATT,CODEPDB,NAMEPDB,DATEPDB,TITLEPDB
     *   ,NSPGR,NSETT,SPGR,NSM,IERR)

        SPGR  = 'P 1'
        NSPGR = 1
        NSETT = 1

        CALL SET_WRF(NSPGR,NSETT,SPGR,CODEPDB
     *                  ,NAMEPDB,DATEPDB,TITLEPDB)

      ENDIF

      CALL OWFILE(MD,MT,NAME,TYPE,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.GT.0) RETURN
C ----------------------------------------------
      IZCNT = -999
      IX0   = 0
      IY0   = 0
      IZ0   = 0
      ITR   = 0
C ----
      SUMRP  = 0.0
      SUMRM  = 0.0
      NDENSP = 0
      NDENSM = 0
      NZERO  = 0
      IZ000  = 0
      SOLV   = 0.0
C --
      S=(ALPHA+BETA+GAMMA)*0.5
      VOL=2.0*A*B*C*
     *    SQRT(SIN(S)*SIN(S-ALPHA)*SIN(S-BETA)*SIN(S-GAMMA))
      COEF  = (VOL)/(NX*NY*NZ)
      H2OBG = (H2OBG*COEF)
C -----------------------------------------------------
      IP1   = ISIZE/NXY
      IR    = IZMIN
      IREND = IZMAX
C -----------------------------------------------------
      RESOL = DMAX
      N1    = NX
      N2    = NY

100   CONTINUE
      IF(IR+IP1.GT.IREND) IP1 = IREND-IR+1
      N3 = IP1
      CALL GENDENN(MDOC,X,N1,N2,N3,IR,IZ000,BADD
     *   ,NCOORD,NCOORM,IBFACT,IZMOCC,IXC,IYC,IZC
     *   ,VOL,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.GT.0) RETURN

      DO     K=1,N3
        ISEC=IR+K-1
        CALL WDENS(MT,MDOC,IZCNT,NX,NY,NZ,IZMIN,IZMAX,RMAX,RMIN,
     *             X(1,K),RESOL,IX0,IY0,IZ0,ITR)
        IF(MT.LE.0) RETURN
      ENDDO
      IR = IR + IP1
      IF(IR.LE.IREND) GO TO 100
C-----------------------------------------------------
      SUMR  = SUMRP+SUMRM
      NDENS = NZERO+NDENSP+NDENSM
      SUMD  = (SUMR*VOL)/(NX*NY*NZ)
      IF(ISPHR.GE.2) THEN
        WRITE(LINE,*) ' SUM-DENS       :',SUMR
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,*) ' N-POINT-DENS =1:',NDENSP
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,*) ' N-POINT-ZERO =0:',NZERO
        CALL MSGDOC(MDOC,LINE)
        IF(NDENS.GT.0) SOLV=(FLOAT(NZERO)*100.)/FLOAT(NDENS)
        WRITE(LINE,201) NZERO,SOLV
      ELSE IF(ISPHR.LE.1) THEN
        WRITE(LINE,200) NDENS,SUMR,SUMD
        CALL MSGDOC(MDOC,LINE)
        IF(NDENS.GT.0) SOLV=(FLOAT(NZERO)*100.)/FLOAT(NDENS)
        WRITE(LINE,201) NZERO,SOLV
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,202) NDENSP,SUMRP
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,203) NDENSM,SUMRM
        CALL MSGDOC(MDOC,LINE)
 200    FORMAT(
     *    ' N-POINT-DENS         :',I8,' ; SUM-R,SUM_DENS :',2F12.4)
 201    FORMAT(
     *    ' N-POINT-SOLV-DENS, % :',I8,F8.3)
 202    FORMAT(
     *    ' N-POINT-POSITIV-DENS :',I8,' ; SUM-POSITIV-DENS :',F12.4)
 203    FORMAT(
     *    ' N-POINT-NEGATIV-DENS :',I8,' ; SUM-NEGATIV-DENS :',F12.4)
      ENDIF
      RETURN
      END

      SUBROUTINE ATSORT(MDOC,NAME,BAVER,BPEAK,BMIN,BAVERW,BAVERF
     *  ,BADD,NEL,SUMFI2,X0,Y0,Z0,ZFADD
     *  ,NCOORD,NCOORM,IBFACT,IZMOCC,IXC,IYC,IZC
     *  ,MODEL,NMODEL,P1,NSYM,ISYM,IPRSYM,IMEM_TEST,IERR)
C -------------------------
      INTEGER   MDOC,IERR
      CHARACTER NAME*(*),NCS_FLAG*1,P1*1
      INTEGER   IPRSYM
      INTEGER*2 ISYM(5,3,IPRSYM)
      INTEGER   IBFACT(NCOORM),IZMOCC(NCOORM)
     *         ,IXC(NCOORM),IYC(NCOORM),IZC(NCOORM)
C ---
      INTEGER   NCOORD,NCOORM
C ---
C ------------------------------------------------------------
      INCLUDE 'mr_crd_com.fh'
C -------------------------------------------------
      PARAMETER (NFMMAX=15)
      COMMON/FORMSS/   NFMFC,IZFMFC(15),FMFCA(5,15),
     *                FMFCB(5,15),FMRAD(15),CATOM
      CHARACTER       CATOM(15)*2
C ---
      COMMON/DIMM/    DMAX,NX,NY,NZ,IZMIN,IZMAX,IHMAX,IKMAX,ILMAX
      COMMON/CELLL/    A,B,C,ALPHA,BETA,GAMMA,ISPHR,DLIM,H2OBG,ICELL
C ---------------------------------------
      COMMON/GENDEN_LIM/ BTEMP_LIM 
C -----------------------------------------------------------------
      INTEGER     NCSOP
      REAL        AMNCS(3,3),TRNCS(3)
C------------------------------------------------------------------
      REAL        XA(3),YA(3),XSU(3),XFU(3)
      REAL        TRNS(3,2),XS(3),XF(3),Y(3)
      INTEGER     IPOINT(3)
c     INTEGER     JXXX(200),JYYY(200),JZZZ(200)
C----------------------------------------------------------------
      INTEGER     MODE
      REAL        FRTOCR(3,3),CRTOFR(3,3)
      REAL        ROT(9),TR(3)
      CHARACTER   ATOM*4,CHAR4*4,CHAR2*2,RES3*3
      CHARACTER   STR*80,NCSF*1,GID*4
C==================================================================
      ICOUNT= 0
      NONH  = 0
      NEL   = 0
      SUMFI2= 0
      NFMFC = 0
C --- integer*2 version
C     IPACK =10000
C --- integer*4 version
      IPACK =100000
C ---
      IERR  = 0
      NIN   = 10
      M     = 99
      MD    = -ABS(MDOC)-1
C --------
      NMODEL = 0

      CALL ORCRD(MD,NIN,NAME,NSYM_R,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) RETURN
      A     = CR_CELL(1)
      B     = CR_CELL(2)
      C     = CR_CELL(3)
      ALPHA = CR_CELL(4)
      BETA  = CR_CELL(5)
      GAMMA = CR_CELL(6)
      CALL FRORTH(CR_CELL(1),CR_CELL(2),CR_CELL(3)
     *           ,CR_CELL(4),CR_CELL(5),CR_CELL(6)
     *                            ,FRTOCR,CRTOFR,IERR)
C -----------------------------------------
      NCRSYM   = 0
      NCS_FLAG = 'N'
      NCSOP    = 0
      CALL GET_NCS(MDOC,NCMAX,NCSOP,AMNCS,TRNCS,IERR)
      IF(IERR.NE.0) THEN
        WRITE(STR,
     *  '('' ERR: GENDEN_ANISO: wrong NCS description'')') 
        CALL MSGERR(MDOC,STR)
        RETURN
      ENDIF
      IF(NCSOP.GT.0) THEN
        IGR=0
        CALL GET_ASYMM(MDOC,NASMAX,NGR,NCH,IGR,ICH,INC,MLT,I_ATM
     *                 ,NCSF,GID,IERR)
        IF(IERR.NE.0) THEN
          WRITE(STR,
     *    '('' ERR: GENDEN_ANISO: wrong NCS description'')') 
          CALL MSGERR(MDOC,STR)
          RETURN
        ENDIF
        IF(NGR.GT.0) THEN
          DO IGR=1,NGR
            CALL GET_ASYMM(MDOC,NASMAX,NGR,ICHOLD,IGR,ICH,INC,MLT
     *                    ,IGOLD,NCSF,GID,IERR)
            IF(IERR.NE.0) THEN
              WRITE(STR,
     *        '('' ERR: genden: wrong NCS description'')') 
              CALL MSGERR(MDOC,STR)
              RETURN
            ENDIF
            IF(NCSF.EQ.'N'.OR.NCSF.EQ.'n') THEN
              NCS_FLAG='Y'
              GO TO 520
            ENDIF
          ENDDO
        ENDIF
      ENDIF
 520  CONTINUE
      IF(NCS_FLAG.EQ.'Y') THEN
        WRITE(STR,
     *  '(''NUMBER OPERATORS OF NON-CRYST.SYMMETRY:'',I5)') NCSOP
        CALL MSGDOC(MDOC,STR)
        IF(NCSOP.GT.0) THEN
          CALL MSGDOC(MD,' ')
          CALL MSGDOC(MD,'  X-NEW           X-0      TX')
          CALL MSGDOC(MD,'  Y-NEW  = [M] *  Y-0  +   TY')
          CALL MSGDOC(MD,'  Z-NEW           Z-0      TZ')
          CALL MSGDOC(MD,' ')
          CALL MSGDOC(MD,' ORTOGONAL COORDINATE SYSTEM')
          CALL MSGDOC(MD,'  COORDINATES IN ANGSTROMS')
          CALL MSGDOC(MD,' ')
          DO     I=1,NCSOP
            CALL GET_NCS(MD,NCMAX,I,AMNCS,TRNCS,IERR)
            IF(IERR.NE.0) THEN
              WRITE(STR,
     *        '('' ERR: genden: wrong NCS description'')') 
              CALL MSGERR(MDOC,STR)
              RETURN
            ENDIF
            WRITE(STR,500) I
            CALL MSGDOC(MD,STR)
  500       FORMAT('  OPERATORS OF NON-CRYST.SYMMETRY :',I5)
            CALL ANGFIX(MD,AMNCS,ALPH,BET,GAMM)
            WRITE(STR,510) (TRNCS(L),L=1,3)
            CALL MSGDOC(MD,STR)
  510       FORMAT(' TRANSLATION VECTOR :',3F10.5,' /ANGSTROM/')
          ENDDO
        ELSE
          WRITE(STR,
     *    '('' ERR: genden: NUMBER OF NCS-OPERATORS:'',I5)') NCSOP
          CALL MSGERR(MDOC,STR)
          IERR=1
          RETURN
        ENDIF
      ENDIF
C--------------------------------------------------
      DLM   = DLIM+0.5
      XS(1) = 0.
      XS(2) = 0.
      XS(3) = 0.
      XF(1) = 1.
      XF(2) = 1.
      XF(3) = 1.

      ZFFS  = FLOAT(IZMIN)/FLOAT(NZ)-DLM/C
      ZFFF  = FLOAT(IZMAX)/FLOAT(NZ)+DLM/C

      XSU(1) = DLM/A
      XSU(2) = DLM/B
      XSU(3) = DLM/C
      XFU(1) = 1.-DLM/A
      XFU(2) = 1.-DLM/B
      XFU(3) = 1.-DLM/C
C
      BAVER  = 0.0
      BMIN   = 1.E30
      BPEAK  =-1.E30
      BAVERW = 0.0 
      BAVERF = 0.0
      MATOMW = 0
      NINALL = 0
      IATT   = 0
      IAT_IN = 0
      I      = 0
      NSUME  = 0
      NCRSYM = 0
      SCHRG  = 0.0
      CHRGP  = 0.0
      CHRGM  = 0.0
      D1     = 0.0
      D2     = 0.0
      D3     = 0.25/(DMAX*DMAX)
C ===========================================
      IEND=-1

1100  CONTINUE
        IF(NCS_FLAG.EQ.'Y'.AND.NCRSYM.GT.NCSOP) NCRSYM=0
        IF(NCRSYM.NE.0) THEN


        ELSE

          MODE = 0
          CALL RDCRD(M,NIN,MODE,IEND,IERR)
          IF(IERR.EQ.1) RETURN
          IF(IEND.NE.0) GO TO 2000
          IF(MODE.GT.0) GO TO 1000    

          IF(MODEL.GT.0.AND.MODEL.NE.CR_MODEL) GO TO 1000

          IF(CR_ATYPE.NE.'.'.AND.CR_ATYPE.NE.' '.AND.
     *       CR_ATYPE.NE.'y'.AND.CR_ATYPE.NE.'Y'.AND.
     *       CR_ATYPE.NE.'r'.AND.CR_ATYPE.NE.'R')
     *    GO TO 1000
          IAT_IN = IAT_IN+1
        ENDIF
C--------------------------------------------------------

        ATOM = CR_ANAME
        IRES = CR_IRES
        RES3 = CR_RNAME
        OCC  = CR_OCC
        BT   = CR_BISO

        SURF   = CR_SURF
        CHARGE = CR_BISO

        IF(CR_MULT_FACTOR.GT.1) THEN
          OCC = OCC / FLOAT(CR_MULT_FACTOR)
        ENDIF

        RVDW = 1.5
        IF(ISPHR.EQ.1.OR.ISPHR.EQ.4) THEN
          SURF   = CR_OCC
          CHARGE = CR_OCC
          OCC    = 1.0
        ENDIF

        IF(ISPHR.EQ.1.AND.CHARGE.EQ.0.0) GO TO 1000
C--------------------------------------------------------
        XA(1)=CR_XYZ(1)
        XA(2)=CR_XYZ(2)
        XA(3)=CR_XYZ(3)

        IF(MODEL.LT.0) THEN
          CALL SET_FLAG_USE(MODEL,XA(1),XA(2),XA(3),X0,Y0,Z0,IUSE)
          IF(IUSE.LE.0) GO TO 1000
        ENDIF

c        WRITE(STR,400) ATOM,IRES,RES3,ICHAIN,
c     *           XA(1),XA(2),XA(3),OCC,BT
c 400    FORMAT(6X,A4,I4,1X,A3,I3,3F10.5,F6.3,F6.1)
c        CALL MSGERR(MDOC,STR)

        IF(NCS_FLAG.EQ.'Y') THEN
          IF(NCRSYM.EQ.0) THEN
            IGR_OLD = CR_IGROUP
            DO IGR=1,NGR
              CALL GET_ASYMM(MDOC,NASMAX,NGR,ICHOLD,IGR,ICH,INC,MLT
     *                     ,IGOLD,NCSF,GID,IERR)
              IF(IERR.NE.0) THEN
                WRITE(STR,
     *  '('' ERR: GENDEN: wrong NCS description for chain :'',I5)') 
     *          IGR_OLD
                CALL MSGERR(MDOC,STR)
                RETURN
              ENDIF
              IF(IGOLD.EQ.IGR_OLD.AND.INC.EQ.0) THEN
                ICHAIN=ICHOLD
                NCRSYM=1
                GO TO 410
              ENDIF
            ENDDO
            WRITE(STR,
     *  '('' ERR: GENDEN: wrong NCS description for chain :'',I5)') 
     *      IGR_OLD
            CALL MSGERR(MDOC,STR)
            IERR=1
            RETURN
  410       CONTINUE
          ELSE
            DO IGR=1,NGR
              CALL GET_ASYMM(MDOC,NASMAX,NGR,ICHOLD,IGR,ICH,INC,MLT
     *                      ,IGOLD,NCSF,GID,IERR)
              IF(IERR.NE.0) THEN
                WRITE(STR,
     *          '('' ERR: GENDEN: wrong NCS description'')') 
                CALL MSGERR(MDOC,STR)
                RETURN
              ENDIF
c            write(*,*) NCSF,NCRSYM,GID(1:2),CHAIN
              IF((NCSF.EQ.'N'.OR.NCSF.EQ.'n').AND.
     *           INC.EQ.NCRSYM.AND.ICHOLD.EQ.ICHAIN) GO TO 530
            ENDDO
            NCRSYM=NCRSYM+1
            GO TO 1000  
 530        CONTINUE
            CALL GET_NCS(MDOC,NCMAX,INC,AMNCS,TRNCS,IERR)
            IF(IERR.NE.0) THEN
              WRITE(STR,
     *        '('' ERR: GENDEN: wrong NCS description'')') 
              CALL MSGERR(MDOC,STR)
              RETURN
            ENDIF
            CALL MVMULT(AMNCS,CR_XYZ,XA)
            XA(1)  = XA(1)+TRNCS(1)
            XA(2)  = XA(2)+TRNCS(2)
            XA(3)  = XA(3)+TRNCS(3)
            NCRSYM = NCRSYM+1
          ENDIF
        ENDIF

        CALL MVMULT(CRTOFR,XA,YA)

c        XA(1)=AMOD(YA(1)/1.,1.)
c        XA(2)=AMOD(YA(2)/1.,1.)
c        XA(3)=AMOD(YA(3)/1.,1.)

        XA(1) = YA(1)
        XA(2) = YA(2)
        XA(3) = YA(3) + ZFADD

C --------------------------------------------------------
        IZZ   = 1
        CHAR2 = CR_ASYMB(1:2)
        CHAR4 = CR_ASYMB
 610    CONTINUE
        IF(NFMFC.GT.0) THEN
          DO IM=1,NFMFC
            IF(CHAR2.EQ.CATOM(IM)) THEN
              IZZ = IM
              IZE = IZFMFC(IZZ)
              RVDW= FMRAD(IM)  
              GO TO 600
            ENDIF
          ENDDO
        ENDIF
        CALL GET_SFA(CHAR4
     *      ,N,NELC,A1,A2,A3,A4,B1,B2,B3,B4,CC,FI,FII,RAD,IERR)
        IF(IERR.NE.0.OR.NFMFC.GE.NFMMAX) THEN

          IF(IERR.NE.0) THEN
            IF(ICOUNT.LT.4) THEN
      WRITE(STR,*)' WARNING: GENDEN: atom"s type "',CHAR4,'" not found'
              CALL MSGERR(MDOC,STR)
              WRITE(STR,
     *'('' WARNING: GENDEN: for atom '',I6,'' name:'',A4,I5,'' '',A3)')
     *        I+1,ATOM,IRES,RES3
              CALL MSGERR(MDOC,STR)
              ICOUNT=ICOUNT+1
            ELSE IF(ICOUNT.EQ.4) THEN
              CALL MSGERR(MDOC,'   ... more ...')
              ICOUNT=ICOUNT+1
            ENDIF
            IERR=0
          ELSE IF(NFMFC.GE.NFMMAX) THEN
            IF(ICOUNT.LT.4) THEN
              WRITE(STR,*) 
     *' ERROR: GENDEN: too many atom"s type > ',NFMMAX
              CALL MSGERR(MDOC,STR)
              ICOUNT=ICOUNT+1
            ELSE IF(ICOUNT.EQ.4) THEN
              CALL MSGERR(MDOC,'   ... more ...')
              ICOUNT=ICOUNT+1
            ENDIF
          ENDIF

          IF(ICOUNT.LE.4) THEN
            WRITE(STR,*) ' WARNING: GENDEN: default type  is "N   "'
            CALL MSGERR(MDOC,STR)
          ENDIF
          CHAR2 = 'N '
          CHAR4 = 'N   '
          GO TO 610
        ENDIF
        NFMFC = NFMFC+1
        IZFMFC(NFMFC)  = NELC
        FMFCA(1,NFMFC) = A1
        FMFCB(1,NFMFC) = B1
        FMFCA(2,NFMFC) = A2
        FMFCB(2,NFMFC) = B2
        FMFCA(3,NFMFC) = A3
        FMFCB(3,NFMFC) = B3
        FMFCA(4,NFMFC) = A4
        FMFCB(4,NFMFC) = B4
        FMFCA(5,NFMFC) = CC
        FMFCB(5,NFMFC) = 0.0
        FMRAD(NFMFC)   = RAD
        CATOM(NFMFC)   = CHAR2
        IZZ  = NFMFC
        IZE  = NELC
        RVDW = RAD
 600    CONTINUE
C ----------------------------------------
        I=I+1
        IF(CR_ASYMB(1:2).NE.'H '.AND.CR_ASYMB(1:2).NE.'D ') THEN
          NONH = NONH +1
        ENDIF
        NEL    = NEL+IZE*OCC
        SUMFI2 = SUMFI2+IZE*IZE*OCC*OCC
C       BT     = BT+BADD
        IF(BT.LT.2.0) BT = 2.0
        IF(ISPHR.EQ.3) THEN

C         IF(BT.GT.BADD.AND.BADD.GT.0.000001) GO TO 1000
          IF(SURF.GT.BTEMP_LIM.AND.
     *             BTEMP_LIM.GT.0.000001) GO TO 1000
          RVDW = RVDW + 1.0
          IZR = RVDW*1000.0
          IF(OCC.GT.99.9) OCC = 99.9
          IOCC   = OCC*10.0
          INEOCC = IZZ*1000+IOCC

        ELSE IF(ISPHR.EQ.4) THEN

          IF(SURF.GT.0.0) THEN
            IZR = RVDW*1000.0
          ELSE
            IZR = DLIM *1000.0
          ENDIF
          IF(OCC.GT.99.9) OCC=99.9
          IOCC   = OCC*10.0
          INEOCC = IZZ*1000+IOCC

        ELSE IF(ISPHR.EQ.2) THEN

C         IF(BT.GT.BADD.AND.BADD.GT.0.000001) GO TO 1000
          IF(BT.GT.BTEMP_LIM.AND.
     *             BTEMP_LIM.GT.0.000001) GO TO 1000

          IZR = DLIM *1000.0
          IF(OCC.GT.99.9) OCC = 99.9
          IOCC   = OCC*10.0
          INEOCC = IZZ*1000+IOCC

        ELSE IF(ISPHR.EQ.1) THEN
          BB = BT
          IF(BB.GT.99.0) BB = 99.0
          IBB = BB
          IF(ABS(CHARGE).GT.1.50) CHARGE=(ABS(CHARGE)/CHARGE)*1.50
          ICHRG = CHARGE*100.0+160.0
          IZR   = ICHRG*100.0+IBB
          SCHRG = SCHRG+CHARGE
          IF(CHARGE.GT.0.0) CHRGP=CHRGP+CHARGE
          IF(CHARGE.LT.0.0) CHRGM=CHRGM+CHARGE
          IF(OCC.GT.99.9) OCC=99.9
          IOCC   = OCC*10.0
          INEOCC = IZZ*1000+IOCC
        ELSE
C         IF(BT.GT.BTEMP_LIM.AND.BTEMP_LIM.GT.0.01) GO TO 1000
          IF(BTEMP_LIM.GT.0.01) THEN
            BT = BT + (SURF-BTEMP_LIM)
          ENDIF
          IF(BT.GT.99.0) BT =99.0
          IF(BT.LT.2.0) BT = 2.0
          IZR = BT*10.0
          D2  = D2+IZE*IZE*OCC*OCC
          D4  = 0.0
          DO IGS=1,5
            D4 = D4+FMFCA(IGS,IZZ)*EXP(-(BT+FMFCB(IGS,IZZ))*D3)
          ENDDO
          D4 = OCC * D4
          D1 = D1+D4*D4
          IF(OCC.GT.99.9) OCC=99.9
          IOCC   = OCC*10.0
          INEOCC = IZZ*1000+IOCC
        ENDIF
        IF(ABS(INEOCC).GT.32766.0) 
     *  INEOCC = (ABS(INEOCC)/INEOCC)*32766.0
        IF(ABS(IZR).GT.32600.0) IZR = (ABS(IZR)/IZR)*32600.0
C -----
        BAVER = BAVER+BT
        IF(CR_RNAME.NE.'HOH') THEN
          BAVERW = BAVERW +BT 
          MATOMW = MATOMW +1
        ENDIF
        IF(BMIN .GT.BT ) BMIN  = BT
        IF(BPEAK.LT.BT ) BPEAK = BT
C ------------------------------
        JJNS  = 0
        N_SYM = NSYM
        IF(P1.EQ.'Y'.OR.P1.EQ.'S') N_SYM = 1
        DO     ISM=1,N_SYM
          ROT(1) = ISYM(1,1,ISM)
          ROT(2) = ISYM(2,1,ISM)
          ROT(3) = ISYM(3,1,ISM)
          ROT(4) = ISYM(1,2,ISM)
          ROT(5) = ISYM(2,2,ISM)
          ROT(6) = ISYM(3,2,ISM)
          ROT(7) = ISYM(1,3,ISM)
          ROT(8) = ISYM(2,3,ISM)
          ROT(9) = ISYM(3,3,ISM)
          TR(1)  = ISYM(4,1,ISM)/REAL(ISYM(5,1,ISM))
          TR(2)  = ISYM(4,2,ISM)/REAL(ISYM(5,2,ISM))
          TR(3)  = ISYM(4,3,ISM)/REAL(ISYM(5,3,ISM))

          X =ROT(1)*XA(1 ) +ROT(2)*XA(2) +ROT(3)*XA(3)
     .       + TR(1)
          YY=ROT(4)*XA(1 ) +ROT(5)*XA(2) +ROT(6)*XA(3)
     .       + TR(2)
          Z =ROT(7)*XA(1 ) +ROT(8)*XA(2) +ROT(9)*XA(3)
     .       + TR(3)

          Y(1)=X
          Y(2)=YY
          Y(3)=Z

          DO     J=1,3
21          IF(Y(J).LT.XS(J)) THEN
              Y(J)=Y(J)+1.
              GO TO 21
            ENDIF
22          IF(Y(J).GE.XF(J)) THEN
              Y(J)=Y(J)-1.
              GO TO 22
            ENDIF
            IPOINT(J)=1
            TRNS(J,1)=0.
            IF(Y(J).LE.XSU(J)) THEN
              IPOINT(J)=IPOINT(J)+1
              TRNS(J,2)=1.
            ELSE IF(Y(J).GE.XFU(J)) THEN
              IPOINT(J)=IPOINT(J)+1
              TRNS(J,2)=-1.
            ENDIF
          ENDDO

          INALL=0

          DO     IX=1,IPOINT(1)
            DO     IY=1,IPOINT(2)
              DO     IZ=1,IPOINT(3)
c                DO     JZ=1,3
                  JZ=2
                  ZZZ =Y(3)+TRNS(3,IZ)+FLOAT(JZ-2)

                  IF(ZZZ.GE.ZFFS.AND.ZZZ.LE.ZFFF) THEN

                    IXXX = (Y(1)+TRNS(1,IX))*FLOAT(IPACK)
                    IYYY = (Y(2)+TRNS(2,IY))*FLOAT(IPACK)
                    IZZZ = ZZZ             *FLOAT(IPACK)
                    IATT = IATT+1
                    IF(IX.EQ.1.AND.IY.EQ.1.AND.IZ.EQ.1) INALL=1
                    IF(IMEM_TEST.LE.0) THEN
                    IF(IATT.GT.NCOORM ) THEN
                      WRITE(STR,*) ' ERROR: too many atoms > ',NCOORM
                      CALL MSGERR(MDOC,STR)
                      IERR=1
                      RETURN
                    ENDIF
                    NSUME       = NSUME+IZE
                    IBFACT(IATT)  =IZR
                    IZMOCC(IATT)=INEOCC
C --- integer*2 version
c                    IF(IXXX.LT.-32766.OR.IXXX.GT.32766.OR.
c     *                 IYYY.LT.-32766.OR.IYYY.GT.32766.OR.
c     *                 IZZZ.LT.-32766.OR.IZZZ.GT.32766) THEN
c                      CALL MSGERR(MDOC,' ERR: !X,Y,Z!(u.c.) > 3.2766')
c                      IERR=1
c                      RETURN
c                    ENDIF
c --------------------
                    IXC(IATT) = IXXX
                    IYC(IATT) = IYYY
                    IZC(IATT) = IZZZ
                    ITRX      = TRNS(1,IX)+1.001
                    ITRY      = TRNS(2,IY)+1.001
                    ITRZ      = TRNS(3,IZ)+1.001
C                   ISCODE(IATT) = ISM*27+ITRX+ITRY*3+ITRZ*9
C                   IANUMB(IATT) = I        
                    IF(ICELL.EQ.1) THEN
                      INEOCC = ISM*27+ITRX+ITRY*3+ITRZ*9
                      IF(OCC.LE.0.0001) INEOCC =-1
                      IZMOCC(IATT) = INEOCC
                    ENDIF
                   
                    ENDIF

                  ENDIF

c                ENDDO
              ENDDO
            ENDDO
          ENDDO
        ENDDO
C ------------------------
        NINALL = NINALL+INALL
1000    CONTINUE
      GO TO 1100
C==================================================
 2000 MATOMS = I
      NATOMS = IATT
      IF(MATOMS.GT.0) THEN
        BAVER = BAVER/MATOMS
      ENDIF
      IF(MATOMW.GT.0) THEN
        BAVERW = BAVERW/MATOMW
      ENDIF
C ------------------------------------------------------
      M=99
      IF(IATT.LE.0) THEN
        CALL MSGERR(MDOC,' ERR: GENDEN: N-ATOMS = 0')
        IERR=1
        CLOSE(NIN)
        RETURN
      ENDIF
      NMODEL = CR_MODEL

      IF(IMEM_TEST.GT.0) THEN
        NCOORD=IATT
        RETURN
      ENDIF

      CALL MSGDOC(M,' --- START SORT ---')
      CALL SORT4(IZC,IATT,IBFACT,IZMOCC,IXC,IYC)
      CALL MSGDOC(M,' --- END   SORT ---')
C ------------------------------------------------------
      IF(ISPHR.EQ.0) THEN
        D1     = SQRT(D1)
        D2     = SQRT(D2)
        BAVE   = ALOG(D2/D1)/D3
        BAVERF = BAVE
        CALL SETBADD(DMAX,BAVE,NX,NY,NZ,BCALC)

        WRITE(STR,'('' Baver/include SF/ :'',F8.3)') BAVERF
        CALL MSGDOC(MDOC,STR)
        WRITE(STR,'('' Badd_in,Badd_calc:'',2F8.3)') BADD,BCALC
        CALL MSGDOC(MDOC,STR)

        BADD_IN = BADD
        IF(BADD.LE.0.000001) BADD=BCALC        

c        IF(BMIN.GT.10.0) THEN
c
c          BADD= - BMIN+5.0
c
c          BAVE_NEW=BAVE+BADD
c
c          CALL SETBADD(DMAX,BAVE_NEW,NX,NY,NZ,BCALC_NEW)
c
c          WRITE(STR,'('' Baver/include SF/_NEW :'',F8.3)') BAVE_NEW
c          CALL MSGDOC(MDOC,STR)
c          WRITE(STR,'('' Badd_calc/NEW/:'',F8.3)') BCALC_NEW
c          CALL MSGDOC(MDOC,STR)
c
c          IF(BADD_IN.LT.0.0) BADD=BCALC_NEW        
c  
c        ENDIF

      ENDIF
      WRITE(STR,430) IAT_IN
      CALL MSGDOC(MDOC,STR)
      IF(NCS_FLAG.EQ.'Y') THEN
        WRITE(STR,434) MATOMS
        CALL MSGDOC(MDOC,STR)
      ENDIF
      IF(MATOMS.NE.NONH) THEN
        WRITE(STR,433) NONH
        CALL MSGDOC(MDOC,STR)
      ENDIF
      WRITE(STR,431) NATOMS
      CALL MSGDOC(MDOC,STR)
      WRITE(STR,432) NINALL
      CALL MSGDOC(MDOC,STR)
 430  FORMAT('ATOMS INPUT                       :',I6)
 433  FORMAT('ATOMS INPUT/non H /               :',I6)
 431  FORMAT('ATOMS INCLUDED IN SORT            :',I6)
 432  FORMAT('ATOMS IN ONCE ONLY                :',I6)
 434  FORMAT('ATOMS INPUT/including NCS-atoms / :',I6)

      IF(ISPHR.EQ.0) THEN
        WRITE(STR,440) BMIN,BPEAK,BAVER
        CALL MSGDOC(MDOC,STR)
 440    FORMAT('MINIMUM B - MAXIMUM B - AVERAGE B:',3F10.4)

        WRITE(STR,'('' B_AVER /without water/:'',F8.3)') BAVERW
        CALL MSGDOC(MDOC,STR)

c        WRITE(STR,442) NSUME
c 442    FORMAT('SUM-ELECTRONS :',I10)
c        CALL MSGDOC(MDOC,STR)
        FAVER=SQRT(SUMFI2*NSYM)
        WRITE(STR,441) NEL,FAVER
 441    FORMAT('SUM-ELECTRONS /IN MODEL/ :',I10,' <!F!> :',F12.0)
        CALL MSGDOC(MDOC,STR)
        AVERI=SUMFI2*NSYM
        WRITE(STR,443) AVERI
 443    FORMAT('                                  <I> :',F12.0)
        CALL MSGDOC(MDOC,STR)
      ELSE IF(ISPHR.EQ.1) THEN
        WRITE(STR,450) BMIN,BPEAK,BAVE
        CALL MSGDOC(MDOC,STR)
        WRITE(STR,451) SCHRG
        CALL MSGDOC(MDOC,STR)
        WRITE(STR,452) CHRGP
        CALL MSGDOC(MDOC,STR)
        WRITE(STR,453) CHRGM
        CALL MSGDOC(MDOC,STR)
 450    FORMAT('MINIMUM B - MAXIMUM B - AVERAGE B:',3F10.4)
 451    FORMAT('SUM-CHARGES           :',F10.4)
 452    FORMAT('SUM-POSITIV-CHARGES   :',F10.4)
 453    FORMAT('SUM-NEGATIV-CHARGES   :',F10.4)
      ENDIF
      NCOORD=IATT
      IF(NCOORD.EQ.0) THEN
        CALL MSGERR(MDOC,' ERR: GENDEN: N-ATOMS =0')
        IERR=1
      ENDIF
      CLOSE(NIN)
      RETURN
      END

      SUBROUTINE GENDENN(MDOC,DEN,N1,N2,N3,R,IATRC1,BADD
     * ,NCOORD,NCOORM,IBFACT,IZMOCC,IXCC,IYCC,IZCC
     * ,VOL,NSYM,ISYM,IPRSYM,IERR)
C------------------------------------------------------
CMS     : DEN
CMS     : IBFACT,IZMOCC,IXCC,IYCC,IZCC
      REAL      DEN(N1,N2,N3)
      INTEGER   R,IATRC1
C --- integer*2 version
C     INTEGER*2        IBFACT(NCOORM),IZMOCC(NCOORM)
C    *                ,IXCC(NCOORM),IYCC(NCOORM),IZCC(NCOORM)
C --- integer*4 version
      INTEGER         IBFACT(NCOORM),IZMOCC(NCOORM)
     *                ,IXCC(NCOORM),IYCC(NCOORM),IZCC(NCOORM)
C ---
      INTEGER          NCOORD,NCOORM
      INTEGER*2        ISYM(5,3,IPRSYM)
      INTEGER*4        NSYM,IPRSYM
C------------------------------------------------------
      COMMON/COMINFF/ NDENSP,NDENSM,NZERO,SUMRP,SUMRM
C------------------------------------------------------
      COMMON/CELLL/    A,B,C,ALPHA,BETA,GAMMA,ISPHR,DLIM,H2OBG,ICELL
      COMMON/DIMM/    DMAX,NX,NY,NZ,IZMIN,IZMAX,IHMAX,IKMAX,ILMAX
C --------------------------
      PARAMETER (NFMMAX=15)
      COMMON/FORMSS/   NFMFC,IZFMFC(15),FMFCA(5,15),
     *                FMFCB(5,15),FMRAD(15),CATOM
      CHARACTER       CATOM(15)*2
C-------------------------------------------------------------
      REAL            BLL(5),CLL(5)
C------------------------------------------------------------------
      IERR=0
C --- integer*2 version
C     IPACK=10000
C --- integer*4 version
      IPACK=100000
C --- 
      NATREC = NCOORD
      COEF   = (FLOAT(NX)*FLOAT(NY)*FLOAT(NZ))
      IF(R.EQ.IZMIN) IATRC1=0
C
      DLIMIT = DLIM*DLIM
      SX     = A/NX
      SY     = B/NY
      SZ     = C/NZ
C
      PI    = 4.0*ATAN(1.0)
      PISQ4 = 4.0*PI*PI
      COSA  = COS(ALPHA)
      SINA  = SIN(ALPHA)
      COSG  = COS(GAMMA)
      SING  = SIN(GAMMA)
      COSB  = COS(BETA)
      SINB  = SIN(BETA)
      CSA2  = COSA*2.
      CSB2  = COSB*2.
      CSG2  = COSG*2
C      COSZ  DEFINES THE ANGLE BETWEEN C AND CSTAR
      SYCOSG = SY*COSG
      SXSING = SX*SING
      SYSING = SY*SING
      SZCOSB = SZ*COSB
      SZCOSA = SZ*COSA
      COSZ   = 
     *  SQRT(ABS((1.-COSA**2-COSB**2-COSG**2+2.*COSA*COSB*COSG)))/SING
      DV     = 8.0*SX*SY*SZ*COSZ*SING*PI**1.5
C
C  CELL VOLUME
C
      S    = (ALPHA+BETA+GAMMA)*0.5
      VOL  = 2.0*A*B*C*
     *       SQRT(ABS(SIN(S)*SIN(S-ALPHA)*SIN(S-BETA)*SIN(S-GAMMA)))
      COEF = COEF/VOL
      DO     I3=1,N3
      DO     I2=1,N2
      DO     I1=1,N1
        DEN(I1,I2,I3)=-32001.0
      ENDDO
      ENDDO
      ENDDO
      ITETR = 0
      ANGSUM = ABS(ALPHA+BETA+GAMMA-(3.0*PI)/2.)
      IF(ANGSUM.GT.0.01) ITETR=1
      IMON = 0
C
C  BEWARE - MONOCLINIC SPACE GROUPS MUST BE TREATED AS HAVING C UNIQUE.
C
      ANGSUM = ABS(BETA+ALPHA-PI/2.)
      IF(ANGSUM.GT.0.01) IMON=1
      DLM = SQRT(DLIMIT)
      IF(IMON.EQ.1) DLM = DLM+0.5

      ZSFG   = FLOAT(R)/NZ     -DLM/C
      ZFFG   = FLOAT(R+N3-1)/NZ+DLM/C
      ZSFNXT = ZFFG-2.*DLM/C
C
      IATREC=IATRC1
C==========================================
1     IATREC = IATREC+1
      IF(IATREC.GT.NATREC) GO TO 400
      
      IATM_P = IATREC
      IBOCC  = IZMOCC(IATM_P)
      IXIN   = IXCC  (IATM_P)
      IYIN   = IYCC  (IATM_P)
      IZIN   = IZCC  (IATM_P)
      Z      = IZIN/FLOAT(IPACK)
C
      IF(Z.LT.ZSFNXT) IATRC1=IATREC
      IF(Z.LT.ZSFG)   GO TO 1
      IF(Z.GT.ZFFG)   GO TO 400
C
      SCALE = 1.0
      BT    = 1.0

      IF(ISPHR.GE.2) THEN
        DLIMIT = IBFACT(IATM_P)/1000.0
        DLIMIT = DLIMIT*DLIMIT
        IF(ICELL.EQ.1) THEN
          IF(IBOCC.LT.0) THEN
            OCC = 0.0
          ELSE
            OCC = 1.0
          ENDIF
          IDNS = ABS(IBOCC)
          IZZ  = 1
        ELSE  
          IZZ = IBOCC/1000
          IT  = IBOCC-IZZ*1000
          OCC = IT/10.
        ENDIF
      ELSE IF(ISPHR.EQ.1) THEN
        ICHRG  = IBFACT(IATM_P)/100.0
        BT     = IBFACT(IATM_P)-ICHRG*100.0
        CHARGE = (ICHRG-160.0)/100.0
        SCALE  = CHARGE/IZFMFC(IZZ)
        IZZ    = IBOCC/1000
        IT     = IBOCC-IZZ*1000
        OCC    = IT/10.
      ELSE IF(ISPHR.EQ.0) THEN
        BT  = IBFACT(IATM_P)/10.0
        BT  = BT+BADD
        IZZ = IBOCC/1000
        IT  = IBOCC-IZZ*1000
        OCC = IT/10.
      ENDIF
      IF(OCC.LT.0.0001) GO TO 1
      X  = IXIN/FLOAT(IPACK)
      Y  = IYIN/FLOAT(IPACK)
      X1 = X *A
      Y1 = Y *B
      Z1 = Z *C
      IF(BT.LT.0.0) THEN
        CALL MSGERR(MDOC,' ERR: GENDEN: B-FACTOR < 0.0 ')
        IERR=1
        RETURN
      ENDIF
      IF(ISPHR.LE.1) THEN
        IF(IZZ.LE.0.OR.IZZ.GT.NFMFC) THEN 
          CALL MSGERR(MDOC,' ERR: GENDEN: IDENTIFY FORMFACTORS = ?')
          IERR=1
          RETURN
        ENDIF
      ENDIF
      IF(ISPHR.EQ.1) THEN
        SCALE=CHARGE/IZFMFC(IZZ)
      ENDIF
      DVOCC  = OCC*DV*SCALE
      DMAXSQ = DLIMIT
      IF(ISPHR.LE.1) THEN
        IM = IZZ
        DO     J=1,5
          BLL(J) = PISQ4/(FMFCB(J,IM)+BT )
          CLL(J) = DVOCC*FMFCA(J,IM)*(FMFCB(J,IM)+BT )**(-1.5)
        ENDDO
      ENDIF
C
      XC  = X1/SX
      IXC = NINT(XC)
      YC  = Y1/SY
      IYC = NINT(YC)
      ZC  = Z1/SZ
      IZC = NINT(ZC)
C
      RRADZ = SQRT(DMAXSQ)/(SZ*COSZ)
      SZL   = ZC-RRADZ
      SZU   = ZC+RRADZ
      ISZL  = INT(SZL+501.)
      ISZU  = INT(SZU+500.)
C
C     CALCULATE THE DENSITY AT ALL POINTS TO WHICH ATOM CONTRIBUTES
C     (IE IN SPHERE OF RADIUS RRADZ)
C
      DO     IZ1=ISZL,ISZU
        IZ=IZ1-500
C
C     TEST WHETHER THIS ATOM LIES IN REQUIRED BLOCK OF FOURIER SECTIONS
C
        IZ2 = IZ+1-R
        IF(IZ2.GT.N3 .OR. IZ2.LE.0)       GO TO 301
        DZ  = IZ*SZ-Z1
        D2  = DZ*DZ
        IF(D2.GT.DMAXSQ .AND. ITETR.EQ.1) GO TO 301
        D3  = DMAXSQ-DZ*DZ*SINA*SINA
        IF(D3.LE.0.)                      GO TO 301
        RRADY  = SQRT(D3)/SYSING
        ZCOSA  = DZ*COSA/SY
        SYL    = YC-RRADY-ZCOSA
        SYU    = YC+RRADY-ZCOSA
        ISYL   = INT(SYL+501.)
        ISYU   = INT(SYU+500.)
        DELZ1  = 2.*DZ
        DZCSA2 = DZ*CSA2
        DZCOSB = DZ*COSB
        DO     IY1=ISYL,ISYU
          IY  = IY1 - 500
          IY2 = IY+1
          IF(IY2.LE.N2.AND.IY2.GE.1) THEN
            DY  = IY*SY-Y1
            DYZ = D2+DY*(DZCSA2+DY)
            IF(DYZ.LE.DMAXSQ.OR.IMON.EQ.0) THEN
C
C             FOR GIVEN X AND Y  THE MINIMUM DSQ IS GIVEN
C             FOR DX=-DY*COSG-DZCOSB
C
              DXMIN  =-DY*COSG-DZCOSB
              DSQMIN = DYZ-DXMIN**2
              IF(DSQMIN.LT.DMAXSQ) THEN
                DFACT2 =-2.*DXMIN
                D4     = DMAXSQ-DSQMIN
                DELZ2  = DELZ1+DY*CSA2
                DELY1  = 2.*DY+DZCSA2
                DELY   = 2.*DY
                RRADX  = SQRT(D4)/SXSING
                XDELTA = DXMIN/SX
                SXL    = XC-RRADX + XDELTA
                SXU    = XC+RRADX + XDELTA
                ISXL   = INT(SXL+501.)
                ISXU   = INT(SXU+500.)
                DO     IX1=ISXL,ISXU
                  IX  = IX1-500
                  IX2 = IX+1
                  IF(IX2.LE.N1.AND.IX2.GE.1) THEN
                    DX  = IX*SX-X1
                    DSQ = DX*(DX+DFACT2) + DYZ
                    IF(DSQ.LE.DMAXSQ) THEN
                      IF(ISPHR.GE.2) THEN
                        IF(ICELL.EQ.0) THEN
                          IF(DEN(IX2,IY2,IZ2).LE.-32000.0)
     *                    DEN(IX2,IY2,IZ2) = 0.0
                          DEN(IX2,IY2,IZ2) = 1.0
                        ELSE
                          IDOLD = DEN(IX2,IY2,IZ2)+0.001
                          IF(IDOLD.LT.-31000.OR.IDOLD.EQ.IDNS) THEN
                            DEN(IX2,IY2,IZ2) = IDNS+0.0001
                          ELSE
                            DEN(IX2,IY2,IZ2) = -27.0
                          ENDIF
                        ENDIF
                      ELSE
                        IF(DEN(IX2,IY2,IZ2).LE.-32000.0)
     *                  DEN(IX2,IY2,IZ2) = 0.0
                        FAC = 0.0
                        DO     J=1,5
                          DSQ1 =-DSQ*BLL(J)
                          FAC  = FAC+CLL(J)*EXP(DSQ1)
                        ENDDO
                        TEMP = FAC*COEF
                        DEN(IX2,IY2,IZ2) = DEN(IX2,IY2,IZ2)+TEMP
                      ENDIF
                    ENDIF
                  ENDIF
                ENDDO
              ENDIF
            ENDIF
          ENDIF
        ENDDO
301     CONTINUE
300     CONTINUE
      ENDDO
      GO TO 1
C -----------------------------------------------
400   CONTINUE
      SUMM = 0.0
      SUMP = 0.0
      DO     I3=1,N3
        DO     I2=1,N2
        DO     I1=1,N1
          IF(DEN(I1,I2,I3).LE.-32000.0) THEN
            DEN(I1,I2,I3) = H2OBG
            NZERO=NZERO+1
          ELSE IF(DEN(I1,I2,I3).GT.0.0) THEN
            NDENSP = NDENSP+1
            SUMP   = SUMP+DEN(I1,I2,I3)
          ELSE IF(DEN(I1,I2,I3).LT.0.0.AND.
     *            DEN(I1,I2,I3).GT.-32000.0) THEN
            NDENSM = NDENSM+1
            SUMM   = SUMM+DEN(I1,I2,I3)
          ENDIF
        ENDDO
        ENDDO
      ENDDO
      SUMRP = SUMRP+SUMP
      SUMRM = SUMRM+SUMM
      RETURN
      END

      SUBROUTINE WFORMFS(MDOC)
C -------------------
      PARAMETER (NFMMAX=15)
      COMMON/FORMSS/   NFMFC,IZFMFC(15),FMFCA(5,15),
     *                FMFCB(5,15),FMRAD(15),CATOM
      CHARACTER       CATOM(15)*2
C -------------------
      INTEGER        MDOC
      CHARACTER      LINE*80
C --------------------------------------------------------------------
C ---
      CALL MSGDOC(MDOC,' ---------------------------')
      WRITE(LINE,*) 
     *  ' FORMFACTOR FOR ATOMS /INT TAB VOL 4 TABLE 2.2B/:'
      CALL MSGDOC(MDOC,LINE)
      DO I=1,NFMFC
        WRITE(LINE,10) CATOM(I),IZFMFC(I),FMRAD(I)
 10     FORMAT(' ----- ',A2,' ---- ',I4,F8.2)
        CALL MSGDOC(MDOC,LINE)
        DO J=1,5
          WRITE(LINE,20) FMFCA(J,I),FMFCB(J,I)
 20       FORMAT( 5X,2F10.5)
         CALL MSGDOC(MDOC,LINE)
       ENDDO 
      ENDDO
      CALL MSGDOC(MDOC,' ---------------------------')
      RETURN
      END

      SUBROUTINE SORT4(A,N,TAG,TAG1,TAG2,TAG3)
C------------------------------------------
CMS     : TAG,TAG1,TAG2,TAG3
C --- integer*2 version
C      INTEGER*2  TAG,TAG1,TG,TG1,TAG2,TAG3,TG2,TG3,A,T,TT
C --- integer*4 version
      INTEGER  TAG,TAG1,TG,TG1,TAG2,TAG3,TG2,TG3,A,T,TT
C ---
      DIMENSION A(*),IU(16),IL(16),TAG(*),TAG1(*),TAG2(*),TAG3(*)
C===========================================================
      M=1
      I=1
      J=N
    5 IF(I.GE.J) GO TO 70
   10 K=I
      IJ=(J+I)/2
      T=A(IJ)
      IF(A(I).LE.T) GO TO 20
      A(IJ)=A(I)
      A(I)=T
      T=A(IJ)
      TG=TAG(IJ)
      TAG(IJ)=TAG(I)
      TAG(I)=TG
      TG1=TAG1(IJ)
      TAG1(IJ)=TAG1(I)
      TAG1(I)=TG1
      TG2=TAG2(IJ)
      TAG2(IJ)=TAG2(I)
      TAG2(I)=TG2
      TG3=TAG3(IJ)
      TAG3(IJ)=TAG3(I)
      TAG3(I)=TG3
   20 L=J
      IF(A(J).GE.T) GO TO 40
      A(IJ)=A(J)
      A(J)=T
      T=A(IJ)
      TG=TAG(IJ)
      TAG(IJ)=TAG(J)
      TAG(J)=TG
      TG1=TAG1(IJ)
      TAG1(IJ)=TAG1(J)
      TAG1(J)=TG1
      TG2=TAG2(IJ)
      TAG2(IJ)=TAG2(J)
      TAG2(J)=TG2
      TG3=TAG3(IJ)
      TAG3(IJ)=TAG3(J)
      TAG3(J)=TG3
      IF(A(I).LE.T) GO TO 40
      A(IJ)=A(I)
      A(I)=T
      T=A(IJ)
      TG=TAG(IJ)
      TAG(IJ)=TAG(I)
      TAG(I)=TG
      TG1=TAG1(IJ)
      TAG1(IJ)=TAG1(I)
      TAG1(I)=TG1
      TG2=TAG2(IJ)
      TAG2(IJ)=TAG2(I)
      TAG2(I)=TG2
      TG3=TAG3(IJ)
      TAG3(IJ)=TAG3(I)
      TAG3(I)=TG3
      GO TO 40
   30 A(L)=A(K)
      A(K)=TT
      TG=TAG(L)
      TAG(L)=TAG(K)
      TAG(K)=TG
      TG1=TAG1(L)
      TAG1(L)=TAG1(K)
      TAG1(K)=TG1
      TG2=TAG2(L)
      TAG2(L)=TAG2(K)
      TAG2(K)=TG2
      TG3=TAG3(L)
      TAG3(L)=TAG3(K)
      TAG3(K)=TG3
   40 L=L-1
      IF(A(L).GT.T) GO TO 40
      TT=A(L)
   50 K=K+1
      IF(A(K).LT.T) GO TO 50
      IF(K.LE.L) GO TO 30
      IF((L-I).LE.(J-K)) GO TO 60
      IL(M)=I
      IU(M)=L
      I=K
      M=M+1
      GO TO 80
   60 IL(M)=K
      IU(M)=J
      J=L
      M=M+1
      GO TO 80
   70 M=M-1
      IF(M.EQ.0) RETURN
      I=IL(M)
      J=IU(M)
   80 IF((J-I).GE.1) GO TO 10
      IF(I.EQ.1) GO TO 5
      I=I-1
   90 I=I+1
      IF(I.EQ.J) GO TO 70
      T=A(I+1)
      IF(A(I).LE.T) GO TO 90
      TG =TAG (I+1)
      TG1=TAG1(I+1)
      TG2=TAG2(I+1)
      TG3=TAG3(I+1)
      K=I
  100 A(K+1)=A(K)
      TAG (K+1)=TAG (K)
      TAG1(K+1)=TAG1(K)
      TAG2(K+1)=TAG2(K)
      TAG3(K+1)=TAG3(K)
      K=K-1
      IF(T.LT.A(K)) GO TO 100
      A   (K+1)=T
      TAG (K+1)=TG
      TAG1(K+1)=TG1
      TAG2(K+1)=TG2
      TAG3(K+1)=TG3
      GO TO 90
      END

C -I-
      SUBROUTINE COPYFL(MDOC,NAME,NAMEI,NAMEO,THRESH,TOP,COEF,BTEMP
     *           ,SCALE,RESMIN,RESMAX,IZMIN,IZMAX,MODE,TITLE
     *           ,RESULT,IPRROW,ISYM,IPRSYM,IERR)
C ---------------------------------------------
C -P- COPYFL : copyies files of type 'F   ', 'FS  ','PH  ', 'ABCD','RI  '
C              You may change title of files, cell parameters, resolution,
C              apply coefficient and temperature factor, ...
C              set Rfree flag for reflections
C -S-
C      Dialog:
C
C      FILE_INF: name of inf-file. Symmetry operators will be taken from
C                                  this file.
C      FILE_I:   name of input file which has to be copied..
C      FILE_O:   name of output file.
C      LIMZ:     IZMIN,IZMAX - serial numbers for first and last Z-section
C                               of electron density.
C      TITLE:    text if you want to write into output file new title.
C
C   If you file is type of "F   " or "FS  " then next requests
C   will be :
C
C      COEF:    program will write into out put file
C      BTEMP:                 Fnew=COEF*Fold*EXP(-BTEMP*RSQ)
C
C      THRESH:  program will write into output files only structure factors
C      TOP:                     THRESH < |F| < TOP
C
C      SCALE:   program will write into output file only such
C                structure factors if |Fnew| > sigma * scale   (if scale > 0) 
C
C      MODE:    if MODE = '0' program will write into output file
C                             only reflexes with L = 0 
C
C                         'F' set Rfree flag for reflections.
C
C               default value MODE = 'A' means  all reflections.
C
C      PERC:    percent of Rfree reflections <10>
C
C      RESOL: RESMIN,RESMAX - program will write into output file only reflexes
C                             between these resolutions ( Default values vill
C                             be taken from file).
C   
C      SUBROUTINE COPYFL(MDOC,NAME,NAMEI,NAMEO,THRESH,TOP,COEF,BTEMP
C     *           ,SCALE,RESMIN,RESMAX,IZMIN,IZMAX,MODE,TITLE
C     *           ,POOL,NCRES,RESULT,IPRROW,ISYM,IPRSYM,IERR)
C
C      Parameters:
C
C      MDOC   - mode of writting messages to DOC-file
C               0 - only terminal , < - 0 only file, 0 < < 99 - both
C               >= 99 - don't write  
C      POOL   - real array (NCRES) for
C               one Z-section of electron density NX x NY < NCRES.
C      NCRES  - NCRES dimension of real array POOL.
C      NAMEI  - name of inf-file. Symmetry operators will be taken from
C               this file.
C      NAME   - name of input file which has to be copied..
C      NAMEO  - name of output file.
C      COEF   - program will write into output file:
C      BTEMP  -                      Fnew=COEF*Fold*EXP(-BTEMP*RSQ)
C
C      THRESH  - program will write into output files only structure factors
C      TOP     -                THRESH < |F| < TOP
C
C      SCALE   - program will write into output file only such
C                structure factors if |Fnew| > sigma * scale.
C                (if scale > 0) 
C
C      IZMIN,IZMAX - serial numbers for first and last Z-section
C                    of electron density.
C                    in case MODE = 'F' program use IZMIN as variable PERC 
C      MODE   - /character*1/ if MODE = '0' program will write into output file
C               only reflexes with L = 0 
C               'F' set Rfree flag, percent = IZMIN
C               else default value MODE = 'A' means  all reflexex.
C      TITLE  - /character*80/ - new title of output file.
C      RESMIN - program will write into output file only reflexes
C      RESMAX - between these resolutions ( Default values vill be
C               taken from file).
C      ISYM   - integer*2 array for cryst.symmetry operators /see INF-file/
C      IPRSYM - dimension of integer*2 array ISYM(5,3,IPRSYM)
C      IERR   - signal of error / =1 -error , =o - OK / 
C      RESULT - real array RESULT(IPRROW) for additional output information
C -I-
C ---------------------------------------------------
C ---
C      REAL      POOL(NCRES)

      real,     allocatable :: POOL(:)

      INTEGER*2 ISYM(5,3,IPRSYM)
      REAL      RLATT(6)
      REAL      RESULT(IPRROW)
      CHARACTER NAMEI*(*),NAME*(*),NAMEO*(*)
C --
      CHARACTER ITYP*4,TTT*160,TITLE*(*),LINE*80
      CHARACTER MSG*1,MODE*1,ITYPI*4
C ----------------------------------------------------------------------
      MTIN  =20
      ITYP  ='    '
      IPRINT=0
      CALL LENSTR_BL(NAME,LEN)
      IF(LEN.LE.0.OR.NAME(1:1).EQ.' '.OR.NAME(1:1).EQ.',') THEN
        IERR=1
        RETURN
      ENDIF
      CALL ORFILE(MDOC,MTIN,NAME,ITYP,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.GT.0) THEN
        RETURN
      ENDIF
      CALL GET_TITLE(MDOC,A,B,C,AL,BE,GA
     *  ,COEF1,BET1,RESMNN,RESMXX,NX,NY,NZ,IZMNR,IZMXR,TTT,IERR)

      RLATT(1)=A
      RLATT(2)=B
      RLATT(3)=C
      RLATT(4)=AL
      RLATT(5)=BE
      RLATT(6)=GA
C      CALL RTITLE(MTIN,NAME,MDOC,ITYP,IPRINT,A,B,C,AL,BE,GA,
C     *            COEF1,BET1,RESMNN,RESMXX,
C     *            IDMX,IDMY,IDMZ,IDM1,IDM2,TTT)

      IF(ITYP.NE.'F   '.AND.ITYP.NE.'FS  '.AND.ITYP.NE.'PH  '.AND.
     *   ITYP.NE.'ABCD'.AND.ITYP.NE.'RI  ') THEN
        CALL MSGERR(MDOC,' ERR: WRONG TYPE OF FILE')
        IERR=1
        RETURN
      ENDIF
      CALL C_RD_CR
C -------------------------------------------------------------
      M   = -ABS(MDOC)-1
      CALL LENSTR_BL(NAMEI,LEN)
      IF(LEN.GT.0.AND.NAMEI(1:1).NE.' '.AND.NAMEI(1:1).NE.',') THEN
C        CALL RD_INF(M,NAMEI,RLATT,NSYM,ISYM,IPRSYM,IERR)
C        IF(IERR.NE.0) THEN
C          CALL MSGERR(MDOC,' ERR: COPYFL: INF-FILE')
C          CLOSE(MTIN)
C          RETURN
C        ENDIF
C        A =RLATT(1)
C        B =RLATT(2)
C        C =RLATT(3)
C        AL=RLATT(4)
C        BE=RLATT(5)
C        GA=RLATT(6)

        MTINI  =21
        ITYPI  ='    '
        CALL ORFILE(MDOC,MTINI,NAMEI,ITYPI,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.GT.0) THEN
          RETURN
        ENDIF
        CLOSE(MTINI)
        CALL C_RD_CR
      ENDIF
      CALL DSTARF(RLATT,AST,BST,CST,COALST,COBEST,COGAST,VOL)
C ----
      CALL C_CR_WR
C ----
C------------------------------------------------------------------------
      MTOUT=13
      CALL LENSTR_BL(NAMEO,LN)
      IF(LN.LE.0.OR.NAMEO(1:1).EQ.' '.OR.NAMEO(1:1).EQ.',') MTOUT=0    
C------------------------------------------------------------------------

      CALL LENSTR_BL(TITLE,LN)    
      IF(LN.GT.9.AND.TITLE(1:1).NE.' '.AND.TITLE(1:1).NE.',') 
     * TTT(1:LN)=TITLE(1:LN)

      IF(ITYP.EQ.'RI  ') GO TO 1000
C------------------------------------------------------------------------
      IF(ITYP.EQ.'F   '.OR.ITYP.EQ.'FS  ') THEN
        MSG='N'
        IF(ITYP.EQ.'FS  ') THEN
          IF(ABS(SCALE).GT.1.0E-6) MSG='Y'
          WRITE(LINE,*) ' OMIT F < SIG *',SCALE
          CALL MSGDOC(M,LINE)
        ENDIF
        IF(COEF.LE.1.E-6) COEF=1.
        WRITE(LINE,10) COEF,BTEMP
        CALL MSGDOC(M,LINE)
   10   FORMAT(' SCALE FACTOR =',E12.4,' TEMP FACTOR =',E12.4)
        CALL MSGDOC(M,
     *  ' APPLIED TO INPUT-FILE AND WRITE TO OUT-FILE')
        CALL MSGDOC(M,
     *  ' FNEW=FOLD*SCALE*EXP(-BTEMP*RSQ) ')
        IF(TOP.LT.1.E-6) TOP=1.E 30
        WRITE(LINE,*) 'THRESH,TOP /FOR !F!-OUTPUT/ :',THRESH,TOP
        CALL MSGDOC(M,LINE)
      ENDIF
C ----------------------------------------------
      IF(RESMIN.LT.RESMAX) THEN
        T=RESMIN
        RESMIN=RESMAX
        RESMAX=T
      ENDIF
      IF(RESMIN.LT.1.E-5) RESMIN=RESMNN
      IF(RESMAX.LT.1.E-5) RESMAX=RESMXX
      IF(RESMIN.GE.1.E-5) THEN
        RHMIN=1.0/RESMIN
      ELSE
        RHMIN=0.001
      ENDIF
      IF(RESMAX.GE.1.E-5) THEN
        RHMAX=1.0/RESMAX
      ELSE
        RHMAX=10.0
      ENDIF
C -------------------------------------------------------
      IPRNT=5000
      IPERC=IZMIN
      IF(IPERC.LE.0.OR.IPERC.GT.100) IPERC=10
C -------------------------------------------------------
      IF(MODE.EQ.'i') MODE='I'
      IF(MODE.EQ.'a') MODE='A'
      IF(MODE.EQ.'f') MODE='F'
      IF(MODE.NE.'0'.AND.MODE.NE.'F'.AND.MODE.NE.'I') MODE='A'
C -------------------------------------------------------
      COEF1 = COEF1*COEF
      BET1  = BET1+BTEMP
      IF(MTOUT.GT.0) THEN

C        IPRINT=1
C        CALL WTITLE(MTOUT,NAMEO,MDOC,ITYP,IPRINT,A,B,C,AL,BE,GA,
C     *  COEF1,BET1,RESMIN,RESMAX,IDM,IDM,DIM,IDM,IDM,TTT)

        CALL C_CR_WR
        CALL SET_TITLE(MDOC,A,B,C,AL,BE,GA,COEF1,BET1,RESMIN,RESMAX
     *  ,IDM,IDM,IDM,IDM,IDM,TTT,IERR)
        IF(IERR.GT.0) THEN
          IERR=2
          CLOSE(MTIN)
          RETURN
        ENDIF
        CALL OWFILE(MDOC,MTOUT,NAMEO,ITYP,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.GT.0) THEN
          IERR=2
          CLOSE(MTIN)
          RETURN
        ENDIF
      ENDIF
C ----------------------------------------------------------
      NREF   = 0
      SUMFA  = 0.
      SUMF   = 0.
      IEND   =-1
      IEND1  =-1
      NUMB1  = 0
      FNN    = 0.0
      FNA    = 0.0
      SNN    = 0.0
      SNA    = 0.0
      FN     = 0.0
      SN     = 0.0
      N_INPUT= 0
      NBAD_SD= 0
      NOUT   = 0
      NGTSIG = 0
C -------------------------------------------------------------------
  100 CONTINUE
      IF(ITYP.EQ.'FS  ') THEN
        CALL RRD1(MTIN,IH,IK,IL,FNN,FNA,SNN,SNA,NUMB,IEND)
      ELSE IF(ITYP.EQ.'ABCD') THEN
        CALL RABCD(MTIN,IH,IK,IL,FNN,FNA,SNN,SNA,NUMB,IEND)
      ELSE
        CALL RD1(MTIN,IH,IK,IL,FNN,FNA,NUMB,IEND)
        IF(ITYP.EQ.'PH  '.AND.MODE.EQ.'I') FNA =-FNA
      ENDIF
      IF(IEND.GT.0)                     GO TO 110
      IF(ITYP.EQ.'F   '.OR.ITYP.EQ.'FS  ') THEN
        IF(FNN.LE.1.E-6.AND.FNA.LE.1.E-6) GO TO 100
        FN=FNN
        SN=SNN
        IF(IH.EQ.0.AND.IK.EQ.0.AND.IL.EQ.0) THEN
          FMOD=FN *COEF
          SNN =SN *COEF
          FAN=0.0
          SNA=0.0
          NREF =NREF +1
          IF(MTOUT.GT.0) THEN
            IF(ITYP.EQ.'F   ') THEN
              CALL WRT(MTOUT,IH,IK,IL,FMOD,FAN,NUMB,IEND1)
            ELSE
              CALL WWRT(MTOUT,IH,IK,IL,FMOD,FAN,SNN,SNA,NUMB,IEND1)
            ENDIF
          ENDIF
          GO TO 100
        ENDIF
      ENDIF
      IF(ITYP.EQ.'F   ') THEN
C       SIG-DUMMY
        SNN=0.04*FNN
        SNA=0.04*FNA
      ENDIF
      CALL DSTAR(IH,IK,IL,RSQ)
      RHKL=SQRT(RSQ)
      IF(RHKL.LT.RHMIN.OR.RHKL.GT.RHMAX) THEN
        NOUT=NOUT+1
        GO TO 100
      ENDIF

      IF(NSYM.GT.1) THEN
CC
CC         SYSABS - check systematic absent for h,k,l: 1 - absent, 0 - no.
CC
        CALL SYSABS_BL(IH,IK,IL,NSYM,ISYM,ICND)
      ELSE
        ICND = 0
      ENDIF
CC
CC ---   ICND NE 0 systematic absent
CC
      IF(ICND.NE.0) THEN
C       NOUT=NOUT+1
        GO TO 100
      ENDIF


      IF(MODE.EQ.'0') THEN
        IF(IL.NE.0) GO TO 100
      ENDIF
      N_INPUT=N_INPUT+1

      IF(MODE.EQ.'F') THEN
        CALL HSRD(RAND)
        IRAND=(RAND + 0.5)*100.0
        IT=NUMB/2
        IF(IRAND.LE.IPERC) THEN
          NUMB=IT*2+1
        ELSE
          NUMB=IT*2
        ENDIF
      ENDIF

      IF(ITYP.EQ.'F   '.OR.ITYP.EQ.'FS  ') THEN
        FN=FNN
        SN=SNN
        IF(FNN.GT.1.E-6.AND.FNA.GT.1.E-6) THEN
          IF(SNN.LT.0.000001) SNN=1.0
          IF(SNA.LT.0.000001) SNA=1.0
          WT1=1./(SNN*SNN)
          WT2=1./(SNA*SNA)
          WT =WT1+WT2
          FN =FNN*WT1+FNA*WT2
          FN =FN/WT
          SN =1./SQRT(WT)
        ELSE IF(FNA.GT.1.E-6) THEN
          FN =FNA
          SN =SNA
        ENDIF
        BT=BTEMP/4.0
        X=COEF*EXP(-BT*RSQ)
        FMOD=FNN*X
        FAN =FNA*X
        SNN =SNN*X
        SNA =SNA*X
        FN  =FN *X
        SN  =SN *X
        IF(FN.LE.THRESH ) GO TO 100
        IF(FN.GT.TOP    ) GO TO 100
        IF(MSG.EQ.'Y') THEN
          SSCL1=SCALE*SN
          IF(FN.GE.SN)  NGTSIG =NGTSIG+1
          IF(FN.LT.SSCL1) THEN
            NBAD_SD=NBAD_SD+1
            GO TO 100
          ENDIF
        ELSE
          NGTSIG =NGTSIG+1
        ENDIF
        SUMF =SUMF +FMOD
        SUMFA=SUMFA+FAN
      ELSE
        FMOD=FNN
        FAN =FNA
      ENDIF
      NREF =NREF +1
      IF(MTOUT.GT.0) THEN
        IF(ITYP.EQ.'FS  ') THEN
          CALL WWRT(MTOUT,IH,IK,IL,FMOD,FAN,SNN,SNA,NUMB,IEND1)
        ELSE IF(ITYP.EQ.'ABCD') THEN
          CALL WABCD(MTOUT,IH,IK,IL,FMOD,FAN,SNN,SNA,NUMB,IEND1)
        ELSE
          CALL WRT(MTOUT,IH,IK,IL,FMOD,FAN,NUMB,IEND1)
        ENDIF
      ENDIF
C ----------
      IF(IPRNT.GT.0) THEN
        IF(MOD(NREF,IPRNT).EQ.0) THEN
          IF(ITYP.EQ.'F   '.OR.ITYP.EQ.'FS  ') THEN
            WRITE(LINE,20) NREF,IH,IK,IL,FMOD,FAN
            CALL MSGDOC(MDOC,LINE)
          ELSE IF(ITYP.EQ.'ABCD') THEN
            WRITE(LINE,30)NREF,IH,IK,IL,FMOD,FAN,SNN,SNA
            CALL MSGDOC(MDOC,LINE)
          ELSE
            WRITE(LINE,40) NREF,IH,IK,IL,FMOD,FAN
            CALL MSGDOC(MDOC,LINE)
          ENDIF
   20     FORMAT(' N',I6,' H=',I4,' K=',I4,' L=',I4,' FA=',E12.4,
     *           ' FB=',E12.4)
   30     FORMAT(' N',I5,' H=',I3,' K=',I3,' L=',I3,' A=',F10.4,
     *           ' B=',F10.4,' C=',F10.4,' D=',F10.4)
   40     FORMAT(' N',I6,' H=',I4,' K=',I4,' L=',I4,' mCOS=',E12.4,
     *           ' mSIN=',E12.4)
        ENDIF
      ENDIF
C -----------
      GO TO 100
C -----------------------------------------------------------
  110 CONTINUE
      IEND1=2
      IF(MTOUT.GT.0) THEN
        IF(ITYP.EQ.'ABCD') THEN
          CALL WABCD(MTOUT,IH,IK,IL,FMOD,FAN,SNN,SNA,NUMB,IEND1)
        ELSE
          CALL WRT(MTOUT,IH,IK,IL,FNN,FNA,NUMB,IEND1)
        ENDIF
      ENDIF
C ----------------
      WRITE(LINE,50) NREF
   50 FORMAT(' NUMBER OF REFLS=',I6)
      CALL MSGDOC(MDOC,LINE)
c      IF(ITYP.EQ.'F   '.OR.ITYP.EQ.'FS  ') THEN
c        FAV =0.0
c        FAVA=0.0
c        IF(NREF.GT.0) THEN
c          FAV =SUMF /NREF
c          FAVA=SUMFA/NREF
c        ENDIF
c        WRITE(LINE,60) FAV,FAVA
c        CALL MSGDOC(MDOC,LINE)
c   60   FORMAT(' F-AVER=',E12.4,' FANOM-AVER=',E12.4)
c      ENDIF
      RESULT(1)  = NREF
      RESULT(2)  = RESMIN
      RESULT(3)  = RESMAX
      RESULT(4)  = 0.0
      RESULT(5)  = 0.0
      RESULT(6)  = 0.0
      RESULT(7)  = NBAD_SD
      IF(IPRROW.GE.21) THEN
        RESULT(11) = 0.0
        RESULT(12) = 0.0
        RESULT(13) = 0.0
        RESULT(14) = 0.0
        RESULT(15) = 0.0
        RESULT(16) = N_INPUT
        RESULT(17) = NBAD_SD
        RESULT(18) = NSYM
        RESULT(19) = 0.0
        RESULT(20) = SCALE
        RESULT(21) = NOUT
C        RESULT(11) - R-mult
C        RESULT(12) - number of refls after average.
C        RESULT(13) - number of refls before average.
C        RESULT(14) - R-st(I)
C        RESULT(15) - number of refls with I > sig.
C        RESULT(16) - number of refls in input file.
C        RESULT(17) - NBAD_SD
C        RESULT(18) - NSYM
C        RESULT(19) - NBAD_ABS
C        RESULT(20) = SD_LIM
      ENDIF
      CLOSE(MTIN)
      RETURN
C -----------------------------------------------
 1000 CONTINUE
      CLOSE(MTIN)
      NCRES = NX*NY + 1000
      allocate(POOL(1:NCRES),STAT=ISTAT)
      IF(ISTAT.NE.0) THEN
        IERR = 1
        CALL MSGERR(MDOC,
     *   ' ERROR: in COPYFL: problem with memory allocation')
        RETURN
      ENDIF
      CLOSE(MTIN)
      ITYPE  =-2
      MTIN   =10
      IERR=0
      CALL RDENS(MTIN,NAME,M,ITYPE,JZ,NXR,NYR,NZR,IZMR,
     * IZNR,RMAX,RMIN,POOL,AR,BR,CR,ALR,BER,GAR,DRMS,
     * RAVER,RESOL,IX0,IY0,IZ0,ITR,TTT,NS,POOL,IPRSYM,IERR)
      NXYR=NXR*NYR
      IF(IERR.GT.0) THEN
        deallocate(POOL,STAT=ISTAT)
        CLOSE(MTIN)
        RETURN
      ENDIF
      IF(NXYR.GT.NCRES) THEN
        deallocate(POOL,STAT=ISTAT)
        WRITE(LINE,'('' ERR: COPYFL: NO MEMORY FOR PLAN-XY :'',I8)')
     *  NCRES
        CALL MSGERR(MDOC,LINE)
        IERR=1
        CLOSE(MTIN)
        RETURN
      ENDIF
C--------------------------------------------------------
      ITYP     = 'RI  '
      IPRINT   = 1
      IZMINW   = IZMIN
      IF(IZMINW.LT.IZNR) IZMINW=IZNR
      IZMAXW   = IZMAX
      IF(IZMAXW.GT.IZMR) IZMAXW=IZMR
      NZW=IZMAXW-IZMINW+1
      IF(MTOUT.GT.0) THEN
        CALL LENSTR_BL(TITLE,LN)    
        IF(LN.GT.9.AND.TITLE(1:1).NE.' '.AND.TITLE(1:1).NE.',') 
     *  TTT=TITLE
        CALL C_CR_WR
        CALL SET_TITLE(MDOC,A,B,C,AL,BE,GA,DDM,DDM,DDM,DDM
     *  ,NXR,NYR,NZW,IZMINW,IZMAXW,TTT,IERR)
        IF(IERR.GT.0) THEN
          IERR=2
          CLOSE(MTIN)
          deallocate(POOL,STAT=ISTAT)
          RETURN
        ENDIF
        CALL OWFILE(MDOC,MTOUT,NAMEO,ITYP,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.GT.0) THEN
          IERR=1
          CLOSE(MTIN)
          deallocate(POOL,STAT=ISTAT)
          RETURN
        ENDIF
      ENDIF
C---------------------------------------------------------------
      ICNTZ3=-999
      ITYPE=1
      DO     IZ=IZNR,IZMR
        CALL RDENS(MTIN,NAME,MDOC,ITYPE,JZ,NXR,NYR,NZR,IZMR,
     *  IZNR,RMAX,RMIN,POOL,AR,BR,CR,ALR,BER,GAR,DRMS,
     *  RAVER,RESOL,IX0,IY0,IZ0,ITR,TITLE,NS,ISYM,IPRSYM,IERR)
        IF(MTOUT.GT.0) THEN
          CALL WDENS(MTOUT,MDOC,ICNTZ3,NXR,NYR,NZW,IZMINW,IZMAXW,
     *             RMAXD,RMIND,POOL,RESOL,IX0,IY0,IZ0,ITR)
        ENDIF
      ENDDO
C -----------------------------------------------
      deallocate(POOL,STAT=ISTAT)
      CLOSE(MTIN)
      RETURN
      END

C -I-
      SUBROUTINE TOBLANC(MDOC,NAME_IN,NAME_OUT
     * ,NAME_C,NAME_F,NAME_I,PATH_SCR,RESCRD,FORM_I,CIF,SETT
     * ,ANOM,ATOP,SD_LIM,ISYM,IPRSYM,RESULT,IPRROW,IERR)
C ---------------------------------------------------
C -P- TOBLANC : converts file of Structure Factors with PDB-format or CIFile. 
C               reads formatted file ( CIF or PDB ) which contains indices 
C               and structure factors or intensities or phases, (also simple
C               formatted file with "h,k,l,!F!"  or "h,k,l,!F!,sig(F)" and
C               without titles is acceptable) sorts, brings to asymmetric
C               unit of reciprical space, averages equivalent elements.
C               The entrance to complex BLANC.
C -S-   
C      Dialog and Batch:
C
C    FILE_IN  - name of formatted input SF_PDB_file or CIFile.
C               For PDB_file program will try to make scratch CIFile: 
C               "toblanc.cif" and to convert it to the internal BLANC format.
C    FILE_OUT - name of output file. Type name of file where you want to
C               save result of this programm.
C
C    FILE_C:  - information about CELL and SYMMetry operators will
C               be taken from this file of coordinates.
C               /without extention "crd"/
C    FILE_INF: - information about CELL and SYMMetry operators will
C               be taken from this INF_file.
C               /without extention "inf"/
C    FILE_F:  - information about CELL and SYMMetry operators will
C               be taken from this file of structure factors.
C               If FILE_C = " ",FILE_INF = " " and FILE_F = " " then the
C               information about CELL and SYMMetry operators will
C               be taken from this FILE_IN.
C
C    ANOM     - <N>,Y -  Y - if you are going to use ANOM. SCATT.
C
C    TOP      - Reflections with !I-<I>! > sd(I) * TOP will be accepted. 
C               Here <I> is average value of intensities of on equalents.
C
C    SLIM     -  <0.0> - Reflections with I > sd(I) * SLIM will be accepted. 
C
C    FORM_I   -  <F>/C/P - get: F - Fobs, C - Fcalc, P - Phase') 
C
C                                                 "toblanc.cif" only. 
C       It is possible to use the subroutine TOBLANC by program:
C
C      SUBROUTINE TOBLANC(MDOC,POOL,MEMORY,NAME_IN,NAME_OUT
C     * ,NAME_C,NAME_F,NAME_I,PATH_SCR,RESCRD,FORM_I,CIF,SETT
C     * ,ANOM,ATOP,SD_LIM,ISYM,IPRSYM,RESULT,IPRROW,IERR)
C
C            Parameters of subroutine: 
C
C    MDOC     - mode of writting messages to DOC-file
C               0 - only terminal , < - 0 only file, 0 < < 99 - both
C               >= 99 - don't write  
C    POOL     - working array /real/. Dimension is equal MEMORY.
C    MEMORY   - maximal number of reflexions is MEMORY/4.           
C    NAME_IN  - name of input file.
C    NAME_OUT - name of output file.
C    NAME_C   - name of input file of coordinates. /see above/
C    NAME_F   - name of intput file of structure factors. /see above/
C    NAME_I   - name of input INF_file. /see above/
C    FORM     -  <F>/C/P /character*1/- get: F - Fobs, C - Fcalc, P - Phase' 
C    CIF      - /character*1/ dummy
C    ANOM     - <N>,Y - /character*1/, Y - if you are going to use ANOM.SCATT.
C    ATOP     - Reflections with !I-<I>! > sd(I) * ATOP will be accepted. 
C    SD_LIM   -  <0.0> reflections with I > sd(I) * SD_LIM will be accepted. 
C    RESCRD   - high resolution limit. 0 means all rflections. 
C    SETT     - now is dummy.
C    ISYM     - integer*2 array for cryst.symmetry operators 
C    IPRSYM   - dimension of integer*2 array ISYM(5,3,IPRSYM)
C               We need not to define contents of arrays ISYM.
C               Here is only reservation of memory.
C    IERR    -  output signal of error / =1 -error , =0 - OK / 
C
C    RESULT /real RESULT(IPRROW)/ - array for output information:
C
C  RESULT(1) - number of refls in output file.
C  RESULT(2) - min resolution
C  RESULT(3) - max resolution
C  RESULT(4) - R-merge
C  RESULT(5) - number of refls after symm. average.
C  RESULT(6) - number of refls befor symm. average.
C  RESULT(7) - NBAD number of bad refls
C  
C  RESULT(8)
C  RESULT(9)   space group / 12 characters/
C  RESULT(10)
C
C  RESULT(11) - R-mult
C  RESULT(12) - number of refls after average.
C  RESULT(13) - number of refls before average.
C  RESULT(14) - R-st(I)
C  RESULT(15) - number of refls with I > sig.
C  RESULT(16) - number of refls in input file.
C  RESULT(17) - NBAD_SD
C  RESULT(18) - NSYM
C  RESULT(19) - NBAD_ABS
C               NBAD = NBAD_SD + NBAD_ABS + ( F < 0.0 ; H=K=L=0 ; H,K,L > LIM )
C  RESULT(I,2) - R-merge
C -I-
C ------------------------------
      INTEGER*2 ISYM(5,3,IPRSYM)
      REAL      RESULT(IPRROW,3)
      REAL      RLATT(6)
      CHARACTER LINE*80,ANOM*1
      REAL      ATOP,SD_LIM,RESCRD
      INTEGER*4 MDOC,IERR,NUMBT
      CHARACTER NAME_IN*(*),NAME_OUT*(*),NAME_I*(*),NAME*256
      CHARACTER PATH_SCR*(*)

      CHARACTER NAME_C*(*),NAME_F*(*),FORM_I*1,CIF*1,SETT*1
C -----------------------------------------------------
      CHARACTER FILE_CIF*256
C -----------------------------------------------------
c      IF(CIF.EQ.'y') CIF='Y'
c      IF(CIF.NE.'Y') CIF='N'

      FILE_CIF='toblanc.cif'
      CALL ADD_PATH(PATH_SCR,FILE_CIF)

      CALL PRESFPDB(MDOC,NAME_IN,FILE_CIF,IERR)
      IF(IERR.GT.0)  RETURN
c      IF(CIF.EQ.'Y') RETURN

      CALL TO_BLANC(MDOC,FILE_CIF,NAME_OUT
     * ,NAME_C,NAME_F,NAME_I,RESCRD,FORM_I,SETT
     * ,ANOM,ATOP,SD_LIM,ISYM,IPRSYM,RESULT,IPRROW,IERR)

       NAME='toblanc.cif'
       CALL DELETE_FILE(PATH_SCR,NAME)

      RETURN
      END

      SUBROUTINE RDSORT(MDOC,NUMBT,RLATT,LINE,TITLEL,NAME,FORM_I,MAXREF
     *   ,IARRH,IARRS,ARRF,ARRS,SUMSDT,ISUM1,N_INPUT,SD_LIM,NBSD,NBABS
     *   ,RESMIN,RESMAX,NSYM,ISYM,IPRSYM,FLAG_C,FLAG_S,NBAD,ITEST,IERR)        
C -----------------------------------------
      REAL RESMIN,RESMAX
C      INTEGER*4 MT
      INTEGER*4 IERR
      INTEGER*4 NUMBT,MAXREF,IARRH(*),IARRS(*)
      REAL      ARRF(*),ARRS(*)
      INTEGER*4 NSYM
      INTEGER*2 ISYM(5,3,IPRSYM)
      REAL RLATT(6)
      CHARACTER FORM_I*1,NAME*(*),LINE*(*),TITLEL*(*)
      INTEGER*4 IPRSYM
      CHARACTER FLAG_C*1,FLAG_S*1,FLAG_PDB*1
      EXTERNAL  PACK
C -------------------------------------
C -----------------------------------------------------------
      PARAMETER ( NWORDSMAX = 40 )
      COMMON /COMCIF/ N_CIF,I_CIF,FDT_CIF,IDT_CIF
     *               ,N_DATA,N_ITEM
     *               ,DT_CIF,ITM_CIF,BLK_CIF,LOOP_FLAG,BLK_FLAG
      REAL      FDT_CIF(NWORDSMAX)
      INTEGER*4 IDT_CIF(NWORDSMAX)
      INTEGER*4 N_DATA   
      INTEGER*4 N_ITEM  
      INTEGER*4 N_CIF   
      INTEGER*4 I_CIF
      CHARACTER DT_CIF (NWORDSMAX)*80
      CHARACTER ITM_CIF(NWORDSMAX)*80
      CHARACTER BLK_CIF*80
      CHARACTER LOOP_FLAG*1,BLK_FLAG*1
C ---
C ---
      CHARACTER   TITLE*80,STR*256
      CHARACTER   PATH*1,EXT*1,SGNAME*24
      CHARACTER   CODE_PDB*4,DATE_PDB*9,NAME_PDB*40,CODE_NDB*8
C ---
      REAL      FDATA
      INTEGER*4 IDATA
      CHARACTER DATA*80,ITEM*80,FLAG_FOM*1,WAVE*5,TEMPER*5,CH10*10
      CHARACTER FORM_F*1,FORM_P*1,FORM_FC*1,FORM_F2*1,FORM*1,STATUS*1
      CHARACTER CRYST*80
      CHARACTER FLAG_SA*1,FLAG_SI*1,FLAG_SIA*1,FLAG_S2*1,FLAG_S2A*1
      CHARACTER FORM_FA*1,FORM_F2A*1,FORM_FI*1,FORM_FIA*1,FORM_OLD*1
      CHARACTER BLOCK*80
C------------------------------------------------
      IERR=0
C      MT=MDOC
      MD   = -ABS(MDOC)-1
      PI   =4.0*ATAN(1.0)
      TWOPI=2.0*PI
      PI180=PI/180.0
C------------------------------
      FLAG_S='N'
      FLAG_PDB = 'N'
      LINE=' '
      TEMPER='?    '
      WAVE  ='?    '
      BLOCK ='?    ' 
C ------------------
      IHMIN=-511
      IHMAX= 511
      IKMIN=-511
      IKMAX= 511
      ILMIN=-511
      ILMAX= 511
C -----------------
      N_INPUT=0
      NUMB  =0
      ICNT  =0
      NBL   =0
      RHMIN =1.E 30
      RHMAX =0.0
      NBAD  =0
      NBSD  =0
      NBABS =0
      SUMSDT=0.0
      SUMINT=0.0
      ISUM1 =0
      ISUM3 =0
      ISUM10=0
      IPRNT=5000

      NRECS=1

C      JRECS=200
C      LRECIN=1600

      SGNAME = ' '
      NSG    = 0
      NSETT  = 0
      ISETT  = 0
      ACELL  = 0.0
      BCELL  = 0.0
      CCELL  = 0.0
      ALCELL = 0.0
      BECELL = 0.0
      GACELL = 0.0
      CODE_PDB='XXXX'
      CODE_NDB='XXXX    '
      DATE_PDB='XX-XXX-XX'
      NAME_PDB='?'

      TITLE   ='?   ?   ?'
      IFIRST=0
      CRYST    = ' '            

      CALL LENSTR_BL(TITLEL,LEN)

      IF(LEN.GT.0) THEN
        TITLE    = TITLEL(1:80)        
      ENDIF

      IF(LEN.GT.80) THEN
        CODE_PDB = TITLEL(81:84)
        CODE_NDB = TITLEL(85:92)
        NAME_PDB = TITLEL(85:124)
      ENDIF
C-------------------------------------
      IERR = 0
      MTIN = 10
      M    = 99
      PATH = ' '
      EXT  = ' '
      CALL OPENFR(MTIN,M,PATH,NAME,EXT,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERR: TOBLANC: can''t open input_CIFile')
        RETURN
      ENDIF
      MD=-ABS(MDOC)-1
      CALL LENSTR_BL(NAME,LEN)
      IF(LEN.GT.64) LEN=64
      WRITE(STR,'('' INPUT-FILE :'',A)') NAME(1:LEN)
      CALL MSGDOC(MD,STR)
C -----
      DO I=1,2000
C#CRYST1   36.520   36.520  139.120  90.00  90.00  90.00 P 43 21 2     8
        READ(MTIN,'(A)',END=110) STR
        IF(STR(1:7).EQ.'#CRYST1') THEN
          CALL LENSTR_BL(STR,LEN)
          CRYST = STR(1:LEN)             
          FLAG_PDB = 'Y'
          GO TO 110
        ENDIF 
      ENDDO
 110  CONTINUE
      CLOSE(MTIN)    

C -----
      CALL OPENFR(MTIN,M,PATH,NAME,EXT,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERR: can''t open input_CIFile')
        RETURN
      ENDIF
C -----
  100 CONTINUE
      IEND=-1
C --------------------------------------------------------
  200 CONTINUE   

      CALL GETCIF(MTIN,MDOC,IERR,IEND)
      IF(IERR.NE.0) THEN
        CLOSE(MTIN)
        RETURN
      ENDIF
      IF(IEND.NE.0) THEN
        GO TO 210
      ENDIF
      LH   = 0
      LK   = 0
      LL   = 0

      FA   = 0.0
      SA   = 0.0
      FA1  = 0.0
      SA1  = 0.0
      FA2  = 0.0
      SA2  = 0.0

      F2A       = 0.0
      S2A       = 0.0
      F2A1      = 0.0
      S2A1      = 0.0
      F2A2      = 0.0
      S2A2      = 0.0

      FIA       = 0.0
      SIA       = 0.0
      FIA1      = 0.0
      SIA1      = 0.0
      FIA2      = 0.0
      SIA2      = 0.0

      FLAG_S   = 'N'
      FLAG_SA  = 'N'
      FLAG_SI  = 'N'
      FLAG_SIA = 'N'
      FLAG_S2  = 'N'
      FLAG_S2A = 'N'

      FORM_F   = ' '
      FORM_FA  = ' '
      FORM_F2  = ' '
      FORM_F2A = ' '
      FORM_FI  = ' '
      FORM_FIA = ' '

      PHI  = 0.0
      FCALC= 0.0
      FCALC_SIG=0.0      
      FOM  = 1.0
      FORM     = ' '
      FORM_OLD = ' '
      FORM_P   = ' '
      FORM_FC  = ' '
      FLAG_FOM = ' '
      NPASS    = 1
      I_PASS   = 0
      STATUS   = 'o'

      IF(BLOCK(1:1).NE.'?') THEN
        IF(BLOCK.NE.BLK_CIF) GO TO 210
      ENDIF
      BLOCK = BLK_CIF
      IF(N_CIF.LE.0) GO TO 200

      DO I=1,N_CIF
        CALL LENSTR_BL(ITM_CIF(I),LENI) 
        ITEM = ITM_CIF(I)(1:LENI)
        CALL LENSTR_BL(DT_CIF(I),LEND) 
        DATA = DT_CIF(I)(1:LEND)
        CALL LENSTR_BL(BLK_CIF,LENB) 
        IDATA=IDT_CIF(I)
        FDATA=FDT_CIF(I)
        IF((ITEM(1:18).EQ.'_database_PDB_code').OR.         
     *     (ITEM(1:18).EQ.'_database_PDB.code').OR.
     *     (ITEM(1:20).EQ.'_database_2.code_PDB').OR.
     *     (ITEM(1:9) .EQ.'_entry.id')) THEN         
          LN=LEND
          IF(LN.GT.4) LN=4
          CODE_PDB=DATA(1:LN)
          IF(LN.LT.4) THEN
            DO II=LN+1,4
              CODE_PDB(II:II)=' '
            ENDDO
          ENDIF
        ELSE IF((ITEM(1:18).EQ.'_database_PDB_name').OR.
     *          (ITEM(1:21).EQ.'_struct_keywords.text').OR.
     *          (ITEM(1:16).EQ.'_struct.keywords')) THEN
          LN=LEND
          IF(LN.GT.40) LN=40
          NAME_PDB=DATA(1:LN)
          IF(LN.LT.40) THEN
            DO II=LN+1,40
              NAME_PDB(II:II)=' '
            ENDDO
          ENDIF
        ELSE IF(ITEM(1:20).EQ.'_database_2.code_NDB') THEN
          LN=LEND
          IF(LN.GT.8) LN=8
          CODE_NDB=DATA(1:LN)
          IF(LN.LT.8) THEN
            DO II=LN+1,8
              CODE_NDB(II:II)=' '
            ENDDO
          ENDIF
        ELSE IF((ITEM(1:27).EQ.'_diffrn.ambient_temperature')) THEN
          IF(LEND.GT.5) LEND=5
          TEMPER = DATA(1:LEND)
          IF(LEND.LT.5) THEN
            DO II=LEND+1,5
              TEMPER(II:II)=' '
            ENDDO
          ENDIF
        ELSE IF((ITEM(1:28).EQ.'_diffrn_radiation.wavelength')) THEN
          IF(LEND.GT.5) LEND=5
          WAVE = DATA(1:LEND)
          IF(LEND.LT.5) THEN
            DO II=LEND+1,5
              WAVE(II:II)=' '
            ENDDO
          ENDIF
        ELSE IF((ITEM(1:31).EQ.'_database_PDB_rev.date_original').OR.        
     *   (ITEM(1:31).EQ.'_database_NDB_rev.date_original')) THEN         
          DATE_PDB = '         '
          IF(LEND.GT.10) LEND=10
          CH10 = DATA(1:LEND)
          IF(CH10(5:5).EQ.'-') THEN
            CALL CHNG_DATE_BACK(CH10,DATE_PDB)         
          ELSE
            DATE_PDB = CH10(1:9)
          ENDIF
        ELSE IF((ITEM(1:18).EQ.'_database_PDB_date').OR.
     *          (ITEM(1:20).EQ.'_audit.creation_date')) THEN         
          DATE_PDB = '         '
          IF(LEND.GT.10) LEND=10
          CH10 = DATA(1:LEND)
          IF(CH10(5:5).EQ.'-') THEN
            CALL CHNG_DATE_BACK(CH10,DATE_PDB)         
          ELSE
            DATE_PDB = CH10(1:9)
          ENDIF
        ELSE IF((ITEM(1:13).EQ.'_struct_title').OR.
     *          (ITEM(1:13).EQ.'_struct.title')) THEN     
          TITLE=DATA(1:LEND)

        ELSE IF((ITEM(1:12) .EQ.'_cell_length').OR.         
     *          (ITEM(1:12) .EQ.'_cell_angle_').OR.         
     *          (ITEM(1:12) .EQ.'_cell.length').OR.         
     *          (ITEM(1:12) .EQ.'_cell.angle_')) THEN         
          IF(IFIRST.EQ.0) THEN     
          IF(ITEM(7:14).EQ.'length_a') THEN         
            ACELL=FDATA
          ELSE IF(ITEM(7:14).EQ.'length_b') THEN         
            BCELL=FDATA
          ELSE IF(ITEM(7:14).EQ.'length_c') THEN         
            CCELL=FDATA
          ELSE IF(ITEM(7:17).EQ.'angle_alpha') THEN     
            ALCELL=FDATA
            ALCELL=ALCELL*PI180
          ELSE IF(ITEM(7:16).EQ.'angle_beta') THEN         
            BECELL=FDATA
            BECELL=BECELL*PI180
          ELSE IF(ITEM(7:17).EQ.'angle_gamma') THEN
            GACELL=FDATA
            GACELL=GACELL*PI180
          ENDIF
          ENDIF
        ELSE IF(ITEM(1:9).EQ.'_symmetry') THEN
          IF(IFIRST.EQ.0) THEN

            IF(ITEM(11:30).EQ.'space_group_name_H-M') THEN         
              SGNAME=DATA
            ELSE IF(ITEM(11:21).EQ.'Int_Tables_') THEN         
              NSG=IDATA
            ELSE IF(ITEM(11:21).EQ.'cell_settin') THEN         
              NSETT=IDATA
            ELSE IF(ITEM(11:21).EQ.'equiv_pos_a') THEN     
            ENDIF

          ENDIF

        ELSE IF((ITEM(1:7) .EQ.'_refln_').OR.
     *          (ITEM(1:23) .EQ.'_cell_measurement_refln').OR.
     *          (ITEM(1:7) .EQ.'_refln.')) THEN
          CALL LENSTR_BL(ITEM,LEN)
          IF((ITEM(8:14) .EQ.'index_h').OR.
     *       (ITEM(25:31).EQ.'index_h')) THEN
            LH=IDATA
          ELSE IF((ITEM(8:14) .EQ.'index_k').OR.
     *       (ITEM(25:31) .EQ.'index_k')) THEN
            LK=IDATA
          ELSE IF((ITEM(8:14) .EQ.'index_l').OR.
     *       (ITEM(25:31) .EQ.'index_l')) THEN
            LL=IDATA
          ELSE IF((ITEM(8:22) .EQ.'figure_of_merit').OR.
     *            (ITEM(8:10) .EQ.'fom')) THEN
            FOM=FDATA  
            IF(FORM_I.EQ.'P') FLAG_FOM='Y'
          ELSE IF((ITEM(8:13) .EQ.'status').OR.
     *       (ITEM(25:30) .EQ.'status')) THEN
            STATUS=DATA(1:1)
          ELSE IF(ITEM(8:17) .EQ.'phase_calc') THEN
            PHI=FDATA
            IF(FORM_I.EQ.'P') FORM='H'
          ELSE IF(ITEM(8:17) .EQ.'coef_H_L_a') THEN

          ELSE IF(ITEM(8:17) .EQ.'coef_H_L_b') THEN

          ELSE IF(ITEM(8:17) .EQ.'coef_H_L_c') THEN

          ELSE IF(ITEM(8:17) .EQ.'coef_H_L_d') THEN

          ELSE IF(ITEM(8:13) .EQ.'F_meas') THEN
            CALL LENSTR_BL(ITEM,LEN)
            IF((LEN.EQ.16.AND.ITEM(8:16).EQ.'F_meas_au').OR. 
     *         (LEN.EQ.13.AND.ITEM(8:13).EQ.'F_meas'   )    ) THEN
C             _refln.F_meas
C             _refln.F_meas_sigma
C             _refln.F_meas_au
C             _refln.F_meas_sigma_au
              FA     = FDATA
              FORM_F = 'Y'
            ELSE IF(LEN.EQ.26.AND.ITEM(8:22) .EQ.'F_meas_au_(+)_s') THEN
              SA1    = FDATA
              FLAG_SA = 'Y'
              NPASS  = 2
            ELSE IF(LEN.EQ.26.AND.ITEM(8:22) .EQ.'F_meas_au_(-)_s') THEN
              SA2    = FDATA
              FLAG_SA = 'Y'
              NPASS  = 2
            ELSE IF(LEN.EQ.20.AND.ITEM(8:20) .EQ.'F_meas_au_(+)') THEN
              FA1    = FDATA
              FORM_FA = 'Y'
              NPASS  = 2
            ELSE IF(LEN.EQ.20.AND.ITEM(8:20) .EQ.'F_meas_au_(-)') THEN
              FA2    = FDATA
              FORM_FA = 'Y'
              NPASS=2
            ELSE IF((LEN.EQ.22.AND.ITEM(8:22).EQ.'F_meas_sigma_au').OR.
     *          (LEN.EQ.22.AND.ITEM(8:22).EQ.'F_meas_au_sigma').OR.
     *          (LEN.EQ.19.AND.ITEM(8:19).EQ.'F_meas_sigma')   ) THEN
              SA     = FDATA
              FLAG_S = 'Y'
            ELSE
              FA     = FDATA
              FORM_F = 'Y'
            ENDIF
          ELSE IF((LEN.EQ.18.AND.ITEM(8:18).EQ.'pdbx_F_plus').OR.
     *            (LEN.EQ.13.AND.ITEM(8:13).EQ.'F_plus')) THEN
            FA1    = FDATA
            FORM_FA = 'Y'
            NPASS  = 2
          ELSE IF((LEN.EQ.18.AND.ITEM(8:19).EQ.'pdbx_F_minus').OR.
     *            (LEN.EQ.14.AND.ITEM(8:14).EQ.'F_minus')) THEN
            FA2    = FDATA
            FORM_FA = 'Y'
            NPASS  = 2
          ELSE IF((LEN.EQ.24.AND.ITEM(8:24).EQ.'pdbx_F_plus_sigma').OR.
     *            (LEN.EQ.19.AND.ITEM(8:19).EQ.'F_plus_sigma')) THEN
            SA1    = FDATA
            FLAG_SA = 'Y'
            NPASS  = 2
          ELSE IF((LEN.EQ.24.AND.ITEM(8:25).EQ.'pdbx_F_minus_sigma').OR.
     *            (LEN.EQ.20.AND.ITEM(8:20).EQ.'F_minus_sigma')) THEN
            SA2    = FDATA
            FLAG_SA = 'Y'
            NPASS  = 2
          ELSE IF(ITEM(8:13) .EQ.'F_calc'.AND.LENI.EQ.13) THEN
            FCALC=FDATA
            FORM_FC='Y'
          ELSE IF(ITEM(8:19) .EQ.'F_calc_sigma') THEN
            FCALC_SIG=FDATA
            FLAG_S='Y'
          ELSE IF(ITEM(8:17) .EQ.'phase_calc') THEN
            PHI=FDATA
            IF(FORM_I.EQ.'P') FORM_P='Y'
          ELSE IF(ITEM(8:14) .EQ.'F_sigma') THEN
            FCALC_SIG=FDATA
            SA=FDATA
            FLAG_S='Y'
          ELSE IF(ITEM(8:21) .EQ.'intensity_meas') THEN
            FIA=FDATA
            FORM_FI='Y'
          ELSE IF(LEN.EQ.16.AND.ITEM(8:16) .EQ.'intensity') THEN
            FIA=FDATA
            FORM_FI='Y'
          ELSE IF((ITEM(8:25) .EQ.'intensity_(+)_meas').OR.
     *            (LEN.EQ.18.AND.ITEM(8:18).EQ.'pdbx_I_plus').OR.
     *            (LEN.EQ.13.AND.ITEM(8:13).EQ.'I_plus')) THEN
            FIA1=FDATA
            FORM_FIA='Y'
            NPASS=2
          ELSE IF((ITEM(8:25) .EQ.'intensity_(-)_meas').OR.
     *            (LEN.EQ.19.AND.ITEM(8:19).EQ.'pdbx_I_minus').OR.
     *            (LEN.EQ.14.AND.ITEM(8:14).EQ.'I_minus')) THEN
            FIA2=FDATA
            FORM_FIA='Y'
            NPASS=2
          ELSE IF(ITEM(8:22) .EQ.'intensity_sigma') THEN
            SIA=FDATA
            FLAG_SI='Y'
          ELSE IF((ITEM(8:26) .EQ.'intensity_(+)_sigma').OR.
     *      (LEN.EQ.24.AND.ITEM(8:24).EQ.'pdbx_I_plus_sigma').OR.
     *      (LEN.EQ.19.AND.ITEM(8:19).EQ.'I_plus_sigma')) THEN
            SIA1=FDATA
            FLAG_SIA='Y'
            NPASS=2
          ELSE IF((ITEM(8:26) .EQ.'intensity_(-)_sigma').OR.
     *      (LEN.EQ.25.AND.ITEM(8:25).EQ.'pdbx_I_minus_sigma').OR.
     *      (LEN.EQ.20.AND.ITEM(8:20).EQ.'I_minus_sigma')) THEN
            SIA2=FDATA
            FLAG_SIA='Y'
            NPASS=2
          ELSE IF(ITEM(8:21) .EQ.'F_squared_meas') THEN
            FORM_F2='Y'
            F2A=FDATA
            FORM='S'
          ELSE IF(ITEM(8:22) .EQ.'F_squared_sigma') THEN
            S2A=FDATA
            FLAG_S2='Y'
          ELSE IF(ITEM(8:25) .EQ.'F_squared_(+)_meas') THEN
            FORM_F2A='Y'
            F2A1=FDATA
            FORM='S'
            NPASS=2
          ELSE IF(ITEM(8:26) .EQ.'F_squared_(+)_sigma') THEN
            S2A1=FDATA
            FLAG_S2A='Y'
            NPASS=2
          ELSE IF(ITEM(8:25) .EQ.'F_squared_(-)_meas') THEN
            FORM_F2A='Y'
            F2A2=FDATA
            FORM='S'
            NPASS=2
          ELSE IF(ITEM(8:26) .EQ.'F_squared_(-)_sigma') THEN
            S2A2=FDATA
            FLAG_S2A='Y'
            NPASS=2
          ENDIF

        ENDIF
      ENDDO

C       _refln.F_meas_au_(+)
C       _refln.F_meas_au_(+)_sigma
C       _refln.F_meas_au_(-)
C       _refln.F_meas_au_(-)_sigma
C       _refln.intensity_(+)_meas
C       _refln.intensity_(+)_meas_sigma
C       _refln.intensity_(-)_meas
C       _refln.intensity_(-)_meas_sigma
C       _refln.F_squared_(+)_meas
C       _refln.F_squared_(+)_sigma
C       _refln.F_squared_(-)_meas
C       _refln.F_squared_(-)_sigma


      IF(FORM_I.EQ.'F') THEN
        IF(FORM_F.EQ.'Y') THEN
C         FA SA
          FORM_F2 = 'N'
          NPASS = 1
          FORM_FC='N'
        ELSE IF(FORM_FA.EQ.'Y') THEN
C         FA1 FA2 SA1 SA2
          FLAG_S = FLAG_SA
          FORM_F = 'Y'
          FORM_F2='N'
          FORM_FC='N'
        ELSE IF(FORM_F2.EQ.'Y') THEN
          FORM_F = 'Y'
          FLAG_S = FLAG_S2
          FA = F2A
          SA = S2A
          NPASS = 1
          FORM_FC='N'
        ELSE IF(FORM_F2A.EQ.'Y') THEN
          FORM_F = 'Y'
          FLAG_S = FLAG_S2A
          FA1 = F2A1
          SA1 = S2A1
          FA2 = F2A2
          SA2 = S2A2
          FORM_F2 = 'Y'
          FORM_FC='N'
        ELSE IF(FORM_FI.EQ.'Y') THEN
          FORM_F = 'Y'
          FLAG_S = FLAG_SI
          FA = FIA
          SA = SIA
          FORM_F2 = 'Y'
          NPASS = 1
          FORM_FC='N'
        ELSE IF(FORM_FIA.EQ.'Y') THEN
          FORM_F = 'Y'
          FLAG_S = FLAG_SIA
          FA1 = FIA1
          SA1 = SIA1
          FA2 = FIA2
          SA2 = SIA2
          FORM_F2 = 'Y'
          FORM_FC='N'
        ENDIF
      ENDIF


      IF(FORM_I.EQ.'F'.AND.(FORM_F.EQ.'Y'.OR.FORM_F2.EQ.'Y')) THEN
        FORM='B'
        IF(FORM_F2.EQ.'Y') FORM='S'
      ELSE IF(FORM_I.EQ.'P'.AND.FORM_P.EQ.'Y') THEN
        FORM='H'
        IF(FLAG_FOM.NE.'Y') FOM=1.0
      ELSE IF(FORM_I.EQ.'C'.AND.FORM_FC.EQ.'Y') THEN
        FORM='B'
        FA=FCALC
        SA=FCALC_SIG
      ENDIF
      IF(FORM.EQ.' ') GO TO 200

 222  CONTINUE

      I_PASS=I_PASS+1
      IF(NPASS.EQ.2) THEN

        IF(I_PASS.EQ.1) THEN
          LHO=LH          
          LKO=LK          
          LLO=LL          
          FA=FA1
          SA=SA1
          FORM_OLD = FORM
        ELSE
          LH=-LHO          
          LK=-LKO          
          LL=-LLO          
          FA=FA2
          SA=SA2
          FORM = FORM_OLD
        ENDIF   
 
      ENDIF   

      IF(IFIRST.EQ.0) THEN

       IF(FLAG_C.EQ.'N'.OR.FLAG_PDB.EQ.'Y') THEN

c        IF(SGNAME(1:1).EQ.' '.AND.NSG.LE.0) THEN

         CALL LENSTR_BL(CRYST,LEN)
         IF(LEN.GT.7) THEN
           READ(CRYST,'(7X,3F9.3,3F7.2,1X,A11)') 
     *               ACELL,BCELL,CCELL,ALCELL,BECELL,GACELL
     *               ,SGNAME
           ALCELL = ALCELL*PI180
           BECELL = BECELL*PI180
           GACELL = GACELL*PI180             
           NSG = 0
         ENDIF

c        ENDIF

         RLATT(1) = ACELL
         RLATT(2) = BCELL
         RLATT(3) = CCELL
         RLATT(4) = ALCELL
         RLATT(5) = BECELL
         RLATT(6) = GACELL
C        IF(NSG.LT.1.OR.NSG.GT.230) NSG=1
C        IF(NSG.LT.1.OR.NSG.GT.9999) NSG=1
C        IF(NSETT.LT.1.OR.NSETT.GT.2) NSETT=1
         IF(ACELL.LE.0.5.OR.BCELL.LE.0.5.OR.CCELL.LE.0.5.OR.
     *     ALCELL.LE.0.001.OR.BECELL.LE.0.001.OR.GACELL.LE.0.001) 
     *   THEN
           CALL MSGERR(MDOC,' WARNING: there is not CELL parameters')
           CLOSE(MTIN)
           IERR = 31
           RETURN
C
C          CALL MSGERR(MDOC,'          Defaut: 100,100,100,90,90,90')
C          ACELL  = 100.0
C          BCELL  = 100.0
C          CCELL  = 100.0
C          ALCELL = PI/2.0
C          BECELL = PI/2.0
C          GACELL = PI/2.0
CC          IERR=3
CC          CLOSE(MTIN)
CC          GO TO 240
C          RLATT(1) = ACELL
C          RLATT(2) = BCELL
C          RLATT(3) = CCELL
C          RLATT(4) = ALCELL
C          RLATT(5) = BECELL
C          RLATT(6) = GACELL
         ENDIF
         IF(SGNAME(1:1).EQ.' '.AND.NSG.LE.0) THEN
           CALL MSGERR(MDOC,
     *     ' WARNING: there is not a symmetry information')
           CLOSE(MTIN)
           IERR = 32
           RETURN
C          CALL MSGERR(MDOC,
C     *    '          Default space group : P1')
C          SGNAME(1:3)='P 1' 
C          NSG   = 1
C          NSETT = 1
C          IERR=3
C          CLOSE(MTIN)
C          GO TO 240
         ENDIF

         IF(SGNAME(1:1).EQ.' ') THEN
c        IF(NSG.GT.0) THEN

           NOSPGR = NSG
           IF(NOSPGR.GT.1000) THEN

             ISETT  = NOSPGR/1000
             NOSPGR = NOSPGR - ISETT*1000
             ISETT  = ISETT + 1
             NOSG   = NOSPGR

             IF(NOSG.EQ.3.OR.NOSG.EQ.4.OR.NOSG.EQ.146.OR.
     *          NOSG.EQ.155) THEN
               IF(ISETT.EQ.1) THEN
                 ISETT = 2
               ELSE IF(ISETT.EQ.2) THEN  
                 ISETT = 1
C              ELSE IF(ISTT.EQ.4) THEN  
C                ISTT = 3
              ENDIF
             ELSE IF(NOSG.EQ.  5) THEN
               IF(ISETT.EQ.1) THEN
                 ISETT = 2
               ELSE IF(ISETT.EQ.2) THEN  
                 ISETT = 1
C              ELSE IF(ISETT.EQ.3) THEN  
C                ISETT = 4
C              ELSE IF(ISETT.EQ.4) THEN  
C                ISETT = 3
               ENDIF
             ENDIF
             NSETT = ISETT
           ENDIF
           IF(NOSPGR.LT.1.OR.NOSPGR.GT.230) THEN
             CALL MSGERR(MDOC
     *       ,' WARNING: wrong space group of input_file.')
             CLOSE(MTIN)
             IERR = 32
             RETURN
C            CALL MSGERR(MDOC
C     *      ,'          default space group: "P 1"')
C            NOSPGR = 1
           ENDIF
           IF(NOSPGR.EQ.146.OR.NOSPGR.EQ.155) THEN
             IF(NSETT.LE.0) NSETT = 1
             T= (PI*2.0)/3.0
             IF(ABS(RLATT(6)-T).LE.0.0001) NSETT=2
           ENDIF
           IF(NOSPGR.GE.3.AND.NOSPGR.LE.5) THEN
             IF(NSETT.LE.0) NSETT = 2
             IF(NSETT.EQ.2) THEN
               T = PI/2.0
               IF(ABS(RLATT(6)-T).GT.0.0001) NSETT=1
             ELSE IF(NSETT.EQ.1) THEN
               T = PI/2.0
               IF(ABS(RLATT(5)-T).GT.0.0001) NSETT=2
             ENDIF
           ENDIF
           IF(NSETT.LE.0) NSETT = 1
           NSYM   = 0
           NSG    = NOSPGR
           SGNAME = ' '

         ELSE
     
           CALL LENSTR_BL(SGNAME,LENS)
           IF((LENS.GE.3.AND.SGNAME(1:3).EQ.'R 3').OR.
     *        (LENS.GE.2.AND.SGNAME(1:2).EQ.'R3')) THEN
             T = (PI*2.0)/3.0
             IF(ABS(RLATT(6)-T).LE.0.0001) THEN
               NSETT       = 2
               SGNAME(1:1) = 'H'
             ENDIF
           ENDIF

         ENDIF

C        write(*,*) '===',NSG,NSETT,SGNAME

         CALL GET_SYMM(MDOC,NSG,NSETT,SGNAME,NSYM,ISYM
     *                                            ,IPRSYM,IERR)

C        write(*,*) '---',NSG,NSETT,SGNAME
C ---
C           input
C         nsg  sett  --> nsg sett' --> nsg+sett
C          3    1         3   2        1003
C          3    2         3   1           3
C          4    1         4   2        1004
C          4    2         4   1           4
C          5    1         5   4        3005               
C          5    2         5   1           5       
C          5    3         5   2        1005  
C          5    4         5   3        2005  
C        146    1 R     146   2        1146 R
C        146    2 H     146   1         146 H
C        155    1 R     155   2        1155 R
C        155    2 H     155   1         155 H
C ---        
C ---
C        IF(IERR.NE.0) GO TO 240
         IF(IERR.NE.0) THEN
           CLOSE(MTIN)
           IERR = 32
           RETURN
         ENDIF

        IF(CODE_NDB(1:4).EQ.'XXXX'.OR.CODE_NDB(1:1).EQ.'?'.OR.
     *     CODE_NDB(1:1).EQ.' '.OR.CODE_NDB(1:1).EQ.'.') 
     *     CODE_NDB(1:4)=CODE_PDB

        CALL LENSTR_BL(TITLE,LEN)
        IF(LEN.LE.0) THEN
          LINE = CODE_PDB//'    '
          LEN  = 9
        ELSE
          IF(LEN.GT.60) LEN=60
          L = 8+LEN
          LINE(9:L) = TITLE(1:LEN)             
        ENDIF

        LINE(69:73) = WAVE
        LINE(74:78) = TEMPER
        TITLEL = LINE(1:80)//CODE_PDB//CODE_NDB//NAME_PDB(1:20)
            

        CALL SET_CELL(RLATT,CODE_PDB,NAME_PDB,DATE_PDB,LINE,NSG
     *        ,NSETT,SGNAME,IERR)

        CALL GET_CELL(RLATT,CODE_PDB,NAME_PDB,DATE_PDB,LINE,NSG
     *        ,NSETT,SGNAME,i,IERR)

        CALL LENSTR_BL(SGNAME,L)

        IF(IERR.NE.0) THEN
          CALL MSGERR(MDOC,' ERR: TOBLANC: WRONG TITLE')
           CLOSE(MTIN)
          IERR = 35
          RETURN
C          GO TO 240
        ENDIF

       ELSE

       ENDIF        


       MMDOC=99
       CALL ANOMF(MMDOC,NSYM,ISYM)
       IFIRST=1
c        GO TO 100
      ENDIF
      IF(FORM.EQ.'B') THEN
        IF(FA.GE.0.00000001) THEN
          IF(SA.LE.0.00000001) THEN
            FSQL=FA*FA
            SDL =0.001*FSQL
          ELSE
            SDL=2.0*FA*SA
            FSQL=FA*FA
          ENDIF
        ELSE
          FSQL=0.0
          SDL=0.0
        ENDIF

        ICNT=ICNT+1
        IHR=LH
        IKR=LK
        ILR=LL
        FRD=FSQL
        SDEV=SDL
      ELSE IF(FORM.EQ.'S') THEN
        IF(FA.GE.0.00000001) THEN
          IF(SA.LE.0.00000001) THEN
            FSQL=FA
            SDL=0.001*FSQL
          ELSE
            SDL =SA
            FSQL=FA
          ENDIF
        ELSE
          FSQL=0.0
          SDL=0.0
        ENDIF
        ICNT=ICNT+1
        IHR=LH
        IKR=LK
        ILR=LL
        FRD=FSQL
        SDEV=SDL
        FORM='B'
      ELSE IF(FORM.EQ.'H') THEN
        IF(PHI.LT.0.0) THEN
          PHI=PHI+360.
        ENDIF
        IF(PHI.GT.360.0) THEN
          PHI=PHI-360.
        ENDIF
        FSQL=PHI+1.0
C       FOM=1.0
        SDL =FOM+1.0
        ICNT=ICNT+1
        IHR=LH
        IKR=LK
        ILR=LL
        FRD=FSQL
        SDEV=SDL
      ENDIF
      IF(FRD.LE.0.0)                   GO TO 230
      IF(IHR.LT.IHMIN.OR.IHR.GT.IHMAX) GO TO 230
      IF(IKR.LT.IKMIN.OR.IKR.GT.IKMAX) GO TO 230
      IF(ILR.LT.ILMIN.OR.ILR.GT.ILMAX) GO TO 230
      IF(ILR.EQ.0.AND.IKR.EQ.0.AND.IHR.EQ.0) GO TO 230

C      IF(FLAG_S.EQ.'Y') THEN
C        IF (NBSD.LE.100.AND.SDEV.LE.0.0.AND.FORM.EQ.'B') THEN
C          WRITE(STR,'(''SD?:H,K,L,I,SD:'',6X,3I4,F14.2,F10.2    )')
C     .                     IHR,IKR,ILR,FRD,SDEV
C          CALL MSGERR(MDOC,STR)
CCCCC          NBSD=NBSD+1
C        ENDIF
C      ENDIF

      IF(ITEST.LE.0) THEN
      IF(NUMBT+1.GT.MAXREF) THEN
        WRITE(STR,7000) MAXREF
        CALL MSGERR(MDOC,STR)
 7000   FORMAT(' ERR: TOBLANC: NUMBER OF INPUT REFLECTIONS > ',I7)
        GO TO 7001
      ENDIF
      ENDIF
      IF(FORM.NE.'H') THEN
        TEST=FRD/SDEV
        IF(TEST.LT.SD_LIM.OR.SDEV.LE.0.0) THEN 
          NBSD=NBSD+1
          NBAD=NBAD+1
          IF (NBAD.LT.20) THEN
          WRITE(STR,'('' -->SD_LIM:H,K,L,I,SD:'',6X,3I4,F14.2,F10.2)')
     .                     IHR,IKR,ILR,FRD,SDEV
            CALL MSGDOC(MDOC,STR)
          ELSE IF (NBAD.EQ.20) THEN
            CALL MSGDOC(MDOC,' ... more ...')
          ENDIF
          GO TO 220 
        ENDIF

        CALL SYSABS_BL(IHR,IKR,ILR,NSYM,ISYM,ICND)
        IF(ICND.NE.0) THEN
          NBABS=NBABS+1
          NBAD=NBAD+1
          IF (NBAD.LT.20) THEN
          WRITE(STR,'('' -->SYSABS:H,K,L,I,SD:'',6X,3I4,F14.2,F10.2)')
     .                     IHR,IKR,ILR,FRD,SDEV
            CALL MSGDOC(MDOC,STR)
          ELSE IF (NBAD.EQ.20) THEN
            CALL MSGDOC(MDOC,' ... more ...')
          ENDIF
          GO TO 220
        ENDIF


        NUMB =NUMB +1
        SUMSDT=SUMSDT+SDEV
        SUMINT=SUMINT+FRD
        IF(TEST.GT. 1.) ISUM1 =ISUM1 +1
        IF(TEST.GT. 3.) ISUM3 =ISUM3 +1
        IF(TEST.GT.10.) ISUM10=ISUM10+1
      ELSE


        CALL SYSABS_BL(IHR,IKR,ILR,NSYM,ISYM,ICND)
        IF(ICND.NE.0) THEN
          NBABS=NBABS+1
          NBAD=NBAD+1
          IF (NBAD.LT.20) THEN
          WRITE(STR,'('' -->SYSABS:H,K,L,I,SD:'',6X,3I4,F14.2,F10.2)')
     .                     IHR,IKR,ILR,FRD,SDEV
            CALL MSGDOC(MDOC,STR)
          ELSE IF (NBAD.EQ.20) THEN
            CALL MSGDOC(MDOC,' ... more ...')
          ENDIF
          GO TO 220
        ENDIF



        TEST=(SDEV-1.0)*10.0
        IF(TEST.GT. 1.) ISUM1 =ISUM1 +1
        IF(TEST.GT. 3.) ISUM3 =ISUM3 +1
        IF(TEST.GT. 9.) ISUM10=ISUM10+1
        NUMB =NUMB +1
        SUMSDT=SUMSDT+SDEV
        SUMINT=SUMINT+FRD
      ENDIF
      NH=IHR
      NK=IKR
      NL=ILR
      CALL ANOMSC(NH,NK,NL,KANOM,JJSYM,NSYM,ISYM)
      IF(KANOM.NE.1) JJSYM=-JJSYM
      CALL PACK(INDEX,NH,NK,NL)
C  ----- IARRH(NUMBT)=((NL+000128)*000256+NK+000128)*000256+NH+000128
      NFL=1
      NUMBT =NUMBT +1

      IF(ITEST.LE.0) THEN

      IARRH(NUMBT)=INDEX

      ISTAT=0
      IF(STATUS.EQ.'f') ISTAT=1
      IF(STATUS.EQ.'r') ISTAT=2

      IARRS(NUMBT)= (ISTAT*256+(JJSYM+128))*256+NFL
      ARRF(NUMBT) =FRD
      ARRS(NUMBT) =SDEV
      IF(IPRNT.GT.0) THEN
        IF(MOD(NUMBT,IPRNT).EQ.0) THEN
          IF(FORM.NE.'H') THEN
            WRITE(STR,
     *'(''   N,H,K,L,I,SD,ISYM:'',I6,3I4,F14.2,F14.2,I4)')
     *       NUMBT,IHR,IKR,ILR,FRD,SDEV,JJSYM
            CALL MSGDOC(MDOC,STR)
          ELSE
            FOM=SDEV-1.0
            PHI=FRD-1.0
            WRITE(STR,
     *'(''   N,H,K,L,m,PH,ISYM:'',I6,3I4,F14.2,F14.2,I4)')
     *       NUMBT,IHR,IKR,ILR,FOM,PHI,JJSYM
            CALL MSGDOC(MDOC,STR)
          ENDIF
       ENDIF
      ENDIF

      ENDIF

      CALL DSTAR(NH,NK,NL,RS)
      RH=SQRT(RS)
      IF(RH.LT.RHMIN) RHMIN=RH
      IF(RH.GT.RHMAX) RHMAX=RH

 220  CONTINUE
      IF(I_PASS.LT.NPASS) GO TO 222

      GO TO 200
230   NBAD=NBAD+1
      IF (NBAD.LT.20) THEN
        WRITE(STR,'('' --> BAD  :H,K,L,I,SD:'',6X,3I4,F14.2,F10.2)')
     .                     IHR,IKR,ILR,FRD,SDEV
        CALL MSGDOC(MD,STR)
      ELSE IF (NBAD.EQ.20) THEN
        CALL MSGDOC(MD,' ... more ...')
      ENDIF

      IF(I_PASS.LT.NPASS) GO TO 222

      GO TO 200
C-----------------------------------------------
  210 CONTINUE
7001  CONTINUE
C     WRITE( *,'('' N-REFLS: READ='',I6,'' PASS='',I6)') ICNT,NUMBT
      IF(RHMAX.GT.0.000001) THEN
        RHMAX=1./RHMAX
      ELSE
        RHMAX=88888.88
      ENDIF
      IF(RHMIN.GT.0.000001) THEN
        RHMIN=1./RHMIN
      ELSE
        RHMIN=88888.88
      ENDIF
      IF(RESMIN.LT.RHMIN) RESMIN=RHMIN
      IF(RESMAX.GT.RHMAX) RESMAX=RHMAX
c --
      IT = RESMIN*1000.0 
      IT = IT + 1
      RESMIN = FLOAT(IT)/1000.0
      IT = RESMAX*1000.0 
      IT = IT - 1
      RESMAX = FLOAT(IT)/1000.0
c --
C      WRITE(*,403) RHMIN,RHMAX
  403 FORMAT(1X,'RESOLUTION OF DATA :',F8.2,' - ',F8.2,' ANGSTR')
      IF(FORM.NE.'H') THEN
        IF(SUMINT.NE.0.0) SUMSDT=SUMSDT/SUMINT
      ENDIF
      IF(NUMB.GT.0) THEN
        TEMP1=FLOAT(ISUM1 )/NUMB
        TEMP2=FLOAT(ISUM3 )/NUMB
        TEMP3=FLOAT(ISUM10)/NUMB
      ELSE
        TEMP1=0.0
        TEMP2=0.0
        TEMP3=0.0
      ENDIF

      CALL MSGDOC(MDOC,' -----------------------------')
      WRITE(STR,'('' N-REFLS: READ='',I6,'' PASS='',I6)') ICNT,NUMBT
      CALL MSGDOC(MDOC,STR)
      N_INPUT=ICNT
      WRITE(STR,403) RHMIN,RHMAX
      CALL MSGDOC(MDOC,STR)
      IF(FORM.NE.'H') THEN
        IF(FLAG_S.EQ.'Y') THEN

          WRITE(STR,'('' R-STAND-OLD :'',F8.4)') SUMSDT
          CALL MSGDOC(MDOC,STR)

C          SUMSDT,ISUM1

      WRITE(STR,'('' I >SIG,>3SIG,>10SIG:'',3I8)')ISUM1,ISUM3,ISUM10
          CALL MSGDOC(MDOC,STR)
      WRITE(STR,'(''                     '',3F8.3)') TEMP1,TEMP2,TEMP3
          CALL MSGDOC(MDOC,STR)
        ENDIF
      ELSE
        WRITE(STR,'('' m >0.1,>0.3 ,>0.9  :'',3I8)')ISUM1,ISUM3,ISUM10
        CALL MSGDOC(MDOC,STR)
      WRITE(STR,'(''                     '',3F8.3)') TEMP1,TEMP2,TEMP3
        CALL MSGDOC(MDOC,STR)
      ENDIF
      CALL MSGDOC(MDOC,' -----------------------------')

      CLOSE(MTIN)
      RETURN

240   WRITE(STR,'('' TOTAL NUMBER OF REFLS :'',I8)') NUMBT
      CALL MSGDOC(MDOC,STR)

      IF(NUMBT.LE.1) THEN
        CALL MSGERR(MDOC,' ERR: TOBLANC: NUMBER OF REFLS < 2')
        IERR=34
        RETURN
      ENDIF
      RETURN
      END

      SUBROUTINE JOINWR(MT,NUMBT,IARRH,IARRS,ARRF,ARRS
     *   ,MAXREF,RLATT,RESMIN,RESMAX,RESCRD,ISYM,NSYM
     *   ,NAME_OUT,IANOM,ATOP
     *   ,IPRSYM,FORM,STR,FLAG_S
     *   ,RESULT,IPRROW,IERR)
C     *   ,DELRFR,NRFR,NRFRT
C     *   ,NREF,DELF,NSMT,NSMTT,IERR)

C --
CMS     : IARRH,IARRS,ARRF,ARRS
      REAL RESMIN,RESMAX
      INTEGER*4 MT,IERR
      INTEGER*4 NUMBT,MAXREF,IARRH(*),IARRS(*)
      REAL      ARRF(*),ARRS(*),RESULT(IPRROW,3)
      INTEGER*4 NSYM
      INTEGER*4 IPRSYM
      INTEGER*2 ISYM(5,3,IPRSYM)
      REAL RLATT(6)
      CHARACTER FORM*1,NAME_OUT*(*),STR*(*),FLAG_S*1
C -----------------------------------------
      PARAMETER ( NEQ=200 )
      REAL       FSQ(NEQ),SD(NEQ)
      INTEGER    MRKR(NEQ)
      INTEGER*4  ITYP,IANOM
      REAL       ATOP
      CHARACTER  NAME*256
C      CHARACTER  LINE*80
C ---------------------------------------------------
      IERR=0
      IF(NUMBT.LE.0) THEN
        CALL MSGERR(MT,' ERR: TOBLANC: NUMBER OF REFLS < 1')
        IERR=1
        RETURN
      ENDIF
C      CALL MSGDOC(MT,' --- SORT ----')
      CALL ISORT3(IARRH,NUMBT,IARRS,ARRF,ARRS)
C      CALL MSGDOC(MT,' --- SORT  FINISHED ---')
C-------
C      CALL MSGDOC(MT,' -----------------------------')
C ----------------------------------------------------
      NAME=NAME_OUT
      CALL LENSTR_BL(NAME,LEN)
      IF(LEN.LE.0.OR.NAME(1:1).EQ.' '.OR.NAME(1:1).EQ.',') THEN
        CALL MSGERR(MT,' ERR: WRONG FILE-NAME')
        IERR=1
        RETURN
      ENDIF

      IF(FORM.NE.'H') THEN
        ITYP=0
        CALL SORTRF(MT,NAME,IANOM,IARRH,IARRS,ARRF,ARRS,MAXREF
     *    ,NUMBT,ATOP,ITYP,NSYM,ISYM,IPRSYM,FSQ,SD,MRKR,NEQ
     *    ,RLATT,FORM,STR,RESMIN,RESMAX,RESCRD,FLAG_S
     *    ,RESULT,IPRROW,IERR)
C     *    ,DELRFR,NRFR,NRFRT
C     *    ,NREF,DELF,NSMT,NSMTT,IERR)
      ELSE
        CALL SORTPH(MT,NAME,STR,IARRH,IARRS,ARRF,ARRS,MAXREF,NUMBT
     *            ,NEQ,RLATT,NSYM,ISYM,IPRSYM,RESMIN,RESMAX,IERR)
      ENDIF
      RETURN
      END

      SUBROUTINE SORTRF(MT,NAME,IANOM,IARRH,IARRS,ARRF,ARRS,MAXREF
     * ,NUMBT,ATOP,ITYP,NSYM,ISYM,IPRSYM,FSQ,SD,MRKR,NEQ
     * ,RLATT,FORM,LINE,RESMIN,RESMAX,RESCRD,FLAG_S
     * ,RESULT,IPRROW,IERR)
C     * ,DELRFR,NRFR,NRFRT
C     * ,NREF,DELF,NSMT,NSMTT,IERR)
C ------------------------------------------------------------------
CMS     : IARRH,IARRS,ARRF,ARRS
      INTEGER   IARRH(MAXREF),IARRS(MAXREF)
      REAL      ARRF (MAXREF),ARRS (MAXREF)
      REAL      FSQ(NEQ),SD(NEQ)
      INTEGER   MRKR(NEQ)
      INTEGER*2 ISYM(5,3,IPRSYM)
      REAL      RLATT(6),RESULT(IPRROW,3),RESLT1(22),RESLT2(22)
      REAL      RESLT3(22)
      CHARACTER FORM*1,LINE*(*),NAME*(*),FLAG_S*1
      INTEGER   IFL(200)
C CMS  NMGRPR,NMGRSM,NMGRSA,NMGR,NMGRRP,RFAC11,RFAC12,RFAC21,RFAC22
C CMS  RFAC31,RFAC32,RFAC41,RFAC42,RFAC51,RFAC52,RFAC61,RFAC62
      INTEGER   NMGRPR(22),NMGRSM(22),NMGRSA(22),NMGR(22),NMGRRP(22)
      REAL      RFAC11(22),RFAC12(22),RFAC21(22),RFAC22(22)
      REAL      RFAC31(22),RFAC32(22),RFAC41(22),RFAC42(22)
      REAL      RFAC51(22),RFAC52(22),RFAC61(22),RFAC62(22)
      CHARACTER   ITPF*4,STR*80
      CHARACTER   MSG*1,MSG1*1,MSG2*1,MSG5*1
      EXTERNAL  UNPACK
C==================================================================
      IPRROW22 = 22
      DO     I=1,22
        NMGR  (I)=0
        NMGRPR(I)=0
        NMGRSM(I)=0
        NMGRSA(I)=0
        NMGRRP(I)=0
        RFAC11(I)=0.
        RFAC21(I)=0.
        RFAC31(I)=0.
        RFAC41(I)=0.
        RFAC12(I)=0.
        RFAC22(I)=0.
        RFAC32(I)=0.
        RFAC42(I)=0.
        RFAC51(I)=0.
        RFAC52(I)=0.
        RFAC61(I)=0.
        RFAC62(I)=0.
        RESLT1(I)=0.
        RESLT2(I)=0.
        RESLT3(I)=0.
      ENDDO
C ---------------------------------------------------
100   CONTINUE
C      CALL DISPL('RESMIN,RESMAX           :')
C      READ(*,*)   RESMIN,RESMAX
      IF(RESMAX.GT.RESMIN) THEN
        STOR=RESMIN
        RESMIN=RESMAX
        RESMAX=STOR
      ENDIF
C      RESMIN=RESMIN+0.001
C      RESMAX=RESMAX-0.001

      RESMX=RESMAX

      IF(RESCRD.GT.0.AND.RESCRD.GT.RESMAX) RESMX=RESCRD

      IF((RESMIN.EQ.RESMX).OR.
     *   (RESMIN.LE.0.0).OR.(RESMX.LE.0.0)) THEN
        IERR=1
        RETURN
      ENDIF 
      IF((RESMIN.EQ.RESMAX).OR.
     *   (RESMIN.LE.0.0).OR.(RESMAX.LE.0.0)) THEN
        IERR=1
        RETURN
      ENDIF 
      RHMIN =1./RESMIN
      RHMAX =1./RESMAX
      RHCMAX=1./RESMX
C -------------
      MSG2='N'
      IF(IANOM.EQ.1) MSG2='Y'
C --------------
      MSG='N'
      IF(ATOP.GT.0.0) MSG='Y'
      ICOUNT=0
      IPRNT=0
      SUMRFR=0.0
      DELRFR=0.0
      NRFR  =0
      NRFRT =0
      SUMFA =0.0
      DELFA =0.0
      NSMTTA=0
      NSMTA =0
      DELF  =0.0
      NPR   =0
      DSYM  =0.0
      SUMSYM=0.0
      SUMF  =0.0
      NSMTT =0
      NSMT  =0
      NREF  =0
      M     =0
      NBL   =0
      IEND  =-1
      RFAC  =0.0
      FAVER =0
C -------------------------------
      IF(FLAG_S.EQ.'Y') THEN
        ITPF='FS  '
        MSG1='Y'
      ELSE
        ITPF='F   '
        MSG1='N'
      ENDIF
      CALL WRITET(MT,MTOUT,NAME,LINE,ITPF,RLATT,RESMIN,RESMAX
     *   ,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) RETURN

C------------------------------------------------------
C     MTOUT=11
      NNNREF=0
      ISUM1 =0.
      ISUM3 =0.
      ISUM10=0.
      SUMST =0.
      SUMIT =0.
      SUMSAT=0.
      SUMIAT=0.
      NBAD  =0
      SUMNCN=0.
      SUMCN =0.
      DELNCN=0.
      DELCN =0.
      NNCN  =0
      NCN   =0
      I     =0
      IN    =0
      IHOLD =-512
      IKOLD =-512
      ILOLD =-512
      KEND  =0
      N     =-1
      NOUT  = 0
      ISTTS1=0
      ISTTS =0
      ISTTS1=0
      ISTTS =0
C==========================================================================
      DO     IJKLM=1,NUMBT+1
        I=I+1
        IF(I.LE.NUMBT) THEN
          IDBL =IARRH(I)
          CALL UNPACK(IDBL,NH,NK,NL)
          CALL DSTAR(NH,NK,NL,RS)
          RH=SQRT(RS)
          IF(RH.LT.RHMIN.OR.RH.GT.RHMAX) THEN
             NOUT=NOUT+1
             GO TO 430
          ENDIF
          IF(RH.GT.1.E-8) THEN
            IRGR=1.0/(RH*0.5)
            IRGR=IRGR+1
            IF(IRGR.GT.22) IRGR=22
          ELSE
            IRGR=22
          ENDIF

          ISTATUS=IARRS(I)/(256*256)
          ITEMP  =IARRS(I)-ISTATUS*(256*256)
          JJSYM  =ITEMP/256
          NFL    =ITEMP-JJSYM*256
          JJSYM  =JJSYM-128
          FFF    =ARRF(I)
          SSS    =ARRS(I)

        ELSE
          NH = -513
          NK = -513
          NL = -513
          KEND=1
        ENDIF
        IF(IHOLD.EQ.NH.AND.IKOLD.EQ.NK.AND.ILOLD.EQ.NL) THEN
          N=N+1
          IF(N.GT.NEQ) THEN
            WRITE(STR,'('' !! NUMB EQUIV OR REPET-REFLS GT:'',I5)')NEQ
            CALL MSGERR(MT,STR)
            IERR=1
            RETURN
          ENDIF
          FSQ (N) =FFF
          IFL (N) =NFL
          SD  (N) =SSS
          MRKR(N) =JJSYM
          ISTTS1  = ISTATUS
          IF(IANOM.NE.1) MRKR(N)=IABS(MRKR(N))
C          IF(I.GE.NUMBT) GO TO 500
          GO TO 430
        ENDIF
C        IF(I.LT.NUMBT) GO TO 510
C -------------------------------------------------------------
C500     KEND=1
510     IF(IHOLD.NE.NH.OR.IKOLD.NE.NK.OR.ILOLD.NE.NL
     .                                    .OR.KEND.EQ.1) THEN
          IF(N.EQ.-1) GO TO 520
          IF(N.EQ. 0) GO TO 560
          IF(N.GT. 1) THEN
            CALL ISORT3(MRKR,N,IFL,FSQ,SD)
2032        CONTINUE
            DO     J=1,N
              NN=0
              IF(J.EQ.N) GO TO 2010
              IF(MRKR(J).EQ.0) GO TO 2010
              MMM=MRKR(J)
              I1=J+1
              NN=1
              IF(SD(J).LE.0.0000001) SD(J)=1.0
              WT=1./(SD(J)*SD(J))
              SM=FSQ(J)*WT
              SMW=WT
              DO     L=I1,N
                IF(MRKR(L).NE.MMM) GO TO 2011
                IF(SD(L).LE.0.0000001) SD(L)=1.0
                WT=1./(SD(L)*SD(L))
                SM=SM  +FSQ(L)*WT
                SMW=SMW+WT
                NN=NN+1
 2011           CONTINUE
              ENDDO
 2010         IF(MRKR(J).EQ.0) GO TO 2030
              IF(NN.LE.1) GO TO 2030
C------ANALISYS REPET-REFLS-----
              SSSSM=SM/SMW
              SSSSMW=1./SQRT(SMW)
              I1=J+1
              IBAD=0
              DO     L=J,N
                IF(MRKR(L).NE.MMM) GO TO 2031
                DEL   =ABS(SSSSM-FSQ(L))
                TTTT=DEL
                ATOPP=ATOP*SD(L)
                IF(MSG.EQ.'Y'.AND.TTTT.GT.ATOPP) THEN
C                 IF(IBAD.GE.NN-1) GO TO 2031
                  IF(NBAD.LE.500) THEN
                    WRITE(STR,
     *              '('' IFL,<I>,SD:'',I5,2E12.4,A4)')
     *              IFL(L),SSSSM,SSSSMW,' BAD'
                    CALL MSGDOC(MT,STR)
                  ENDIF
                  IH=IHOLD
                  IK=IKOLD
                  IL=ILOLD
                  IF(MSG.EQ.'Y') THEN
                    NBAD=NBAD+1
                    IF(NBAD.LE.500) THEN
                      WRITE(STR,
     *                '('' RPT-H,K,L,I,SD:'',3I5,2E12.4)')
     *                IH,IK,IL,FSQ(L),SD(L)
                      CALL MSGDOC(MT,STR)
                      WRITE(STR,'('' --------'')')
                      CALL MSGDOC(MT,STR)
                      ICOUNT=ICOUNT+3
C                      IF(ICOUNT.GE.18.AND.MT.GE.0.AND.MT.LT.99) THEN
C                        CALL DISPL('FOR CONTINUE TYPE "CR"')
C                        READ(*,'(A)') MSG5
C                        ICOUNT=0
C                      ENDIF
                    ENDIF
                  ENDIF
                  MRKR(L)=0
                  IBAD=IBAD+1
                ENDIF
 2031           CONTINUE
              ENDDO
              IF(IBAD.NE.0) GO TO 2032
C----------------------------------
              SM=SM/SMW
              SMW=1./SQRT(SMW)
              NRFR=NRFR+1
              NRFRT=NRFRT+1
              SUMRFR=SUMRFR+FSQ(J)
              DEL   =ABS(SM-FSQ(J))
              DELRFR=DELRFR+DEL
              NMGRRP(IRGR)=NMGRRP(IRGR)+1
              RFAC61(IRGR)=RFAC61(IRGR)+DEL
              RFAC62(IRGR)=RFAC62(IRGR)+FSQ(J)
              FSQ(J)=SM
              SD(J)=SMW
              I1=J+1
              DO     L=I1,N
                IF(MRKR(L).NE.MMM) GO TO 2033
                SUMRFR=SUMRFR+FSQ(L)
                DEL   =ABS(SM-FSQ(L))
                DELRFR=DELRFR+DEL
                NMGRRP(IRGR)=NMGRRP(IRGR)+1
                RFAC61(IRGR)=RFAC61(IRGR)+DEL
                RFAC62(IRGR)=RFAC62(IRGR)+FSQ(L)
                NRFRT=NRFRT+1
                MRKR(L)=0
 2033           CONTINUE
              ENDDO
 2030         CONTINUE
            ENDDO
          ENDIF
C
C --- CALC <F>-SYMM <FANOM>-SYM ---
C
471       CONTINUE
          ISTTS=ISTTS1
          FSYM=0.
          SWT=0.
          NSM=0
          FSYMA=0.
          SWTA =0.
          NSMA=0
          TDEL=0.
          TSUM=0.
          SSUMF=0.
          SSUMFA=0.
          SDELF=0.
          SDELFA=0.
          FAVER=0.
          FAVERA=0.
          FMAX=0.
          DO     L=1,N
            IF(MRKR(L).EQ.0) GO TO 540
            TEMP =ABS(FSQ(L))
            IF(SD(L).LE.0.0000001) SD(L)=1.0
            WT   =1./(SD(L)*SD(L))
            IF(MRKR(L).LE.0) THEN
              FSYMA=FSYMA+TEMP*WT
              FAVERA=FAVERA+TEMP
              SWTA=SWTA+WT
              NSMA=NSMA+1
            ELSE
              FSYM=FSYM+TEMP*WT
              IF(TEMP.GT.FMAX) THEN
                FMAX=TEMP
                SDMAX=WT
              ENDIF
              FAVER=FAVER+TEMP
              SWT=SWT+WT
              NSM=NSM+1
            ENDIF
540         CONTINUE
          ENDDO
          IF(NSM .NE.0) THEN
            FSYM=FSYM/SWT
            FAVER=FAVER/NSM
            SWT=1./SQRT(SWT)
          ENDIF
          IF(NSMA.NE.0) THEN
            FSYMA=FSYMA/SWTA
            FAVERA=FAVERA/NSMA
            SWTA=1./SQRT(SWTA)
          ENDIF
C ---
          IBAD=0
          IBADA=0
          ITOT=0
          ITOTA=0
          ATMIN=-1.E30
          ATMINA=-1.E30
          IF(N.LE.1) GO TO 490
C ---     ANALISYS !F-<F>!/<F>
          DO     L=1,N
            IF(MRKR(L).EQ.0) GO TO 470
            STOR=ABS(FSQ(L))
            SDTOR=ABS(SD(L))
            IF(MRKR(L).LE.0) THEN
              IF(NSMA.LE.1) GO TO 470
              ITOTA=ITOTA+1
              SSUMFA=SSUMFA+STOR
              DELTA= ABS(FSYMA-STOR)
              DDELTA= ABS(FAVERA-STOR)
              SDELFA=SDELFA+DELTA
              IF(MSG.EQ.'Y') THEN
                TATOP=DDELTA
                ATOPP=ATOP*SDTOR
                IF(ATMINA.LT.TATOP) ATMINA=TATOP
                IF(TATOP.GT.ATOPP) THEN
                  IBADA=IBADA+1
                ENDIF
              ENDIF
            ELSE
              IF(NSM.LE.1) GO TO 470
              ITOT=ITOT+1
              SSUMF=SSUMF+STOR
              TSUM=TSUM+STOR
              DELTA=ABS(FSYM-STOR)
              DDELT= ABS(FAVER-STOR)
              TDEL=TDEL+DELTA
              SDELF=SDELF+DELTA
              IF(MSG.EQ.'Y') THEN
                TATOP=DDELT
                ATOPP=ATOP*SDTOR
                IF(ATMIN.LT.TATOP) ATMIN=TATOP
                IF(TATOP.GT.ATOPP) THEN
                  IBAD=IBAD+1
                ENDIF
              ENDIF
            ENDIF
  470       CONTINUE
          ENDDO
C ------ PRINT OF BAD REFLEXION -----
          IF(IBAD.NE.0.OR.IBADA.NE.0) THEN
C          IBADD=0
C          IBADDA=0
          DO     L=1,N
            IF(MRKR(L).EQ.0) GO TO 472
            STOR=ABS(FSQ(L))
            SDTOR=ABS(SD(L))
            IF(MRKR(L).LE.0) THEN
              IF(NSMA.LE.1) GO TO 472
              DELTA= ABS(FSYMA-STOR)
              DDELTA=ABS(FAVERA-STOR)
              IF(MSG.EQ.'Y') THEN
C                IF(IBADDA.GE.NSMA-1) GO TO 472
                TATOP=DDELTA
                ATOPP=ATOP*SDTOR
                ATOPP=ATMINA
                IF(IBADA.NE.0.AND.ITOTA.EQ.2) ATOPP=0.
                IF(TATOP.GE.ATOPP) THEN
                  IF(NBAD.LE.500) THEN
                    WRITE(STR,'('' ISYM,I,SD:'',I5,2E12.4,A4)')
     *                       MRKR(L),STOR,SD(L),' BAD'
                    CALL MSGDOC(MT,STR)
                    ICOUNT=ICOUNT+1
C                    IF(ICOUNT.GE.20.AND.MT.GE.0.AND.MT.LT.99) THEN
C                      CALL DISPL('FOR CONTINUE TYPE "CR"')
C                      READ(*,'(A)') MSG5
C                      ICOUNT=0
C                    ENDIF
                  ENDIF
C                  IBADDA=IBADDA+1
                  NBAD=NBAD+1
                  MRKR(L)=0
                ELSE
                  IF(NBAD.LE.500) THEN
                    WRITE(STR,'('' ISYM,I,SD:'',I5,2E12.4)')
     *                           MRKR(L),STOR,SD(L)
                    CALL MSGDOC(MT,STR)
                    ICOUNT=ICOUNT+1
C                    IF(ICOUNT.GE.20.AND.MT.GE.0.AND.MT.LT.99) THEN
C                      CALL DISPL('FOR CONTINUE TYPE "CR"')
C                      READ(*,'(A)') MSG5
C                      ICOUNT=0
C                    ENDIF
                  ENDIF
                ENDIF
              ENDIF
            ELSE
              IF(NSM.LE.1) GO TO 472
              IF(MSG.EQ.'Y') THEN
C                IF(IBADD.GE.NSM-1) GO TO 472
                DELTA=ABS(FSYM-STOR)
                DDELT=ABS(FAVER-STOR)
                TATOP=DDELT
                ATOPP=ATOP*SDTOR
                ATOPP=ATMIN
                IF(TATOP.GE.ATOPP) THEN
                  IF(NBAD.LE.500) THEN
                    WRITE(STR,'('' ISYM,I,SD:'',I5,2E12.4,A4)')
     *                    MRKR(L),STOR,SD(L),' BAD'
                    CALL MSGDOC(MT,STR)
                    ICOUNT=ICOUNT+1
                    IF(ICOUNT.GE.20.AND.MT.GE.0.AND.MT.LT.99) THEN
                      CALL DISPL_BL('FOR CONTINUE TYPE "CR"')
                      READ(*,'(A)') MSG5
                      ICOUNT=0
                    ENDIF
                  ENDIF
C                  IBADD=IBADD+1
                  NBAD=NBAD+1
                  MRKR(L)=0
                ELSE
                  IF(NBAD.LE.500) THEN
                    WRITE(STR,'('' ISYM,I,SD:'',I5,2E12.4)')
     *                     MRKR(L),STOR,SD(L)
                    CALL MSGDOC(MT,STR)
                    ICOUNT=ICOUNT+1
C                    IF(ICOUNT.GE.20.AND.MT.GE.0.AND.MT.LT.99) THEN
C                      CALL DISPL('FOR CONTINUE TYPE "CR"')
C                      READ(*,'(A)') MSG5
C                      ICOUNT=0
C                    ENDIF
                  ENDIF
                ENDIF
              ENDIF
            ENDIF
  472       CONTINUE
          ENDDO
          IH=IHOLD
          IK=IKOLD
          IL=ILOLD
          IF(MSG.EQ.'Y') THEN
            IF(NBAD.LE.500) THEN
              IF(NSM.NE.0) THEN
                WRITE(STR,'(''  H, K, L,I,SD:'',3I5,2E12.4)')
     *                 IH,IK,IL,FAVER,SWT
                CALL MSGDOC(MT,STR)
                ICOUNT=ICOUNT+1
              ENDIF
              IF(NSMA.NE.0) THEN
                WRITE(STR,'('' -H,-K,-L,I,SD:'',3I5,2E12.4)')
     *               IH,IK,IL,FAVERA,SWTA
                CALL MSGDOC(MT,STR)
                ICOUNT=ICOUNT+1
              ENDIF
              WRITE(STR,'('' --------'')')
              CALL MSGDOC(MT,STR)
              ICOUNT=ICOUNT+1
C              IF(ICOUNT.GE.18.AND.MT.GE.0.AND.MT.LT.99) THEN
C                CALL DISPL('FOR CONTINUE TYPE "CR"')
C                READ(*,'(A)') MSG5
C                ICOUNT=0
C              ENDIF
            ENDIF
          ENDIF
          GO TO 471
          ENDIF
C ----------------------------------------------------------------
          IF(NSM.EQ.0.AND.NSMA.EQ.0) GO TO 521
          JPR=0
          IF(NSM.NE.0.AND.NSMA.NE.0) THEN
            SUMSYM=SUMSYM+FSYM+FSYMA
            SUMSMT=       FSYM+FSYMA
            DSYM=DSYM+ABS(FSYM-FSYMA)
            DSYMT=    ABS(FSYM-FSYMA)
            NPR=NPR+1
            JPR=1
          ENDIF
          DELF=DELF+SDELF
          DELFA=DELFA+SDELFA
          SUMF=SUMF+SSUMF
          SUMFA=SUMFA+SSUMFA
  490     CONTINUE
c          IF(NSMA.GT.0) THEN
          IF(NSMA.GT.1) THEN
            NSMTA=NSMTA+1
            NSMTTA=NSMTTA+NSMA
          ENDIF
c          IF(NSM .GT.0) THEN
          IF(NSM .GT.1) THEN
            NSMT =NSMT +1
            NSMTT=NSMTT+NSM
          ENDIF
          SUMST=SUMST+SWT
          SUMIT=SUMIT+FSYM
          FMOD=SQRT(FSYM)
          SSWT=SWT
          IF(FMOD.NE.0.) THEN
            SWT =(.5*SWT)/FMOD
            TEST=FMOD/SWT
            IF(TEST.GT. 1.) ISUM1=ISUM1  +1
            IF(TEST.GT. 3.) ISUM3=ISUM3  +1
            IF(TEST.GT.10.) ISUM10=ISUM10+1
            NNNREF=NNNREF+1
          ENDIF
          SUMSAT=SUMSAT+SWTA
          SUMIAT=SUMIAT+FSYMA
          FMODA=SQRT(FSYMA)
          SSWTA=SWTA
          IF(FMODA.NE.0.) THEN
            SWTA =(.5*SWTA)/FMODA
            TEST=FMODA/SWTA
            IF(TEST.GT. 1.) ISUM1= ISUM1 +1
            IF(TEST.GT. 3.) ISUM3= ISUM3 +1
            IF(TEST.GT.10.) ISUM10=ISUM10+1
            NNNREF=NNNREF+1
          ENDIF
          IH=IHOLD
          IK=IKOLD
          IL=ILOLD
          NREF=NREF+1
          IF(ITYP.NE.0.AND.NSM.GT.1) THEN
            ICENT=0
            IF((ITYP.EQ.1.OR.ITYP.EQ.5).AND.IH.EQ.0) ICENT=1
            IF((ITYP.EQ.2.OR.ITYP.EQ.5).AND.IK.EQ.0) ICENT=1
            IF((ITYP.EQ.3.OR.ITYP.EQ.5).AND.IL.EQ.0) ICENT=1
            IF(ITYP.EQ.4.AND.IH.EQ.IK) ICENT=1
            IF(ICENT.EQ.0) THEN
              SUMNCN=SUMNCN+TSUM
              DELNCN=DELNCN+TDEL
              NNCN=NNCN+1
            ELSE
              SUMCN=SUMCN+TSUM
              DELCN=DELCN+TDEL
              NCN=NCN+1
            ENDIF
          ENDIF

          NMGR(IRGR)=NMGR(IRGR)+1
          IF(JPR .EQ.1) NMGRPR(IRGR)=NMGRPR(IRGR)+1

c          IF(NSM .GT.0) THEN
          IF(NSM .GT.1) THEN
            NMGRSM(IRGR)=NMGRSM(IRGR)+1
          ENDIF
          RFAC11(IRGR)=RFAC11(IRGR)+SDELF
          RFAC12(IRGR)=RFAC12(IRGR)+SSUMF

          IF(NSM .GT.1) THEN
             NKR=IPRROW22-1
             DRK=(RHCMAX-RHMIN)/NKR
             KR=(RH-RHMIN)/DRK+1.
             IF(KR.GT.NKR) KR=NKR
             IF(KR.LT.1) KR=1
             RESLT1(KR)=RESLT1(KR)+SDELF
             RESLT1(IPRROW22)=RESLT1(IPRROW22)+SDELF
             RESLT2(KR)=RESLT2(KR)+SSUMF
             RESLT2(IPRROW22)=RESLT2(IPRROW22)+SSUMF
             RESLT3(KR)=RESLT3(KR)+NSM
             RESLT3(IPRROW22)=RESLT3(IPRROW22)+NSM
          ENDIF
         


c          IF(NSMA.GT.0) THEN
          IF(NSMA.GT.1) THEN
            NMGRSA(IRGR)=NMGRSA(IRGR)+1
          ENDIF

          RFAC21(IRGR)=RFAC21(IRGR)+SDELFA
          RFAC22(IRGR)=RFAC22(IRGR)+SSUMFA
          RFAC31(IRGR)=RFAC31(IRGR)+SSWT
          RFAC32(IRGR)=RFAC32(IRGR)+FSYM
          RFAC41(IRGR)=RFAC41(IRGR)+SSWTA
          RFAC42(IRGR)=RFAC42(IRGR)+FSYMA
          IF(JPR.EQ.1) THEN
            RFAC51(IRGR)=RFAC51(IRGR)+DSYMT
            RFAC52(IRGR)=RFAC52(IRGR)+SUMSMT
          ENDIF
          IF(IPRNT.GT.0) THEN
          IF(MOD(NREF,IPRNT).EQ.0) THEN
            IF(NSM.NE.0) THEN
              WRITE(STR,'(''  N,H,K,L,F,SD:'',I6,2X,3I5,2E12.4)')
     .             NREF,IH,IK,IL,FMOD ,SWT
              CALL MSGDOC(MT,STR)
            ENDIF
            IF(NSMA.NE.0) THEN
              IHM=-IH
              IKM=-IK
              ILM=-IL
              WRITE(STR,'(''  N,H,K,L,F,SD:'',I6,2X,3I5,2E12.4)')
     .             NREF,IHM,IKM,ILM,FMODA,SWTA
              CALL MSGDOC(MT,STR)
            ENDIF
          ENDIF
          ENDIF
          IF(MTOUT.GT.0) THEN
            KEY=ISTTS
            NBL=NBL+1
            IF(MSG1.NE.'N') THEN
              CALL WWRT(MTOUT,IH,IK,IL,FMOD,FMODA,SWT,SWTA,KEY,IEND)
            ELSE
              CALL WRT(MTOUT,IH,IK,IL,FMOD ,FMODA,KEY,IEND)
            ENDIF
            IF(MTOUT.LE.0) THEN
              IERR=1
              RETURN
            ENDIF
          ENDIF
521       CONTINUE
          IF(KEND.EQ.1) GO TO 560
520       N=1
          FSQ (N)=FFF
          SD  (N)=SSS
          IFL (N)=NFL
          MRKR(N)=JJSYM
          ISTTS1 =ISTATUS
          IF(IANOM.NE.1) MRKR(N)=IABS(MRKR(N))
          IHOLD=NH
          IKOLD=NK
          ILOLD=NL
        ENDIF
  430   CONTINUE
      ENDDO
C--------------------------------------------
560   IEND=2
      IF(MTOUT.GT.0) THEN
        CALL WRT(MTOUT,IH,IK,IL,FMOD,FMODA,NBL,IEND)
      ENDIF

c      IF(NRFR.GT.0.AND.SUMRFR.GT.0.0) THEN
c        DELRFR=DELRFR/SUMRFR
c      ENDIF
c      IF(NSMT.GT.0.AND.SUMF.GT.0.0) THEN
c        DELF=DELF/SUMF
c      ENDIF
c      IF(NSMT.GT.0.AND.SUMIT.GT.0.0) THEN
c        SUMST=SUMST/SUMIT
c      ENDIF
c      IF(NSMTA.GT.0.AND.SUMFA.GT.0.0) THEN
c        DELFA=DELFA/SUMFA
c      ENDIF
c      IF(NSMTA.GT.0.AND.SUMIAT.GT.0.0) THEN
c        SUMSAT=SUMSAT/SUMIAT
c      ENDIF
      IF(SUMRFR.GT.0.0) THEN
        DELRFR=DELRFR/SUMRFR
      ENDIF
      IF(SUMF.GT.0.0) THEN
        DELF=DELF/SUMF
      ENDIF
      IF(SUMIT.GT.0.0) THEN
        SUMST=SUMST/SUMIT
      ENDIF
      IF(SUMFA.GT.0.0) THEN
        DELFA=DELFA/SUMFA
      ENDIF
      IF(SUMIAT.GT.0.0) THEN
        SUMSAT=SUMSAT/SUMIAT
      ENDIF

      WRITE(STR,400) NREF
      CALL MSGDOC(MT,STR)
      IF(MSG.EQ.'Y') THEN
        WRITE(STR,'('' N-BAD-REFLS                :'',I6)') NBAD
        CALL MSGDOC(MT,STR)
      ENDIF
      IF(ITPF.EQ.'FS  ') THEN
      WRITE(STR,'('' F >SIG,>3SIG,>10SIG:'',3I8)') ISUM1,ISUM3,ISUM10
        CALL MSGDOC(MT,STR)
        IF(NNNREF.GT.0) THEN
          TEMP1=FLOAT(ISUM1 )/NNNREF
          TEMP2=FLOAT(ISUM3 )/NNNREF
          TEMP3=FLOAT(ISUM10)/NNNREF
        ELSE
          TEMP1=0.0
          TEMP2=0.0
          TEMP3=0.0
        ENDIF
      WRITE(STR,'(''                     '',3F8.3)') TEMP1,TEMP2,TEMP3
        CALL MSGDOC(MT,STR)
      ENDIF
      IF(NRFR.GT.0) THEN
        WRITE(STR,409) NRFR,NRFRT
        CALL MSGDOC(MT,STR)
        WRITE(STR,1409) DELRFR
        CALL MSGDOC(MT,STR)
      ENDIF
      IF(NSMT.LT.NSMTT) THEN
        WRITE(STR,406)  NSMT,NSMTT
        CALL MSGDOC(MT,STR)
        WRITE(STR,1406) DELF
        CALL MSGDOC(MT,STR)
      ELSE
        DELF=0.0
      ENDIF
      IF(ITPF.EQ.'FS  ') THEN
        WRITE(STR,416) SUMST
        CALL MSGDOC(MT,STR)
      ELSE
        SUMST=0.0
      ENDIF
      IF(ITYP.NE.0) THEN
        IF(NNCN.GT.0) DELNCN=DELNCN/SUMNCN
        IF(NCN .GT.0) DELCN =DELCN/SUMCN
        WRITE(STR,411) NCN
        CALL MSGDOC(MT,STR)
        WRITE(STR,1411) DELCN
        CALL MSGDOC(MT,STR)
        WRITE(STR,410) NNCN
        CALL MSGDOC(MT,STR)
        WRITE(STR,410) DELNCN
        CALL MSGDOC(MT,STR)
      ENDIF
      IF(IANOM.NE.0) THEN
        RFAC=0.
        IF(NSMTA.LT.NSMTTA) THEN
          WRITE(STR,407) NSMTA,NSMTTA
          CALL MSGDOC(MT,STR)
          WRITE(STR,1407) DELFA
          CALL MSGDOC(MT,STR)
          WRITE(STR,417) SUMSAT
          CALL MSGDOC(MT,STR)
        ENDIF
        IF(NPR.NE.0)THEN
          RFAC=2.0*DSYM/SUMSYM
          WRITE(STR,408) NPR
          CALL MSGDOC(MT,STR)
          WRITE(STR,1408) RFAC
          CALL MSGDOC(MT,STR)
        ENDIF
      ENDIF

      MM=MT           
      IF(MT.GE.0.AND.MT.LT.99) MM=0
      CALL MSGDOC(MM,' ')
      WRITE(STR,730)
  730 FORMAT(' ANGSTR:2.5   3.0   3.5   4.',
     *   '0   4.5   5.0   5.5   6.0   6.5   7.0   7.5   8.0')
      CALL MSGDOC(MM,STR)
      WRITE(STR,740) (NMGR(K),K=6,16)
  740 FORMAT(' N      ',11I6)
      CALL MSGDOC(MM,STR)
      DO     I=1,22
        IF(RFAC12(I).NE.0.) RFAC11(I)=RFAC11(I)/RFAC12(I)
        IF(RFAC22(I).NE.0.) RFAC21(I)=RFAC21(I)/RFAC22(I)
        IF(RFAC32(I).NE.0.) RFAC31(I)=RFAC31(I)/RFAC32(I)
        IF(RFAC42(I).NE.0.) RFAC41(I)=RFAC41(I)/RFAC42(I)
        IF(RFAC52(I).NE.0.) RFAC51(I)=RFAC51(I)/RFAC52(I)
        IF(RFAC62(I).NE.0.) RFAC61(I)=RFAC61(I)/RFAC62(I)
        IF(RESLT2(I).NE.0.) RESLT1(I)=RESLT1(I)/RESLT2(I)
      ENDDO
      IF(NSMT .GT.0) THEN
        CALL MSGDOC(MM,' ')
        WRITE(STR,741) (RFAC11(K),K=6,16)
        CALL MSGDOC(MM,STR)
        WRITE(STR,743) (RFAC31(K),K=6,16)
        CALL MSGDOC(MM,STR)
        WRITE(STR,740) (NMGRSM(K),K=6,16)
        CALL MSGDOC(MM,STR)
      ENDIF
      IF(NSMTA.GT.0) THEN
        CALL MSGDOC(MM,' ')
        WRITE(STR,742) (RFAC21(K),K=6,16)
        CALL MSGDOC(MM,STR)
        WRITE(STR,744) (RFAC41(K),K=6,16)
        CALL MSGDOC(MM,STR)
        WRITE(STR,740) (NMGRSA(K),K=6,16)
        CALL MSGDOC(MM,STR)
      ENDIF
      IF(NPR.GT.0) THEN
        CALL MSGDOC(MM,' ')
        WRITE(STR,747) (RFAC51(K),K=6,16)
        CALL MSGDOC(MM,STR)
        WRITE(STR,740) (NMGRPR(K),K=6,16)
        CALL MSGDOC(MM,STR)
      ENDIF
      IF(NRFR.GT.0) THEN
        CALL MSGDOC(MM,' ')
        WRITE(STR,748) (RFAC61(K),K=6,16)
        CALL MSGDOC(MM,STR)
        WRITE(STR,740) (NMGRRP(K),K=6,16)
        CALL MSGDOC(MM,STR)
      ENDIF
  741 FORMAT(' R-SYM  ',11F6.3)
  742 FORMAT(' R-SYM A',11F6.3)
  743 FORMAT(' R-STAN ',11F6.3)
  744 FORMAT(' R-STANA',11F6.3)
  747 FORMAT(' R-PAIRS',11F6.3)
  748 FORMAT(' R-REPET',11F6.3)
C ------------
      MM=99
      IF(MT.NE.0.AND.MT.LT.99) MM=-1

      WRITE(STR,745)
  745 FORMAT(' ANGSTR:0.0   0.5   1.0   1.',
     *   '5   2.0   2.5   3.0   3.5   4.0   4.5   5.0   5.5')
      CALL MSGDOC(MM,STR)
      WRITE(STR,740) (NMGR(K),K=1,11)
      CALL MSGDOC(MM,STR)
      IF(NSMT.GT.0) THEN
        CALL MSGDOC(MM,' ')
        WRITE(STR,741) (RFAC11(K),K=1,11)
        CALL MSGDOC(MM,STR)
        WRITE(STR,743) (RFAC31(K),K=1,11)
        CALL MSGDOC(MM,STR)
        WRITE(STR,740)  (NMGRSM(K),K=1,11)
        CALL MSGDOC(MM,STR)
      ENDIF
      IF(NSMTA.GT.0) THEN
        CALL MSGDOC(MM,' ')
        WRITE(STR,742) (RFAC21(K),K=1,11)
        CALL MSGDOC(MM,STR)
        WRITE(STR,744) (RFAC41(K),K=1,11)
        CALL MSGDOC(MM,STR)
        WRITE(STR,740)  (NMGRSA(K),K=1,11)
        CALL MSGDOC(MM,STR)
      ENDIF
      IF(NPR.GT.0) THEN
        CALL MSGDOC(MM,' ')
        WRITE(STR,747)  (RFAC51(K),K=1,11)
        CALL MSGDOC(MM,STR)
        WRITE(STR,740)  (NMGRPR(K),K=1,11)
        CALL MSGDOC(MM,STR)
        CALL MSGDOC(MM,' ')
      ENDIF
      IF(NRFR.GT.0) THEN
        CALL MSGDOC(MM,' ')
        WRITE(STR,748) (RFAC61(K),K=1,11)
        CALL MSGDOC(MM,STR)
        WRITE(STR,740) (NMGRRP(K),K=1,11)
        CALL MSGDOC(MM,STR)
      ENDIF
      CALL MSGDOC(MM,' ')
      WRITE(STR,746)
  746 FORMAT(' ANGSTR:5.5   6.0   6.5   7.',
     *   '0   7.5   8.0   8.5   9.0   9.5  10.0  10.5  11.0')
      CALL MSGDOC(MM,STR)
      WRITE(STR,740) (NMGR(K),K=12,22)
      CALL MSGDOC(MM,STR)
      IF(NSMT .GT.0) THEN
        CALL MSGDOC(MM,' ')
        WRITE(STR,741) (RFAC11(K),K=12,22)
        CALL MSGDOC(MM,STR)
        WRITE(STR,743) (RFAC31(K),K=12,22)
        CALL MSGDOC(MM,STR)
        WRITE(STR,740)  (NMGRSM(K),K=12,22)
        CALL MSGDOC(MM,STR)
      ENDIF
      IF(NSMTA.GT.0) THEN
        CALL MSGDOC(MM,' ')
        WRITE(STR,742) (RFAC21(K),K=12,22)
        CALL MSGDOC(MM,STR)
        WRITE(STR,744) (RFAC41(K),K=12,22)
        CALL MSGDOC(MM,STR)
        WRITE(STR,740)  (NMGRSA(K),K=12,22)
        CALL MSGDOC(MM,STR)
      ENDIF
      IF(NPR.GT.0) THEN
        CALL MSGDOC(MM,' ')
        WRITE(STR,747)  (RFAC51(K),K=12,22)
        CALL MSGDOC(MM,STR)
        WRITE(STR,740)  (NMGRPR(K),K=12,22)
        CALL MSGDOC(MM,STR)
        CALL MSGDOC(MM,' ')
      ENDIF
      IF(NRFR.GT.0) THEN
        CALL MSGDOC(MM,' ')
        WRITE(STR,748) (RFAC61(K),K=12,22)
        CALL MSGDOC(MM,STR)
        WRITE(STR,740) (NMGRRP(K),K=12,22)
        CALL MSGDOC(MM,STR)
      ENDIF

C ------------------
      RESULT(1,1)=NREF
      RESULT(4,1)=DELF
      RESULT(5,1)=NSMT
      RESULT(6,1)=NSMTT
      RESULT(11,1)=DELRFR
      IF(IPRROW.GE.21) THEN
        RESULT(12,1)=NRFR
        RESULT(13,1)=NRFRT
        RESULT(21,1)=NOUT
      ENDIF
      N = IPRROW22
      IF(IPRROW.LT.N) N = IPRROW
      DO I=1,N
        RESULT(I,2)=RESLT1(I)
        RESULT(I,3)=RESLT3(I)
      ENDDO
      RETURN
C--------
  400 FORMAT(1X,'NUMB REFLS                   =',I6)
  406 FORMAT(1X,'NUMB SYMM REFLS(HKL)         =',I6,
     * '(before average',I6,')')
 1406 FORMAT(1X,'Rmerge INT(HKL)-SYMM         =',E12.4,
     .          ' S(!I-IAVER!)/S(I)')
  416 FORMAT(1X,'R-FAC-STAND S(SD)/S(I)       =',E12.4)
  417 FORMAT(1X,'R-FAC-STAND S(SD)/S(I)       =',E12.4)
  407 FORMAT(1X,'NUMB SYMM-ANOM-REFLS(-H-K-L) =',I6,
     *'(before average',I6,')')          
 1407 FORMAT(1X,'Rmerge INT(-H-K-L)-SYMM-ANOM =',E12.4)
  409 FORMAT(1X,'NUMB OF REPEATING REFLS      =',I6,
     * '(before average',I6,')')
 1409 FORMAT(1X,'Rmerge INT-multiple          =',E12.4,
     .       ' S(!I-IAVER!)/S(I)')
  408 FORMAT(1X,'NUMB PAIRS (I(HKL),I(-H-K-L))=',I6)
 1408 FORMAT(1X,'R-FAC                         =',E12.4,
     .      ' 2*S(!I1-I2!)/S(I1+I2)')
  410 FORMAT(1X,'NUMB OF NON-CENTR REFLS      =',I6)
 1410 FORMAT(1X,'R-FAC INT-NON-CENTRS.        =',E12.4,
     .       ' S(!I-IAVER!)/S(I)')
  411 FORMAT(1X,'NUMB OF CENTRSYM. REFLS      =',I6)
 1411 FORMAT(1X,'R-FAC INT-CENTRSYM.          =',E12.4,
     .       ' S(!I-IAVER!)/S(I)')
C ----------------------------------------------
      END

      SUBROUTINE SORTPH(MT,NAME,LINE,IARRH,IARRS,ARRF,ARRS
     * ,MAXREF,NUMBT,NEQ,RLATT,NSYM,ISYM,IPRSYM,RESMIN,RESMAX,IERR)
C ------------------------------------------------------------------
CMS     : IARRH,IARRS,ARRF,ARRS
      INTEGER    IARRH(MAXREF),IARRS(MAXREF)
      REAL       ARRF (MAXREF),ARRS (MAXREF)
      REAL       RLATT(6)
      CHARACTER  LINE*(*),NAME*(*)
      INTEGER*2  ISYM(5,3,IPRSYM)
      INTEGER    NMGR(22)
      CHARACTER  ITPF*4,STR*80
      EXTERNAL  UNPACK
C==================================================================
      PI=3.1415926
      DO     I=1,22
        NMGR(I)=0
      ENDDO
      IPRNT=0
C ---------------------------------------------------
100   CONTINUE
      IF(RESMAX.GT.RESMIN) THEN
        STOR=RESMIN
        RESMIN=RESMAX
        RESMAX=STOR
      ENDIF
      IF(RESMIN.EQ.RESMAX) GO TO 100
      IF(RESMIN.LE.0.0) GO TO 100
      IF(RESMAX.LE.0.0) GO TO 100
      RHMIN=1./RESMIN
      RHMAX=1./RESMAX
C ------------------------------------------------------------
      NREF  =0
      NBL   =0
      IEND  =-1
C -------------------------------
      ITPF='PH  '
      CALL WRITET(MT,MTOUT,NAME,LINE,ITPF,RLATT,RESMIN,RESMAX
     *    ,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) RETURN
C------------------------------------------------------
C     MTOUT=11
      IHOLD =-512
      IKOLD =-512
      ILOLD =-512
      I     =0
      NOUT=0
C==========================================================================
      DO     IJKLM=1,NUMBT
        I=I+1
        IDBL =IARRH(I)
        CALL UNPACK(IDBL,NH,NK,NL)
        CALL DSTAR(NH,NK,NL,RS)
        RH=SQRT(RS)
        IF(RH.LT.RHMIN.OR.RH.GT.RHMAX) THEN
          NOUT=NOUT+1
          GO TO 430
        ENDIF
        IF(RH.GT.1.E-8) THEN
          IRGR=1.0/(RH*0.5)
          IRGR=IRGR+1
          IF(IRGR.GT.22) IRGR=22
        ELSE
          IRGR=22
        ENDIF
        ISTATUS=IARRS(I)/(256*256)
        ITEMP  =IARRS(I)-ISTATUS*(256*256)
        JJSYM  =ITEMP/256
        NFL    =ITEMP-JJSYM*256
        JJSYM  =JJSYM-128
        JSYM =IABS(JJSYM)
        FFF  =ARRF(I)
        SSS  =ARRS(I)
        IF(IHOLD.EQ.NH.AND.IKOLD.EQ.NK.AND.ILOLD.EQ.NL) GO TO 430
C ------------------
        IH=NH
        IK=NK
        IL=NL
        PHI=FFF-1.0
        FOM =SSS-1.0
        NREF=NREF+1
        NMGR(IRGR)=NMGR(IRGR)+1
        IF(IPRNT.GT.0) THEN
          IF(MOD(NREF,IPRNT).EQ.0) THEN
            WRITE(STR,'(''  N,H,K,L,PH,m:'',I6,2X,3I5,2E12.4)')
     .             NREF,IH,IK,IL,PHI,FOM
            CALL MSGDOC(M,STR)
          ENDIF
        ENDIF
        IF(FOM.LT.0.00001) GO TO 431
        ANG=(PHI*3.1415926)/180.0
        COSPH=COS(ANG)*FOM
        SINPH=SIN(ANG)*FOM
        IF(JJSYM.LT.0) SINPH=-SINPH
        IF(JSYM.NE.1) THEN
          TEMP= IH*(REAL(ISYM(4,1,JSYM))/REAL(ISYM(5,1,JSYM)))
     *         +IK*(REAL(ISYM(4,2,JSYM))/REAL(ISYM(5,2,JSYM)))
     *         +IL*(REAL(ISYM(4,3,JSYM))/REAL(ISYM(5,3,JSYM)))
          ANG=2.0*PI*TEMP
          COST=COS(ANG)
          SINT=SIN(ANG)
          TEMP =COSPH*COST-SINPH*SINT
          SINPH=COSPH*SINT+SINPH*COST
          COSTH=TEMP
        ENDIF
        IF(MTOUT.GT.0) THEN
          NBL=NBL+1
          KEY=0
          CALL WRT(MTOUT,IH,IK,IL,COSPH,SINPH,KEY,IEND)
          IF(MTOUT.LE.0) THEN
            IERR=1
            RETURN
          ENDIF
        ENDIF
 431    CONTINUE
        IHOLD=NH
        IKOLD=NK
        ILOLD=NL
  430   CONTINUE
      ENDDO
C--------------------------------------------
560   IEND=2
      IF(MTOUT.GT.0) THEN
        CALL WRT(MTOUT,IH,IK,IL,FMOD,FMODA,NBL,IEND)
      ENDIF
C -------------
      M=MT
      IF(MT.GE.0.AND.MT.LT.99) M=0
      WRITE(LINE,400) NREF
      CALL MSGDOC(M,LINE)
  400 FORMAT(1X,'NUMB REFLS                   =',I6)
      CALL MSGDOC(M,' ')
      WRITE(LINE,730)
  730 FORMAT(' ANGSTR:2.5   3.0   3.5   4.',
     *   '0   4.5   5.0   5.5   6.0   6.5   7.0   7.5   8.0')
      CALL MSGDOC(M,LINE)
      WRITE(LINE,740) (NMGR(K),K=6,16)
  740 FORMAT(' N      ',11I6)
      CALL MSGDOC(M,LINE)
C--------
      M=99
      IF(MT.NE.0.AND.MT.LT.99) M=-1      
      WRITE(STR,400) NREF
      CALL MSGDOC(M,STR)
      WRITE(STR,745)
  745 FORMAT(' ANGSTR:0.0   0.5   1.0   1.',
     *   '5   2.0   2.5   3.0   3.5   4.0   4.5   5.0   5.5')
      CALL MSGDOC(M,STR)
      WRITE(STR,740) (NMGR(K),K=1,11)
      CALL MSGDOC(M,STR)
      CALL MSGDOC(M,' ')
      WRITE(STR,746)
  746 FORMAT(' ANGSTR:5.5   6.0   6.5   7.',
     *   '0   7.5   8.0   8.5   9.0   9.5  10.0  10.5  11.0')
      CALL MSGDOC(M,STR)
      WRITE(STR,740) (NMGR(K),K=12,22)
      CALL MSGDOC(M,STR)
C ------------------
      RETURN
      END

      SUBROUTINE WRITET(MT,MTOUT,NAME,LINE,ITPF,RLATT,RESMIN,RESMAX
     *    ,NSYM,ISYM,IPRSYM,IERR)
      REAL      RLATT(6),RESMIN,RESMAX
      INTEGER*4 IERR,MT
      INTEGER*2 ISYM(5,3,IPRSYM)
      CHARACTER ITPF*4
      CHARACTER NAME*(*),LINE*(*)
C -----------------------------------------
C ------
      COMMON/CRYSTL/ A_CELL,B_CELL,C_CELL,AL_CELL,BE_CELL,GA_CELL
     *              ,A_STAR,B_STAR,C_STAR,COALST,COBEST,COGAST
     *              ,SIALST,SIBEST,SIGAST
     *              ,FRTOCR,CRTOFR,VOLUME
     *              ,PDB_SCALE,PDB_U
     *              ,NSP_GROUP,N_SETT,PDB_MODEL
     *              ,PDB_CODE,PDB_NAME,PDB_DATE
     *              ,PDB_RESL,PDB_RFAC
     *              ,SP_GROUP,USER_TITLE
C -
      REAL      FRTOCR(3,3),CRTOFR(3,3),VOLUME
      REAL      PDB_SCALE(3,3),PDB_U(3) 
      INTEGER*4 NSP_GROUP,N_SETT,PDB_MODEL
      CHARACTER PDB_CODE*4,PDB_NAME*40,PDB_DATE*9 
      CHARACTER PDB_RESL*40,PDB_RFAC*40
      CHARACTER SP_GROUP*24,USER_TITLE*80
C -------
C ---------------------------------------------
c      RESMIN=RESMIN+0.001
c      RESMAX=RESMAX-0.001
      COEF  =1.0
      B     =0.0
      MTOUT=11
      M=-ABS(MT)-1
      CALL C_CR_WR
      CALL SET_TITLE(M,RLATT(1),RLATT(2),
     *  RLATT(3),RLATT(4),RLATT(5),RLATT(6),COEF,B,RESMIN,RESMAX,
     *  IDM,IDM,IDM,IDM,IDM,LINE,IERR)
      CALL OWFILE(M,MTOUT,NAME,ITPF,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.GT.0) THEN
        RETURN
      ENDIF
      RETURN
      END

      SUBROUTINE PRESFPDB(MDOC,FILE_PDB,FILE_CIF,IERR)
C ------------------------------------------------------------
      INTEGER*4 MDOC,IERR
      CHARACTER FILE_PDB*(*),FILE_CIF*(*)
C -----------------------------------------------------------
C    presfPDB - convert file of Structure Factors with PDB-format to CIFile.
C   
C
C  Dialog and Batch: 
C
C    FILE_SF_PDB  - input formatted PDB file of struture factors.
C                   (also simple formatted file with "h,k,l,!F!,sig(F)" 
C                    or "h,k,l,!F!,sig(F)" and without titles is acceptable)
C    FILE_SF_CIF  - output CIFile.
C
C  Parameters of subroutine PRESFPDB: 
C
C      SUBROUTINE PRESFPDB(MDOC,FILE_PDB,FILE_CIF,IERR)
C
C    MDOC   - mode of writting messages to DOC-file
C             0 - only terminal , < - 0 only file, 0 < < 99 - both
C             >= 99 - don't write  
C    FILE_SF_PDB  - input formatted PDB file of struture factors.
C    FILE_SF_CIF  - output CIFile.
C    IERR   - output signal of error / = 1 -error , = 0 - OK / 
C 
C -----------------------------------------------------------
      PARAMETER ( NWORDSMAX = 40 )
      COMMON /COM3FREAD/ FWORDS,IFRD_ERR,NWORDS,LEN_WORDS,IWORDS
     *                 ,WORDS,IN_STRING
      REAL      FWORDS   (NWORDSMAX)
      INTEGER*4 LEN_WORDS(NWORDSMAX)
      INTEGER*4 IWORDS   (NWORDSMAX)
      INTEGER*4 NWORDS,IFRD_ERR
      CHARACTER WORDS(NWORDSMAX)*80
      CHARACTER IN_STRING*256
C --------------------------------------------------------------
C ----
      CHARACTER LINE*256,STR*256,PATH*1,EXT*3,CODE*4
      CHARACTER CONTENT*256,FORM*80,CH1*1,LINE1*256,CHAR1*1
C==================================================================
      IERR   = 0
      NREFLS = 0
      MD     =-ABS(MDOC)-1
      M      = 99
      MT     = 10
      PATH   = ' '
      EXT    = ' '
      CONTENT = ' '
      LENC   = 0
      LENF   = 0
      CALL OPENFR(MT,M,PATH,FILE_PDB,EXT,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MD,' ERR: CAN NOT OPEN INPUT_SF_FILE')
        CLOSE(MT)
        RETURN
      ENDIF
      CODE=FILE_PDB(1:4)
C ---------------------------
      IFORM  = 0
      IFIRST = 0
 800  CONTINUE
      READ(MT,'(A)',END=100,ERR=200) STR
      CALL LENSTR_BL(STR,LEN)
      IF(IFIRST.EQ.0) THEN
        LINE1=STR
        IF(LEN.LE.0) GO TO 800
        IF(LEN.GT.0) THEN
          NB=0
          DO I=1,LEN
            IF(STR(I:I).EQ.' ') THEN
              NB=NB+1 
            ELSE
              GO TO 801
            ENDIF
          ENDDO
 801      CONTINUE
          IF(NB.GT.0) THEN
            DO I=1,LEN-NB
              LINE1(I:I)=STR(NB+I:NB+I)
            ENDDO
          ENDIF
        ENDIF
        IF(LINE1(1:1).EQ.'#') GO TO 800
        CALL REMOVE_FIRST_BLANC(LINE1)
      ENDIF

      IF(IFIRST.EQ.0.AND.LINE1(1:5).EQ.'data_') THEN
        CALL MSGDOC(MDOC,' ---  This is CIFile ----')
        FILE_CIF=FILE_PDB
        CLOSE(MT)
        RETURN
      ELSE
        IFIRST=1
        CALL MSGDOC(MDOC
     *  ,' ---  This is PDB_file of structure factors ---')
        CALL MSGDOC(MDOC
     *  ,'      Program will try to make scratch CIFile: "toblanc.cif"')
        CALL MSGDOC(MDOC
     *  ,'      and to convert it to the internal BLANC format.')
      ENDIF
      IF(STR(1:8).EQ.'*HEADER ') THEN

        CALL LENSTR_BL(STR,LEN)
        IF(LEN.GT.0) THEN
          CALL MSGDOC(MDOC,STR(1:LEN))
        ENDIF

 300    CONTINUE 
        READ(MT,'(A)',END=100,ERR=200) STR
        CALL LENSTR_BL(STR,LEN)
C        IF(LEN.GT.0) THEN
C          CALL MSGDOC(MDOC,STR(1:LEN))
C        ENDIF
        IF(STR(1:8).EQ.'*CONTNT ') THEN
          CALL LENSTR_BL(CONTENT,LENC)
          IF(LENC.GT.0) THEN
            CONTENT=CONTENT(1:LENC)//' '//STR(11:LEN) 
          ELSE
            CONTENT=' '//STR(11:LEN) 
          ENDIF              
          LENC=LENC+LEN+1
        ELSE IF(STR(1:8).EQ.'*FORMAT ') THEN
          IF(STR(LEN:LEN).NE.')') THEN
            STR(LEN+1:LEN+1)=STR(LEN+1:LEN+1)//')'
            LEN=LEN+1 
          ENDIF 
          FORM=STR(11:LEN)
          IF(STR(11:11).NE.'(') FORM='('//STR(11:LEN) 
          CALL LENSTR_BL(FORM,LENF)
        ELSE IF(STR(1:1).NE.'*') THEN
          GO TO 400
        ENDIF
        GO TO 300
      ELSE IF(STR(1:1).EQ.'*'.OR.STR(1:1).EQ.'#') THEN
        GO TO 800
      ELSE
        CALL MSGERR(MDOC,' ERR: unknown format of SF_PDB_file')
        CALL MSGERR(MDOC,'      Program will try to make CIFile')
        IFORM=-1
      ENDIF       
C ---------------------------
 400  CONTINUE  
C      IF(LENF.LE.0) THEN        
C        CALL MSGERR(MDOC,
C     *  ' ERR: can not find "FORMAT" card in SF_PDB_file')
C        IERR=1
C        CLOSE(MT)
C        RETURN
C      ENDIF
      IF(IFORM.GE.0) THEN
        IF(LENC.LE.0) THEN
          CALL MSGERR(MDOC,
     *    ' ERR: can not find "CONTNT" card in SF_PDB_file')
          IERR=1
          CLOSE(MT)
          RETURN
        ENDIF
        CALL CHECK_CNTNT(CONTENT,IPH,IPK,IPL,IFOBS,IFSIG
     *   ,IPHASE,IFCALC,IFORM)
        IF(IFORM.EQ.0) THEN
          CALL MSGERR(MDOC,
     *    ' ERR: can not read "CONTNT" card in SF_PDB_file')
          IERR=1
          CLOSE(MT)
          RETURN
        ENDIF
      ENDIF
C ---------------------------------------------------
      REWIND MT
      JERR=0
      MTOUT=11
      PATH=' '
      EXT =' '
      CALL OPENFW(MTOUT,M,PATH,FILE_CIF,EXT,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERR: CAN NOT OPEN SF_CIF_FILE')
        CLOSE(MT)
        CLOSE(MTOUT)
        RETURN
      ENDIF
      LINE='data_structure_'//CODE
      CALL LENSTR_BL(LINE,LEN)
      WRITE(MTOUT,'(A)',ERR=700) LINE(1:LEN)
      LINE='_entry.id '//CODE
      CALL LENSTR_BL(LINE,LEN)
      WRITE(MTOUT,'(A)',ERR=700) LINE(1:LEN)
      LINE='loop_'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(MTOUT,'(A)',ERR=700) LINE(1:LEN)
      IF(IFORM.GT.0) THEN
        DO I=1,IFORM
          IF(IPH.EQ.I) THEN
            LINE='_refln.index_h'
            CALL LENSTR_BL(LINE,LEN)
            WRITE(MTOUT,'(A)',ERR=700) LINE(1:LEN)
          ELSE IF(IPK.EQ.I) THEN
            LINE='_refln.index_k'
            CALL LENSTR_BL(LINE,LEN)
            WRITE(MTOUT,'(A)',ERR=700) LINE(1:LEN)
          ELSE IF(IPL.EQ.I) THEN
            LINE='_refln.index_l'
            CALL LENSTR_BL(LINE,LEN)
            WRITE(MTOUT,'(A)',ERR=700) LINE(1:LEN)
          ELSE IF(IFOBS.EQ.I) THEN
            LINE='_refln.F_meas_au'
            CALL LENSTR_BL(LINE,LEN)
            WRITE(MTOUT,'(A)',ERR=700) LINE(1:LEN)
          ELSE IF(IFSIG.EQ.I) THEN
            LINE='_refln.F_meas_au_sigma'
            CALL LENSTR_BL(LINE,LEN)
            WRITE(MTOUT,'(A)',ERR=700) LINE(1:LEN)
          ELSE IF(IPHASE.EQ.I) THEN
            LINE='_refln.phase_calc'
            CALL LENSTR_BL(LINE,LEN)
            WRITE(MTOUT,'(A)',ERR=700) LINE(1:LEN)
          ELSE IF(IFCALC.EQ.I) THEN
            LINE='_refln.F_calc'
            CALL LENSTR_BL(LINE,LEN)
            WRITE(MTOUT,'(A)',ERR=700) LINE(1:LEN)
          ELSE 
            WRITE(CH1,'(I1)') I-1
            LINE='_refln.dm'//CH1
            CALL LENSTR_BL(LINE,LEN)
            WRITE(MTOUT,'(A)',ERR=700) LINE(1:LEN)
          ENDIF
        ENDDO
      ELSE
        LINE='_refln.index_h'
        CALL LENSTR_BL(LINE,LEN)
        WRITE(MTOUT,'(A)',ERR=700) LINE(1:LEN)
        LINE='_refln.index_k'
        CALL LENSTR_BL(LINE,LEN)
        WRITE(MTOUT,'(A)',ERR=700) LINE(1:LEN)
        LINE='_refln.index_l'
        CALL LENSTR_BL(LINE,LEN)
        WRITE(MTOUT,'(A)',ERR=700) LINE(1:LEN)
        LINE='_refln.F_meas_au'
        CALL LENSTR_BL(LINE,LEN)
        WRITE(MTOUT,'(A)',ERR=700) LINE(1:LEN)
      ENDIF
C ---------------------------
      IFORM2=IFORM*2
      IFORM3=IFORM*3
      IFORM4=IFORM*4
      IFIRST=0
      ICOUNT=0
 500  CONTINUE
      LINE=' '
      READ(MT,'(A)',END=600,ERR=200) STR
      CALL LENSTR_BL(STR,LEN)
      IF(LEN.GT.0) THEN

        IF(LEN.GT.256.AND.IFIRST.EQ.0) THEN
          JERR=1
          IFIRST=1
          WRITE(LINE,'('' ERR: Length of records > 256'')') 
          CALL MSGERR(MDOC,LINE)
        ENDIF
         
        IF(STR(1:1).EQ.'*') THEN
          STR(1:1)='#'
          IF(NREFLS.EQ.0) THEN
            CALL MSGDOC(MDOC,STR(1:LEN))
          ENDIF
        ELSE
          IF(NREFLS.EQ.0) THEN
            IF(ICOUNT.LT.3) THEN
              CALL MSGDOC(MDOC,STR(1:LEN))
            ENDIF
            ICOUNT=ICOUNT+1
          ENDIF
          DO J=1,LEN
            CHAR1 = STR(J:J)
            CALL CHKSMB(CHAR1,CH1)
            IF(CH1.NE.'D'.AND.CH1.NE.'S'.AND.
     *        STR(J:J).NE.'.') THEN
              STR(J:J)=' '
            ENDIF
          ENDDO
          IN_STRING=STR(1:LEN)
          CALL FRD_4PARM
          IF(NREFLS.EQ.0) THEN
            IF(NWORDS.LE.0) GO TO 500
            IF(IFORM.GT.0) THEN
              IF(NWORDS.NE.IFORM .AND.NWORDS.NE.IFORM2.AND.
     *           NWORDS.NE.IFORM3.AND.NWORDS.NE.IFORM4) THEN
c                JERR=1
                IF(ICOUNT.LT.3) THEN
                  CALL MSGERR(MDOC
     *            ,' ERR: wrong number of items in SF_PDB_FILE')
                  CALL MSGERR(MDOC
     *            ,'      check SF_CIFile and maybe run again')
                ENDIF
                ICOUNT=ICOUNT+1
              ENDIF
            ELSE IF(IFORM.LT.0) THEN
              IF(NWORDS.LT.4) THEN
c                JERR=1
                IF(ICOUNT.LT.3) THEN
                  CALL MSGERR(MDOC
     *            ,' ERR: wrong number of items in SF_PDB_FILE')
                  CALL MSGERR(MDOC
     *            ,'      check SF_CIFile and maybe run again')
                ENDIF
                ICOUNT=ICOUNT+1
                IFORM=4
              ELSE IF(NWORDS.EQ.5) THEN
                LINE='_refln.F_dm'
                CALL LENSTR_BL(LINE,LN)
                WRITE(MTOUT,'(A)',ERR=700) LINE(1:LN)
                IFORM=5
              ELSE IF(NWORDS.GT.5) THEN
                LINE='_refln.dm'
                CALL LENSTR_BL(LINE,LN)
                WRITE(MTOUT,'(A)',ERR=700) LINE(1:LN)
                DO J=1,NWORDS-5
                  WRITE(CH1,'(I1)') J-1
                  LINE='_refln.dm'//CH1
                  CALL LENSTR_BL(LINE,LN)
                  WRITE(MTOUT,'(A)',ERR=700) LINE(1:LN)
                ENDDO
                IFORM=NWORDS
              ELSE
                IFORM=4
              ENDIF
              IFORM2=IFORM*2
              IFORM3=IFORM*3
              IFORM4=IFORM*4
            ENDIF
          ENDIF
          IF(NWORDS.LE.0) GO TO 500
          IF(IFORM.LE.0)  GO TO 500
          IF(NWORDS.NE.IFORM .AND.NWORDS.NE.IFORM2.AND.
     *    NWORDS.NE.IFORM3.AND.NWORDS.NE.IFORM4) THEN
            L=LEN_WORDS(1)
            STR=WORDS(1)(1:L)
            LS=L
            NF=IFORM
C           IF(NWORDS.GT.IFORM2) NF=IFORM2
C           IF(NWORDS.GT.IFORM3) NF=IFORM3
C           IF(NWORDS.GT.IFORM4) NF=IFORM4
            DO I=2,NF
              L=LEN_WORDS(I)
              STR=STR(1:LS)//' '//WORDS(I)(1:L)
              LS=LS+L+1
            ENDDO
            LEN=LS
          ENDIF
          NREFLS=NREFLS+1
        ENDIF
        WRITE(MTOUT,'(A)',ERR=700) STR(1:LEN)
      ENDIF
      GO TO 500
 600  CONTINUE
      IERR=JERR
      END FILE MTOUT
      CLOSE(MT)
      CLOSE(MTOUT)
      WRITE(LINE,'('' Number of records :'',I8)') NREFLS
      CALL MSGDOC(MDOC,LINE)
      IF(NREFLS.LE.1) THEN
        IERR=1
        WRITE(LINE,'('' ERR: Number of records :'',I8)') NREFLS
        CALL MSGERR(MDOC,LINE)
      ENDIF
      RETURN
C ---------------------------
 100  CALL MSGERR(MDOC,' ERR: END OF SF_PDB_FILE')
      CLOSE(MT)
      IERR=1
      RETURN
C ---------------------------
 200  CALL MSGERR(MDOC,' ERR: READ SF_PDB_FILE')
      CLOSE(MT)
      IERR=1
      RETURN
C ---------------------------
 700  CALL MSGERR(MDOC,' ERR: WRITE SF_CIF_FILE')
      CLOSE(MT)
      IERR=1
      RETURN
C ---------------------------
      END

      SUBROUTINE CHECK_CNTNT(STR,IPH,IPK,IPL,IFOBS,IFSIG
     *   ,IPHASE,IFCALC,IFORM)
      CHARACTER STR*(*)
      INTEGER   IPH,IPK,IPL,IFOBS,IFSIG,IFORM,IPHASE
C -----------------------------------------------------------
      PARAMETER ( NWORDSMAX = 40 )
      COMMON /COM3FREAD/ FWORDS,IFRD_ERR,NWORDS,LEN_WORDS,IWORDS
     *                 ,WORDS,IN_STRING
      REAL      FWORDS   (NWORDSMAX)
      INTEGER*4 LEN_WORDS(NWORDSMAX)
      INTEGER*4 IWORDS   (NWORDSMAX)
      INTEGER*4 NWORDS,IFRD_ERR
      CHARACTER WORDS(NWORDSMAX)*80
      CHARACTER IN_STRING*256
C --------------------------------------------------------------
C -------------------------------------------------------
      IPH=0
      IPK=0
      IPL=0
      IFOBS=0
      IFSIG=0
      IFORM=0
      IFMEAN=0
      IPHASE=0
      IFCALC=0
      IN_STRING=STR
      CALL FRD_3PARM

      IF(NWORDS.LT.4) RETURN

      DO I=1,NWORDS
        IF(LEN_WORDS(I).EQ.1.AND.WORDS(I)(1:1).EQ.'H') IPH=I
        IF(LEN_WORDS(I).EQ.1.AND.WORDS(I)(1:1).EQ.'K') IPK=I
        IF(LEN_WORDS(I).EQ.1.AND.WORDS(I)(1:1).EQ.'L') IPL=I
        IF(LEN_WORDS(I).EQ.4.AND.WORDS(I)(1:2).EQ.'FP') IFOBS=I
        IF(LEN_WORDS(I).EQ.4.AND.WORDS(I)(1:4).EQ.'FOBS') IFOBS=I
        IF(LEN_WORDS(I).EQ.5.AND.WORDS(I)(1:5).EQ.'FMEAN')IFMEAN=I
        IF(LEN_WORDS(I).GE.5.AND.WORDS(I)(1:5).EQ.'SIGMA') IFSIG=I
        IF(LEN_WORDS(I).GE.9.AND.WORDS(I)(1:9).EQ.'ABS(FOBS)')IFOBS=I
        IF(LEN_WORDS(I).GE.5.AND.WORDS(I)(1:5).EQ.'PHASE')IPHASE=I
        IF(LEN_WORDS(I).GE.5.AND.WORDS(I)(1:5).EQ.'FCALC')IFCALC=I
      ENDDO        
      IF(IFOBS.EQ.0) IFOBS=IFMEAN
      IF(IPH.EQ.0.OR.IPK.EQ.0.OR.IPL.EQ.0.OR.IFOBS.EQ.0) THEN
        IFORM=0
      ELSE
        IFORM=NWORDS
      ENDIF

      RETURN
      END

      SUBROUTINE FRD_3PARM
C -------------------------------------------------------
C     FRD_3PARM - free format reading of the string of characters.
C                See common /COM3FREAD/
C
C     input:     IN_STRING - input string; a word is the part of the string
C                            between two blancs or two "'" or ",".
C     output:    NWORDS    - number of words of the string
C                IWORDS    - array of integer value of each word.
C                FWORDS    - array of real value of each word.
C                WORDS     - array of words
C                LEN_WORDS - array of lengths of the words
C                IFRD_ERR  - signal of error. 
C                            0  means OK.
C                            1 - number of words > NWORDSMAX = 40
C 
C -----------------------------------------------------------
      PARAMETER ( NWORDSMAX = 40 )
      COMMON /COM3FREAD/ FWORDS,IFRD_ERR,NWORDS,LEN_WORDS,IWORDS
     *                 ,WORDS,IN_STRING
      REAL      FWORDS   (NWORDSMAX)
      INTEGER*4 LEN_WORDS(NWORDSMAX)
      INTEGER*4 IWORDS   (NWORDSMAX)
      INTEGER*4 NWORDS,IFRD_ERR
      CHARACTER WORDS(NWORDSMAX)*80
      CHARACTER IN_STRING*256
C --------------------------------------------------------------
      REAL      FA
      INTEGER*4 NW,IS,IW,IAP,LEN,IP,IA
      CHARACTER CH*1,CK*1,STR*80
C --------------------------------------------------------------
      IFRD_ERR=0
      NWORDS=0
      NW=0
      IW=0
      IS=0
      IAP=0
      CALL LENSTR_BL(IN_STRING,LEN)
      IF(LEN.LE.0) RETURN
      IF(LEN.GT.256) LEN=256
C -----------------
      LN=0
      DO   IP=1,LEN
        CH=IN_STRING(IP:IP)
        CALL CHKSMB(CH,CK)
        IF(CK.EQ.'?') CH=' '
        IF(CH.NE.' ') THEN
          LN=LN+1
          IN_STRING(LN:LN)=CH
        ENDIF
      ENDDO
      LEN=LN
      DO   IP=1,LEN
        CH=IN_STRING(IP:IP)
        IF(CH.EQ.'''') THEN
          IAP=IAP+1
          IF(IAP.GE.2) IAP=0
        ENDIF
        IF(CH.EQ.',') CH=' '
        IF(CH.NE.' '.OR.IAP.EQ.1) THEN
C         start of a word
          IF(IS.EQ.0) THEN
            IS=1
            NW=NW+1
            IF(NW.GT.20) THEN
              IFRD_ERR=1
              RETURN
            ENDIF
          ENDIF
          IF(CH.NE.'''') THEN
            IW=IW+1
            STR(IW:IW)=CH       
          ELSE
            IF(IW.GT.0) THEN
            ENDIF
          ENDIF
        ENDIF
        IF((CH.EQ.' '.AND.IS.EQ.1.AND.IAP.EQ.0).OR.
     *       (IP.EQ.LEN.AND.IW.NE.0)) THEN
          IF(IW.LE.0) THEN
            WORDS(NW)='?'
            LEN_WORDS(NW)=1
          ELSE
            WORDS(NW)=STR(1:IW)
            LEN_WORDS(NW)=IW
          ENDIF
          NWORDS=NW
          CALL WTODIG(STR,IW,FA,IA)
          IWORDS(NW)=IA
          FWORDS(NW)=FA
          IS=0
          IW=0
          IAP=0
        ENDIF
      ENDDO
C -----------------
      RETURN
      END      

      SUBROUTINE FRD_4PARM
C -------------------------------------------------------
C    FRD_4PARM - free format reading of the string of characters.
C                See common /COM3FREAD/
C
C     input:     IN_STRING - input string; a word is the part of the string
C                            between two blancs or two "'" or "," or " ".
C     output:    NWORDS    - number of words of the string
C                IWORDS    - array of integer value of each word.
C                FWORDS    - array of real value of each word.
C                WORDS     - array of words
C                LEN_WORDS - array of lengths of the words
C                IFRD_ERR  - signal of error. 
C                            0  means OK.
C                            1 - number of words > NWORDSMAX = 40
C 
C -----------------------------------------------------------
      PARAMETER ( NWORDSMAX = 40 )
      COMMON /COM3FREAD/ FWORDS,IFRD_ERR,NWORDS,LEN_WORDS,IWORDS
     *                 ,WORDS,IN_STRING
      REAL      FWORDS   (NWORDSMAX)
      INTEGER*4 LEN_WORDS(NWORDSMAX)
      INTEGER*4 IWORDS   (NWORDSMAX)
      INTEGER*4 NWORDS,IFRD_ERR
      CHARACTER WORDS(NWORDSMAX)*80
      CHARACTER IN_STRING*256
C --------------------------------------------------------------
      REAL      FA
      INTEGER*4 NW,IS,IW,IAP,LEN,IP,IA
      CHARACTER CH*1,CK*1,STR*80
C --------------------------------------------------------------
      IFRD_ERR=0
      NWORDS=0
      NW=0
      IW=0
      IS=0
      IAP=0
      CALL LENSTR_BL(IN_STRING,LEN)
      IF(LEN.LE.0) RETURN
      IF(LEN.GT.256) LEN=256
C -----------------
      DO   IP=1,LEN
        CH=IN_STRING(IP:IP)
        CALL CHKSMB(CH,CK)
        IF(CK.EQ.'?') CH=' '
        IF(CH.EQ.'''') THEN
          IAP=IAP+1
          IF(IAP.GE.2) IAP=0
        ENDIF
        IF(CH.EQ.',') CH=' '
        IF(CH.NE.' '.OR.IAP.EQ.1) THEN
C         start of a word
          IF(IS.EQ.0) THEN
            IS=1
            NW=NW+1
            IF(NW.GT.20) THEN
              IFRD_ERR=1
              RETURN
            ENDIF
          ENDIF
          IF(CH.NE.'''') THEN
            IW=IW+1
            STR(IW:IW)=CH       
          ELSE
            IF(IW.GT.0) THEN
            ENDIF
          ENDIF
        ENDIF
        IF((CH.EQ.' '.AND.IS.EQ.1.AND.IAP.EQ.0).OR.
     *       (IP.EQ.LEN.AND.IW.NE.0)) THEN
          IF(IW.LE.0) THEN
            WORDS(NW)='?'
            LEN_WORDS(NW)=1
          ELSE
            WORDS(NW)=STR(1:IW)
            LEN_WORDS(NW)=IW
          ENDIF
          NWORDS=NW
          CALL WTODIG(STR,IW,FA,IA)
          IWORDS(NW)=IA
          FWORDS(NW)=FA
          IS=0
          IW=0
          IAP=0
        ENDIF
      ENDDO
C -----------------
      RETURN
      END      



      SUBROUTINE RMS_LUZZ(RRES,RRFAC,RMS)
C
C      THE UPPER ESTIMATE IN THE ERROR IN ATOMIC POSITIONS
C
C       input:  RES ( in angstrom), from 0.05 to 10.0
C               RFAC (for example 0.20), from 0.01 to .60
C       output: RMS (in angstrom)
C
       REAL RM(2),RF(2)
C ----------------------------------
       RMS=0.0
       RFAC=RRFAC
       RES=RRES
       IF(RFAC.LT.0.01)   RFAC=0.01
       IF(RFAC.GT.0.60)   RFAC=.60
       IF(RES.GT.10.0)    RES=10.0
       IF(RES.LT.0.05)    RES=0.05
       RM(2)= 2.0
       RM(1)= 0.01
       CALL RF_LUZZ(RES,RM(1),RF(1))
c       write(*,*) ' --1- rms,rfc,res:',RM(1),RF(1),RES
       CALL RF_LUZZ(RES,RM(2),RF(2))
c       write(*,*) ' --2- rms,rfc,res:',RM(2),RF(2),RES

       DO   I=1,1000      
         D=RF(2)-RF(1)
         IF(D.LT.0.001) GO TO 100           
         RMS=((RFAC-RF(1))*(RM(2)-RM(1)))/D+RM(1)
C         write(*,*) ' i,res,rms:',I,RES,RMS
         CALL RF_LUZZ(RES,RMS,RFC)
C         write(*,*) ' r-fac:',RFC
         IF(RFC.GT.RFAC) THEN
           RF(2) =RFC
           RM(2) =RMS
         ELSE
           RF(1) =RFC
           RM(1) =RMS
         ENDIF
       ENDDO
100    CONTINUE
      RETURN
      END

      SUBROUTINE RF_LUZZ(RRESOL,RRMS,RFAC)
C ------------------------
      REAL*8 SUM,RM
C ------------------------
       PI=3.14159265359
       RMS=RRMS
       RESOL=RRESOL
       IF(RMS.LT.0.01)   RMS=0.01
       IF(RMS.GT.2.0)    RMS=2.0
       IF(RESOL.GT.10.0)  RESOL=10.0
       IF(RESOL.LT.0.05)  RESOL=0.05
       S=1.0/RESOL
       TEMP=-PI*PI*PI*S*S*RMS*RMS*0.25
       D=EXP(TEMP)
       IF(D.LE.0.OR.D.GT.1) THEN
         RFAC=0.0
         RETURN
       ENDIF
       SUM=0.0
       DELTA=PI/1000.0
       N=1000
       DO    I=1,N
         GAM=COS(I*DELTA)
         RM=(2+(12*D*GAM-4)/(2-2*D*GAM)**1.5)/(1+D*GAM)**2
         SUM=SUM+DELTA*RM
       ENDDO
       SUMM=SUM
       RFAC=(1-D*D)**1.5*SUMM/PI
      RETURN
      END



C -I-   
      SUBROUTINE PSCALE(MDOC,F_NAME,F2_NAME,FO_NAME
     * ,BOFFR,BADDR,MODE,RESTR,RFACD
     * ,RESMNIR,RESMXIR,ISYM,IPRSYM,RESULT,IPRROW,IERR)
C 
C -P- PSCALE - scaling by origine peak of Patterson.
C              Program calculates Boverall factor by Patterson or
C              by Wilson plot, calculates parameters of scaling
C              Scale & Thermal factor for file_1, restores missing
C              reflections in file_1 (to use reflections from file_2),
C              defines effective resolution, writes scaled !F! of file_1
C              to output file. Without file_2 program just restore missing
C              reflections by Faver, B_overal defined by Patterson.
C              Can scale two files with different unit cell.
C -S-
C      Dialog and Batch:
C
C     FILE_F: - input file of the modules of structure factors for scaling.
C     FILE_2: - input second file / test file/
C               without this file program will only restore missing
C               reflections by Faver, B_overal defined by Patterson.
C     FILE_O: - output file / scaled file / 
C     RESOL: MIN,MAX  - resolution /default from input file/
C     MODE: <P>/W  scaling: "W" by Wilson plot, "P" by Patterson
C     REST: <N>/Y/O , Y - restore missing refls to get its from file_2
C                     O - restore by Faver, B_overal defined by Patterson
C                         Resolution for restoration: 1)input or 2)from file-2
C                         without file-2: REST: <N>,O , resolution 1) input
C                         or 2) from file-1.       
C     BOFF:    <0> , 256 corresponds to RESmin=8 
C     BADD:    <0> , BOFF and BADD mean :
C            !F!new = !F!input *EXP(-BADD*RSQ)*(1-EXP(-BOFF*RSQ)
C
C       It is possible to use the subroutine PSCALE by program:
C
C      SUBROUTINE PSCALE(MDOC,F_NAME,F2_NAME,FO_NAME
C     * ,BOFF,BADD,MODE,REST,RFACD
C     * ,RESMNI,RESMXI,ISYM,IPRSYM,RESULT,IPRROW,IERR)
C
C  Parameters of subroutine: 
C
C    MDOC  - mode of writting messages to DOC-file
C            0 - only terminal , < - 0 only file, 0 < < 99 - both
C            >= 99 - don't write  
C    F_NAME  - input file of the modules of structure factors.
C    F2_NAME - second input file.
C    FO_NAME - output file.
C    RESMNI  - resolution MIN  
C    RESMXI               MAX
C    MODE    <P>/W  scaling: "W" by Wilson plot, "P" by Patterson
C    REST    <N>/Y/O , Y - restore missing refls to get its from file_2
C                      O - restore by Faver, B_overal defined by Patterson
C    RFACD    /character*1/ dummy
C    BOFF    <0>     - 256 corresponds to RESmin=8 
C    BADD    <0>     - BOFF and BADD mean :
C                       !F!new = !F!input *EXP(-BADD*RSQ)*(1-EXP(-BOFF*RSQ)
C    ISYM    - integer*2 array for cryst.symmetry operators.
C    IPRSYM  - dimension of integer*2 array ISYM(5,3,IPRSYM),
C              number of cryst. symm. operators.
C    IERR    - output signal of error / =1 -error , =o - OK / 
C
C    RESULT /real RESULT(IPRROW,21) / - array for output information:
C
C     i = 1 - information about !F! of file_1
C     i = 2 - information about !F! of file_2
C     
C
C      RESULT(1,i)  =NREF    N_refls
C      RESULT(2,i)  =RESMNI  min resolution
C      RESULT(3,i)  =RESMXI  max resolution
C      RESULT(4,i)  =LAP     sqrt(<s^2*F>)*4*pi^2/VOL for complete data set
C      RESULT(5,i)  =DT      <u>_patt 
C      RESULT(6,i)  =BSUM    B_patt  = 8pi^2*<u>_patt^2
C      RESULT(7,i)  =DTR     <u>_res = Resmax/3
C      RESULT(8,i)  =BRES    Bres    = 4*<u>_res^2
C      RESULT(9,i)  =DTFOUR  <u>_four= <u>_patt/sqrt(2)
C      RESULT(10,i) =BEFF    Beff    = 4*RESeff^2
C      RESULT(11,i) =RESEFF  RESeff  = <u>_four*2*sqrt(2)
C      RESULT(12,i) =SF2     sqrt(<F^2>)/VOL
C      RESULT(13,i) =SF4     sqrt(<F^4>)/VOL
C      RESULT(14,i) =SH2F    sqrt(<s^2*F>)*4*pi^2/(VOL*A^2) curvature(x)
C      RESULT(15,i) =COMPL   completeness
C      RESULT(16,i) =RESEFF_COMP  RESeff for complete data set
C      RESULT(17,i) =LAP     sqrt(<s^2*F>)*4*pi^2/VOL
C      RESULT(18,i) =FSCALE  Scale    for !F! by Wilson plot
C      RESULT(19,i) =BTEMP   Boverall for !F! by Wilson plot
C      RESULT(20,i) =RESN    Resmin for scaling by Wilson Plot
C      RESULT(21,i) =SCALE   P(000) /Patterson/
C      
C      RESULT(1,3)  =scale1P
C      RESULT(2,3)  =btemp1P
C      RESULT(3,3)  =scale2P
C      RESULT(4,3)  =btemp2P
C      RESULT(10,3) = ERR_MIN    
C      RESULT(11,3) =RFAC_FREE
C      RESULT(12,3) =DPI_VAL     
C      RESULT(13,3) =ERR_MAX     
C      RESULT(14.3) =NUMGP    
C      RESULT(15,3) =BOFF     
C      RESULT(16,3) =BADD     
C      RESULT(17,3) =RCORR  - correlation factor   
C      RESULT(18,3) =CSCALE - Scaling F_out = F_2*cscale*exp(-bscale*S^2/4)
C      RESULT(19,3) =BSCALE
C      RESULT(20,3) =R-FAC  - R-factor
C
C      RESULTA(I,4)= RHRP(I)
C      RESULTA(I,5)= RES_EFF(I)
C      RESULTA(I,6)= RES_EFF_B0(I)
C      RESULTA(I,7)= ERR_MIN(I)
C
C      RESULTA(I,8)=RHRP(I)
C      RESULTA(I,9)=ERR_MAX(I)
C -I-
C ------------------------------
      INTEGER*2 ISYM(5,3,IPRSYM)
      REAL      RESULT(IPRROW,*)
      REAL      RESMNI,RESMXI
      INTEGER*4 MDOC,NUMGP,IERR
      CHARACTER F_NAME*(*),F2_NAME*(*),FO_NAME*(*),MODE*1,TITLE1*80
      CHARACTER REST*1,RESTR*1,MISS*1,NAME*256,RFACD*1,RFAC*1
      CHARACTER NAME_SCL*256,MSG*1,ITYP*4
C ==============================
      CHARACTER LINE*80,TITLE*80
C -----------------------------------------------------------
      MSG  ='Y'
      IF(ABS(MDOC).EQ.999) MSG='N'      
C --
      NATOM= IERR
      IERR = 0
C --
      MD   =-ABS(MDOC)-1
      M    = 99
C -------------------------------------------------------------
      DO I=1,IPRROW
      DO J=1,9
        RESULT(I,J)=0.0
      ENDDO
      ENDDO
C ---
      REST=RESTR
      BADD=BADDR
      BOFF=BOFFR
      IF(BOFF.LT.0.000001) BOFF=256
      RESMNI=RESMNIR
      RESMXI=RESMXIR
      RFAC='Y'
      IF(REST.EQ.'y') REST='Y'
      IF(REST.EQ.'o') REST='O'
      IF(REST.NE.'Y'.AND.REST.NE.'O') REST='N'
      MISS='N'
      IF(MODE.EQ.'w') MODE='W'
      IF(MODE.NE.'W') MODE='P'
      COEF=0.0
      NUMGP=20
C -----------------------------------------------------------
      ITYP  ='FF  '
      CALL LENSTR_BL(F_NAME,LEN)
      IF(LEN.LE.0.OR.F_NAME(1:1).EQ.' '.OR.F_NAME(1:1).EQ.',') THEN
        IERR=1
        RETURN
      ELSE
        MTIN=10
        CALL ORFILE(MD,MTIN,F_NAME,ITYP,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MDOC,' ERROR: OPEN FILE-F /for scaling/')
          RETURN
        ENDIF
        CALL GET_TITLE(MD,A,B,C,AL,BE,GA
     *  ,COEF1,BET1,RESMIN,RESMAX,IDM,IDM,IDM,IDM,IDM,TITLE,IERR)
        CLOSE(MTIN)
      ENDIF
      IF(RESMNI.LT.1.E-5 ) RESMNI=RESMIN
      IF(RESMXI.LT.1.E-5 ) RESMXI=RESMAX
      IF(RESMXI.GT.RESMAX) RESMXI=RESMAX
      IF(RESMNI.LT.RESMIN) RESMNI=RESMIN
C ---------
      ITYP  ='FF  '
      CALL LENSTR_BL(F2_NAME,LEN)
      IF(LEN.LE.0.OR.F2_NAME(1:1).EQ.' '.OR.F2_NAME(1:1).EQ.',') THEN

      ELSE
        MTIN=10
        CALL ORFILE(MD,MTIN,F2_NAME,ITYP,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MDOC,' ERROR: OPEN FILE-F /test-file/')
          RETURN
        ENDIF
        CALL GET_TITLE(MD,A2,B2,C2,AL2,BE2,GA2
     *  ,COEF2,BET2,RESMIN2,RESMAX2,IDM,IDM,IDM,IDM,IDM,TITLE,IERR)
        CLOSE(MTIN)
        IF(RESMNI.GT.RESMIN2) RESMNI=RESMIN2
        IF(RESMNI.LT.RESMAX2) RESMXI=RESMAX2
      ENDIF

      CALL MSGDOC(MDOC,' ')
      CALL MSGDOC(MDOC,' --------  checking file_1 --------')
      CALL MSGDOC(MDOC,' ')
      CALL CHECK_PATT(MDOC,F_NAME
     *  ,NUMGP,COEF,BOFF,BADD,MISS,RESULT_S,RESULT_B
     *  ,RESMNI,RESMXI,ISYM,IPRSYM,RESULT(1,1),RESULT,IPRROW,IERR)
      IF(IERR.NE.0) RETURN

      FSCALE      = RESULT(18,1) 
      BTEMP       = RESULT(19,1)
      RESULT(1,3) = RESULT_S
      RESULT(2,3) = RESULT_B 
      SCALEP      = SQRT(RESULT(1,3)) 
      PBTEMP      = RESULT( 2,3)/2.0 
      NAME        = ' '
      NAME_SCL    = F_NAME
C -------------------------------------------------------------
      IFILE2=0
      ITYP  ='FF  '
      CALL LENSTR_BL(F2_NAME,LEN)
      IF(LEN.LE.0.OR.F2_NAME(1:1).EQ.' '.OR.F2_NAME(1:1).EQ.',') THEN
        IF(REST.EQ.'Y') REST='O'
        NAME=' '
        IF(MODE.EQ.'W') THEN
          CSCALE=1.0
          BSCALE=0.0
          BOVER=BTEMP
          FAVER=FSCALE
        ELSE
          BSCALE=0.0
          CSCALE=1.0
          BOVER=PBTEMP
          FAVER=SCALEP
        ENDIF
        GO TO 100
      ENDIF
      CALL MSGDOC(MDOC,' ')
      CALL MSGDOC(MDOC,' --------  checking file_2 --------')
      CALL MSGDOC(MDOC,' ')
      MTIN  = 10
      ITYP  = 'FF  '
      CALL ORFILE(MD,MTIN,F2_NAME,ITYP,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERROR: OPEN FILE-F-2 /test-file/')
        RETURN
      ENDIF
      CALL GET_TITLE(MD,A2,B2,C2,AL2,BE2,GA2
     *,COEF2,BET2,RESMIN2,RESMAX2,IDM,IDM,IDM,IDM,IDM,TITLE,IERR)
      CLOSE(MTIN)
      DA  = ABS(A-A2)
      DB  = ABS(B-B2)
      DC  = ABS(C-C2)
      DAL = ABS(AL-AL2)
      DBE = ABS(BE-BE2)
      DGA = ABS(GA-GA2)
      IF(DA.GT.1.0.OR.DB.GT.1.0.OR.DC.GT.1.0.OR.DAL.GT.0.03.OR.
     *   DBE.GT.0.03.OR.DGA.GT.0.03) THEN
        IF(MSG.EQ.'Y')
     *  CALL MSGERR(MD,' WARNING: different unit cell parameters')
        RFAC='N'
        IF(REST.EQ.'Y') REST='O'
      ELSE
        RFAC='Y'
      ENDIF
      CALL CHECK_PATT(MDOC,F2_NAME
     * ,NUMGP,COEF,BOFF,BADD,MISS,RESULT_S,RESULT_B
     * ,RESMNI,RESMXI,ISYM,IPRSYM,RESULT(1,2),RESULT,IPRROW,IERR)
      IF(IERR.NE.0) RETURN

      FSCALE2     = RESULT(18,2) 
      BTEMP2      = RESULT(19,2) 
      RESULT(3,3) = RESULT_S
      RESULT(4,3) = RESULT_B 
      PSCALE2     = SQRT(RESULT(3,3)) 
      PBTEMP2     = RESULT( 4,3)/2.0 

      IF(MODE.EQ.'W') THEN
        BSCALE = BTEMP2-BTEMP
        CSCALE = (FSCALE2/FSCALE)
        BOVER  = BTEMP2
        FAVER  = FSCALE2
      ELSE
        BSCALE = PBTEMP2-PBTEMP
        CSCALE = (PSCALE2/SCALEP)
        BOVER  = PBTEMP2
        FAVER  = PSCALE2
      ENDIF

      NAME     = F2_NAME
      NAME_SCL = F_NAME
      IF(RFAC.EQ.'N') THEN
        NAME    =' '
      ENDIF
      IFILE2=1
C ---
  100 CONTINUE
      IF(IFILE2.GT.0) THEN
        IF(MODE.EQ.'W') THEN
          TITLE1='by Wilson plot'
        ELSE
          TITLE1='by Patterson'
        ENDIF
        CALL LENSTR_BL(TITLE1,LEN)
        CALL MSGDOC(MDOC,' ')
        LINE=' ----  scaling '//TITLE1(1:LEN)//'  ----'
        CALL MSGDOC(MDOC,LINE)
        CALL MSGDOC(MDOC,' ')
        WRITE(LINE,
     *'('' Scaling of file_1: SCALE,BTEMP:'',2G12.4)') CSCALE,BSCALE
        CALL MSGDOC(MDOC,LINE)
      ELSE
         IF(REST.EQ.'N') RETURN 
      ENDIF
C ---
      CALL LENSTR_BL(FO_NAME,LEN)
      IF(LEN.GT.0.AND.FO_NAME(1:1).NE.' '.AND.FO_NAME(1:1).NE.',')
     *THEN
        CALL MSGDOC(MDOC,' ')
        CALL MSGDOC(MDOC
     *   ,' ----   writing to output file   ----')
        CALL MSGDOC(MDOC,' ')
      ENDIF

      RESMNI=0.0
      RESMXI=0.0
      IF(RESMNIR.GT.1.E-5)  RESMNI=RESMNIR
      IF(RESMXIR.GT.1.E-5)  RESMXI=RESMXIR

      CALL WRT_PSCLF(MDOC,NAME,NAME_SCL,FO_NAME,FAVER,BOVER
     * ,REST,BOFF,BADD,CSCALE,BSCALE,NUMGP,RESULT(1,3),RESULT
     * ,IPRROW,RESMNI,RESMXI,ISYM,IPRSYM,NATOM,IERR)
      RETURN
      END

      SUBROUTINE CHECK_PATT(MDOC,F_NAME
     * ,NUMGPR,COEFR,BOFFR,BADDR,MISSR,RESULT_S,RESULT_B
     * ,RESMNIR,RESMXIR,ISYM,IPRSYM,RESULT,RESULTA,IPRROW,IERR)
C ------------------------------
      INTEGER*2 ISYM(5,3,IPRSYM)
      REAL      RESULT(IPRROW)
      REAL      RESULTA(IPRROW,*)
      REAL      RESMNI,RESMXI
      INTEGER*4 MDOC,NUMGP,IERR
      CHARACTER F_NAME*(*),MISS*1,MISSR*1
C ==============================
      INTEGER*4 MTIN
      REAL      RLATT(6),DISTR(41),AVERF(40),SUMF20(40),RHRP2(40)
      REAL      AVERF2(40),SUMN(40),SUMFNT(40),SUMH2F(40)
      REAL      SUMA(40),SUMB(40),SUMC(40),SUMD(40),SUME(40)
      REAL      SUMH2F2T(40),AVERF2T(40),SUMAT(40),AVERFT(40)
      REAL      AVERF2T0(40),SUMSIG2(40),SUMSIG0(40),SUMH2F2(40)
      REAL      RHR(41),SUMF2(40),SUMFN(40),SUMF(40),RHRP(41)
      REAL      SUMR(40)
      CHARACTER ITYP*4
      CHARACTER LINE*80,TITLE*80,TITLE1*80
C -----------------------------------------------------------
      PI   =4.0*ATAN(1.0)
      TWOPI=2.0*PI
      IERR =0
      MD   =-ABS(MDOC)-1
      M    = 99
C -----------------------------------------------------------
      NUMGP=NUMGPR
      COEF =COEFR
      BOFF =BOFFR
      BADD =BADDR
      RESMNI=RESMNIR
      RESMXI=RESMXIR
      MTIN=20
      ITYP  ='FF  '
      CALL LENSTR_BL(F_NAME,LEN)
      IF(LEN.LE.0.OR.F_NAME(1:1).EQ.' '.OR.F_NAME(1:1).EQ.',') THEN
        CALL MSGERR(MDOC,' ERROR: wrong name of FILE-F')
        IERR=1
        RETURN
      ENDIF
      CALL ORFILE(M,MTIN,F_NAME,ITYP,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERROR: open FILE-F')
        RETURN
      ENDIF
      CALL GET_TITLE(M,A,B,C,AL,BE,GA
     *  ,COEF1,BET1,RESMIN,RESMAX,IDM,IDM,IDM,IDM,IDM,TITLE,IERR)
C -------------------------------------------------------------
      IF(RESMNI.LT.1.E-5)  RESMNI=RESMIN
      IF(RESMXI.LT.1.E-5)  RESMXI=RESMAX
      IF(RESMXI.LT.RESMAX) RESMXI=RESMAX
      IF(RESMNI.GT.RESMIN) RESMNI=RESMIN
      WRITE(LINE,
     *'(''Resolution       :'',2F10.2)') RESMNI,RESMXI
      CALL MSGDOC(MDOC,LINE)
C ---
      CALL C_RD_CR
      RLATT(1)=A
      RLATT(2)=B
      RLATT(3)=C
      RLATT(4)=AL
      RLATT(5)=BE
      RLATT(6)=GA
      CALL DSTARF(RLATT,AST,BST,CST,COALST,COBEST,COGAST,VOL)
C ---
      IF(COEF.LE.0.0) COEF=1.5
      WRITE(LINE,
     *'(''Boff,Badd        :'',2F10.2)') BOFF,BADD
      CALL MSGDOC(MDOC,LINE)
C ---
      IF(NUMGP.LE. 0) NUMGP=20
      IF(NUMGP.GT.20) NUMGP=20
      WRITE(LINE,
     *'(''Number of shells :'',I7)') NUMGP
      CALL MSGDOC(MDOC,LINE)
C ---
      CALL ANOMF(M,NSYM,ISYM)
      CALL LIMHKL(RESMXI,IHMAX,IKMAX,ILMAX,NXMIN,NYMIN,NZMIN)
C ----------------------------------------------------------------
C     ----   Scaling by Wilson plot ------------------
      RESN=RESMNI
      RESX=RESMXI
      IF(RESX.LE.3.0.AND.RESN.GE.6.0) THEN
        RESN=6.0
      ENDIF 
      IF(RESX.LE.2.0.AND.RESN.GE.5.0) THEN
        RESN=5.0
      ENDIF 
      IF(RESX.GT.3.0.AND.RESX.LT.6.0.AND.RESN.GE.20.0) THEN
        RESN=20.0
      ENDIF 
      RHMIN=1.0/RESN
      RHMAX=1.0/RESX
      DO    K=1,NUMGP
        SUMF2  (K) =0.
        SUMFN  (K) =0.
        SUMFNT (K) =0.
      ENDDO
      DELTRH=(RHMAX-RHMIN)/NUMGP
      IH    =0
      IK    =0
      IL    =-1
      IFIRST=0
      IEND  =-1
      NUMB  =0
      NREF  =0
      NTOT  =0
      MISS  ='N'
      KEY   =0
      IHMAX1=IHMAX+1
      IKMAX1=IKMAX+1
      ILMAX1=ILMAX+1

C --------------------------------------
      DO     ILP=0,ILMAX1
      DO     IKP=-IKMAX1,IKMAX1
      DO     IHP=-IHMAX1,IHMAX1
        IF(IHP.EQ.0.AND.IKP.EQ.0.AND.ILP.EQ.0) GO TO 300
        IIHP=IHP
        IIKP=IKP
        IILP=ILP
        CALL ANOMSC(IIHP,IIKP,IILP,IANOM,JJSYM,NSYM,ISYM)
        IF(IANOM.NE.1.OR.JJSYM.NE.1) GO TO 300
        CALL SYSABS_BL(IHP,IKP,ILP,NSYM,ISYM,ICND)
        IF(ICND.NE.0) GO TO 300
        CALL DSTAR(IHP,IKP,ILP,RSQ)
        RH=SQRT(RSQ)
        IF(RH.LT.RHMIN.OR.RH.GT.RHMAX) GO TO 300
        K=(RH-RHMIN)/DELTRH+1.0
        IF(K.GT.NUMGP) K=NUMGP
        IF(K.LT.1) K=1     

 5060   IF(MTIN.LE.0)  THEN
          IERR=1
          RETURN
        ENDIF

        IF(IEND.GT.0) GO TO 5040

c        IF(IL-ILP) 5050,5010,5040
c 5010   IF(IK-IKP) 5050,5020,5040
c 5020   IF(IH-IHP) 5050,5030,5040

        IF((IL-ILP).LT.0) GO TO 5050
        IF((IL-ILP).EQ.0) GO TO 5010
        IF((IL-ILP).GT.0) GO TO 5040
 5010   IF((IK-IKP).LT.0) GO TO 5050
        IF((IK-IKP).EQ.0) GO TO 5020
        IF((IK-IKP).GT.0) GO TO 5040
 5020   IF((IH-IHP).LT.0) GO TO 5050
        IF((IH-IHP).EQ.0) GO TO 5030
        IF((IH-IHP).GT.0) GO TO 5040

 5040   CONTINUE
C       MISS REFL IHP,IKP,ILP   
        CALL DSTAR(IH,IK,IL,RSQI)
        RHI=SQRT(RSQI)
        IF(RHI.LT.RHMIN.OR.RHI.GT.RHMAX) GO TO 300
        CALL SYSABS_BL(IH,IK,IL,NSYM,ISYM,ICND)
        IF(ICND.NE.0) GO TO 300

        SUMFNT(K)=SUMFNT(K)+1
        NTOT=NTOT+1

        GO TO 300

 5050   CONTINUE

        IF(ITYP.EQ.'FS  ') THEN
          CALL RRD1(MTIN,IH,IK,IL,FN,FNA,SN,SNA,KEY,IEND)
        ELSE
          CALL RD1(MTIN,IH,IK,IL,FN,FNA,KEY,IEND)
C         SIG-DUMMY
          SN =0.04*FN
          SNA=0.04*FNA
        ENDIF
        IF(MTIN.LE.0) THEN
          CALL MSGERR(MDOC,' ERR: READ FILE_F')
          IERR=1
          RETURN
        ENDIF

        IF(IEND.GT.0)      GO TO 5060
        IF(FN.LE.1.E-6.AND.FNA.LE.1.E-6) GO TO 5060
        IF(FN.GT.1.E-6.AND.FNA.GT.1.E-6) THEN
          IF(SN .LT.0.000001) SN =1.0
          IF(SNA.LT.0.000001) SNA=1.0
          WT1=1./(SN*SN)
          WT2=1./(SNA*SNA)
          WT =WT1+WT2
          FN =FN*WT1+FNA*WT2
          FN =FN/WT
          SN =1./SQRT(WT)
        ELSE IF(FNA.GT.1.E-6) THEN
          FN =FNA
          SN =SNA
        ENDIF
        GO TO 5060

 5030   CONTINUE
        NREF=NREF+1
        NTOT=NTOT+1
        IF(BOFF.GT.0.0) THEN
          BT=BOFF/4.0
          CBOFF=1.0-EXP(-BT*RSQ)
        ELSE
          CBOFF=1.0
        ENDIF
        IF(ABS(BADD).GT.0.00001) THEN
          BT=BADD/4.0
          CBADD=EXP(-BT*RSQ)
        ELSE
          CBADD=1.0
        ENDIF
C        FN2       =FN*FN*CBOFF*CBOFF*CBADD*CBADD
        FN2       =FN*FN
        SUMF2 (K) =SUMF2(K)  +FN2
        SUMFN (K) =SUMFN(K) + 1
        SUMFNT(K) =SUMFNT(K)+ 1
  300   CONTINUE
      ENDDO
      ENDDO
      ENDDO
C ---
      IF(NREF.LE.0) THEN
        CALL MSGERR(MDOC
     *  ,' ERROR : number of reflections / for scaling / = 0')
        CLOSE (MTIN)
        IERR=1
        RETURN
      ENDIF
      DO I=1,NUMGP
        IF(SUMFN(I).LE.0) SUMFNT(I)=0.0
      ENDDO
C -----------------------
      CALL MSGDOC(MDOC,' ')
      CALL MSGDOC(MDOC,
     *' ----     Scaling by Wilson plot        ----')
      CALL MSGDOC(MDOC,' ')
      WRITE(LINE,200) RESN,RESX
 200  FORMAT(
     * 'Resolution /for scaling by Wilson plot/       :',2F7.2)
      CALL MSGDOC(MDOC,LINE)
      CALL TEMP_FLLL(SUMF2,SUMFN,NUMGP,RHMIN,DELTRH,FSCALE,BTEMP)
      BI     = BTEMP*2.0
      FSCLI  = FSCALE
      FSCALE = SQRT(FSCALE)
      WRITE(LINE,
     *'(''Scale,Boverall /for F by Wilson plot/         :'',2G12.4)' 
     * ) FSCALE,BTEMP
      CALL MSGDOC(MDOC,LINE)
      IF(BTEMP.LT.0.0) BTEMP=0.0
      UFOUR=SQRT(BTEMP/(8.0*PI*PI))
      UPATT=UFOUR*SQRT(2.0)
      CALL MSGDOC(MDOC,
     * 'corresponding displacement:')
      WRITE(LINE,
     *'(''<u>_four,<u>_patt                             :'',2G12.4)'
     *) UFOUR,UPATT 
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,
     *'(''Number of refls/for scaling/                  :'',I8)')NREF
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,
     *'(''Number of refls/total for scaling resolution /:'',I8)')NTOT
      CALL MSGDOC(MDOC,LINE)
      COMPL=0.0
      IF(NTOT.GT.0) COMPL=FLOAT(NREF)/FLOAT(NTOT)
      WRITE(LINE,
     *'(''Completeness/for scaling/                     :'',F9.3)')
     * COMPL
      CALL MSGDOC(MDOC,LINE)
C --------------------------------------
      CALL MSGDOC(MDOC,' ')
      WRITE(LINE,
     *'('' ---- Scaling by Patterson with Boff ='',F9.0,'' ----'')')
     * BOFF
      CALL MSGDOC(MDOC,LINE)
      CALL MSGDOC(MDOC,' ')
      ITYP  ='    '
      CALL OPFILE(M,MTIN,F_NAME,ITYP,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERROR: open FILE-F')
        RETURN
      ENDIF
C ---
      RHMIN=1.0/RESMNI
      RHMAX=1.0/RESMXI
      DMAX =(RESMXI/3.0)*2.0*COEF
      B=BTEMP
      IF(B.LT.0.0) B=0.0

      DMAX1=SQRT(B/(8.0*PI*PI))*2.0*COEF
      IF(DMAX1.GT.DMAX) DMAX=DMAX1
c      WRITE(LINE,1000) DMAX,VOL,DVOL
c 1000 FORMAT('D-max, VOL , 4/3*PI*Rmax^3:'
c     *  ,F7.2,1X,2G14.4)
c      CALL MSGDOC(MDOC,LINE)
C ---
      DELT =DMAX/NUMGP
      DO    K=1,NUMGP
        SUMA    (K) =0.
        SUMB    (K) =0.
        SUMF2   (K) =0.
        SUMF20  (K) =0.
        SUMFN   (K) =0.
        SUMFNT  (K) =0.
        SUMF    (K) =0.
        SUMSIG2 (K) =0.
        SUMSIG0 (K) =0.
        AVERF   (K) =0.
        AVERF2  (K) =0.
        AVERF2T0(K) =0.
        SUMH2F  (K) =0.
        SUMH2F2 (K) =0.
        SUMH2F2T(K) =0.
      ENDDO
      D=0
      DO    K=1,NUMGP+1
        DISTR(K)=D
        D=D+DELT
      ENDDO
      DELTRH=(RHMAX-RHMIN)/NUMGP
      RHR(1) =RHMIN
      RHRP(1)=1./RHMIN
      DO    I=2,NUMGP+1
        RHR(I)=RHR(I-1)+DELTRH
        RHRP(I)=1.0/RHR(I)
      ENDDO
      IH    = 0
      IK    = 0
      IL    =-1
      IFIRST= 0
      IEND  =-1
C
      NREF  = 0
      NTOT  = 0
      NREFA = 0
      NTOTA = 0
      NREAD = 0
      NREF0 = 0
      NSIG0 = 0
      NREF_ABS = 0
      NREF_OUT = 0
      NREF_MISS= 0
      NADD     = 0
      NF000    = 0
      NABS     = 0
C
      F000  =0.0
      SSIG  =0.0
      SF    =0.0
      SF2   =0.0
      SF20  =0.0
      SF4   =0.0
      SH2F  =0.0
      SH2S2 =0.0
      SH2   =0.0
      MISS  ='Y'
c ------------------------
      DO     ILP=0,ILMAX
      DO     IKP=-IKMAX,IKMAX
      DO     IHP=-IHMAX,IHMAX
        IF(IHP.EQ.0.AND.IKP.EQ.0.AND.ILP.EQ.0) GO TO 100
        IIHP=IHP
        IIKP=IKP
        IILP=ILP
        CALL ANOMSC(IIHP,IIKP,IILP,IANOM,JJSYM,NSYM,ISYM)
        IF(IANOM.NE.1.OR.JJSYM.NE.1) GO TO 100

        CALL SYSABS_BL(IHP,IKP,ILP,NSYM,ISYM,ICND)
        IF(NSYM.GT.1) THEN
          CALL SYSABS_BL(IHP,IKP,ILP,NSYM,ISYM,ICND)
        ELSE
          ICND=0
        ENDIF
        IF(ICND.NE.0) THEN
           GO TO 100
        ENDIF

        CALL DSTAR(IHP,IKP,ILP,RSQ)
        RH=SQRT(RSQ)
        IF(RH.LT.RHMIN.OR.RH.GT.RHMAX) THEN
          GO TO 100
        ENDIF

        IHT=IHP
        IKT=0
        ILT=0
        CALL DSTAR(IHT,IKT,ILT,RSQT)
        RHT=SQRT(RSQT)

        K=(RH-RHMIN)/DELTRH+1.0
        IF(K.GT.NUMGP) K=NUMGP
        IF(K.LT.1) K=1     

        CALL INDMLTT(IHP,IKP,ILP,NGEN,NSYM,ISYM)

 4060   IF(MTIN.LE.0)  THEN
          IERR=1
          RETURN
        ENDIF
        IF(IEND.GT.0) GO TO 4040

C        IF(IL-ILP) 4050,4010,4040
C 4010   IF(IK-IKP) 4050,4020,4040
C 4020   IF(IH-IHP) 4050,4030,4040

        IF((IL-ILP).LT.0) GO TO 4050
        IF((IL-ILP).EQ.0) GO TO 4010
        IF((IL-ILP).GT.0) GO TO 4040
 4010   IF((IK-IKP).LT.0) GO TO 4050
        IF((IK-IKP).EQ.0) GO TO 4020
        IF((IK-IKP).GT.0) GO TO 4040
 4020   IF((IH-IHP).LT.0) GO TO 4050
        IF((IH-IHP).EQ.0) GO TO 4030
        IF((IH-IHP).GT.0) GO TO 4040

 4040   CONTINUE

        CALL DSTAR(IH,IK,IL,RSQI)
        RHI=SQRT(RSQI)
        IF(RHI.LT.RHMIN.OR.RHI.GT.RHMAX) THEN
          NREF_OUT = NREF_OUT + 1
          GO TO 100
        ENDIF
        IF(NSYM.GT.1) THEN
          CALL SYSABS_BL(IHP,IKP,ILP,NSYM,ISYM,ICND)
        ELSE
          ICND=0
        ENDIF
        IF(ICND.NE.0) THEN
          NREF_ABS = NREF_ABS + 1
          GO TO 100
        ENDIF
        IF(MISS.EQ.'Y') THEN
          SUMFNT(K)=SUMFNT(K)+NGEN
          NTOT=NTOT+NGEN
        ENDIF
        NTOTA=NTOTA+1
        NREF_MISS = NREF_MISS + 1
        GO TO 100

 4050   CONTINUE
        IF(IFIRST.EQ.1) THEN
C         ADDITIONAL IL,IK,IL,REFLS
          IF(NSYM.GT.1) THEN
            CALL SYSABS_BL(IH,IK,IL,NSYM,ISYM,ICND)
          ELSE
            ICND=0
          ENDIF
          IF(ICND.NE.0) THEN 
            NABS = NABS + 1
            IFIRST=0
            GO TO 4050 
          ENDIF
          NADD = NADD + 1
          IFIRST=0
          CALL DSTAR(IH,IK,IL,RSQI)
          RHI=SQRT(RSQI)
          IF(RHI.LT.RHMIN.OR.RHI.GT.RHMAX) THEN
            NREF_OUT = NREF_OUT + 1
c            T=1/RHI
c            WRITE(*,*) IH,IK,IL,T,FN,SN
            IFIRST=0
            GO TO 4050 
          ENDIF
          GO TO 4050
        ENDIF
        IFIRST=1
        IF(ITYP.EQ.'FS  ') THEN
          CALL RRD1(MTIN,IH,IK,IL,FN,FNA,SN,SNA,KEY,IEND)
          IDUMMY_SIG=0
        ELSE
          CALL RD1(MTIN,IH,IK,IL,FN,FNA,KEY,IEND)
C         SIG-DUMMY
          IDUMMY_SIG=1
          SN =0.05*FN
          SNA=0.05*FNA
        ENDIF
        IF(MTIN.LE.0) THEN
          CALL MSGERR(MDOC,' ERROR: read FILE_F')
          IERR=1
          RETURN
        ENDIF
        IF(IEND.GT.0)                    GO TO 4040
        NREAD = NREAD+1
        IF(IH.EQ.0.AND.IK.EQ.0.AND.IL.EQ.0) THEN
          NF000=NF000+1
          F000 =FN
          IFIRST=0
          GO TO 4060
        ENDIF
        IF(FN.GT.1.E-6.AND.FNA.GT.1.E-6) THEN
          IF(SN .LT.0.000001) SN =1.0
          IF(SNA.LT.0.000001) SNA=1.0
          WT1=1./(SN*SN)
          WT2=1./(SNA*SNA)
          WT =WT1+WT2
          FN =FN*WT1+FNA*WT2
          FN =FN/WT
          SN =1./SQRT(WT)
        ELSE IF(FNA.GT.1.E-6) THEN
          FN =FNA
          SN =SNA
        ENDIF
        GO TO 4060

 4030   IFIRST=0
        IF(NSYM.GT.1) THEN
          CALL SYSABS_BL(IH,IK,IL,NSYM,ISYM,ICND)
        ELSE
          ICND=0
        ENDIF
        IF(ICND.NE.0) THEN
          NABS = NABS + 1
          IF(IFIRST.EQ.0) GO TO 100
          IFIRST=0
          GO TO 4050 
        ENDIF

        IF(FN.LE.1.E-8) THEN
          NREF0 = NREF0 + 1
          GO TO 100
        ENDIF

        IF(SN.LE.1.E-6) THEN
          NSIG0 = NSIG0 + 1 
          GO TO 100
        ENDIF


        NREF =NREF+NGEN
        NTOT =NTOT+NGEN
        NREFA=NREFA+1
        NTOTA=NTOTA+1
        IF(BOFF.GT.0.0) THEN
          BT=BOFF/4.0
          CBOFF=1.0-EXP(-BT*RSQ)
        ELSE
          CBOFF=1.0
        ENDIF
        IF(ABS(BADD).GT.0.00001) THEN
          BT=BADD/4.0
          CBADD=EXP(-BT*RSQ)
        ELSE
          CBADD=1.0
        ENDIF
        Y = CBOFF*CBADD
        FN2       =FN*FN*CBOFF*CBOFF*CBADD*CBADD
        SN2       =SN*SN*CBOFF*CBOFF*CBADD*CBADD
        SUMF2 (K) =SUMF2(K)   +FN2    *NGEN
        SUMF20(K) =SUMF20(K)  +FN*FN  *NGEN

        SUMH2F(K) =SUMH2F(K)  +RSQT*FN*NGEN*Y
        SUMSIG2(K)=SUMSIG2(K) +RSQT*SN*SN*NGEN*Y*Y

        SUMH2F2(K)=SUMH2F2(K) +RSQ *FN*NGEN
        SUMFN (K) =SUMFN(K)   +        NGEN
        SUMFNT(K) =SUMFNT(K)  +        NGEN
        SUMSIG0(K)=SUMSIG0(K) +SN     *NGEN
        SSIG      =SSIG       +SN     *NGEN
        SF        =SF         +FN     *NGEN
        SF20      =SF20       +FN*FN  *NGEN
        SF2       =SF2        +FN2    *NGEN
        SF4       =SF4        +FN2*FN2*NGEN

        SH2F      =SH2F       +RSQT*FN*NGEN*Y
        SH2S2     =SH2S2      +RSQT*SN*SN*NGEN*Y*Y

        SH2       =SH2        +RSQT   *NGEN
  100   CONTINUE
      ENDDO
      ENDDO
      ENDDO
C ---
      CLOSE (MTIN)
      IF(NREF.LE.0) THEN
        CALL MSGERR(MDOC,
     *  ' ERROR: CHECK_PATT number of reflections = 0')
        IERR=1
        RETURN
      ENDIF

C      IF(MISS.EQ.'Y'.AND.NTOT.NE.NREF) THEN
C        CALL MSGDOC(MDOC,
C     *  ' ---  Missing reflections will be included with F=0 ---')
C      ELSE
C        NTOT=NREF
C        DO I=1,NUMGP
C          SUMFNT(I)=SUMFN(I)
C        ENDDO
C      ENDIF
      A_CELL=A
      SF2   =(SQRT(SF2*2.0)        )/VOL
      SF4   =(SQRT(SF4*2.0)        )/VOL
      SH2S2 =(SQRT(SH2S2*8.0)*TWOPI)  /(VOL*A_CELL)
      SH2   =(SQRT(SH2  *4.0)*TWOPI)  /(VOL*A_CELL)
      SH2F  =((SH2F *2.0)*TWOPI*TWOPI)/(VOL*A_CELL*A_CELL)
      COMPL=1.0
      IF(NTOTA.GT.0) COMPL=FLOAT(NREFA)/FLOAT(NTOTA)
      RSTAND=0.0
      IF(NREF.GT.0) THEN
        SSIG=SSIG/NREF
        SF  =SF  /NREF
        SF20=SF20/NREF
        IF(SF.GT.0.0.AND.IDUMMY_SIG.LE.0) RSTAND=SSIG/SF
      ENDIF
      DO I=1,NUMGP
        AVERF2  (I)=0.0
        AVERF2T (I)=0.0
        AVERF2T0(I)=0.0
        IF(SUMFNT(I).GT.0.0) AVERF2T (I) =SUMF2 (I)/SUMFNT(I)
        IF(SUMFNT(I).GT.0.0) AVERF2T0(I) =SUMF20(I)/SUMFNT(I)
        IF(SUMFN(I) .GT.0.0) AVERF2  (I) =SUMF2 (I)/SUMFN(I)
        AVERF (I) =SQRT(AVERF2 (I))
        AVERFT(I) =SQRT(AVERF2T(I))
        SUMH2F2T(I)=0.0
        IF(SUMFN (I).GT.0.0) THEN
          SUMH2F2T(I)=(SUMH2F2(I)*SUMFNT(I))/SUMFN(I)
        ENDIF
      ENDDO
C -----------------------
      WRITE(LINE,
     *'(''Number of reflections / & total number/  :'',2I8)') 
     *NREFA,NTOTA
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,
     *'(''Numbers: In file,Sys.abs,Miss,RES_out    :'',4I8)') 
     * NREAD,NREF_ABS,NREF_MISS,NREF_OUT
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,
     *'(''Numbers: With_F=<0,With_sig=<0,Nadd,NF000:'',4I8)') 
     * NREF0,NSIG0,NADD,NF000
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,
     *'(''Resolution                               :'',2F8.3)') 
     *RESMNI,RESMXI
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,
     *'(''Completeness                             :'',F9.3)')COMPL
      CALL MSGDOC(MDOC,LINE)
      IF(NF000.GT.0) THEN
        WRITE(LINE,
     *  '(''F000                                     :'',G14.4)')
     *  F000
        CALL MSGDOC(MDOC,LINE)
      ENDIF
      WRITE(LINE,
     *'(''<F>,<F^2>                                :'',2G14.4)')
     *SF,SF20
      CALL MSGDOC(MDOC,LINE)
      IF(IDUMMY_SIG.LE.0) THEN
        WRITE(LINE,
     *  '(''<sig(F)>,R_stand(F) (<sig(F)>/<F>)       :'',G14.4,F9.3)')
     *  SSIG,RSTAND
        CALL MSGDOC(MDOC,LINE)
      ENDIF
c      WRITE(LINE,'(
c     *''rsm(F^2),rms(F^4)                        :'',2G14.4)')
c     * SF2,SF4
c      CALL MSGDOC(MDOC,LINE)

      WRITE(LINE,
     *'(''<Curvature>_of atomic peak               :'',G14.4)') 
     *SH2F 
      CALL MSGDOC(MDOC,LINE)
c      CALL MSGDOC(MDOC,'Curv(x) = 4pi^2*sum(h^2*F)/(VOL*A^2)')
c      WRITE(LINE,'(
c     *''sig(Ah):''
c     * ,G14.4)') SH2S2
c      CALL MSGDOC(MDOC,LINE)
c      WRITE(LINE,'(
c     *''4pi*sqrt(sum(h^2))/(VOL*A):''
c     * ,G14.4)') SH2
c      CALL MSGDOC(MDOC,LINE)

      T=0.0
      IF(SH2F.GT.0.0000001) T=(SH2S2*SQRT(3.0))/SH2F 
      WRITE(LINE,
     *'(''sig(r)/expected minimal coordinate error/:'',G14.4)') T
      CALL MSGDOC(MDOC,LINE)
      ERR_MIN=T
      IF(IDUMMY_SIG.GT.0) THEN
        CALL MSGDOC(MDOC,'with assumption <sig(F)>/<F> = 0.05')
      ENDIF
      CALL MSGDOC(MDOC,
     *'sig(r) = (4pi*A*sqrt(3*sum(h^2*sig(F)^2)))/VOL')

      WRITE(LINE,1000) VOL
 1000 FORMAT(
     * 'Volume of cell                           :',G14.4)
      CALL MSGDOC(MDOC,LINE)

      DVOL=(4.0*PI*RHMAX*RHMAX*RHMAX)/3.0
c      WRITE(LINE,1001) DVOL
c 1001 FORMAT(
c     * '4/3*PI*Rmax^3                            :',G14.4)
c      CALL MSGDOC(MDOC,LINE)


C -----------------------------------------------------
      CALL MSGDOC(MDOC,' ')
      CALL MSGDOC(MDOC,
     *' ----       <F> and Wilson plot(F)      ----')
      CALL MSGDOC(MDOC,' ')
      DO I=1,NUMGP
        RH=(RHR(I+1)-RHR(I))/2.0+RHR(I)
        RSQ=RH*RH
C        RSQ=RHR(I)*RHR(I)
c for F  
        FSC=FSCALE
        BT =BTEMP/4.0
c for I     
c        FSC=FSCLI
c        BT =BI/4.0
        X=FSC*EXP(-BT*RSQ)
        SUMA(I)= X
      ENDDO
      NF=2
      FMIN = 1.E30
      FMAX =-1.E30
      FFMAX=-1.E30
      DO I=1,NUMGP
C        SUMC(I)=AVERF2T0(I)/COMPL
C
         SUMC(I)=SQRT(AVERF2T0(I))/SQRT(COMPL)
        IF(SUMC(I).GT.FMAX)  FMAX =SUMC(I)
        IF(SUMC(I).GT.FFMAX) FFMAX=SUMC(I)
        IF(SUMC(I).LT.FMIN)  FMIN =SUMC(I)
        IF(SUMA(I).GT.FMAX)  FMAX=SUMA(I)
      ENDDO
      WRITE(LINE,'(''  min,max:'',2G14.4)') 
     *FMIN,FFMAX
      CALL MSGDOC(MDOC,LINE)
      TITLE1='  (*) <F>     (+) SCALE_F*EXP(-Bover*S^2)'
      IMSG=0
      FMIN=0
      CALL GRAPH_PP(MDOC,NUMGP,NF,RHRP,SUMC,SUMA,FMIN,FMAX,SUMFN
     *             ,TITLE1,IMSG)
C ------------------------------------------------
      CALL MSGDOC(MDOC,' ')
      CALL MSGDOC(MDOC,
     *' ---- ln(<I>)  and ln(Sc*exp(-Bov*s^2)) ----')
      CALL MSGDOC(MDOC,' ')
      S2MAX=RHMAX*RHMAX
      S2MIN=RHMIN*RHMIN
      DL   =(S2MAX-S2MIN)/NUMGP
      DO I=1,NUMGP

        S2  = S2MIN+DL*(FLOAT(I)-0.5)
        RH  = SQRT(S2)
        RHRP2(I)=1.0/RH
        RH  = (RH - RHMIN)/DELTRH
        IRH = RH
        FRH = RH-IRH
        IRH=IRH+1
        IF(IRH.LT.1    ) IRH=1
        IF(IRH.GT.NUMGP) IRH=NUMGP
        IRH1=IRH+1
        IF(IRH1.LT.1    ) IRH1=1
        IF(IRH1.GT.NUMGP) IRH1=NUMGP
C
C
        T1=AVERF2T0(IRH )/COMPL
        T2=AVERF2T0(IRH1)/COMPL
        T=(1.0-FRH)*T1+FRH*T2 
        IF(T.GT.0.0000001) THEN
          T=LOG(T)
        ELSE
          T=0.0
        ENDIF
        SUMC(I)=T
 
        RSQ=S2
        FSC=FSCLI
        BT=BI/4.0
        X=FSC*EXP(-BT*RSQ)
        IF(X.GT.0.00001) THEN
          SUMB(I)= LOG(X)
        ELSE
          SUMB(I)= 0.0
        ENDIF

      ENDDO

      NF=2
      FMIN= 1.E30
      FMAX=-1.E30   
      DO I=1,NUMGP
C       T=AVERF2T0(I)/COMPL
        IF(SUMC(I).GT.FMAX)  FMAX=SUMC(I)
        IF(SUMB(I).GT.FMAX)  FMAX=SUMB(I)
        IF(SUMC(I).LT.FMIN)  FMIN=SUMC(I)
        IF(SUMB(I).LT.FMIN)  FMIN=SUMB(I)
      ENDDO
      WRITE(LINE,'(''  min,max:'',2G14.4)') 
     *FMIN,FMAX
      CALL MSGDOC(MDOC,LINE)
      CALL CORR_MAX(FMAX,FMAXN)
      FFMAX=FMAX
      IF(ABS(FMIN).GT.FMAX) FFMAX=ABS(FMIN)     
      DO I=1,NUMGP
        T=0.0
        IF(FFMAX.GT.0.0) T=SUMC(I)/FFMAX
        SUMR(I)=T
      ENDDO

      TITLE1='  (*) ln(<I>) (+) ln(SCALE_I*EXP(-2Bover*S^2))'
      IMSG=1
      CALL GRAPH_PP(MDOC,NUMGP,NF,RHRP2,SUMC,SUMB,FMIN,FMAX,SUMR
     *             ,TITLE1,IMSG)
C -----------------------------------------
      CALL MSGDOC(MDOC,' ')
      CALL MSGDOC(MDOC,
     *' ---- sig(r) - expected minimal coordinate error     ----')
      CALL MSGDOC(MDOC,' ')
      IF(IDUMMY_SIG.GT.0) THEN
        CALL MSGDOC(MDOC,
     *'               with assumption <sig(F)>/<F> = 0.05')
      ENDIF
      S =0.0
      ST=0.0
      FFMIN= 1.E30
      FFMAX=-1.E30   
      FMIN = 1.E30
      FMAX =-1.E30   
      DO I=1,NUMGP
        SUMC(I)=0.0
        S =S +SUMSIG2(I)
        T =(SQRT(S*8.0)*TWOPI)/(VOL*A_CELL)
        ST=ST+SUMH2F (I)
        TT=((ST *2.0)*TWOPI*TWOPI)/(VOL*A_CELL*A_CELL)
        IF(TT.GT.0.000000001) THEN
          SUMC(I)=(T*SQRT(3.0))/TT
          IF(SUMC(I).GT.FFMAX) FFMAX = SUMC(I)
          IF(SUMC(I).LT.FFMIN) FFMIN = SUMC(I)
          IF(I.GT.5) THEN
            IF(SUMC(I).GT.FMAX) FMAX=SUMC(I)
            SUMR(I)=0.0
          ELSE
            SUMR(I)=10000000000000.0
          ENDIF
          IF(SUMC(I).LT.FMIN) FMIN =SUMC(I)
        ELSE
          SUMR(I)=10000000000000.0
        ENDIF

C        WRITE(LINE,'(''error,curv :'',2G14.4,F8.3)') 
C     *  SUMC(I),TT,RHRP(I+1)
C        CALL MSGDOC(MDOC,LINE)

      ENDDO

      NF=1

C      FMIN= 1.E30
C      FMAX=-1.E30   
C      DO I=1,NUMGP
C        IF(I.GT.5) THEN
C          IF(SUMC(I).GT.FMAX)  FMAX=SUMC(I)
C        ENDIF
C        IF(SUMC(I).LT.FMIN)  FMIN =SUMC(I)
C      ENDDO

      DO I=1,NUMGP
        RESULTA(I,4)= RHRP(I)
        RESULTA(I,7)= SUMC(I)
      ENDDO
      RESULTA(IPRROW,4)= RHRP(NUMGP+1)
      RESULTA(IPRROW,7)= ERR_MIN
      RESULTA(10,3)    = ERR_MIN    

      TITLE1='     (*)  sig(r)'
      WRITE(LINE,'(''  min,max:'',2G14.4)') 
     *FFMIN,FFMAX
      CALL MSGDOC(MDOC,LINE)

      CALL CORR_MAX(FMAX,FMAXN)

      DO I=1,NUMGP
        IF(SUMR(I).EQ.0.0) THEN
          T=0.0
          IF(FMAX.GT.0) T=SUMC(I)/FMAX
          SUMR(I)=T
        ENDIF
      ENDDO

      FMIN=0.0
      IMSG=1
      CALL GRAPH_PP(MDOC,NUMGP,NF,RHRP,SUMC,SUMB,FMIN,FMAXN,SUMR
     *             ,TITLE1,IMSG)
      CALL MSGDOC(MDOC,' ')
C
C -----------------------------------------
      CALL MSGDOC(MDOC,' ')
      CALL MSGDOC(MDOC,
     *' ----     Laplacian     ----')
      CALL MSGDOC(MDOC,' ')
      S =0.0
      ST=0.0
      DO I=1,NUMGP
        RH=(RHR(I+1)-RHR(I))/2.0+RHR(I)
        RSQ=RH*RH
        S =S + SUMH2F2 (I)
        ST=ST+ SUMH2F2T(I)
        T =((S  *2.0)*TWOPI*TWOPI)/VOL
        TT=((ST *2.0)*TWOPI*TWOPI)/VOL
        SUMH2F2 (I)=T
        SUMH2F2T(I)=TT
      ENDDO
      SLAP = T

      WRITE(LINE,
     *'(''L = 4pi^2*sqrt<s^2*F>/VOL                :'',G14.4)') 
     *SLAP
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,
     *'(''L /for complete data set/                :'',G14.4)') 
     *TT
      CALL MSGDOC(MDOC,LINE)

      NF=1
      FMIN= 1.E30
      FMAX=-1.E30   
      DO I=1,NUMGP
        SUMC(I)= SUMH2F2(I)
        IF(SUMC(I).GT.FMAX)  FMAX=SUMC(I)
        IF(SUMC(I).LT.FMIN)  FMIN=SUMC(I)
      ENDDO
      TITLE1='     (*) Laplacian'
      WRITE(LINE,'(''  min,max:'',2G14.4)') 
     *FMIN,FMAX
      CALL MSGDOC(MDOC,LINE)
      CALL CORR_MAX(FMAX,FMAXN)
      DO I=1,NUMGP
        T=0.0
        IF(FMAX.GT.0) T=SUMC(I)/FMAX
        SUMR(I)=T
      ENDDO
      FMIN=0.0
      IMSG=1
      CALL GRAPH_PP(MDOC,NUMGP,NF,RHRP,SUMC,SUMB,FMIN,FMAXN,SUMR
     *             ,TITLE1,IMSG)
      CALL MSGDOC(MDOC,' ')
C
C ---- PATTERSON ----------------------------------------------------
C
      CALL MSGDOC(MDOC,
     *' ----          Patterson                ----')
      CALL MSGDOC(MDOC,' ')
      NUMGPF=NUMGP

      CALL CALC_PATT(MDOC,NUMGP,NUMGPF,DELT,DELTRH,RHR,COMPL
     *     ,AVERF2,AVERF2T,SUMA,SUMC,IERR)

      ALIM=0.1
      CALL  TEMP_FLPP(SUMC,NUMGP,DISTR,SCALE,BTP,ALIM)

      IF(BTP.NE.0.0) THEN
        DT2=1.0/(2.0*BTP)
      ELSE
        DT2=0.0
      ENDIF
      DT=SQRT(DT2)
      BSUM=8.0*PI*PI*DT2
      BSUMF=BSUM/2.0
      DTFOUR=SQRT(BSUMF/(8.0*PI*PI))
      DTR =RESMXI/3.0
      BRES=4.0*RESMXI*RESMXI

      RESEFF=DTFOUR*2.0*SQRT(2.0)
      BEFF=4.0*RESEFF*RESEFF

      RESEFF_COMP=RESEFF
      SLAP_COMP =SLAP
      DTFOURT   =DTFOUR
      SCALET    =SCALE
      BSUMT     =BSUM
      BSUMFT    =BSUMF


C /////
c     *''4pi*sqrt(sum(h^2))/(VOL*A):''
c      DLTDR=sh2s2*DVOL
c      WRITE(LINE,'(
c     *''DEL(DR/DX)               :''
c     * ,G14.4)') DLTDR
c      CALL MSGDOC(MDOC,LINE)
c      DTFOUR5=DTFOUR*DTFOUR*DTFOUR*DTFOUR*DTFOUR
C      PE=1.0/(2.0*DTFOUR*DTFOUR)
c      PE5=PE*PE*PE*PE*PE
c      CUR  = 6.0/(DTFOUR5*(TWOPI**1.5))
c      t1=(pe/pi)**1.5
C      t2=sqrt(SCALE)
c      write(*,*) pe,t1,t2
c      curr=6.0*2.0*pe*(pe/pi)**1.5
C      currr=2.0*t2*2.0*pe
C      WRITE(LINE,'(
C     *''Curvature of origin peak  :''
C     * ,G14.4)') currr
C      CALL MSGDOC(MDOC,LINE)
c
c      SIGX=DLTDR/CUR
c      PI5=PI*PI*PI*PI*PI
c      T=(DVOL*PI5)/(5.0*PE5*VOL)
c      SIGXX=(SQRT(T)*RHMAX*ssig)/6.0
c      WRITE(LINE,'(
c     *''sig(x)               :''
c     * ,2G14.4)') SIGX,SIGXX
c      CALL MSGDOC(MDOC,LINE)
c      SIGX=SIGX*SQRT(3.0)
c      SIGXX=SIGXX*SQRT(3.0)
c      WRITE(LINE,'(
c     *''sig(R)               :''
c     * ,2G14.4)') SIGX,SIGXX
c      CALL MSGDOC(MDOC,LINE)
C ///

C ---
      IF(MISS.EQ.'Y'.AND.NTOT.NE.NREF) THEN

        CALL  TEMP_FLPP(SUMA,NUMGP,DISTR,SCALET,BTPT,ALIM)

        IF(BTPT.NE.0.0) THEN
          DT2T=1.0/(2.0*BTPT)
        ELSE
          DT2T=0.0
        ENDIF
        DTT=SQRT(DT2T)
        BSUMT=8.0*PI*PI*DT2T
        BSUMFT=BSUMT/2.0
        DTFOURT=SQRT(BSUMFT/(8.0*PI*PI))
        RESEFF_COMP=DTFOURT*2.0*SQRT(2.0)
        BEFFT=4.0*RESEFF_COMP*RESEFF_COMP

      ENDIF
C --- 
      WRITE(LINE,
     *'(''Patt_origin_peak,Width_of__peak             :'',2G14.4)') 
     * SCALE,DT
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,
     *'(''Corresponding Thermal factor: B_patt        :'',G14.4)') 
     * BSUM
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,
     *'(''Expected <width> of atomic peaks / <u>_four/:'',G14.4)') 
     * DTFOUR
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,
     *'(''Corresponding B_overall /8pi^2*<u>_four^2 / :'',G14.4)') 
     * BSUMF
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,
     *'(''<u>_resol = RESmax/3                        :'',G14.4)') 
     * DTR
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,
     *'(''B_resol = 4*RESmax^2                        :'',G14.4)') 
     * BRES
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,
     *'(''Resolution_effective                        :'',G14.4)') 
     * RESEFF
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,
     *'(''Corresponding thermal factor/4Res_eff^2/    :'',G14.4)') 
     * BEFF
      CALL MSGDOC(MDOC,LINE)

c      PE=1.0/(2.0*DTFOUR*DTFOUR)
c      t2=sqrt(SCALE)
c      currr=2.0*t2*2.0*pe
c      WRITE(LINE,'(
c     *''Curvature of origin peak  :''
c     * ,G14.4)') currr
c      CALL MSGDOC(MDOC,LINE)

      RESULT(1) =NREF
      RESULT(2) =RESMNI
      RESULT(3) =RESMXI
      RESULT(4) =SLAP_COMP
      RESULT(5) =DT

      RESULT(6) =BSUM

      RESULT(7) =DTR
      RESULT(8) =BRES
      RESULT(9) =DTFOUR
      RESULT(10)=BEFF
      RESULT(11)=RESEFF
      IF(IPRROW.GE.21) THEN
        RESULT(12) =SF2
        RESULT(13) =SF4
        RESULT(14) =SH2F 
        RESULT(15) =COMPL
        RESULT(16) =RESEFF_COMP
        RESULT(17) =SLAP
        RESULT(18) =FSCALE
        RESULT(19) =BTEMP
        RESULT(20) =RESN

        RESULT(21) =SCALE

      ENDIF


      DO I=1,NUMGP
        D2=DISTR(I)*DISTR(I)
        FSC=SCALE
        BT=1.0/(2.0*DT2)
        X=FSC*EXP(-BT*D2)
        SUMB(I)= X
      ENDDO

C     CALL MSGDOC(MDOC,' --- P(000) /scaling till 1/10 of P(000)/ ---')
      CALL MSGDOC(MDOC,' ')
      CALL MSGDOC(MDOC,
     *' ---- <Patterson> and corresponding Gaussian ----')
      CALL MSGDOC(MDOC,' ')
      NF=2
      FMIN= 1.E30
      FMAX=-1.E30   
      FFMIN= 1.E30
      FFMAX=-1.E30   
      DO I=1,NUMGP
        IF(SUMB(I) .GT.FMAX )  FMAX =SUMB(I)
        IF(SUMC(I) .GT.FMAX )  FMAX =SUMC(I)
        IF(SUMC(I) .GT.FFMAX)  FFMAX=SUMC(I)
        IF(SUMB(I) .LT.FMIN )  FMIN =SUMB(I)
        IF(SUMC(I) .LT.FMIN )  FMIN =SUMC(I)
        IF(SUMC(I) .LT.FFMIN)  FFMIN=SUMC(I)
      ENDDO
      CALL CORR_MAX(FMAX,FMAXN)
      WRITE(LINE,'(''  min,max:'',2G14.4)') 
     *FFMIN,FFMAX
      CALL MSGDOC(MDOC,LINE)
      DO I=1,NUMGP
        T=0.0
        IF(FMAX.GT.0) T=SUMC(I)/FMAX
        SUMR(I)=T
      ENDDO
      TITLE1='   (*) Patterson     (+) Gaussian'
      IMSG=1
      IF(FMIN.GT.0.0) FMIN=0.0 
      CALL GRAPH_PATTT(MDOC,NUMGP,NF,DISTR,SUMC,SUMB,FMIN,FMAX,SUMR
     * ,TITLE1,IMSG)
C ------------------------
      IF(MISS.EQ.'Y'.AND.NTOT.NE.NREF) THEN
C  ---
        CALL MSGDOC(MDOC,' ')
        CALL MSGDOC(MDOC
     *  ,' --- for complete data set ---')
        CALL MSGDOC(MDOC,' ')
C ---
        SLAP_COMP = ST
C ---

        WRITE(LINE,
     *'(''Patt_origin_peak,Width_of__peak             :'',2G14.4)') 
     *  SCALET,DTT
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,
     *'(''Corresponding Thermal factor: B_patt        :'',G14.4)') 
     *  BSUMT
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,
     *'(''Expected <width> of atomic peaks / <u>_four/:'',G14.4)') 
     *  DTFOURT
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,
     *'(''Corresponding B_overall /8pi^2*<u>_four^2/  :'',G14.4)') 
     *  BSUMFT
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,
     *'(''Resolution_effective                        :'',G14.4)') 
     *  RESEFF_COMP
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,
     *'(''Corresponding thermal factor/4Res_eff^2/    :'',G14.4)') 
     *  BEFFT
        CALL MSGDOC(MDOC,LINE)

        RESULT(4)= SLAP_COMP
        IF(IPRROW.GE.21) THEN   
          RESULT(16) =RESEFF_COMP
C         RESULT(21) =SCALET
        ENDIF
      ENDIF
      RESULT_B = BSUMT
      RESULT_S = SCALET
C -----------------------

      BTEST=BTEMP
      BTEST=0.0
      DO I=1,NUMGP
        RH=(RHR(I+1)-RHR(I))/2.0+RHR(I)
        RSQ=RH*RH
        IF(BOFF.GT.0.0) THEN
          BT=BOFF/4.0
          CBOFF=1.0-EXP(-BT*RSQ)
        ELSE
          CBOFF=1.0
        ENDIF
        IF(ABS(BADD).GT.0.00001) THEN
          BT=BADD/4.0
          CBADD=EXP(-BT*RSQ)
        ELSE
          CBADD=1.0
        ENDIF
        FSC    = FSCALE
        BT     = BTEST/4.0
        SUMD(I)= FSC*EXP(-BT*RSQ)*CBADD*CBOFF
        SUMB(I)= 0.0
        SUME(I)= 0.0
      ENDDO

      FMIN= 1.E30
      FMAX=-1.E30   
      DO I=1,16

        NUMGPF = NUMGP-I+1

        CALL CALC_PATT(MDOC,NUMGP,NUMGPF,DELT,DELTRH,RHR,COMPL
     *       ,SUMD,AVERF2T,SUMA,SUMC,IERR)

        ALIM=0.1
        CALL  TEMP_FLPP(SUMC,NUMGP,DISTR,SCALE,BTP,ALIM)
        IF(BTP.NE.0.0) THEN
          DT2=1.0/(2.0*BTP)
        ELSE
          DT2=0.0
        ENDIF
        BSUM=8.0*PI*PI*DT2
        BSUMF=BSUM/2.0
        DTFOUR=SQRT(BSUMF/(8.0*PI*PI))
        RESEFF=DTFOUR*2.0*SQRT(2.0)

        SUMB (NUMGPF) = RESEFF

        IF(RESEFF.GT.FMAX)  FMAX=RESEFF
        IF(RESEFF.LT.FMIN)  FMIN=RESEFF

        CALL  TEMP_FLPP(SUMA,NUMGP,DISTR,SCALE,BTP,ALIM)

        IF(BTP.NE.0.0) THEN
          DT2=1.0/(2.0*BTP)
        ELSE
          DT2=0.0
        ENDIF
        BSUM=8.0*PI*PI*DT2
        BSUMF=BSUM/2.0
        DTFOUR=SQRT(BSUMF/(8.0*PI*PI))
        RESEFF_G=DTFOUR*2.0*SQRT(2.0)

        SUME (NUMGPF) = RESEFF_G

C        WRITE(LINE,'(''RES_eff :'',2G14.4,F8.3)') 
C     *  RESEFF,RESEFF_G,RHRP(NUMGPF+1)
C        CALL MSGDOC(MDOC,LINE)

      ENDDO
C --
      CALL MSGDOC(MDOC,' ')
      WRITE(LINE,
     *'('' -- Res_eff and Res_eff for atom with B :'',F8.3,'' --'')'
     *) BTEST
      CALL MSGDOC(MDOC,LINE)
      CALL MSGDOC(MDOC,' ')

      WRITE(LINE,'(''  min,max:'',2G14.4)') 
     *FMIN,FMAX
      CALL MSGDOC(MDOC,LINE)


      DO I=1,NUMGP
        RESULTA(I,5)= SUMB(I)
        RESULTA(I,6)= SUME(I)
      ENDDO
      RESULTA(IPRROW,5)= SUMB(NUMGP)
      RESULTA(IPRROW,6)= SUME(NUMGP)

      NF=2
      FMIN= 1.E30
      FMAX=-1.E30   
      DO I=1,NUMGP
        IF(SUMB(I).GT.FMAX)  FMAX=SUMB(I)
        IF(SUME(I).GT.FMAX)  FMAX=SUME(I)
        IF(SUMB(I).LT.FMIN)  FMIN=SUMB(I)
        IF(SUME(I).LT.FMIN)  FMIN=SUME(I)
      ENDDO
      CALL CORR_MAX(FMAX,FMAXN)
      DO I=1,NUMGP
        IF(SUMB(I).GT.0.0) THEN
          T=0.0
          IF(FMAX.GT.0) T=SUMB(I)/FMAX
          SUMR(I)=T
        ELSE
          SUMR(I)=10000000000.0
        ENDIF
      ENDDO
      IMSG=1
      FMIN=0
      TITLE1='  (*) Res_eff    (+) Res_eff for SC*EXP(-Bover*S^2)'
      CALL GRAPH_PP(MDOC,NUMGP,NF,RHRP,SUMB,SUME,FMIN,FMAXN,SUMR
     *             ,TITLE1,IMSG)
C -----------------------
      RETURN
      END


      SUBROUTINE CALC_PATT(MDOC,NUMGP,NUMGPF,DELT,DELTRH,RHR,COMPL
     *     ,AVERF2,AVERF2T,SUMA,SUMC,IERR)
      REAL      SUMA(40),SUMC(40)
      REAL      AVERF2(40),AVERF2T(40)
      REAL      RHR(41)
      CHARACTER LINE*80
C -----------------------------------------------------------
      PI   =4.0*ATAN(1.0)
      TWOPI=2.0*PI
      IERR=0
      MD  =-ABS(MDOC)-1
      M = 99

      DO I=1,NUMGP
        SUMA (I) = 0.0
        SUMC(I)  = 0.0
      ENDDO

      DO I=1,NUMGP
        DIST=(I-1)*DELT 
        DIST2=DIST*DIST

        DO J=1,NUMGPF
          RH=(RHR(J+1)-RHR(J))/2.0+RHR(J)
          RSQ=RH*RH
          IF(I.GT.1) THEN
            SR=(RH*DIST*TWOPI)
            SINSR=SIN(SR)

            TEMP =(AVERF2 (J)*SINSR*RSQ*DELTRH)/SR

            SUMA(I) =SUMA(I) +TEMP

            TEMP =(AVERF2T(J)*SINSR*RSQ*DELTRH)/SR

            SUMC(I) =SUMC(I) +TEMP

          ELSE

            TEMP =AVERF2(J)*RSQ*DELTRH

            SUMA(I) =SUMA(I) +TEMP

            TEMP =AVERF2T(J)*RSQ*DELTRH

            SUMC(I) =SUMC(I) +TEMP

          ENDIF
        ENDDO

        SUMA (I)= SUMA (I)*2.0 *TWOPI
        SUMC (I)= SUMC(I) *2.0 *TWOPI
      ENDDO
C  ----------------------------------------
C
C
      T = COMPL
      IF(T.LT.0.000000001) T=1.0
       DO I=1,NUMGP
        SUMC(I)=SUMC(I)/SQRT(T)
      ENDDO

      RETURN
      END


      SUBROUTINE WRT_PSCLF(MDOC,F_NAME,F2_NAME,FO_NAME,FAVER,BOVER
     * ,REST,BOFFR,BADDR,CSCALE,BT,NUMGRP,RESULT,RESULTA,IPRROW
     * ,RESMNIR,RESMXIR,ISYM,IPRSYM,NATOM,IERR)
C ------------------------------
      INTEGER*2 ISYM(5,3,IPRSYM)
      INTEGER*4 MDOC,IERR
      CHARACTER F_NAME*(*),F2_NAME*(*),FO_NAME*(*),REST*1
      CHARACTER TITLE1*80
C ==============================
      INTEGER*4 MTIN,MTIN2,MTOUT
      REAL      RESULT(*)
      REAL      RESULTA(IPRROW,*)
      CHARACTER ITYP*4,ITYP2*4
      CHARACTER LINE*80,TITLE*80,TTT*80
      REAL      RHR(41),RHRP(41),RLATT(6),SUMSIGN(40)
      REAL      SUMF1(40),SUMF1N(40),SUMD(40),SUME(40),SUMSIG(40)
      REAL      SUMF1_FREE(40),SUMF1N_FREE(40),SUMD_FREE(40)
      REAL      DERK(40),CURK(40),SUMC(40),DLUZZ(40)
C -----------------------------------------------------------
      BOFF =BOFFR
      BADD =BADDR

      RESMXI=RESMXIR
      RESMNI=RESMNIR

      NUMGP=NUMGRP
      IF(NUMGP.LE. 0) NUMGP=20
      IF(NUMGP.GT.20) NUMGP=20
      PI   =4.0*ATAN(1.0)
      TWOPI=2.0*PI
      IERR=0
      MD  =-ABS(MDOC)-1
      M = 99
C ----
      MTIN=20
      ITYP  ='FF  '
      CALL LENSTR_BL(F_NAME,LEN)
      IF(LEN.LE.0.OR.F_NAME(1:1).EQ.' '.OR.F_NAME(1:1).EQ.',') THEN
        MTIN=0
      ELSE
        CALL ORFILE(M,MTIN,F_NAME,ITYP,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MDOC,' ERR: OPEN FILE-F /TEST/')
          RETURN
        ENDIF
        CALL GET_TITLE(M,A,B,C,AL,BE,GA
     *  ,COEF1,BET1,RESMIN,RESMAX,IDM,IDM,IDM,IDM,IDM,TITLE,IERR)
      ENDIF
C ----
      MTIN2=21
      ITYP2 ='FF  '
      CALL LENSTR_BL(F2_NAME,LEN)
      IF(LEN.LE.0.OR.F2_NAME(1:1).EQ.' '.OR.F2_NAME(1:1).EQ.',') THEN
        IF(MTIN.GT.0) CLOSE (MTIN)
        IERR=1
        RETURN
      ENDIF
      CALL ORFILE(M,MTIN2,F2_NAME,ITYP2,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERROR: OPEN FILE-F_2')
        IF(MTIN.GT.0) CLOSE (MTIN)
        RETURN
      ENDIF
      CALL GET_TITLE(M,A,B,C,AL,BE,GA
     *  ,COEF2,BET2,RESMIN2,RESMAX2,IDM,IDM,IDM,IDM,IDM,TTT,IERR)
C ---
      CALL C_RD_CR
      IF(RESMNI.LE.0.0) THEN
        RESMNO=RESMIN2
      ELSE
        RESMNO=RESMNI
      ENDIF
      IF(RESMXI.LE.0.0) THEN
        RESMXO=RESMAX2
      ELSE
        RESMXO=RESMXI
      ENDIF

      WRITE(LINE,'(''Resolution         :'',2F8.2)') RESMNO,RESMXO
      CALL MSGDOC(MDOC,LINE)

      RESMXI=RESMXO
      RESMNI=RESMNO
C ---
      CALL ANOMF(M,NSYM,ISYM)
      CALL LIMHKL(RESMXO,IHMAX,IKMAX,ILMAX,NXMIN,NYMIN,NZMIN)
      RLATT(1)=A
      RLATT(2)=B
      RLATT(3)=C
      RLATT(4)=AL
      RLATT(5)=BE
      RLATT(6)=GA
      CALL DSTARF(RLATT,AST,BST,CST,COALST,COBEST,COGAST,VOL)

C ----------------------------------------------------------------
      RHMIN=1.0/RESMNO
      RHMAX=1.0/RESMXO
      DELTRH =(RHMAX-RHMIN)/NUMGP
      RHR(1) =RHMIN
      RHRP(1)=1./RHMIN
      DO    I=2,NUMGP+1
        RHR(I) =RHR(I-1)+DELTRH
        RHRP(I)=1.0/RHR(I)
      ENDDO

      DO    K=1,NUMGP
        SUMSIG (K) =0.0
        SUMSIGN(K) =0.0
      ENDDO
      

      IF(MTIN.GT.0) THEN
        IH     =  0
        IK     =  0
        IL     = -1
        JH     =  0
        JK     =  0
        JL     = -1
        IFIRST =  0
        IEND   = -1
        IEND2  = -1
        FSCALE =  0.04
        FN0    =  0.0
        FN     =  0.0
        SN     =  0.0
        NTOT   =  0 
        SFF12  =  0.0
        SFF22  =  0.0
        DO    K=1,NUMGP
          SUMSIG (K) =0.0
          SUMSIGN(K) =0.0
        ENDDO
C ---

      DO     ILP=0,ILMAX
      DO     IKP=-IKMAX,IKMAX
      DO     IHP=-IHMAX,IHMAX
        IF(IHP.EQ.0.AND.IKP.EQ.0.AND.ILP.EQ.0) GO TO 200
        IIHP=IHP
        IIKP=IKP
        IILP=ILP
        CALL ANOMSC(IIHP,IIKP,IILP,IANOM,JJSYM,NSYM,ISYM)
        IF(IANOM.NE.1.OR.JJSYM.NE.1) GO TO 200
        CALL SYSABS_BL(IHP,IKP,ILP,NSYM,ISYM,ICND)
        IF(ICND.NE.0) GO TO 200
        CALL DSTAR(IHP,IKP,ILP,RSQ)
        RH=SQRT(RSQ)
        IF(RH.LT.RHMIN.OR.RH.GT.RHMAX) GO TO 200
        K=(RH-RHMIN)/DELTRH+1.0
        IF(K.GT.NUMGP) K=NUMGP
        IF(K.LT.1) K=1     

 2060   CONTINUE 

        IF(IEND.GT.0) GO TO 2040

        IF(IH.EQ.0.AND.IK.EQ.0.AND.IL.EQ.0) THEN
          FN0=FN
          SN0=SN
        ENDIF
        IFLAG_FN = 1

C        IF(IL-ILP) 2050,2010,2040
C 2010   IF(IK-IKP) 2050,2020,2040
C 2020   IF(IH-IHP) 2050,2030,2040

        IF((IL-ILP).LT.0) GO TO 2050
        IF((IL-ILP).EQ.0) GO TO 2010
        IF((IL-ILP).GT.0) GO TO 2040
 2010   IF((IK-IKP).LT.0) GO TO 2050
        IF((IK-IKP).EQ.0) GO TO 2020
        IF((IK-IKP).GT.0) GO TO 2040
 2020   IF((IH-IHP).LT.0) GO TO 2050
        IF((IH-IHP).EQ.0) GO TO 2030
        IF((IH-IHP).GT.0) GO TO 2040

 2040   CONTINUE
C       MISS REFL IHP,IKP,ILP   
        IFLAG_FN = -1
        GO TO 2030

 2050   CONTINUE

        IF(IEND.GT.0) GO TO 2040

        IF(ITYP.EQ.'FS  ') THEN
          CALL RRD1(MTIN,IH,IK,IL,FN,FNA,SN,SNA,NUMB,IEND)
        ELSE
          CALL RD1(MTIN,IH,IK,IL,FN,FNA,NUMB,IEND)
C         SIG-DUMMY
          SN =0.04*FN
          SNA=0.04*FNA
        ENDIF
        IF(MTIN.LE.0) THEN
          CALL MSGERR(MDOC,' ERROR: READ FILE_F')
          CLOSE (MTIN2)
          IERR=1
          RETURN
        ENDIF
        IF(IEND.GT.0)      GO TO 2060
        IF(FN.LE.1.E-6.AND.FNA.LE.1.E-6) GO TO 2060
        IF(FN.GT.1.E-6.AND.FNA.GT.1.E-6) THEN
          IF(SN .LT.0.000001) SN =1.0
          IF(SNA.LT.0.000001) SNA=1.0
          WT1=1./(SN*SN)
          WT2=1./(SNA*SNA)
          WT =WT1+WT2
          FN =FN*WT1+FNA*WT2
          FN =FN/WT
          SN =1./SQRT(WT)
        ELSE IF(FNA.GT.1.E-6) THEN
          FN =FNA
          SN =SNA
        ENDIF
        IFLAG_FN = 1
        GO TO 2060

 2030   CONTINUE

 3060   CONTINUE

        IF(IEND2.GT.0) GO TO 3040

        IFLAG_GN = 1

C        IF(JL-ILP) 3050,3010,3040
C 3010   IF(JK-IKP) 3050,3020,3040
C 3020   IF(JH-IHP) 3050,3030,3040

        IF((JL-ILP).LT.0) GO TO 3050
        IF((JL-ILP).EQ.0) GO TO 3010
        IF((JL-ILP).GT.0) GO TO 3040
 3010   IF((JK-IKP).LT.0) GO TO 3050
        IF((JK-IKP).EQ.0) GO TO 3020
        IF((JK-IKP).GT.0) GO TO 3040
 3020   IF((JH-IHP).LT.0) GO TO 3050
        IF((JH-IHP).EQ.0) GO TO 3030
        IF((JH-IHP).GT.0) GO TO 3040

 3040   CONTINUE
C       MISS REFL IHP,IKP,ILP   
        IFLAG_GN = -1
        GO TO 3030

 3050   CONTINUE

        IF(IEND2.GT.0) GO TO 3040

        IF(ITYP2.EQ.'FS  ') THEN
          CALL RRD2(MTIN2,JH,JK,JL,GN,GNA,SGN,SGNA,NUMB2,IEND2)
C
C
        ELSE
          CALL RD2(MTIN2,JH,JK,JL,GN,GNA,NUMB2,IEND2)
C         SIG-DUMMY
          SGN =0.04*GN
          SGNA=0.04*GNA
        ENDIF
        IF(MTIN2.LE.0) THEN
          CALL MSGERR(MDOC,' ERROR: READ FILE_F_2')
          IF(MTIN.GT.0) CLOSE (MTIN)
          IERR=1
          RETURN
        ENDIF
        IF(IEND2.GT.0)      GO TO 3060
        IF(IFIRST.LE.0) THEN
          FMOD=0.0
          IF(JH.EQ.0.AND.JK.EQ.0.AND.JL.EQ.0) THEN
            FMOD=GN  *CSCALE
            SNN =SGN *CSCALE
            FAN=0.0
            SNA=0.0
          ELSE
            IF(FN0.GT.0.0) THEN
              FMOD=FN0  
              SNN =SN0 
              FAN=0.0
              SNA=0.0
            ENDIF
          ENDIF



          IF(FMOD.GT.0.0) THEN
            IFIRST=1
            IF(JH.EQ.0.AND.JK.EQ.0.AND.JL.EQ.0) GO TO 3060
          ENDIF

        ENDIF


        IF(GN.LE.1.E-6.AND.GNA.LE.1.E-6) GO TO 3060
        IF(GN.GT.1.E-6.AND.GNA.GT.1.E-6) THEN
          IF(SGN .LT.0.000001) SGN =1.0
          IF(SGNA.LT.0.000001) SGNA=1.0
          WT1=1./(SGN*SGN)
          WT2=1./(SGNA*SGNA)
          WT =WT1+WT2
          GN =GN*WT1+GNA*WT2
          GN =GN/WT
          SGN =1./SQRT(WT)
        ELSE IF(GNA.GT.1.E-6) THEN
          GN  =GNA
          SGN =SGNA
        ENDIF
        IFLAG_GN = 1
        GO TO 3060

 3030   CONTINUE

        IF(BOFF.GT.0.0) THEN
          BTTT=BOFF/4.0
          CBOFF=1.0-EXP(-BTTT*RSQ)
        ELSE
          CBOFF=1.0
        ENDIF
        IF(ABS(BADD).GT.0.00001) THEN
          BTTT=BADD/4.0
          CBADD=EXP(-BTTT*RSQ)
        ELSE
          CBADD=1.0
        ENDIF
        Y=CBADD*CBOFF
        IF(IFLAG_GN.LT.0) THEN
          IF(REST.NE.'Y'.AND.REST.NE.'O') GO TO 200
          IF(REST.EQ.'O') THEN
            BTT  =BOVER/4.0
            X    =FAVER*EXP(-BTT*RSQ)
            GGN  =X
            SGGN =X*0.04
            GGNA =0.0
            SGGNA=0.0
          ELSE
            IF(IFLAG_FN.LT.0) GO TO 200
            GGN  =FN
            SGGN =SN
            GGNA =FNA
            SGGNA=SNA
            SUMSIG(K) = SUMSIG(K) + SN
            SUMSIGN(K)= SUMSIGN(K)+ 1.0
          ENDIF
        ELSE
          GGN  =GN
          SGGN =SGN
          GGNA =GNA
          SGGNA=SGNA
          BTT=BT/4.0
          X=CSCALE*EXP(-BTT*RSQ)
C         IF(MTIN.LE.0) X=1.0
          GGN  =GGN   *X
          SGGN =SGGN  *X
          GGNA =GGNA  *X
          SGGNA=SGGNA *X
          IF(IFLAG_FN.GE.0) THEN
            NTOT=NTOT+1
            SFF12     = SFF12     + FN*FN*Y*Y
            SFF22     = SFF22     + GGN*GGN*Y*Y
            SUMSIG(K) = SUMSIG(K) + SN
            SUMSIGN(K)= SUMSIGN(K)+ 1.0
          ENDIF
        ENDIF
  200   CONTINUE
      ENDDO
      ENDDO
      ENDDO
C ---
        IF(SFF22.GT.0.0.AND.SFF12.GT.0.0) THEN
          SCALE_ADD= SQRT(SFF12/SFF22)
        ELSE
          SCALE_ADD=1.0
        ENDIF
        CSCALE=CSCALE*SCALE_ADD

        WRITE(LINE,'('' New Scale:'',G12.4)') CSCALE
        CALL MSGDOC(MDOC,LINE)

        DO    K=1,NUMGP
         IF(SUMSIGN(K).GT.0.0) SUMSIG (K) = SUMSIG (K) / SUMSIGN(K) 
C
        ENDDO

        RESULT(18) =CSCALE
        RESULT(19) =BT

        CLOSE(MTIN)
        CLOSE(MTIN2)
        CALL ORFILE(M,MTIN,F_NAME,ITYP,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MDOC,' ERROR: OPEN FILE-F /TEST/')
          RETURN
        ENDIF
        CALL ORFILE(M,MTIN2,F2_NAME,ITYP2,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MDOC,' ERROR: OPEN FILE-F_2')
          IF(MTIN.GT.0) CLOSE (MTIN)
          RETURN
        ENDIF
      ENDIF
C -------------------------------------------------------------
      RESULT(18) =CSCALE
      RESULT(19) =BT
C ----
      CALL C_CR_WR
      MTOUT=22
      CALL LENSTR_BL(FO_NAME,LEN)
      IF(LEN.LE.0.OR.FO_NAME(1:1).EQ.' '.OR.FO_NAME(1:1).EQ.',') THEN
C        IF(MTIN.GT.0) CLOSE (MTIN)
C        CLOSE (MTIN2)
C        IERR=1
C        RETURN
        MTOUT=0
      ENDIF
      COEF3=COEF2*CSCALE
      BET3=BET2+BT

      RESN_OUT = RESMNO
      RESX_OUT = RESMXO

      RESN_OUT = RESMIN2
      RESX_OUT = RESMAX2

      IF(MTOUT.GT.0) THEN
        CALL SET_TITLE(MD,A,B,C,AL,BE,GA
     *    ,COEF3,BET3,RESN_OUT,RESX_OUT,IDM,IDM,IDM,IDM,IDM,TTT,IERR)
        CALL OWFILE(MD,MTOUT,FO_NAME,ITYP2,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) THEN
          IF(MTIN.GT.0) CLOSE (MTIN)
          CLOSE (MTIN2)
          CALL MSGERR(MD,' ERROR: OPEN OUTPUT_FILE /pscale/')
          IERR=1
          RETURN
        ENDIF
      ENDIF
C -------------------------------------------------------------
      RHMIN=1.0/RESMNO
      RHMAX=1.0/RESMXO
      RHMIN2=1.0/RESN_OUT
      RHMAX2=1.0/RESX_OUT
      DO    K=1,NUMGP
        SUMD_FREE   (K) =0.0
        SUMF1_FREE  (K) =0.0
        SUMF1N_FREE (K) =0.0
        SUMD   (K) =0.0
        SUMF1  (K) =0.0
        SUMF1N (K) =0.0
        CURK   (K) =0.0
        DERK   (K) =0.0
      ENDDO
      DELTRH =(RHMAX-RHMIN)/NUMGP
      RHR(1) =RHMIN
      RHRP(1)=1./RHMIN
      DO    I=2,NUMGP+1
        RHR(I) =RHR(I-1)+DELTRH
        RHRP(I)=1.0/RHR(I)
      ENDDO
      NTOT =0
      NTOTG=0
      NREFA=0
      NREFG=0
      NC   =0
      SUMDT=0.0
      SF1  =0.0
      SFF2 =0.0
      SFF12=0.0
      SFF22=0.0
      SF1F2=0.0
      SUMDT_FREE=0.0
      SF1_FREE  =0.0
      NFREE = 0

      DER_TEST=0.0
      CUR_TEST=0.0

      CUR  =0.0
      DER  =0.0
      IH   =0
      IK   =0
      IL   =-1
      JH   =0
      JK   =0
      JL   =-1
      IFIRST=0
      IEND  =-1
      IEND2 =-1
      KEY1  =0
      KEY2  =0
      KEY3  =0
      NREF  =0
      NREST =0
      IEND1 =-1
      FSCALE=0.04
      NMISS = 0
      FN0=0.0
      IF(MTIN.LE.0) IEND=1
C --------------------------------------
C ---
      DO     ILP=0,ILMAX
      DO     IKP=-IKMAX,IKMAX
      DO     IHP=-IHMAX,IHMAX

        IF(IHP.EQ.0.AND.IKP.EQ.0.AND.ILP.EQ.0) GO TO 100
        IIHP=IHP
        IIKP=IKP
        IILP=ILP
        CALL ANOMSC(IIHP,IIKP,IILP,IANOM,JJSYM,NSYM,ISYM)
        IF(IANOM.NE.1.OR.JJSYM.NE.1) GO TO 100
        CALL SYSABS_BL(IHP,IKP,ILP,NSYM,ISYM,ICND)
        IF(ICND.NE.0) GO TO 100
        CALL DSTAR(IHP,IKP,ILP,RSQ)
        RH=SQRT(RSQ)

C        IF(RH.LT.RHMIN.OR.RH.GT.RHMAX) GO TO 100
        IF(RH.LT.RHMIN2.OR.RH.GT.RHMAX2) GO TO 100

        IHT=IHP
        IKT=0
        ILT=0
        CALL DSTAR(IHT,IKT,ILT,RSQT)
        RHT=SQRT(RSQT)

        CALL INDMLTT(IHP,IKP,ILP,NGEN,NSYM,ISYM)
        NTOT =NTOT  +1
        NTOTG=NTOTG +NGEN
        IF(RH.LT.RHMIN.OR.RH.GT.RHMAX) THEN
          K=1
        ELSE
          K=(RH-RHMIN)/DELTRH+1.0
          IF(K.GT.NUMGP) K=NUMGP
          IF(K.LT.1) K=1     
        ENDIF
 4060   IF(IEND.GT.0) GO TO 4040

        IF(MTIN2.LE.0)  THEN
          IF(MTIN2.GT.0) CLOSE (MTIN2)
          IF(MTIN.GT.0)  CLOSE (MTIN)
          CLOSE (MTOUT)
          IERR=1
          RETURN
        ENDIF


        IF(IH.EQ.0.AND.IK.EQ.0.AND.IL.EQ.0) THEN
          FN0=FN
          SN0=SN
        ENDIF

        IFLAG_FN = 1

C        IF(IL-ILP) 4050,4010,4040
C 4010   IF(IK-IKP) 4050,4020,4040
C 4020   IF(IH-IHP) 4050,4030,4040

        IF((IL-ILP).LT.0) GO TO 4050
        IF((IL-ILP).EQ.0) GO TO 4010
        IF((IL-ILP).GT.0) GO TO 4040
 4010   IF((IK-IKP).LT.0) GO TO 4050
        IF((IK-IKP).EQ.0) GO TO 4020
        IF((IK-IKP).GT.0) GO TO 4040
 4020   IF((IH-IHP).LT.0) GO TO 4050
        IF((IH-IHP).EQ.0) GO TO 4030
        IF((IH-IHP).GT.0) GO TO 4040

 4040   CONTINUE
C       MISS REFL IHP,IKP,ILP   
        IFLAG_FN = -1
        KEY1     =  0
        GO TO 4030

 4050   CONTINUE
        IF(IEND.GT.0) GO TO 4040
        IF(ITYP.EQ.'FS  ') THEN
          CALL RRD1(MTIN,IH,IK,IL,FN,FNA,SN,SNA,KEY1,IEND)
        ELSE
          CALL RD1(MTIN,IH,IK,IL,FN,FNA,KEY1,IEND)
C         SIG-DUMMY
          SN =0.04*FN
          SNA=0.04*FNA
        ENDIF
        IF(MTIN.LE.0) THEN
          CALL MSGERR(MDOC,' ERROR: READ FILE_F')
          CLOSE (MTIN2)
          CLOSE (MTOUT)
          IERR=1
          RETURN
        ENDIF
        IF(IEND.GT.0)      GO TO 4060
        IF(FN.LE.1.E-6.AND.FNA.LE.1.E-6) GO TO 4060
        IF(FN.GT.1.E-6.AND.FNA.GT.1.E-6) THEN
          IF(SN .LT.0.000001) SN =1.0
          IF(SNA.LT.0.000001) SNA=1.0
          WT1=1./(SN*SN)
          WT2=1./(SNA*SNA)
          WT =WT1+WT2
          FN =FN*WT1+FNA*WT2
          FN =FN/WT
          SN =1./SQRT(WT)
        ELSE IF(FNA.GT.1.E-6) THEN
          FN =FNA
          SN =SNA
        ENDIF
        IFLAG_FN = 1
        IF(RH.LT.RHMIN.OR.RH.GT.RHMAX) THEN
          IFLAG_FN = -1
          KEY1     =  0
          GO TO 4030
        ENDIF
        GO TO 4060

 4030   CONTINUE

 5060   IF(IEND2.GT.0) GO TO 5040
        IF(MTIN2.LE.0)  THEN
          IF(MTIN2.GT.0) CLOSE (MTIN2)
          IF(MTIN.GT.0)  CLOSE (MTIN)
          CLOSE (MTOUT)
          IERR=1
          RETURN
        ENDIF

        IFLAG_GN = 1

C        IF(JL-ILP) 5050,5010,5040
C 5010   IF(JK-IKP) 5050,5020,5040
C 5020   IF(JH-IHP) 5050,5030,5040

        IF((JL-ILP).LT.0) GO TO 5050
        IF((JL-ILP).EQ.0) GO TO 5010
        IF((JL-ILP).GT.0) GO TO 5040
 5010   IF((JK-IKP).LT.0) GO TO 5050
        IF((JK-IKP).EQ.0) GO TO 5020
        IF((JK-IKP).GT.0) GO TO 5040
 5020   IF((JH-IHP).LT.0) GO TO 5050
        IF((JH-IHP).EQ.0) GO TO 5030
        IF((JH-IHP).GT.0) GO TO 5040


 5040   CONTINUE
C       MISS REFL IHP,IKP,ILP   
        IFLAG_GN = -1
        KEY2=0
        IF(IFLAG_FN.LT.0) THEN
          NMISS=NMISS+1
        ENDIF
        GO TO 5030

 5050   CONTINUE
        IF(IEND2.GT.0) GO TO 5040
        IF(ITYP2.EQ.'FS  ') THEN
          CALL RRD2(MTIN2,JH,JK,JL,GN,GNA,SGN,SGNA,KEY2,IEND2)
c
c
        ELSE
          CALL RD2(MTIN2,JH,JK,JL,GN,GNA,KEY2,IEND2)
C         SIG-DUMMY
          SGN =0.04*GN
          SGNA=0.04*GNA
        ENDIF
        IF(MTIN2.LE.0) THEN
          CALL MSGERR(MDOC,' ERROR: READ FILE_F_2')
          IF(MTIN.GT.0) CLOSE (MTIN)
          CLOSE (MTOUT)
          IERR=1
          RETURN
        ENDIF
        IF(IEND2.GT.0)      GO TO 5060
        IF(IFIRST.LE.0) THEN
          FMOD=0.0
          IF(JH.EQ.0.AND.JK.EQ.0.AND.JL.EQ.0) THEN
            FMOD=GN  *CSCALE
            SNN =SGN *CSCALE
            FAN=0.0
            SNA=0.0
          ELSE
            IF(FN0.GT.0.0) THEN
              FMOD=FN0  
              SNN =SN0 
              FAN=0.0
              SNA=0.0
            ENDIF
          ENDIF
          IF(FMOD.GT.0.0) THEN
            NREF =NREF +1
            JJH=0
            JJK=0
            JJL=0
            KEY3=0
            IF(MTOUT.GT.0) THEN 
              IF(ITYP2.EQ.'F   ') THEN
                CALL WRT(MTOUT,JJH,JJK,JJL,FMOD,FAN,KEY3,IEND1)
              ELSE
            CALL WWRT(MTOUT,JJH,JJK,JJL,FMOD,FAN,SNN,SNA,KEY3,IEND1)
              ENDIF
              IF(MTOUT.LE.0) THEN
                CALL MSGERR(MDOC,' ERROR: WRITE FILE_OUT')
                IF(MTIN.GT.0) CLOSE (MTIN)
                CLOSE (MTIN2)
                IERR=1
                RETURN
              ENDIF
            ENDIF
            IFIRST=1
           IF(JH.EQ.0.AND.JK.EQ.0.AND.JL.EQ.0) GO TO 5060
          ENDIF
        ENDIF
        IF(GN.LE.1.E-6.AND.GNA.LE.1.E-6) GO TO 5060
        IF(GN.GT.1.E-6.AND.GNA.GT.1.E-6) THEN
          IF(SGN .LT.0.000001) SGN =1.0
          IF(SGNA.LT.0.000001) SGNA=1.0
          WT1=1./(SGN*SGN)
          WT2=1./(SGNA*SGNA)
          WT =WT1+WT2
          GN =GN*WT1+GNA*WT2
          GN =GN/WT
          SGN =1./SQRT(WT)
        ELSE IF(GNA.GT.1.E-6) THEN
          GN  =GNA
          SGN =SGNA
        ENDIF
        IFLAG_GN = 1
        GO TO 5060

 5030   CONTINUE

        IF(BOFF.GT.0.0) THEN
          BTTT=BOFF/4.0
          CBOFF=1.0-EXP(-BTTT*RSQ)
        ELSE
          CBOFF=1.0
        ENDIF
        IF(ABS(BADD).GT.0.00001) THEN
          BTTT=BADD/4.0
          CBADD=EXP(-BTTT*RSQ)
        ELSE
          CBADD=1.0
        ENDIF
        Y=CBADD*CBOFF

        IF(IFLAG_GN.LT.0) THEN

          IF(IFLAG_FN.GE.0) THEN
            ACUR = FN
            IF(SUMSIG(K).GT.0.0) THEN
              DEL  = SUMSIG(K) 
            ELSE
              DEL  = FN*0.04 
            ENDIF

            ACUR=ACUR*Y
            DEL=DEL  *Y

            CUR_TEST  =CUR_TEST  + ACUR*RSQT*NGEN
            DER_TEST  =DER_TEST  + DEL*DEL*RSQT*NGEN
          ELSE
            BTT  = BOVER/4.0
            X    = FAVER*EXP(-BTT*RSQ)
            ACUR = X
            IF(SUMSIG(K).GT.0.0) THEN
              DEL  = SUMSIG(K) 
            ELSE
              DEL  = X*0.04 
            ENDIF

            ACUR=ACUR*Y
            DEL=DEL  *Y

            CUR_TEST  =CUR_TEST  + ACUR*RSQT*NGEN
            DER_TEST  =DER_TEST  + DEL*DEL*RSQT*NGEN
          ENDIF

          IF(REST.NE.'Y'.AND.REST.NE.'O') GO TO 100

          IF(REST.EQ.'O') THEN

            BTT  =BOVER/4.0
            X    =FAVER*EXP(-BTT*RSQ)
            GGN  =X
            SGGN =X*0.04
            GGNA =0.0
            SGGNA=0.0

          ELSE

            IF(IFLAG_FN.LT.0.AND.REST.EQ.'O') THEN
              GO TO 100
            ENDIF
            GGN  =FN
            SGGN =SN
            GGNA =FNA
            SGGNA=SNA
          ENDIF

          IT1=KEY2/2 
          IT2=KEY2-IT1*2 
          IT3=IT1/2
          KEY3=IT3*4+1+IT2 

          NREST=NREST+1

        ELSE

          KEY3 =KEY2

          GGN  = GN
          SGGN = SGN
          GGNA = GNA
          SGGNA= SGNA
          BTT  = BT/4.0
          X=CSCALE*EXP(-BTT*RSQ)
C         IF(MTIN.LE.0) X=1.0
          GGN  =GGN   *X
          SGGN =SGGN  *X
          GGNA =GGNA  *X
          SGGNA=SGGNA *X

          IF(IFLAG_FN.GE.0) THEN

            IT1=KEY1/2 
            IT2=KEY1-IT1*2 
            IF(IT2.GT.0) THEN

              SUMDT_FREE=SUMDT_FREE +ABS(FN-GGN)*Y
              SF1_FREE  =SF1_FREE   +FN     *Y
              NFREE=NFREE+1
              SUMF1_FREE(K)  =SUMF1_FREE(K)  +FN     *Y
              SUMF1N_FREE(K) =SUMF1N_FREE(K) +1
              SUMD_FREE(K)   =SUMD_FREE(K)   +ABS(FN-GGN)*Y

            ENDIF
            
            NREFA=NREFA+1
            NREFG=NREFG+NGEN
            SUMD(K)   =SUMD(K)   +ABS(FN-GGN)*Y
            SUMDT     =SUMDT     +ABS(FN-GGN)*Y
            SF1       =SF1       +FN     *Y
            SFF2      =SFF2      +GGN    *Y
            SFF12     =SFF12     +FN *FN *Y*Y
            SFF22     =SFF22     +GGN*GGN*Y*Y
            SF1F2     =SF1F2     +FN *GGN*Y*Y
            SUMF1(K)  =SUMF1(K)  +FN     *Y
            SUMF1N(K) =SUMF1N(K) +1
            
            DEL       = FN-GGN
            ACUR      = FN
            ACUR=ACUR*Y
            DEL=DEL  *Y

            CUR_TEST  =CUR_TEST  +ACUR*RSQT*NGEN
            CUR       =CUR       +ACUR*RSQT*NGEN
            CURK(K)   =CURK(K)   +ACUR*RSQT*NGEN

            DER_TEST  =DER_TEST  + DEL*DEL*RSQT*NGEN
            DER       =DER       + DEL*DEL*RSQT*NGEN
            DERK(K)   =DERK(K)   + DEL*DEL*RSQT*NGEN

          ELSE
 
            BTT  =BOVER/4.0
            X    =FAVER*EXP(-BTT*RSQ)
C           ACUR =  X
            ACUR = GGN 

            IF(SUMSIG(K).GT.0.0) THEN
              DEL  = SUMSIG(K) 
            ELSE
              DEL  = X*0.04 
            ENDIF

            IF(RH.GE.RHMIN.AND.RH.LE.RHMAX) THEN
              ACUR=ACUR*Y
              DEL =DEL  *Y
              CUR_TEST  =CUR_TEST  + ACUR*RSQT*NGEN
              DER_TEST  =DER_TEST  + DEL*DEL*RSQT*NGEN
              DER       =DER       + DEL*DEL*RSQT*NGEN
              DERK(K)   =DERK(K)   + DEL*DEL*RSQT*NGEN
            ENDIF

            IF(REST.EQ.'O'.AND.MTIN.GT.0) THEN
              NC = NC + 1
            ENDIF

          ENDIF
        ENDIF

        NREF=NREF+1
        IF(MTOUT.GT.0) THEN
          IF(ITYP2.EQ.'F   ') THEN
            CALL WRT(MTOUT,IHP,IKP,ILP,GGN,GGNA,KEY3,IEND1)
          ELSE
            CALL WWRT(MTOUT,IHP,IKP,ILP,GGN,GGNA,SGGN,SGGNA
     *      ,KEY3,IEND1)
          ENDIF
          IF(MTOUT.LE.0) THEN
            CALL MSGERR(MDOC,' ERROR: WRITE OUTPUT_FILE')
            IF(MTIN.GT.0) CLOSE(MTIN)
            CLOSE(MTIN2)
            IERR=1
            RETURN
          ENDIF
        ENDIF
  100   CONTINUE
      ENDDO
      ENDDO
      ENDDO
C ---
      IF(MTIN.GT.0) CLOSE (MTIN)
      CLOSE (MTIN2)
      IEND1=2
      IF(MTOUT.GT.0) THEN
        CALL WRT(MTOUT,IH,IK,IL,FNN,FNA,KEY3,IEND1)
        IF(MTOUT.LE.0) THEN
          CALL MSGERR(MDOC,' ERROR: WRITE TO FILE_OUT')
          IERR=1
          RETURN
        ENDIF
        CLOSE(MTOUT)
      ENDIF
C ----------- R-FAC ------------
      A_CELL=A
      IF(MTIN.GT.0) THEN
 
      IF(NREFA.GT.0) THEN
        RFAC=SUMDT/SF1
      ELSE
        RFAC=0.0
      ENDIF      
      IF(NFREE.GT.0) THEN
        RFAC_FREE=SUMDT_FREE/SF1_FREE
      ELSE
        RFAC_FREE=0.0
      ENDIF      
      WRITE(LINE,'('' R-factor               :'',F8.4)') RFAC
      CALL MSGDOC(MDOC,LINE)
      IF(NFREE.GT.0) THEN
        WRITE(LINE,'('' Nfree, Rfree           :'',I8,F8.4)') 
     *  NFREE,RFAC_FREE
        CALL MSGDOC(MDOC,LINE)
      ENDIF
      ERR_MAX=0.0 
      ERR_MAX_TEST=0.0 
      IF(NREFA.GT.0) THEN
        DER_TEST  =(SQRT(DER_TEST*8.0)*TWOPI)/(VOL*A_CELL)
        CUR_TEST  =(CUR_TEST*2.0*TWOPI*TWOPI)/(VOL*A_CELL*A_CELL)

        DER  =(SQRT(DER*8.0)*TWOPI)/(VOL*A_CELL)
        CUR  =(CUR*2.0*TWOPI*TWOPI)/(VOL*A_CELL*A_CELL)
        IF(CUR.GT.0.0000001) ERR_MAX=(DER/CUR)*SQRT(3.0)
        IF(CUR_TEST.GT.0.0000001) 
     *  ERR_MAX_TEST=(DER_TEST/CUR_TEST)*SQRT(3.0)
        SF1A =SF1  /NREFA
        SF2A =SFF2 /NREFA
        SF12A=SFF12/NREFA
        SF22A=SFF22/NREFA
        SF1F2A=SF1F2/NREFA
        T1=(SF12A-SF1A*SF1A)
        T2=(SF22A-SF2A*SF2A)
        T1=T1*T2
        IF(T1.GE.0.0) THEN
          RCORR=(SF1F2A-SF1A*SF2A)/SQRT(T1)
        ELSE
          RCORR=0.0
        ENDIF
      ELSE
        RCORR=0.0
      ENDIF
      WRITE(LINE,'(''Correlation coefficient :'',F8.4)') RCORR
      CALL MSGDOC(MDOC,LINE)
      CALL MSGDOC(MDOC,
     *'CC = <F1*F2>-<F1><F2>/SQRT((<F1^2>-<F1>^2)(<F2^2>-<F2>^2))')
      WRITE(LINE,
     *'(''sig(r)/expected maximal coordinate error/:'',G14.4)')
     * ERR_MAX
      CALL MSGDOC(MDOC,LINE)
      CALL MSGDOC(MDOC,
     *'sig(r) = 4pi*sqrt(3*sum(h^2*(F1-F2)^2*A))/VOL')
      WRITE(LINE,
     *'(''sig(r)/for complete data set/            :'',G14.4)')
     * ERR_MAX_TEST
      CALL MSGDOC(MDOC,LINE)

      DPI_VAL= 0.0
      IF(NATOM.GT.0.AND.NTOT.GT.0) THEN
        COMPL=FLOAT(NREFA)/FLOAT(NTOT)
        P=FLOAT(NREFA)-4.0*FLOAT(NATOM)
        IF(P.GT.0.0000001.AND.COMPL.GT.0.001) THEN
          T1=SQRT(FLOAT(NATOM)/P)       
          T2=COMPL**(-0.333333)        
          DPI_VAL= 0.7  *T1*T2*RESMXO*RFAC
        ENDIF
        WRITE(LINE,'('' DPI   :'',G14.5)') DPI_VAL
        CALL MSGDOC(MDOC,LINE)
      ENDIF

c      WRITE(LINE,*) ' CUR:',CUR,CUR_TEST
c      CALL MSGDOC(MDOC,LINE)
c      WRITE(LINE,*) ' DER:',DER,DER_TEST
c      CALL MSGDOC(MDOC,LINE)
C       WRITE(LINE,'('' NT,NTG,NF,NFG,NC,NREST:'',7I8)') 
C     *NTOT,NTOTG,NREFA,NREFG,NC,NREST,NATOM
C       CALL MSGDOC(MDOC,LINE)

C --------------- R-factor ------------

      FMIN  = 1.E30
      FFMIN = 1.E30
      FMAX  =-1.E30   
      FFMAX =-1.E30   
      sd=0.0
      sc=0.0
      DO I=1,NUMGP
        IF(SUMF1N (I).GT.0.0 ) THEN
          SUME(I)=SUMD(I)/SUMF1(I)
          IF(I.GT.1) THEN
            IF(SUME(I).GT.FFMAX) FFMAX=SUME(I)
            IF(SUME(I).LT.FFMIN) FFMIN=SUME(I)
          ENDIF
        ELSE
          SUME(I)=0.0
        ENDIF
        IF(SUME(I).GT.FFMAX) FFMAX=SUME(I)

        IF(SUMF1N_FREE (I).GT.0.0 ) THEN
          SUMD_FREE(I)=SUMD_FREE(I)/SUMF1_FREE(I)
        ELSE
          SUMD_FREE(I)=0.0
        ENDIF

c        tt=0.0
c        SD  = SD + DERK(I)
c        T1  = (SQRT(SD*8.0)*TWOPI)/(VOL*A_CELL)
c        SC  = SC + CURK(I)
c        T2  = (SC*2.0*TWOPI*TWOPI)/(VOL*A_CELL*A_CELL)
c        IF(T2.GT.0.00000001) THEN 
c          TT=(T1/T2)*SQRT(3.0)
c        endif
c        WRITE(*,*) t1,t2,tt

      ENDDO


      SUM=0.0
      WT =0.0
      RESLIM=RESMNI
      IF(RESMXI.LE.3.0.AND.RESMNI.GE.5.0) THEN
        RESLIM =5.0
      ENDIF 
      IF(RESMXI.LE.2.0.AND.RESMNI.GE.4.0) THEN
        RESLIM=4.0
      ENDIF 
      IF(RESMXI.GT.3.0.AND.RESMXI.LT.5.0.AND.RESMNI.GE.10.0) 
     *THEN
        RESLIM=10.0
      ENDIF

      IF(RESLIM.GT.10.0) RESLIM=10.0 
      DO I=2,NUMGP-2
        RRES=(RHRP(I)+RHRP(I+1))/2.0
        IF(RRES.LE.RESLIM) THEN
          RRFAC=SUME(I)
          CALL RMS_LUZZ(RRES,RRFAC,RRMS)
          R1 =RHR(I)
          R2 =RHR(I+1)
          W  =R2-R1
          SUM = SUM + RRMS * SUMF1N(I)/W
          WT  = WT  +        SUMF1N(I)/W
        ENDIF
      ENDDO

      ERR_LUZZ=0.0
      IF(WT.GT.0.0) ERR_LUZZ=SUM/WT

      DO I=1,NUMGP
        RRES=(RHRP(I)+RHRP(I+1))/2.0
        IF(RRES.LE.10.0) THEN
          CALL RF_LUZZ(RRES,ERR_LUZZ,RRFAC)
          DLUZZ(I)=RRFAC
        ELSE
          DLUZZ(I)= 0.0
        ENDIF
      ENDDO

      CALL MSGDOC(MDOC,' ')
      WRITE(LINE,
     *'(''<u>/upper estimate error in coords by Luzzati plot/='',F8.4)'
     *) ERR_LUZZ
      CALL MSGDOC(MDOC,LINE)

      CALL MSGDOC(MDOC,' ')
      CALL MSGDOC(MDOC,
     *' ----    Distribution of R-factor     ----')
      CALL MSGDOC(MDOC,' ')

      WRITE(LINE,'(''  min,max:'',2G14.4)') 
     *FFMIN,FFMAX
      CALL MSGDOC(MDOC,LINE)

      TITLE1='     (*) R-factor   (+) Luzzati plot'
      IF(FMAX.GT.0.75) FMAX=0.75
      IF(FMAX.LE.0.20) FMAX=0.20
      IF(FMAX.LE.0.30) FMAX=0.30
      IF(FMAX.LE.0.40) FMAX=0.40
      IF(FMAX.LE.0.50) FMAX=0.50
      IF(FMAX.LE.0.60) FMAX=0.60
      IF(FMAX.LE.0.75) FMAX=0.75
      NF=2
      IMSG=0
      FMIN=0
      CALL GRAPH_PP(MDOC,NUMGP,NF,RHRP,SUME,DLUZZ,FMIN,FMAX,SUMF1N
     *              ,TITLE1,IMSG)
C ---------------------------------------
C ---------------
      FMIN  = 1.E30
      FFMIN = 1.E30
      FMAX  =-1.E30   
      FFMAX =-1.E30
      S  = 0.0
      S1 = 0.0  
      DO I=1,NUMGP
        S  = S  + SUMD(I)
        S1 = S1 + SUMF1(I)
        IF(S1.GT.0.0 ) THEN
          SUME(I) = S/S1
          IF(I.GT.1) THEN
            IF(SUME(I).GT.FFMAX) FFMAX=SUME(I)
            IF(SUME(I).LT.FFMIN) FFMIN=SUME(I)
          ENDIF
        ELSE
          SUME(I)=0.0
        ENDIF
        IF(SUME(I).GT.FFMAX) FFMAX=SUME(I)
      ENDDO


      SUM=0.0
      WT =0.0
      RESLIM=RESMNI
      IF(RESMXI.LE.3.0.AND.RESMNI.GE.5.0) THEN
        RESLIM =5.0
      ENDIF 
      IF(RESMXI.LE.2.0.AND.RESMNI.GE.4.0) THEN
        RESLIM=4.0
      ENDIF 
      IF(RESMXI.GT.3.0.AND.RESMXI.LT.5.0.AND.RESMNI.GE.10.0) 
     *THEN
        RESLIM=10.0
      ENDIF

      IF(RESLIM.GT.10.0) RESLIM=10.0 
      DO I=2,NUMGP-2
        RRES=(RHRP(I)+RHRP(I+1))/2.0
        IF(RRES.LE.RESLIM) THEN
          RRFAC=SUME(I)
          CALL RMS_LUZZ(RRES,RRFAC,RRMS)
          R1 =RHR(I)
          R2 =RHR(I+1)
          W  =R2-R1
          SUM = SUM + RRMS * SUMF1N(I)/W
          WT  = WT  +        SUMF1N(I)/W
        ENDIF
      ENDDO

      ERR_LUZZ=0.0
      IF(WT.GT.0.0) ERR_LUZZ=SUM/WT


      DO I=1,NUMGP
        RRES=(RHRP(I)+RHRP(I+1))/2.0
        IF(RRES.LE.10.0) THEN
          CALL RF_LUZZ(RRES,ERR_LUZZ,RRFAC)
          DLUZZ(I)=RRFAC
        ELSE
          DLUZZ(I)= 0.0
        ENDIF
      ENDDO

      CALL MSGDOC(MDOC,' ')
      CALL MSGDOC(MDOC,
     *' ----    Cumulative R-factor     ----')
      CALL MSGDOC(MDOC,' ')

      WRITE(LINE,'(''  min,max:'',2G14.4)') 
     *FFMIN,FFMAX
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,  
     *'('' Luzzati plot / for <u> = '',F8.4,'' /'')') 
     *ERR_LUZZ
      CALL MSGDOC(MDOC,LINE)

      TITLE1='     (*) R-factor   (+) Luzzati plot'
      IF(FMAX.GT.0.75) FMAX=0.75
      IF(FMAX.LE.0.20) FMAX=0.20
      IF(FMAX.LE.0.30) FMAX=0.30
      IF(FMAX.LE.0.40) FMAX=0.40
      IF(FMAX.LE.0.50) FMAX=0.50
      IF(FMAX.LE.0.60) FMAX=0.60
      IF(FMAX.LE.0.75) FMAX=0.75
      NF=2
      IMSG=0
      FMIN=0
      CALL GRAPH_PP(MDOC,NUMGP,NF,RHRP,SUME,DLUZZ,FMIN,FMAX,SUMF1N
     *              ,TITLE1,IMSG)
C ---------------------------------------
      CALL MSGDOC(MDOC,' ')
      CALL MSGDOC(MDOC,
     *' ---- sig(r) - expected maximal coordinate error ----')
      CALL MSGDOC(MDOC,' ')
      NF=1
      FMIN = 1.E30
      FFMIN= 1.E30
      FMAX =-1.E30
      FFMAX=-1.E30

      SD=0.0
      SC=0.0   
      DO I=1,NUMGP
        TT  = 0.0
        SD  = SD + DERK(I)
        T1  = (SQRT(SD*8.0)*TWOPI)/(VOL*A_CELL)
        SC  = SC + CURK(I)
        T2  = (SC*2.0*TWOPI*TWOPI)/(VOL*A_CELL*A_CELL)
        IF(T2.GT.0.00000001) THEN 
          TT=(T1/T2)*SQRT(3.0)
          IF(TT.GT.FFMAX) FFMAX = TT
          IF(TT.LT.FFMIN) FFMIN = TT
          IF(I.GT.5) THEN
            IF(TT.GT.FMAX)  FMAX =TT
            IF(TT.LT.FMIN)  FMIN =TT
            SUMF1N(I)=0.0
          ELSE
            SUMF1N(I)=10000000000000.0
          ENDIF
        ELSE
          SUMF1N(I)=10000000000000.0
        ENDIF
        SUMC(I)=TT
      ENDDO
      TITLE1='     (*) sig(r)'
      WRITE(LINE,'(''  min,max:'',2G14.4)') 
     *FFMIN,FFMAX
      CALL MSGDOC(MDOC,LINE)

      DO I=1,NUMGP
        RESULTA(I,8)=RHRP(I)
        RESULTA(I,9)=SUMC(I)
      ENDDO
      RESULTA(IPRROW,8)=RHRP(NUMGP+1)
      RESULTA(IPRROW,9)=ERR_MAX

      DO I=1,NUMGP
        IF(SUMF1N(I).EQ.0.0) THEN
          IF(FMAX.GT.0.0) THEN
            T=SUMC(I)/FMAX
          ELSE
            T=0.0
          ENDIF 
          SUMF1N(I)=T
        ENDIF 
      ENDDO      
      CALL CORR_MAX(FMAX,FMAXN)
      IMSG  = 1
      FMIN  = 0
      CALL GRAPH_PP(MDOC,NUMGP,NF,RHRP,SUMC,SUMF1,FMIN,FMAXN,SUMF1N
     *              ,TITLE1,IMSG)
C -----------------------------------
      IF(IPRROW.GE.21) THEN
        RESULT(11) =RFAC_FREE
        RESULT(12) =DPI_VAL     
        RESULT(13) =ERR_MAX     
        RESULT(14) =NUMGP    
        RESULT(15) =BOFF     
        RESULT(16) =BADD     
        RESULT(17) =RCORR
        RESULT(20) =RFAC
      ENDIF

      ELSE

      IF(IPRROW.GE.21) THEN
        RESULT(15) =BOFF     
        RESULT(16) =BADD     
        RESULT(17) =0.0
        RESULT(20) =0.0
      ENDIF

      ENDIF
C ----------------
      CALL MSGDOC(MDOC,' ')
      IF(MTOUT.GT.0) THEN
        CALL MSGDOC(MDOC,'Writing to output file')
      ELSE
        CALL MSGDOC(MDOC,'Scaled file')
      ENDIF
      WRITE(LINE,'(''Number of refls                  :'',I8)')NREF
      CALL MSGDOC(MDOC,LINE)
      IF(REST.EQ.'Y'.OR.REST.EQ.'O') THEN
        IF(NREST.GT.0) THEN
        CALL MSGDOC(MDOC,'      /including restored refls/ ')
        WRITE(LINE,'(''Number restored refls            :'',I8)')NREST
        CALL MSGDOC(MDOC,LINE)
        ENDIF
        IF(MTIN.GT.0.AND.NMISS.GT.0) THEN
        WRITE(LINE,'(''Number missed refls in both files:'',I8)')NMISS
        CALL MSGDOC(MDOC,LINE)
        ENDIF
      ENDIF
C ---
      IF(NREF.LE.0) THEN
        CALL MSGERR(MDOC,' ERROR: NUMBER OF REFLS = 0')
        IERR=1
      ENDIF
      RETURN
      END


      SUBROUTINE GRAPH_PATTT(MDOC,NG,NF,R,X,Y,FMIN,FMAX,SN
     *                      ,TITLE,IMSG)
      REAL X(NG),Y(NG),R(NG),SN(NG)
      CHARACTER STR*61,MSG*1,LINE*80,TITLE1*80,TITLE*(*),LINE1*80
C----------------------------------------------------------------
      CHARACTER FRMT1*7,FRMT2*7,FRMT3*7,FRM*7,CH6*6
      DATA FRMT1/'(F12.2)'/,FRMT2/'(F12.3)'/,FRMT3/'(F12.5)'/
C----------------------------------------------------------------
      NNG=NG
      IF(NNG.GT.20) NNG=20
      IF(NNG.LE. 0) NNG=1

      CALL MSGDOC(MDOC
     *,' ---------------------------------------------------------------
     *-------')      

      SCALE=1.0
      IF(FMAX.LT.0.00001.OR.
     *   FMAX.GE.1000000000.0) THEN
        SCALE=100.0/FMAX + 0.00000001
        WRITE(LINE,'(''Scale :'',F12.2)') 
     *  SCALE
        CALL MSGDOC(MDOC,LINE)
      ENDIF

      FRM=FRMT1
      IF(FMAX.LT.0.1)  FRM=FRMT2
      IF(FMAX.LT.0.01) FRM=FRMT3
      LINE=
     *'                                                              
     *        '
      T=FMIN*SCALE
      WRITE(LINE( 6:17),FRM) T
       
      DEL=((FMAX-FMIN)*SCALE)/5.0
      DO I=1,4
        T =FMIN*SCALE+DEL*I
        I2=12*I+17
        I1=I2-11
        WRITE(LINE(I1:I2),FRM) T
      ENDDO
      T=FMAX*SCALE
      WRITE(LINE(66:77),FRM) T
C ----
      IF(IMSG.GT.0) THEN
        TITLE1='Ratio Distance'
      ELSE
        TITLE1='   N  Distance'
      ENDIF
      CALL LENSTR_BL(TITLE1,LEN1)
      CALL LENSTR_BL(TITLE ,LEN)
      I=80-(LEN1+LEN+2)
      IF(I.LT.0) LEN=LEN+I
      IF(LEN.LE.0) THEN
        LEN=1
      ELSE IF(LEN.GT.60) THEN
        LEN=60
      ENDIF
      I=LEN+LEN1
      LINE1=' '
      IF(I.GT.0.AND.I.LE.80)
     *LINE1=TITLE1(1:LEN1)//TITLE(1:LEN)
      CALL LENSTR_BL(LINE1,LEN)
      IF(LEN.LE.0) THEN
        LINE1=' '
        LEN=1
      ELSE IF(LEN.GT.78) THEN
        LEN=78
      ENDIF
      CALL MSGDOC(MDOC,LINE1(1:LEN))
      CALL MSGDOC(MDOC,LINE)
      CALL MSGDOC(MDOC
     *,' ---------------------------------------------------------------
     *-------')      
      TEMP=(FMAX-FMIN)*SCALE
      IF(TEMP.LT.1.E-5) TEMP=1.0
      COEF=60.0/TEMP
      IFN0=(-FMIN*SCALE)*COEF+1
      IF(IFN0.GT.61) IFN0=61
      IF(IFN0.LE. 0) IFN0=0

      DO     I=1,NNG
          RES=R(I)
          IFN=(X(I)-FMIN)*SCALE*COEF+1
          IF(IFN.GT.61) IFN=61
          IF(IFN.LE. 0) IFN= 1
          STR=' '
          STR( 1: 1)  ='.'
          STR(13:13)  ='.'
          STR(25:25)  ='.'
          STR(37:37)  ='.'
          STR(49:49)  ='.'
          STR(61:61)  ='.'
          IF(IFN0.GT.0) STR(IFN0:IFN0)='o'
          STR(IFN:IFN)='*'
          IF(NF.GT.1) THEN
            IFD=(Y(I)-FMIN)*SCALE*COEF+1
            IF(IFD.GT.61) IFD=61
            IF(IFD.LE. 0) IFD= 1
            STR(IFD:IFD)='+'
            IF(IFN.EQ.IFD) STR(IFN:IFN)='#'
          ENDIF
          IF(IMSG.GT.0) THEN
            WRITE(CH6,'(F6.4)') SN(I)
            IF(CH6(1:1).EQ.'*') CH6='   -  ' 
            WRITE(LINE,'(A,1X,F7.2,2X,A61)') CH6,RES,STR
          ELSE
            NP=I
            WRITE(LINE,'(I6,F8.2,2X,A61)') NP,RES,STR
          ENDIF
          CALL MSGDOC(MDOC,LINE)
      ENDDO
      CALL MSGDOC(MDOC
     *,' ---------------------------------------------------------------
     *-------')      
      RETURN
      END

      SUBROUTINE TEMP_FLPP(SUMMET,NGP,RHR,SCALE,BTEMP,ALIM)
      REAL    SUMMET(*),X(40),Y(40),RHR(*)
C --------------------------------------------------------------------
      SUMXY =0.0
      SUMXX =0.0
      SUMX  =0.0
      SUMY  =0.0
      COUNT =0.0
      IFIRST=0
      FMAX  =0.0
      DO     J=1,NGP
        IF(SUMMET(J).GE.FMAX) FMAX=SUMMET(J)
      ENDDO  
      DO     J=1,NGP
        GP=1.0
        X(J)=(RHR(J)**2)/4.0
        IF(SUMMET(J).LE.(FMAX*ALIM)) IFIRST=1
        IF(IFIRST.EQ.0) THEN
          Y(J)=ALOG(1.0/SUMMET(J))
          SUMXY=SUMXY + X(J)*Y(J)*GP
          SUMXX=SUMXX + X(J)*X(J)*GP
          SUMX =SUMX  + X(J)*GP
          SUMY =SUMY  + Y(J)*GP
          COUNT=COUNT + GP
        ENDIF
      ENDDO  
      SLOPE=((COUNT*SUMXY)-(SUMX*SUMY))/((COUNT*SUMXX)-(SUMX*SUMX))
      CEPT=(1.0/COUNT)*(SUMY-(SLOPE*SUMX))
      BTEMP=0.5*SLOPE*0.5
      SCALE=EXP(-CEPT)
      RETURN
      END

      SUBROUTINE GRAPH_PP(MDOC,NG,NF,R,X,Y,FMIN,FMAX,SN
     *                   ,TITLE,IMSG)
      REAL X(NG),Y(NG),R(NG),SN(NG)
      CHARACTER STR*61,MSG*1,LINE*80,TITLE*(*),TITLE1*80,LINE1*80
      CHARACTER FRMT1*7,FRMT2*7,FRMT3*7,FRM*7,CH6*6
      DATA FRMT1/'(F12.2)'/,FRMT2/'(F12.3)'/,FRMT3/'(F12.5)'/
C----------------------------------------------------------------
      NNG=NG
      IF(NNG.GT.20) NNG=20
      IF(NNG.LE. 0) NNG=1

      CALL MSGDOC(MDOC
     *,' ---------------------------------------------------------------
     *-------')      

      SCALE=1.0
      IF(FMAX.LT.0.00001.OR.
     *   FMAX.GE.1000000000.0) THEN
        SCALE=100.0/FMAX + 0.00000001
        WRITE(LINE,'(''Scale :'',F12.2)') 
     *  SCALE
        CALL MSGDOC(MDOC,LINE)
      ENDIF

      FRM=FRMT1
      IF(FMAX.LT.0.1)  FRM=FRMT2
      IF(FMAX.LT.0.01) FRM=FRMT3
      LINE=
     *'                                                              
     *        '
      T=FMIN*SCALE
      WRITE(LINE( 6:17),FRM) T
       
      DEL=((FMAX-FMIN)*SCALE)/5.0
      DO I=1,4
        T =FMIN*SCALE+DEL*I
        I2=12*I+17
        I1=I2-11
        WRITE(LINE(I1:I2),FRM) T
      ENDDO
      T=FMAX*SCALE
      WRITE(LINE(66:77),FRM) T
C ---------------

      IF(IMSG.GT.0) THEN
        TITLE1=' Ratio Resolution'
      ELSE
        TITLE1='   N   Resolution'
      ENDIF
      CALL LENSTR_BL(TITLE1,LEN1)
      CALL LENSTR_BL(TITLE ,LEN)
      I=80-(LEN1+LEN+2)
      IF(I.LT.0) LEN=LEN+I
      IF(LEN.LE.0) THEN
        LEN=1
      ELSE IF(LEN.GT.60) THEN
        LEN=60
      ENDIF
      I=LEN+LEN1
      LINE1=' '
      IF(I.GT.0.AND.I.LE.80)
     *LINE1=TITLE1(1:LEN1)//TITLE(1:LEN)
      CALL LENSTR_BL(LINE1,LEN)
      IF(LEN.LE.0) THEN
        LINE1=' '
        LEN=1
      ELSE IF(LEN.GT.78) THEN
        LEN=78
      ENDIF
      CALL MSGDOC(MDOC,LINE1(1:LEN))

      CALL MSGDOC(MDOC,LINE)
      CALL MSGDOC(MDOC
     *,' ---------------------------------------------------------------
     *-------')      
      TEMP=(FMAX-FMIN)*SCALE
      IF(TEMP.LT.1.E-5) TEMP=1.0
      COEF=60.0/TEMP
      IFN0=(-FMIN*SCALE)*COEF+1
      IF(IFN0.GT.61) IFN0=61
      IF(IFN0.LE. 0) IFN0=0
      DO     I=1,NNG
          RES=R(I)
          IFN=(X(I)-FMIN)*SCALE*COEF+1
          IF(IFN.GT.61) IFN=61
          IF(IFN.LE. 0) IFN= 1
          STR=' '
          STR( 1: 1)  ='.'
          STR(13:13)  ='.'
          STR(25:25)  ='.'
          STR(37:37)  ='.'
          STR(49:49)  ='.'
          STR(61:61)  ='.'
          IF(IFN0.GT.0) STR(IFN0:IFN0)='o'
          STR(IFN:IFN)='*'
          IF(NF.GT.1) THEN
            IFD=(Y(I)-FMIN)*SCALE*COEF+1
            IF(IFD.GT.61) IFD=61
            IF(IFD.LE. 0) IFD= 1
            STR(IFD:IFD)='+'
            IF(IFN.EQ.IFD) STR(IFN:IFN)='#'
          ENDIF
          IF(IMSG.GT.0) THEN
            if ( sn(i).gt.10.0 .or. sn(i).lt.0 ) then
              ch6 = '   -  '
            else  
              WRITE(CH6,'(F6.4)') SN(I)
            endif
c           WRITE(CH6,'(F6.4)') SN(I)
            IF(CH6(1:1).EQ.'*') CH6='   -  ' 
            WRITE(LINE,'(A,1X,F7.2,2X,A61)') CH6,RES,STR
          ELSE
            NP=SN(I)
            if ( np.gt.999999 .or. np.lt.-99999 ) then
              ch6 = '   -  '
            else
              WRITE(CH6,'(I6)') NP
            endif
c            WRITE(CH6,'(I6)') NP
            IF(CH6(1:1).EQ.'*'.OR.NP.EQ.0) CH6='   -  ' 
            WRITE(LINE,'(A,1X,F7.2,2X,A61)') CH6,RES,STR
          ENDIF
          CALL MSGDOC(MDOC,LINE)
      ENDDO
      CALL MSGDOC(MDOC
     *,' ---------------------------------------------------------------
     *-------')      
      RETURN
      END


      SUBROUTINE TEMP_FLLL(SUMMET,SUMAZ,NGP,RHMIN,THINT,SCALE,BTEMP)
      REAL    SUMMET(40),SUMAZ(40),X(40),Y(40)
C --------------------------------------------------------------------
      SUMXY=0.0
      SUMXX=0.0
      SUMX =0.0
      SUMY =0.0
      COUNT=0.0
      DO     J=1,NGP
        GP=SUMAZ(J)
        NP=GP+0.001
        IF(NP.GT.0) THEN
          FJ=J
          X(J)=(((FJ-0.5)*THINT+RHMIN)**2)/4.0
          Y(J)=ALOG(SUMAZ(J)/SUMMET(J))
          SUMXY=SUMXY + X(J)*Y(J)*GP
          SUMXX=SUMXX + X(J)*X(J)*GP
          SUMX =SUMX  + X(J)*GP
          SUMY =SUMY  + Y(J)*GP
          COUNT=COUNT + GP

        ENDIF
      ENDDO  
      SLOPE = ((COUNT*SUMXY)-(SUMX*SUMY))/((COUNT*SUMXX)-(SUMX*SUMX))
      CEPT  = (1.0/COUNT)*(SUMY-(SLOPE*SUMX))
      BTEMP = 0.5*SLOPE
      SCALE = EXP(-CEPT)
      RETURN
      END

      SUBROUTINE CORR_MAX(AMAX,AMAXN)
C -------------------------------------------
      IF(AMAX.LE.0.0) THEN
        AMAXN=0.0
        RETURN
      ENDIF
      ALG = LOG(AMAX)/LOG(10.0)
      N   = ALG
      IF(N.LE.0) N=N-1
      A1N   = FLOAT(1-N)
      COEF  = 10.0**A1N
      AMAXC = AMAX*COEF
      DEL   = AMAXC/5.0
      IDEL  = DEL
      A     = DEL-IDEL
      IF(A.GT.0.0) IDEL = IDEL+1 
      IMAX  = IDEL*5
      AMAXN = IMAX/COEF
      RETURN
      END


C -I-
      SUBROUTINE CONCRD(MDOC,MODE,NAME1,NAME2,NAMEI,SETT,REST
     * ,WAT,P1,HATM,NUM,NOCC,ALT,CONV
     * ,A,B,C,ALPHA,BETA,GAMMA,BOV,ISYM,IPRSYM,IERR)
C ----------------------------------------------------------
C -P- CONCRD - copies "BLANC"_file to "BLANC"_file and :
C                changes SETTING for monoclinic space groups; 
C                restores NCS-related atoms; 
C                removes water molecules; 
C                sets new value B_iso or/and occupancies = 1 to all atoms; 
C                changes space group ;
C                sets new atom's number (started from 1); 
C                removes H-atoms;
C                removes alternative position; 
C                removes all atoms except:
C                   -  CA
C                   -  back bond"s atoms + CB
C                   -  P
C                converts fract. coords to ort. or ort. to fract.
C -S-
C
C  Dialog and Batch: 
C
C    FILE_IN  - input file of coordinates.
C    FILE_OUT - output file.
C
C    SETT     - <N>/Y -  change SETTING 
C                        for monoclinic space groups
C    REST     - <N>/Y  - restore NCS-related atoms
C    WAT      - <N>/Y -  remove water molecules
C    HATM     - <N>/Y -  remove H-atoms
C    HATM:    - <N>/Y/Q  Y- remove H_atoms, Q and atoms with name started by Q
C    ALT      - <N>/Y -  remove alternative positions /except "A" or "1"/
C    NUM      - <N>/Y -  set new atom's number.
C    NOCC     - <N>/Y -  set all occupancies = 1.0
C    P1       - <N>/Y -  Y set new space group P1
C                        or P1= new space group name, for example 'P 1 21 1'
C    CELL: <from file> - A,B,C,alpha,beta,gamma/degrees/ if P1="Y"
C    BOV        <0> - Boverall, set this value for all atoms.
C                     0 means not to change 
C    MODE:  <Y>  - all  atoms will be included in output file.
C            A   - only CA
C            B   - only back bond"s atoms + CB
C            P   - only P
C    CONV:  <N>  - 
C            F   - convert to fractional coordinates
C            C   - convert to ortoganal  coordinates
C                        
C
C  Parameters of subroutine CONCRD: 
C
C      SUBROUTINE CONCRD(MDOC,MODE,NAME1,NAME2,NAMEI,SETT,REST
C     * ,WAT,P1,HATM,NUM,NOCC,ALT,CONV
C     * ,A,B,C,ALPHA,BETA,GAMMA,BOV,ISYM,IPRSYM,IERR)
C
C    MDOC   - mode of writting messages to DOC-file
C             0 - only terminal , < - 0 only file, 0 < < 99 - both
C             >= 99 - don't write  
C    MODE   - see above. / character*1 /
C    NAME1  - name of input file without extention.
C    NAME2  - name of output file without extention.
C    NAMEI  - dummy
C    SETT   - see above. / character*1 /
C    REST   - see above. / character*1 /
C    WAT    - see above. / character*1 /
C    HATM   - see above. / character*1 /
C    ALT    - see above. / character*1 /
C    NUM    - see above. / character*1 /
C    NOCC   - see above. / character*1 /
C    P1     - see above. / character*1 /
C    CONV   - see above. / character*1 /
C    A,B,C  - for P1 ne "N" - new cell parameters.
C    ALPHA,BETA,GAMMA
C    BOV    - Boverall, 0 means not to change / MODE="C"/
C    ISYM   - integer*2 array for cryst.symmetry operators.
C    IPRSYM - dimension of integer*2 array ISYM(5,3,IPRSYM),
C             number of cryst. symm. operators.
C    IERR   - output signal of error / = 1 -error , = 0 - OK / 
C -I-
C ----------------------------------------------------------
      INTEGER     MDOC,IPRSYM,IERR
      INTEGER*2   ISYM(5,3,IPRSYM)
      CHARACTER   MODE*1,SETT*1,REST*1,WAT*1,P1*(*)
      CHARACTER   HATM*1,NUM*1,NOCC*1,ALT*1,CONV*1
      CHARACTER   NAME1*(*),NAME2*(*),NAMEI*(*)
C==================================================================
      IERR=0

        IF(MODE.EQ.'b') MODE='B'
        IF(MODE.EQ.'p') MODE='P'
        IF(MODE.EQ.'a') MODE='A'
        IF(MODE.NE.'B'.AND.MODE.NE.'P'.AND.MODE.NE.'A') MODE='Y'

        IF(CONV.EQ.'f') CONV='F'
        IF(CONV.EQ.'c') CONV='C'
        IF(CONV.NE.'F'.AND.CONV.NE.'C') CONV='N'

        IF(SETT.EQ.'y') SETT='Y'
        IF(SETT.NE.'Y') SETT='N'

        IF(WAT.EQ.'y') WAT='Y'
        IF(WAT.NE.'Y') WAT='N'

        IF(P1(1:1).EQ.'y') P1='Y'
        IF(P1(1:1).EQ.'n'.OR.P1(1:1).EQ.' '.OR.P1(1:1).EQ.'.') P1='N'

        IF(NUM.EQ.'y')  NUM='Y'
        IF(NUM.NE.'Y') NUM='N'

        IF(ALT.EQ.'y') ALT='Y'
        IF(ALT.NE.'Y') ALT='N'

        IF(NOCC.EQ.'y') NOCC='Y'
        IF(NOCC.EQ.'r') NOCC='R'
        IF(NOCC.NE.'Y'.AND.NOCC.NE.'R') NOCC='N'

        IF(HATM.EQ.'y') HATM='Y'
        IF(HATM.EQ.'q') HATM='Q'
        IF(HATM.NE.'Y'.AND.HATM.NE.'Q') HATM='N'

        CALL COPY_CRD(MDOC,MODE,NAME1,NAME2,SETT,REST,WAT,P1,
     *   HATM,NUM,NOCC,ALT,CONV
     *   ,A,B,C,ALPHA,BETA,GAMMA,BOV,ISYM,IPRSYM,IERR)

C ---------------------------
      RETURN
      END


      SUBROUTINE COPY_CRD(MDOC,MOD,NAME1,NAME2,SETT,REST,WAT,P1
     * ,HATM,NUM,NOCC,ALT,CONV
     * ,A,B,C,CALPHA,CBETA,CGAMMA,BOV,ISYM,IPRSYM,IERR)
C --------------------------------------------------------------
      INTEGER   MDOC,IERR
      CHARACTER NAME1*(*),NAME2*(*),MOD*1,CONV*1
      INTEGER   IPRSYM
      INTEGER*2 ISYM(5,3,IPRSYM)
      CHARACTER SETT*1,REST*1,WAT*1,P1*(*),HATM*1,NUM*1,NOCC*1,ALT*1
C ---
C ------------------------------------------------------------
      INCLUDE 'mr_crd_com.fh'
C -----------------------------------------------------------
      PARAMETER ( NWORDSMAX = 40 )
      COMMON /COMFREAD/ FWORDS,IFRD_ERR,NWORDS,LEN_WORDS,IWORDS
     *                 ,WORDS,IN_STRING
      REAL      FWORDS   (NWORDSMAX)
      INTEGER*4 LEN_WORDS(NWORDSMAX)
      INTEGER*4 IWORDS   (NWORDSMAX)
      INTEGER*4 NWORDS,IFRD_ERR
      CHARACTER WORDS(NWORDSMAX)*80
      CHARACTER IN_STRING*256
C --------------------------------------------------------------
C ----------------------
      REAL        X(3),Y(3),Z(3),AMNCS(3,3),TRNCS(3)
      REAL        AM(3,3)
      INTEGER     MODE
      CHARACTER   LINE*80,NCSF*1,GID*4,NCS_FLAG*1,CHAIN*2,STR*80
      CHARACTER   BMODE*1
C --------------------------------------------------------------
      PI  = 4.0*ATAN(1.0)
      IN  = 10
      MD  = -ABS(MDOC)-1
C --------
      BMODE = 'N'
      IF(BOV.GT.1000.0) THEN
        BMODE = 'A'
        BOV   = BOV-1000.0
      ENDIF
      IF(REST.EQ.'y') REST='Y'
      IF(REST.NE.'Y') REST='N'
      NCS_FLAG='N'
C --------
      CALL ORCRD(MD,IN,NAME1,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERR: OPEN IN_FILE')
        CLOSE(IN)
        RETURN
      ENDIF
C ------------------------------------------------
      CALL C_AT_CR
      NCSOP=0
      CALL GET_NCS(MDOC,NCMAX,NCSOP,AMNCS,TRNCS,IERR)
      IF(IERR.NE.0) RETURN      
      IF(NCSOP.GT.0) THEN
        IGR=0
        CALL GET_ASYMM(MDOC,NASMAX,NGR,ICHOLD,IGR,ICH,INC,MLT
     *                 ,IGOLD,NCSF,GID,IERR)
        IF(IERR.NE.0) RETURN      
        IF(NGR.GT.0) THEN
          DO IGR=1,NGR
            CALL GET_ASYMM(MDOC,NASMAX,NGR,ICHOLD,IGR,ICH,INC,MLT
     *                    ,IGOLD,NCSF,GID,IERR)
c            write(*,*) IGR,ICH,INC,MLT
            IF(IERR.NE.0) RETURN      
            IF(NCSF.EQ.'c') NCSF='C'
            IF(NCSF.EQ.'N'.OR.NCSF.EQ.'n') THEN
              NCS_FLAG='Y'
              IF(REST.EQ.'Y') NCSF='c'
            ENDIF
            CALL SET_ASYMM(MDOC,NASMAX,NGR,ICHOLD,IGR,ICH,INC,MLT
     *                 ,IGOLD,NCSF,GID,IERR)
          ENDDO
        ENDIF
        WRITE(STR,
     *  '(''NUMBER OPERATORS OF NON-CRYST.SYMMETRY:'',I5)') NCSOP
        CALL MSGDOC(MDOC,STR)
        IF(NCSOP.GT.0) THEN
          CALL MSGDOC(MDOC,' ')
          CALL MSGDOC(MDOC,'  X-NEW           X-0      TX')
          CALL MSGDOC(MDOC,'  Y-NEW  = [M] *  Y-0  +   TY')
          CALL MSGDOC(MDOC,'  Z-NEW           Z-0      TZ')
          CALL MSGDOC(MDOC,' ')
          CALL MSGDOC(MDOC,' ORTOGONAL COORDINATE SYSTEM')
          CALL MSGDOC(MDOC,'  COORDINATES IN ANGSTROMS')
          CALL MSGDOC(MDOC,' ')
          DO     I=1,NCSOP
            CALL GET_NCS(MDOC,NCMAX,I,AMNCS,TRNCS,IERR)
            IF(IERR.NE.0) RETURN      
            WRITE(STR,600) I
            CALL MSGDOC(MDOC,STR)
  600       FORMAT('  OPERATORS OF NON-CRYST.SYMMETRY :',I5)
            CALL ANGFIX(MDOC,AMNCS,ALPHA,BETA,GAMMA)
            WRITE(STR,610) (TRNCS(L),L=1,3)
            CALL MSGDOC(MDOC,STR)
  610       FORMAT(' TRANSLATION VECTOR :',3F10.5,' /ANGSTROM/')
          ENDDO
        ELSE
          WRITE(STR,
     *    '('' ERR: NUMBER OF NCS-OPERATORS:'',I5)') NCSOP
          CALL MSGDOC(MDOC,STR)
          IERR=1
          RETURN
        ENDIF
      ENDIF
C--------------------------------------------------
      IF(CR_NSPGR.GE.3.AND.CR_NSPGR.LE.15.AND.CR_SETT.LE.2.AND.
     *   SETT.EQ.'Y') THEN
        IS=CR_SETT
        IF(IS.EQ.2) THEN
          T     = CR_CELL(1) 
          CR_CELL(1) = CR_CELL(3)
          CR_CELL(3) = CR_CELL(2)
          CR_CELL(2) = T
          T     = CR_CELL(4)
          CR_CELL(4) = CR_CELL(6)
          CR_CELL(6) = CR_CELL(5)
          CR_CELL(5) = T
          GAMMA = CR_CELL(6)-PI/2.0
        ELSE                 
          GAMMA  = -(CR_CELL(6)-PI/2.0)
          T     = CR_CELL(1) 
          CR_CELL(1)  = CR_CELL(2)
          CR_CELL(2)  = CR_CELL(3)
          CR_CELL(3)  = T
          T     = CR_CELL(4)
          CR_CELL(4) = CR_CELL(5)
          CR_CELL(5) = CR_CELL(6)
          CR_CELL(6) = T
        ENDIF
        IN_STRING = CR_SPGR
        CALL FRD_PARM
        IF(WORDS(1)(1:1).EQ.'B') THEN
          WORDS(1)(1:1)='C'
        ELSE IF(WORDS(1)(1:1).EQ.'B') THEN
          WORDS(1)(1:1)='C'
        ENDIF
        CR_SPGR=WORDS(1)(1:LEN_WORDS(1))//' '
     *      //WORDS(2)(1:LEN_WORDS(2))//' '
     *      //WORDS(4)(1:LEN_WORDS(4))//' '
     *      //WORDS(3)(1:LEN_WORDS(3))
        IF(IS.EQ.2) THEN
          CR_SETT=1
        ELSE
          CR_SETT=2
        ENDIF
        ALPHA=0.0
        BETA =0.0
        CALL EULERM(ALPHA,BETA,GAMMA,AM)

        DO I=1,NSYM
          DO K=1,5
            IT         = ISYM(K,2,I)
            ISYM(K,2,I)= ISYM(K,3,I)
            ISYM(K,3,I)= IT
          ENDDO
          DO J=1,3
            IT         = ISYM(2,J,I)
            ISYM(2,J,I)= ISYM(3,J,I)
            ISYM(3,J,I)= IT
          ENDDO
        ENDDO

        IF(NCSOP.GT.0) THEN
          DO I=1,NCSOP

            CALL GET_NCS(MDOC,NCMAX,I,AMNCS,TRNCS,IERR)
            IF(IERR.NE.0) RETURN      

            DO K=1,3
              T        = AMNCS(K,2)
              AMNCS(K,2)= AMNCS(K,3)
              AMNCS(K,3)= T
            ENDDO
            DO J=1,3
              T        = AMNCS(2,J)
              AMNCS(2,J)= AMNCS(3,J)
              AMNCS(3,J)= T
            ENDDO

            X(1)=TRNCS(1)
            X(2)=TRNCS(2)
            X(3)=TRNCS(3)
            IF(IS.EQ.2) THEN
              T = X(1) 
              X(1) = X(3) 
              X(3) = X(2)
              X(2) = T
            ENDIF        
            CALL MVMULT(AM,X,Y)
            IF(IS.EQ.1) THEN
              TRNCS(1)=Y(2)
              TRNCS(2)=Y(3)
              TRNCS(3)=Y(1)
            ELSE
              TRNCS(1)=Y(1)
              TRNCS(2)=Y(2)
              TRNCS(3)=Y(3)
            ENDIF
        
            CALL SET_NCS(MDOC,NCMAX,I,AMNCS,TRNCS,IERR)
            IF(IERR.NE.0) RETURN      

          ENDDO

        ENDIF
      ENDIF
C -------------------------------------------------
      IOUT=0
      CALL LENSTR_BL(NAME2,LEN2)
      IF(LEN2.GT.0.AND.NAME2(1:1).NE.','.AND.NAME2(1:1).NE.' ') THEN 
        NSM=NSYM

        IF(P1(1:1).EQ.'Y') THEN

          IF(A.GT.0.1.AND.B.GT.0.1.AND.C.GT.0.1.AND.
     *       CALPHA.GT.0.1.AND.CBETA.GT.0.1.AND.CGAMMA.GT.0.1) THEN
            CR_CELL(1) = A
            CR_CELL(2) = B
            CR_CELL(3) = C
            CR_CELL(4) = (CALPHA*PI)/180.0 
            CR_CELL(5) = (CBETA *PI)/180.0
            CR_CELL(6) = (CGAMMA*PI)/180.0
          ENDIF
          CR_NSPGR = 1
          CR_SETT  = 1
          CR_NSYM  = 1
          CR_SPGR  = 'P 1'
          NSM      = 1

        ELSE IF(P1(1:1).NE.'N') THEN

          CALL LENSTR_BL(P1,LEN)
          IF(LEN.GT.0.AND.LEN.LE.24) THEN
            IF(A.GT.0.1.AND.B.GT.0.1.AND.C.GT.0.1.AND.
     *         CALPHA.GT.0.1.AND.CBETA.GT.0.1.AND.CGAMMA.GT.0.1) THEN
              CR_CELL(1) = A
              CR_CELL(2) = B
              CR_CELL(3) = C
              CR_CELL(4) = (CALPHA*PI)/180.0 
              CR_CELL(5) = (CBETA *PI)/180.0
              CR_CELL(6) = (CGAMMA*PI)/180.0
              CR_NSPGR   = 0
              CR_SETT    = 0
              CR_NSYM    = 0
              CR_SPGR    = P1(1:LEN)

              IF(CR_SPGR.EQ.'P2' .OR.CR_SPGR.EQ.'P 2' .OR.
     *           CR_SPGR.EQ.'P21'.OR.CR_SPGR.EQ.'P 21'.OR.
     *           CR_SPGR.EQ.'B2' .OR.CR_SPGR.EQ.'B 2' .OR.
     *           CR_SPGR.EQ.'C2' .OR.CR_SPGR.EQ.'C 2'     ) THEN
                T  = PI/2.0
                CR_SETT = 2
                IF(ABS(CR_CELL(6)-T).GT.0.0001.AND.
     *             ABS(CR_CELL(5)-T).LE.0.0001     ) CR_SETT = 1
                IF(CR_SPGR.EQ.'P2'.OR.CR_SPGR.EQ.'P 2') THEN
                  IF(CR_SETT.EQ.1) THEN
                    CR_SPGR = 'P 1 1 2'
                  ELSE
                    CR_SPGR = 'P 1 2 1'
                  ENDIF
                ELSE IF(CR_SPGR.EQ.'P21'.OR.CR_SPGR.EQ.'P 21') THEN
                  IF(CR_SETT.EQ.1) THEN
                    CR_SPGR = 'P 1 1 21'
                  ELSE
                    CR_SPGR = 'P 1 21 1'
                  ENDIF
                ELSE IF(CR_SPGR.EQ.'B2'.OR.CR_SPGR.EQ.'B 2'.OR.
     *              CR_SPGR.EQ.'C2'.OR.CR_SPGR.EQ.'C 2'    ) THEN
                  IF(CR_SETT.EQ.1) THEN
                    CR_SPGR = 'B 1 1 2'
                  ELSE
                    CR_SPGR = 'C 1 2 1'
                  ENDIF
                ENDIF
              ENDIF

              CALL GET_SYMM(MDOC,CR_NSPGR,CR_SETT,CR_SPGR
     *        ,CR_NSYM,ISYM,IPRSYM,IERR)
              IF(IERR.NE.0) RETURN      
              NSM = CR_NSYM
            ENDIF
          ENDIF
        ENDIF          
        IOUT=11
        CALL OWCRD(MDoc,IOUT,NAME2,NSM,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MDOC,' ERR: OPEN OUT_FILE.')
          CLOSE(IN) 
          RETURN
        ENDIF
      ENDIF
C -------------------------------------------------
      IENDW=-1
C      MODE=0     
C      CALL WRCRD(MDOC,IOUT,MODE,IEND,IERR)
C      IF(IERR.NE.0) THEN
C        CLOSE(IN) 
C        RETURN
C      ENDIF
      NA=0
      IEND=-1
      MD=99
      IF(REST.EQ.'N') NCSOP=0
      N_NCS=NCSOP+1

      DO ISM=1,N_NCS
        NCRSYM=ISM-1
        IF(NCRSYM.GT.0) THEN

          CALL ORCRD(MD,IN,NAME1,NSYM,ISYM,IPRSYM,IERR)
          IF(IERR.NE.0) THEN
            CALL MSGERR(MDOC,' ERR: OPEN IN_FILE')
            CLOSE(IN)
            RETURN
          ENDIF

          IEND=-1
        ENDIF

 200  CONTINUE
C --------------------------------
      CALL RDCRD(MD,IN,MODE,IEND,IERR)
      IF(IERR.NE.0) THEN
        CLOSE(IOUT)
        RETURN
      ENDIF
      IF(IEND.NE.0) GO TO 300
      IF(MODE.EQ.0) THEN
        
        IF(WAT.EQ.'Y'.AND.
     *  (CR_RNAME(1:3).EQ.'HOH'.OR.CR_RNAME(1:3).EQ.'DOD')) GO TO 200

        IF(HATM.EQ.'Y'.AND.(CR_ASYMB(1:4).EQ.'H   '.OR.
     *  CR_ASYMB(1:4).EQ.'D   ')) GO TO 200


        IF(HATM.EQ.'Q'.AND.(CR_ASYMB(1:4).EQ.'H   '.OR.
     *  CR_ASYMB(1:4).EQ.'D   ')) GO TO 200

        IF(HATM.EQ.'Q'.AND.CR_ANAME(1:1).EQ.'Q') GO TO 200

        IF(ALT.EQ.'Y'.AND.(CR_ALT.NE.'A'.AND.CR_ALT.NE.'1'.AND.
     *     CR_ALT.NE.'.'.AND.CR_ALT.NE.'0')) GO TO 200

        IF(NOCC.EQ.'R') THEN
          IF(CR_OCC.LE.0.0001) GO TO 200 
        ENDIF

        IF(MOD.EQ.'B') THEN
          IF(CR_ANAME.NE.'C   '.AND.CR_ANAME.NE.'CA  '.AND.
     *    CR_ANAME.NE.'O   '.AND.CR_ANAME.NE.'N   '.AND.
     *    CR_ANAME.NE.'CB  ')
     *    GO TO 200
        ELSE IF(MOD.EQ.'A') THEN
          IF(CR_ANAME.NE.'CA  ') GO TO 200
        ELSE IF(MOD.EQ.'P') THEN
          IF(CR_ANAME.NE.'P   ') GO TO 200
        ENDIF

        IF(ALT.EQ.'Y') THEN
          CR_ALT ='.'
          CR_CORR='.'
        ENDIF
        IF(SETT.EQ.'Y') THEN
          X(1)=CR_XYZ(1)
          X(2)=CR_XYZ(2)
          X(3)=CR_XYZ(3)
          IF(IS.EQ.2) THEN
            T = X(1) 
            X(1) = X(3) 
            X(3) = X(2)
            X(2) = T
          ENDIF        
          CALL MVMULT(AM,X,Y)
          IF(IS.EQ.1) THEN
            CR_XYZ(1)=Y(2)
            CR_XYZ(2)=Y(3)
            CR_XYZ(3)=Y(1)
          ELSE
            CR_XYZ(1)=Y(1)
            CR_XYZ(2)=Y(2)
            CR_XYZ(3)=Y(3)
          ENDIF        
        ENDIF

        IF(REST.EQ.'Y'.AND.NCS_FLAG.EQ.'Y') THEN

          IF(NCRSYM.EQ.0) THEN
            IGR_OLD=CR_IGROUP
            DO IGR=1,NGR
              CALL GET_ASYMM(MDOC,NASMAX,NGR,ICHOLD,IGR,ICH,INC,MLT
     *                     ,IGOLD,NCSF,GID,IERR)
              IF(IERR.NE.0) THEN
                WRITE(STR,
     *          '('' ERR: wrong NCS description'')') 
                CALL MSGERR(MDOC,STR)
                RETURN
              ENDIF
              IF(IGOLD.EQ.IGR_OLD.AND.INC.EQ.0) THEN
                GO TO 400
              ENDIF
            ENDDO
            WRITE(STR,
     *      '('' ERR: wrong NCS description'')') 
            CALL MSGERR(MDOC,STR)
            IERR=1
            RETURN

  400       CONTINUE                    
            ICHAIN=ICHOLD
            Z(1)=CR_XYZ(1)
            Z(2)=CR_XYZ(2)
            Z(3)=CR_XYZ(3)
          ELSE
            IGR_OLD=CR_IGROUP
            DO IGR=1,NGR
              CALL GET_ASYMM(MDOC,NASMAX,NGR,ICHOLD,IGR,ICH,INC,MLT
     *                     ,IGOLD,NCSF,GID,IERR)
              IF(IERR.NE.0) THEN
                WRITE(STR,
     *          '('' ERR: wrong NCS description'')') 
                CALL MSGERR(MDOC,STR)
                RETURN
              ENDIF
              IF(IGOLD.EQ.IGR_OLD) THEN
                GO TO 410
              ENDIF
            ENDDO
            WRITE(STR,
     *      '('' ERR: wrong NCS description'')') 
            CALL MSGERR(MDOC,STR)
            IERR=1
            RETURN

  410       CONTINUE                    
            ICHAIN=ICHOLD
            Z(1)=CR_XYZ(1)
            Z(2)=CR_XYZ(2)
            Z(3)=CR_XYZ(3)
            DO IGR=1,NGR
              CALL GET_ASYMM(MDOC,NASMAX,NGR,ICHOLD,IGR,ICH,INC,MLT
     *                      ,IGOLD,NCSF,GID,IERR)
              IF(IERR.NE.0) THEN
                WRITE(STR,
     *          '('' ERR: wrong NCS description'')') 
                CALL MSGERR(MDOC,STR)
                RETURN
              ENDIF
c             write(*,*) NCSF,NCRSYM,GID(1:2),CHAIN
              IF((NCSF.EQ.'N'.OR.NCSF.EQ.'n').AND.
     *           INC.EQ.NCRSYM.AND.ICHOLD.EQ.ICHAIN) GO TO 730
            ENDDO
            GO TO 710  
 730        CONTINUE
            CR_IGROUP=IGOLD
            CALL GET_NCS(MDOC,NCMAX,INC,AMNCS,TRNCS,IERR)
            IF(IERR.NE.0) THEN
              WRITE(STR,
     *        '('' ERR: wrong NCS description'')') 
              CALL MSGERR(MDOC,STR)
              RETURN      
            ENDIF
            CALL MVMULT(AMNCS,Z,Y)
            Y(1)=Y(1)+TRNCS(1)
            Y(2)=Y(2)+TRNCS(2)
            Y(3)=Y(3)+TRNCS(3)
            CR_XYZ(1)=Y(1)
            CR_XYZ(2)=Y(2)
            CR_XYZ(3)=Y(3)
          ENDIF

        ENDIF

c        IF(BOV.GT.0.0)  THEN
c          CR_BISO  = BOV
c          CR_BTYPE = 'I'
c        ENDIF
        IF(BOV.GT.0.00001) THEN
          IF(BMODE.EQ.'A') THEN
            CR_BISO = CR_BISO +  BOV 
          ELSE
            CR_BISO = BOV 
          ENDIF
          CR_BTYPE     = '.'
          CR_FLAG_USER = 'I'
        ELSE IF(BOV.LT.-0.00001.AND.BOV.GT.-998.9) THEN
          IF(CR_BISO.GT.ABS(BOV)) GO TO 200
        ELSE IF(BOV.LT.-998.9) THEN
          CR_BTYPE     = '.'
          CR_FLAG_USER = 'I'
        ENDIF
 
        IF(NOCC.EQ.'Y') CR_OCC=1.0 

        IF(CONV.EQ.'F'.AND.CR_PDB_REC(1:1).NE.'F') THEN

          CR_PDB_REC(1:1)='F'
          Z(1)=CR_XYZ(1)
          Z(2)=CR_XYZ(2)
          Z(3)=CR_XYZ(3)
          CALL MVMULT(CR_ORT_TO_FRAC,Z,Y)
          CR_XYZ(1)=Y(1)
          CR_XYZ(2)=Y(2)
          CR_XYZ(3)=Y(3)

        ELSE IF(CONV.EQ.'C'.AND.CR_PDB_REC(1:1).EQ.'F') THEN

          CR_PDB_REC(1:1)='C'
          Z(1)=CR_XYZ(1)
          Z(2)=CR_XYZ(2)
          Z(3)=CR_XYZ(3)
          CALL MVMULT(CR_FRAC_TO_ORT,Z,Y)
          CR_XYZ(1)=Y(1)
          CR_XYZ(2)=Y(2)
          CR_XYZ(3)=Y(3)

        ENDIF

      ENDIF      
C ----
      IF(MODE.EQ.0) NA=NA+1
      IF(NUM.EQ.'Y') CR_IATOLD=NA

      IF(CONV.EQ.'F') THEN
        CALL WRCRD(MD,IOUT,MODE,IENDW,IERR)
      ELSE
        CALL WRCRD(MD,IOUT,MODE,IENDW,IERR)
      ENDIF
      IF(IERR.NE.0) THEN
        CLOSE(IN) 
        RETURN
      ENDIF
 710  CONTINUE


C ------------------------
      GO TO 200
C ------------------------------------------------------
 300  CONTINUE

      ENDDO

      WRITE(LINE,500) NA
  500 FORMAT(' NUMBER OF ATOMS   :',I6)
      CALL MSGDOC(MDOC,LINE)
      CLOSE(IN)
      IEND=1
      MODE=0     
      CALL WRCRD(MDOC,IOUT,MODE,IEND,IERR)
C --------------------------------------
      RETURN
      END

C -I-
      SUBROUTINE WRITEPDB(MDOC,NAME1,NAME2,ISYM,IPRSYM,IERR)
C ----------------------------------------------------------
C -P- writePDB - converts cooordinate's file from "BLANC"-system to "PDB"; 
C -S-
C
C  Dialog and Batch: 
C
C    FILE_IN  - input file of coordinates.
C    FILE_OUT - output file.
C      
C    IF(ABS(IERR).NE.0.AND.IERR.GT.-1000) set  B_OVER = ABS(IERR)
C    IF(IERR.LE.0) keep surf info
C
C  Parameters of subroutine WRITEPDB: 
C
C      SUBROUTINE WRITEPDB(MDOC,NAME1,NAME2,ISYM,IPRSYM,IERR)
C
C
C    MDOC   - mode of writting messages to DOC-file
C             0 - only terminal , < - 0 only file, 0 < < 99 - both
C             >= 99 - don't write  
C    NAME1  - name of input file without extention.
C    NAME2  - name of output file without extention.
C    ISYM   - integer*2 array for cryst.symmetry operators.
C    IPRSYM - dimension of integer*2 array ISYM(5,3,IPRSYM),
C             number of cryst. symm. operators.
C    IERR   - output signal of error / = 1 -error , = 0 - OK / 
C -I-
C ----------------------------------------------------------
      INTEGER   MDOC,IERR
      CHARACTER NAME1*(*),NAME2*(*)
      INTEGER   IPRSYM
      INTEGER*2 ISYM(5,3,IPRSYM)
C ---
C ------------------------------------------------------------
      INCLUDE 'mr_crd_com.fh'
C -------------------------------------------------
      INTEGER     MODE,IANIS(6)
      REAL        FRTOCR(3,3),CRTOFR(3,3),XA(3),B_OVER
      CHARACTER   ATOM*4,RES*3,ALT*1,CHAIN*2,SEG*4,CSURF*6
      CHARACTER   EXT*3,PATH*1,LINE*256,STR*80,ASYMB*4
      CHARACTER   NCSF*1,GID*4
C --------------------------------------------------------------
      B_OVER = 0.0
      ISURF  = 0
      IF(IERR.NE.0.AND.IERR.GT.-1000) B_OVER = ABS(FLOAT(IERR))
      IF(IERR.LT.0) ISURF = 1
      IERR   = 0
C-----
      IN  = 10
      IOUT=  0
      MD  = 99
      PATH=' '
C --------
      CALL ORCRD(MD,IN,NAME1,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERR: OPEN IN_FILE')
        CLOSE(IN)
        RETURN
      ENDIF
C ---
      IGR=0
      CALL GET_ASYMM(MDOC,NMAX,NGR,NCH,IGR,ICH,INC,MLT,IATM
     *               ,NCSF,GID,IERR)
C ---
      CALL LENSTR_BL(NAME2,LEN)
      IF(LEN.GT.0.AND.NAME2(1:1).NE.','.AND.NAME2(1:1).NE.' ') THEN 
        EXT ='pdb'
        IOUT=11
        CALL OPENFW(IOUT,MD,PATH,NAME2,EXT,IERR)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MDOC,' ERR: OPEN OUT_FILE')
          CLOSE(IN)
          RETURN
        ENDIF
      ENDIF
C -------------------
      CALL FRORTH(CR_CELL(1),CR_CELL(2),CR_CELL(3)
     *           ,CR_CELL(4),CR_CELL(5),CR_CELL(6)
     *                            ,FRTOCR,CRTOFR,IERR)
C
C                                 ! 11 21 31 !
C            Xo=[FRTOCR] Xf    RO=! 12 22 32 !
C                                 ! 13 23 33 !
C
C ---- PDB-TITLE ----
      CALL LENSTR_BL(CR_NAME_PDB,LEN)
      IF(LEN.GE.13) THEN
        LN=LEN-12
        STR(1:LN)=CR_NAME_PDB(13:LEN)
      ELSE
        STR(1:1)='?'
        LN=1      
      ENDIF
      IF(LN.LT.40) THEN
        DO II=LN+1,40
          STR(II:II)=' '
        ENDDO
      ENDIF
      WRITE(LINE,140) STR(1:40),CR_DATE_PDB,CR_CD_PDB
  140 FORMAT ('HEADER',4X,A40,A9,3X,A4)
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT ,'(A)') LINE(1:LEN)
      WRITE(LINE,150) CR_TITLE(9:68)
  150 FORMAT ('COMPND',4X,A60)
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT ,'(A)') LINE(1:LEN)
      NCODE = 1
      ZERO  = 0.0
      CR_CELL(4)=(CR_CELL(4)*180.0)/3.1415926
      CR_CELL(5)=(CR_CELL(5)*180.0)/3.1415926
      CR_CELL(6)=(CR_CELL(6)*180.0)/3.1415926
      WRITE(LINE,100) CR_CELL(1),CR_CELL(2),CR_CELL(3)
     *           ,CR_CELL(4),CR_CELL(5),CR_CELL(6),CR_SPGR
  100 FORMAT ('CRYST1',3F9.3,3F7.2,1X,A11)
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT ,'(A)') LINE(1:LEN)
      WRITE(LINE,110) CRTOFR(1,1),CRTOFR(2,1),CRTOFR(3,1),ZERO
  110 FORMAT ('SCALE1',4X,3F10.6,5X,F10.6)
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT ,'(A)') LINE(1:LEN)
      WRITE(LINE,120) CRTOFR(1,2),CRTOFR(2,2),CRTOFR(3,2),ZERO
  120 FORMAT ('SCALE2',4X,3F10.6,5X,F10.6)
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT ,'(A)') LINE(1:LEN)
      WRITE(LINE,130) CRTOFR(1,3),CRTOFR(2,3),CRTOFR(3,3),ZERO
  130 FORMAT ('SCALE3',4X,3F10.6,5X,F10.6)
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT ,'(A)') LINE(1:LEN)
C -------------------
      NA     = 0
      NNA    = 0
      IEND   =-1
      MD     = 99
      IMODEL = 0
  200 CONTINUE
C --------------------------------
      CALL RDCRD(MD,IN,MODE,IEND,IERR)
      IF(IERR.EQ.1) THEN
        CLOSE(IOUT)
        RETURN
      ENDIF
      IF(IEND.NE.0) GO TO 300

      IF(MODE.GT.0) THEN
        IF(CR_LINE(1:6).EQ.'#MODEL'.OR.CR_LINE(1:7).EQ.'#DOMAIN'.OR.
     *     CR_LINE(1:9).EQ.'#MOLECULE') THEN
          IF(CR_LINE(1:6).EQ.'#MODEL') THEN
            READ(CR_LINE(8:11),'(I4)') IMODEL
            WRITE(LINE,'(''MODEL'',5X,I4)') IMODEL

          ELSE


            LINE = CR_LINE
            CALL LENSTR_BL(LINE,LEN)
            LINE = 'REMARK '// LINE(1:LEN)
          
          ENDIF
          CALL LENSTR_BL(LINE,LN)
          IF(LN.GT.0) THEN
            WRITE(IOUT,'(A)') LINE(1:LN)
          ENDIF
        ENDIF
        GO TO 200    
      ENDIF

      IF(CR_ATYPE.NE.'.'.AND.CR_ATYPE.NE.' '.AND.CR_ATYPE.NE.'y'.AND.
     *   CR_ATYPE.NE.'Y'.AND.CR_ATYPE.NE.'r'.AND.CR_ATYPE.NE.'R')
     *   GO TO 200

      CALL PDB_ANAME(CR_ANAME,CR_ASYMB,CR_RNAME,ATOM)

      RES   = CR_RNAME
      IRES  = CR_IRES
      ALT   = CR_ALT 
      CHAIN = CR_CHAIN
      XA(1) = CR_XYZ(1)
      XA(2) = CR_XYZ(2)
      XA(3) = CR_XYZ(3)
      OCC   = CR_OCC
      B     = CR_BISO
      SEG   = CR_SEG
      IF(SEG.EQ.'.') SEG = '    '
      SURF  = CR_SURF
      CSURF ='      '
      IF(ISURF.EQ.1) THEN
        IF(SURF.GT.999.99) SURF = 999.99
        WRITE(CSURF,'(F6.2)') SURF
      ENDIF
      ASYMB = CR_ASYMB
      CALL LENSTR_BL(ASYMB,LN)
      IF(LN.LE.0) THEN
        ASYMB = '    '
      ELSE IF(LN.EQ.1) THEN
        ASYMB = ' '//ASYMB(1:1)//'  '
      ENDIF
C ----
      NA  = NA+1
      NNA = NNA+1
      IF(NNA.GE.100000) NNA=1
      IF(ALT.EQ.'.') ALT=' '
      IF(CHAIN(1:1).EQ.'.') CHAIN(1:1)=' '
      IF(CHAIN(2:2).EQ.'.') CHAIN(2:2)=' '
      WRITE(CHAIN,'(I2)') CR_IGROUP
      CHAIN(1:1)=' '
      IF(NGR.GT.0) THEN
        IGR=CR_IGROUP
        IF(IGR.GT.0.AND.IGR.LE.NGR) THEN
          CALL GET_ASYMM(MDOC,NMAX,NGR,ICHOLD,IGR,ICH,INC,MLT,IGOLD
     *                    ,NCSF,GID,IERR)
          IF(IERR.NE.0) RETURN
          CHAIN(2:2)=GID(1:1)
        ENDIF
      ENDIF
      IF(CHAIN(1:1).EQ.'.') CHAIN(1:1)=' ' 
      IF(CHAIN(2:2).EQ.'.') CHAIN(2:2)=' ' 

      IF(B_OVER.GT.0.0001) B = B_OVER      

      IF(CHAIN(2:2).EQ.' '.OR.CHAIN(2:2).EQ.'_') THEN
        SEG(1:1) = '-' 
      ELSE
        SEG(1:1) = CHAIN(2:2) 
      ENDIF
      SEG(4:4) = ' '

      IF(RES(3:3).EQ.' ') THEN
        RES(3:3) = RES(2:2)
        RES(2:2) = RES(1:1)
        RES(1:1) = ' '
        IF(RES(3:3).EQ.' ') THEN
          RES(3:3) = RES(2:2)
          RES(2:2) = ' '
        ENDIF
      ENDIF

      WRITE(LINE,400) NNA,ATOM,ALT,RES,CHAIN,IRES
     *               ,XA(1),XA(2),XA(3),OCC,B,CSURF,SEG,ASYMB
 400  FORMAT ('ATOM',2X,I5,1X,A4,A1,A3,A2,I4,4X,3F8.3,2F6.2,A6,A4,A4)
      CALL LENSTR_BL(LINE,LN)
      IF(LN.GT.0) THEN
        WRITE(IOUT,'(A)') LINE(1:LN)
      ENDIF

      IF(CR_BTYPE.EQ.'A') THEN

        DO I=1,6
          IANIS(I) = CR_ANIS(I)*10000.0
        ENDDO 

        WRITE(LINE,410) NNA,ATOM,ALT,RES,CHAIN,IRES
     *                  ,(IANIS(L),L=1,6)
 410    FORMAT ('ANISOU',I5,1X,A4,A1,A3,A2,I4,2X,6I7)
        CALL LENSTR_BL(LINE,LN)
        IF(LN.GT.0) THEN
          WRITE(IOUT,'(A)') LINE(1:LN)
        ENDIF
      ENDIF

      GO TO 200
C ------------------------------------------------------
 300  CONTINUE
      WRITE(LINE,500) NA
  500 FORMAT(' NUMBER OF ATOMS   :',I6)
      CALL MSGDOC(MDOC,LINE)
      END FILE IOUT
      CLOSE(IOUT)
C --------------------------------------
      RETURN
      END

C -I-
      SUBROUTINE WRITEPDB1(MDOC,NAME1,NAME2,ISYM,IPRSYM,IERR)
C ----------------------------------------------------------
C -P- writePDB - converts cooordinate's file from "BLANC"-system to "PDB"; 
C -S-
C
C  Dialog and Batch: 
C
C    FILE_IN  - input file of coordinates.
C    FILE_OUT - output file.
C      
C    IF(ABS(IERR).NE.0.AND.IERR.GT.-1000) set  B_OVER = ABS(IERR)
C    IF(IERR.LE.0) keep surf info
C
C  Parameters of subroutine WRITEPDB: 
C
C      SUBROUTINE WRITEPDB(MDOC,NAME1,NAME2,ISYM,IPRSYM,IERR)
C
C
C    MDOC   - mode of writting messages to DOC-file
C             0 - only terminal , < - 0 only file, 0 < < 99 - both
C             >= 99 - don't write  
C    NAME1  - name of input file without extention.
C    NAME2  - name of output file without extention.
C    ISYM   - integer*2 array for cryst.symmetry operators.
C    IPRSYM - dimension of integer*2 array ISYM(5,3,IPRSYM),
C             number of cryst. symm. operators.
C    IERR   - output signal of error / = 1 -error , = 0 - OK / 
C -I-
C ----------------------------------------------------------
      INTEGER   MDOC,IERR
      CHARACTER NAME1*(*),NAME2*(*)
      INTEGER   IPRSYM
      INTEGER*2 ISYM(5,3,IPRSYM)
C ---
C ------------------------------------------------------------
      INCLUDE 'mr_crd_com.fh'
C -------------------------------------------------
      INTEGER     MODE,IANIS(6)
      REAL        FRTOCR(3,3),CRTOFR(3,3),XA(3),B_OVER
      CHARACTER   ATOM*4,RES*3,ALT*1,CHAIN*2,SEG*4,CSURF*6
      CHARACTER   EXT*3,PATH*1,LINE*256,STR*80,ASYMB*4
      CHARACTER   NCSF*1,GID*4
C --------------------------------------------------------------
      B_OVER = 0.0
      ISURF  = 0
      IF(IERR.NE.0.AND.IERR.GT.-1000) B_OVER = ABS(FLOAT(IERR))
      IF(IERR.LT.0) ISURF = 1
      IERR   = 0
C-----
      IN  = 10
      IOUT=  0
      MD  = 99
      PATH=' '
C --------
      CALL ORCRD(MD,IN,NAME1,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERR: OPEN IN_FILE')
        CLOSE(IN)
        RETURN
      ENDIF
C ---
      IGR=0
      CALL GET_ASYMM(MDOC,NMAX,NGR,NCH,IGR,ICH,INC,MLT,IATM
     *               ,NCSF,GID,IERR)
C ---
      CALL LENSTR_BL(NAME2,LEN)
      IF(LEN.GT.0.AND.NAME2(1:1).NE.','.AND.NAME2(1:1).NE.' ') THEN 
        EXT ='pdb'
        IOUT=11
        CALL OPENFW(IOUT,MD,PATH,NAME2,EXT,IERR)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MDOC,' ERR: OPEN OUT_FILE')
          CLOSE(IN)
          RETURN
        ENDIF
      ENDIF
C -------------------
      CALL FRORTH(CR_CELL(1),CR_CELL(2),CR_CELL(3)
     *           ,CR_CELL(4),CR_CELL(5),CR_CELL(6)
     *                            ,FRTOCR,CRTOFR,IERR)
C
C                                 ! 11 21 31 !
C            Xo=[FRTOCR] Xf    RO=! 12 22 32 !
C                                 ! 13 23 33 !
C
C ---- PDB-TITLE ----
      CALL LENSTR_BL(CR_NAME_PDB,LEN)
      IF(LEN.GE.13) THEN
        LN=LEN-12
        STR(1:LN)=CR_NAME_PDB(13:LEN)
      ELSE
        STR(1:1)='?'
        LN=1      
      ENDIF
      IF(LN.LT.40) THEN
        DO II=LN+1,40
          STR(II:II)=' '
        ENDDO
      ENDIF
      WRITE(LINE,140) STR(1:40),CR_DATE_PDB,CR_CD_PDB
  140 FORMAT ('HEADER',4X,A40,A9,3X,A4)
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT ,'(A)') LINE(1:LEN)
      WRITE(LINE,150) CR_TITLE(9:68)
  150 FORMAT ('COMPND',4X,A60)
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT ,'(A)') LINE(1:LEN)
      NCODE = 1
      ZERO  = 0.0
      CR_CELL(4)=(CR_CELL(4)*180.0)/3.1415926
      CR_CELL(5)=(CR_CELL(5)*180.0)/3.1415926
      CR_CELL(6)=(CR_CELL(6)*180.0)/3.1415926
      WRITE(LINE,100) CR_CELL(1),CR_CELL(2),CR_CELL(3)
     *           ,CR_CELL(4),CR_CELL(5),CR_CELL(6),CR_SPGR
  100 FORMAT ('CRYST1',3F9.3,3F7.2,1X,A11)
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT ,'(A)') LINE(1:LEN)
      WRITE(LINE,110) CRTOFR(1,1),CRTOFR(2,1),CRTOFR(3,1),ZERO
  110 FORMAT ('SCALE1',4X,3F10.6,5X,F10.6)
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT ,'(A)') LINE(1:LEN)
      WRITE(LINE,120) CRTOFR(1,2),CRTOFR(2,2),CRTOFR(3,2),ZERO
  120 FORMAT ('SCALE2',4X,3F10.6,5X,F10.6)
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT ,'(A)') LINE(1:LEN)
      WRITE(LINE,130) CRTOFR(1,3),CRTOFR(2,3),CRTOFR(3,3),ZERO
  130 FORMAT ('SCALE3',4X,3F10.6,5X,F10.6)
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT ,'(A)') LINE(1:LEN)
C -------------------
      NA     = 0
      NNA    = 0
      IEND   =-1
      MD     = 99
      IMODEL = 0
      IWRITE = 1
  200 CONTINUE
C --------------------------------
      CALL RDCRD(MD,IN,MODE,IEND,IERR)
      IF(IERR.EQ.1) THEN
        CLOSE(IOUT)
        RETURN
      ENDIF
      IF(IEND.NE.0) GO TO 300

      IF(MODE.GT.0) THEN
        IF(CR_LINE(1:6).EQ.'#MODEL'.OR.CR_LINE(1:7).EQ.'#DOMAIN'.OR.
     *     CR_LINE(1:9).EQ.'#MOLECULE') THEN
          IF(CR_LINE(1:6).EQ.'#MODEL') THEN
c#MODEL    1
c12345671234
            READ(CR_LINE(8:11),'(I4)') IMODEL
            IWRITE = 1
            IF(IMODEL.GT.1) THEN
              IWRITE = 0
            ENDIF
            GO TO 200
          ELSE

            LINE = CR_LINE
            CALL LENSTR_BL(LINE,LEN)
            LINE = 'REMARK '// LINE(1:LEN)

          ENDIF
          CALL LENSTR_BL(LINE,LN)
          IF(LN.GT.0) THEN
            WRITE(IOUT,'(A)') LINE(1:LN)
          ENDIF
        ENDIF
        GO TO 200    
      ENDIF

      IF(IWRITE.LE.0) GO TO 200

      IF(CR_ATYPE.NE.'.'.AND.CR_ATYPE.NE.' '.AND.CR_ATYPE.NE.'y'.AND.
     *   CR_ATYPE.NE.'Y'.AND.CR_ATYPE.NE.'r'.AND.CR_ATYPE.NE.'R')
     *   GO TO 200

      CALL PDB_ANAME(CR_ANAME,CR_ASYMB,CR_RNAME,ATOM)

      RES   = CR_RNAME
      IRES  = CR_IRES
      ALT   = CR_ALT 
      CHAIN = CR_CHAIN
      XA(1) = CR_XYZ(1)
      XA(2) = CR_XYZ(2)
      XA(3) = CR_XYZ(3)
      OCC   = CR_OCC
      B     = CR_BISO
      SEG   = CR_SEG
      IF(SEG.EQ.'.') SEG = '    '
      SURF  = CR_SURF
      CSURF ='      '
      IF(ISURF.EQ.1) THEN
        IF(SURF.GT.999.99) SURF = 999.99
        WRITE(CSURF,'(F6.2)') SURF
      ENDIF
      ASYMB = CR_ASYMB
      CALL LENSTR_BL(ASYMB,LN)
      IF(LN.LE.0) THEN
        ASYMB = '    '
      ELSE IF(LN.EQ.1) THEN
        ASYMB = ' '//ASYMB(1:1)//'  '
      ENDIF
C ----
      NA  = NA+1
      NNA = NNA+1
      IF(NNA.GE.100000) NNA=1
      IF(ALT.EQ.'.') ALT=' '
      IF(CHAIN(1:1).EQ.'.') CHAIN(1:1)=' '
      IF(CHAIN(2:2).EQ.'.') CHAIN(2:2)=' '
      WRITE(CHAIN,'(I2)') CR_IGROUP
      CHAIN(1:1)=' '
      IF(NGR.GT.0) THEN
        IGR=CR_IGROUP
        IF(IGR.GT.0.AND.IGR.LE.NGR) THEN
          CALL GET_ASYMM(MDOC,NMAX,NGR,ICHOLD,IGR,ICH,INC,MLT,IGOLD
     *                    ,NCSF,GID,IERR)
          IF(IERR.NE.0) RETURN
          CHAIN(2:2)=GID(1:1)
        ENDIF
      ENDIF
      IF(CHAIN(1:1).EQ.'.') CHAIN(1:1)=' ' 
      IF(CHAIN(2:2).EQ.'.') CHAIN(2:2)=' ' 

      IF(B_OVER.GT.0.0001) B = B_OVER      

      IF(CHAIN(2:2).EQ.' '.OR.CHAIN(2:2).EQ.'_') THEN
        SEG(1:1) = '-' 
      ELSE
        SEG(1:1) = CHAIN(2:2) 
      ENDIF
      SEG(4:4) = ' '

      IF(RES(3:3).EQ.' ') THEN
        RES(3:3) = RES(2:2)
        RES(2:2) = RES(1:1)
        RES(1:1) = ' '
        IF(RES(3:3).EQ.' ') THEN
          RES(3:3) = RES(2:2)
          RES(2:2) = ' '
        ENDIF
      ENDIF

      WRITE(LINE,400) NNA,ATOM,ALT,RES,CHAIN,IRES
     *               ,XA(1),XA(2),XA(3),OCC,B,CSURF,SEG,ASYMB
 400  FORMAT ('ATOM',2X,I5,1X,A4,A1,A3,A2,I4,4X,3F8.3,2F6.2,A6,A4,A4)
      CALL LENSTR_BL(LINE,LN)
      IF(LN.GT.0) THEN
        WRITE(IOUT,'(A)') LINE(1:LN)
      ENDIF

      IF(CR_BTYPE.EQ.'A') THEN

        DO I=1,6
          IANIS(I) = CR_ANIS(I)*10000.0
        ENDDO 

        WRITE(LINE,410) NNA,ATOM,ALT,RES,CHAIN,IRES
     *                  ,(IANIS(L),L=1,6)
 410    FORMAT ('ANISOU',I5,1X,A4,A1,A3,A2,I4,2X,6I7)
        CALL LENSTR_BL(LINE,LN)
        IF(LN.GT.0) THEN
          WRITE(IOUT,'(A)') LINE(1:LN)
        ENDIF
      ENDIF

      GO TO 200
C ------------------------------------------------------
 300  CONTINUE
      WRITE(LINE,500) NA
  500 FORMAT(' NUMBER OF ATOMS   :',I6)
      CALL MSGDOC(MDOC,LINE)
      END FILE IOUT
      CLOSE(IOUT)
C --------------------------------------
      RETURN
      END

      SUBROUTINE PDB_ANAME(ANAME,ASYMB,RNAME,ATOM)
C -----------------------------------------------
      CHARACTER ANAME*4,ASYMB*4,ATOM*4,RNAME*3
C ----------------------------------------------
      PARAMETER (N_NAME = 95)
C -----------------------------------------------
      CHARACTER CH2*2
      CHARACTER NAME(N_NAME)*2
      PARAMETER ( NRNAMED = 38 )
      CHARACTER RNAMED(38)*3
C ----
      DATA NAME/'CO','MG','CA','ZN','CU','FE','CL','BR','MN','PB',
     *          'HG','AL','GD','NA','CD','NI','SR','IN','HO','YB',
     *          'TE','LI','RB','BA','CS','SM','TL','PT','BE','SE',
     *          'MO','SI','I ','NE','AR','SC','TI','CR','GA','GE',
     *          'AS','KR','HE','ZR','NB','TC','RU','RH','PD','AG',
     *          'SN','SB','XE','LA','HF','TA','RE','OS','IR','AU',
     *          'BI','PO','AT','RN','FR','RA','AC','CE','PR','ND',
     *          'PM','EU','TB','DY','ER','TM','LU','TH','PA','NP',
     *          'PU','AM','CM','BK','CF','ES','FM','MD','NO','LR',
     *          'K ','V ','Y ','U ','W '                          /
C 
C
      DATA RNAMED/'A  ','C  ','G  ','T  ','U  ','I  ','+A ','+C ' 
     *           ,'+G ','+T ','+U ','1MA','1MG','2MG','5MC','5MU'
     *           ,'7MG','H2U','M2G','OMC','OMG','OMU','PSU','YG '
     *           ,'Ad ','Ar ','Cd ','Cr ','Gd ','Gr ','Td ','Ur '
     *           ,'Ir ','DA ','DC ','DT ','DG ','DI '/
C ---------------------------------------------
      ATOM= '    '
      CH2=ASYMB(1:2)
      DO  I=1,N_NAME
        IF(NAME(I).EQ.CH2) THEN
          ATOM=ANAME
          RETURN
        ENDIF
      ENDDO
      IF(ASYMB.EQ.'H   '.OR.ASYMB.EQ.'D   ') THEN
        ATOM(2:4) = ANAME(1:3)
        IF(ANAME(4:4).NE.' ') ATOM(1:1)=ANAME(4:4)
      ELSE
        IF(ANAME(4:4).NE.' ') THEN
          IF(ANAME(1:1).EQ.ASYMB(1:1)) THEN
            ATOM(2:4)=ANAME(1:3)
            ATOM(1:1)=ANAME(4:4)
          ELSE
            ATOM(1:4)=ANAME(1:4)
          ENDIF
        ELSE
          IF(ANAME(1:1).EQ.ASYMB(1:1)) THEN
            IF(ANAME(2:2).EQ.ASYMB(1:1)) THEN
              ATOM(1:3)=ANAME(1:3)
            ELSE
              ATOM(2:4)=ANAME(1:3)
            ENDIF
          ELSE
            ATOM(1:4)=ANAME(1:3)
          ENDIF
        ENDIF
      ENDIF
C --- special cases --

C      IF(RNAME.EQ.'HEM'.AND.ANAME.EQ.'NA  ') ATOM=' N A'
C      IF(RNAME.EQ.'HEM'.AND.ANAME.EQ.'NB  ') ATOM=' N B'
C      IF(RNAME.EQ.'HEM'.AND.ANAME.EQ.'NC  ') ATOM=' N C'
C      IF(RNAME.EQ.'HEM'.AND.ANAME.EQ.'ND  ') ATOM=' N D'

      DO I=1,NRNAMED
        IF(RNAME.EQ.RNAMED(I)) THEN
          IF(ATOM(1:1).EQ.'*') ATOM(1:1)=''''
          IF(ATOM(2:2).EQ.'*') ATOM(2:2)=''''
          IF(ATOM(3:3).EQ.'*') ATOM(3:3)=''''
          IF(ATOM(4:4).EQ.'*') ATOM(4:4)=''''
        ENDIF
      ENDDO
      RETURN
      END

C -I-
      SUBROUTINE READPDB(MDOC,FILE,PATH_SCR,ISYM,IPRSYM
     *  ,STR_TITLE,STR_DATE,RESULT,IPRROW,PDB,IERR)
C --------------------------------------------------------------
C -P- readPDB - convert of cooordinates with PDB-format to BLANC-system format.
C -S-
C
C  Dialog and Batch: 
C
C    FILE_I  - input PDB file of coordinates, without extention "pdb".
C              output file will have the same name with extention "crd".
C
C      SUBROUTINE READPDB(MDOC,FILE,ISYM,IPRSYM
C     *  ,STR_TITLE,STR_DATE,RESULT,IPRROW,PDB,IERR)
C
C  Parameters of subroutine READPDB: 
C
C    MDOC   - mode of writting messages to DOC-file
C             0 - only terminal , < - 0 only file, 0 < < 99 - both
C             >= 99 - don't write  
C    FILE   - name of input file without extention "pdb".
C    ISYM   - integer*2 array for cryst.symmetry operators.
C    IPRSYM - dimension of integer*2 array ISYM(5,3,IPRSYM),
C             number of cryst. symm. operators.
C    IERR   - output signal of error / = 1 -error , = 0 - OK / 
C
C    output information:  RESULT(IPRROW)
C
C      PDB   /character*1/ "Y".  
C      RESULT(1) - PDB_code
C      RESULT(2) - number of atoms
C      RESULT(3) - number of water molecules
C      RESULT(4) - reported resolution
C      RESULT(5) - reported R-FAC
C      RESULT(6)-(11) - CELL parameters
C
C      RESULT(12)   
C      RESULT(13)  Space group
C      RESULT(14)
C
C      RESULT(15) - number of H-atoms
C      RESULT(16) - number of chains
C      RESULT(17) - NCS , number of NCS  operators.
C      RESULT(18) - IGIVEN
C      RESULT(19) = NRES_TOT
C      RESULT(20) = N_model
C -I-
C ----------------------------------------------------------
      INTEGER   MDOC,IERR
      CHARACTER FILE*(*),PATH_SCR*(*),PDB*1
      INTEGER   IPRSYM
      INTEGER*2 ISYM(5,3,IPRSYM)
      REAL      RESULT(*)
C ----------------------
      CHARACTER   EXT*80,PATH*1,LINE*80
      CHARACTER   STR_TITLE*40,STR_DATE*9,CHAIN*1
C ---
      REAL      R4
      INTEGER*4 IEND
      CHARACTER REC*6,CH7*7,NCSF*1,GID*4,NAME*256,FILE_OUT*256
      CHARACTER MODE*4,CH1*1,CHAR1*1,CH2*2,CH4*4
      EQUIVALENCE (R4,CH4)
C -----------------------------------
C -----------------------------------------------
      COMMON/COM_PDB/ CP_CELL,CP_IA,CP_IRES,CP_ICH,CP_MODEL,CP_NAN
     *               ,CP_XYZ,CP_OCC,CP_BISO,CP_SCALE,CP_U,CP_ANIS
     *               ,CP_IGIVEN,CP_NCS,CP_PASS,CP_NSCALE,CP_NV
     *               ,CP_MOLECULE,CP_SURF,CP_SEG,CP_LINE
     *               ,CP_ANAME,CP_RNAME,CP_ASYMB,CP_ATYPE
     *               ,CP_PNUM,CP_CORR,CP_ALT,FLAG_CR,FLAG_SC
     *               ,CP_SPGR,FLAG_MT,CP_NAME,CP_DATE,CP_CODE
     *               ,CP_TITLE,CP_RESL,CP_RFAC,CP_BTYPE,CP_OXT
     *               ,CP_PNUM_OLD
      INTEGER   CP_IA,CP_IRES,CP_ICH,CP_MODEL,CP_NAN,CP_NCS,CP_PASS
      INTEGER   CP_IGIVEN
      REAL      CP_CELL(6),CP_XYZ(3),CP_OCC,CP_BISO,CP_SCALE(3,3)
      REAL      CP_U(3),CP_ANIS(6)
      REAL      CP_NSCALE(3,3),CP_NV(3)
      CHARACTER CP_PNUM*7,CP_ANAME*4,CP_RNAME*3,CP_ASYMB*4
      CHARACTER CP_ATYPE*4,CP_CORR*1,CP_ALT*1,FLAG_CR*1,FLAG_SC*1
      CHARACTER CP_SPGR*24,FLAG_MT*1,CP_NAME*40,CP_DATE*9,CP_CODE*4
      CHARACTER CP_TITLE*40,CP_RESL*36,CP_RFAC*36,CP_BTYPE*1,CP_OXT*1
      CHARACTER CP_PNUM_OLD*7
      INTEGER   CP_MOLECULE
      REAL      CP_SURF
      CHARACTER CP_SEG*4
      CHARACTER CP_LINE*80 
C --------------------------------------------------------------
C ===
      MODEL = IERR
      CHAIN = PDB
C ===
      IERR = 0
      M    = 99
      MD   =-ABS(MDOC)-1
      CALL LENSTR_BL(FILE,LEN)
      IF(LEN.LT.1.OR.FILE(1:1).EQ.','.OR.FILE(1:1).EQ.' ') THEN
        CALL MSGERR(MD,' ERROR: readPDB: WRONG NAME OF INPUT_FILE')
        IERR=1
        RETURN
      ENDIF
c      LN = LEN
c      DO I=LEN,1,-1
c        IF(FILE(I:I).EQ.','.OR.FILE(I:I).EQ.' ') THEN
c          LN = LN-1
c        ENDIF
c      ENDDO
c      NAME = FILE(1:LN)
c      FILE = NAME
c      LEN  = LN
      CALL CORR_NAME_ALL(FILE)
      CALL LENSTR_BL(FILE,LEN)
C --
      EXT = ' '
      LN  = 0
      DO I=LEN,1,-1
        IF(FILE(I:I).EQ.'.') GO TO 300
        LN = LN + 1
      ENDDO
      LN = 0
 300  CONTINUE
      IF(LN.GT.0) THEN
        L1   = LEN-LN+1
        L2   = LEN-LN-1
        EXT  = FILE(L1:LEN)
        NAME = FILE(1:L2)
        FILE = NAME
      ENDIF
      PDB = 'Y'

      FILE_OUT = FILE
      CALL REMOVE_PATH(FILE_OUT)
      CALL ADD_PATH(PATH_SCR,FILE_OUT)

C --------------------------------------------------------------
      PI   = 4.0*ATAN(1.0)
      IN   = 10
c     IOUT = 11
      IOUT = 0
      PATH = ' '
C --------
      CP_PASS = 0
      NCS     = 0
      CALL SET_NCS(MDOC,NCMAX,NCS,CP_NSCALE,CP_NV,IERR)
      IF(IERR.NE.0) RETURN
      IGR  = 0
      CALL SET_ASYMM(MDOC,NMAX,NGR,NCH,IGR,ICH,INC,MLT,IATM
     *                    ,NCSF,GID,IERR)
      IF(IERR.NE.0) RETURN
      NCHAIN  =0
      CP_NAN  =0
C --------------------------------------------------------------
C     IFIRST      = 0
 400  CONTINUE
      CP_PASS = CP_PASS+1

C     EXT ='pdb'
      CALL OPENFR(IN,M,PATH,NAME,EXT,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERROR: readPDB: cannot OPEN INPUT_FILE')
        RETURN
      ENDIF
C ---
C -------------------
      IFIRST      = 0
      IERR        = 0
      JERR        = 0
      KERR        = 0
      REC         = 'START '
      IR          = 0
      IADD        = 0
      CP_IRES     = 0
      CH7         = '???????'
      CP_PNUM_OLD = '???????'
      CH1         = 'N'
      CH2         = '??'
      NA          = 0
      NRES_TOT    = 0
      NHATOM      = 0
      NAHOH       = 0
C ===
      MODEL_R     = 0
C ===
      FLAG_CR     = 'N'
      FLAG_SC     = 'N'
      FLAG_MT     = 'N'
      CP_BTYPE    = 'I'
C -------------------
  100 CONTINUE
      CALL GETREC(MDOC,IN,IOUT,REC,MODEL,MODEL_R,CHAIN,IERR,IEND)
      IF(IERR.NE.0) GO TO 600

      IF(IEND.NE.0) GO TO 200

      IF(REC.EQ.'ATOM  ') THEN
        IF(CP_PNUM.NE.CH7) THEN
          IF(CP_PNUM(1:2).NE.CH2) THEN
c           new chain
            IR=0
CV--  09.07.05
            IADD = 0
            CH7  = '???????'
C^--  09.07.05
c            READ(CP_PNUM(3:6),'(I4)') IR
c            IR=IR-1
            IF(CP_ICH.LT.NMAX) CP_ICH=CP_ICH+1
            CH2=CP_PNUM(1:2)
C --
            IF(CP_PASS.EQ.1) THEN
              IF(NCHAIN.LE.NMAX) THEN
                NCHAIN = NCHAIN+1
                IGR    = NCHAIN
                ICH    = IGR
                IGOLD  = IGR
                ICHOLD = IGR
                INC    = 0
                MLT    = 0
                IATM   = 0
                NCSF   = 'Y'
                GID    = '    '
                GID(1:2)=CH2
                CALL SET_ASYMM(MDOC,NMAX,NGR,ICHOLD,IGR,ICH,INC,MLT
     *                   ,IGOLD,NCSF,GID,IERR)
                IF(IERR.NE.0) GO TO 600
              ENDIF
            ENDIF
C --
          ENDIF
c         new residue
c         IR =IR+1
          READ(CP_PNUM(3:6),'(I4)') IR
          NRES_TOT = NRES_TOT+1
c-- 25.06.00 IF(IR.GT.0.AND.IR.LE.CP_IRES) IR = CP_IRES + 1
CV--  09.07.05
          IF(CP_PNUM(7:7).NE.CH7(7:7).AND.CH7(7:7).NE.'?') 
     *    IADD = IADD + 1
          IR   = IR + IADD
C^--  09.07.05
        ENDIF
        CP_IRES  = IR
        NA=NA+1

        CALL CP_CRD(MDOC,IOUT,IFIRST,FILE_OUT,NAHOH,NHATOM,NA
     *  ,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) GO TO 600

        CH7=CP_PNUM
        CP_PNUM_OLD=CP_PNUM
      ENDIF
      KERR=JERR
      GO TO 100
C --------------------
  200 CONTINUE
      CLOSE(IN)
      IEND=1
      IMODE=0     
      IF(CP_PASS.EQ.2) THEN
        CALL WRCRD(M,IOUT,IMODE,IEND,IERR)
      ENDIF
C ---
      IF(CP_PASS.EQ.1) THEN
        NCS=0
        CALL GET_NCS(MDOC,NCMAX,NCS,CP_NSCALE,CP_NV,IERR)
        IF(IERR.NE.0) GO TO 600
        IGR=0
        CALL GET_ASYMM(MDOC,NMAX,NGRT,ICHOLD,IGR,ICH,INC,MLT
     *                    ,IGOLD,NCSF,GID,IERR)
        IF(IERR.NE.0) GO TO 600
        IF(NCS.GT.0.AND.CP_IGIVEN.EQ.0) THEN
          JGR=NGRT
          DO I=1,NGRT
            IGR=I
            CALL GET_ASYMM(MDOC,NMAX,NGR,ICHOLD,IGR,ICH,INC,MLT
     *                      ,IGOLD,NCSF,GID,IERR)
            IF(IERR.NE.0) GO TO 600
            DO J=1,NCS
              INC=J
              NCSF='N'               
              JGR   =JGR+1
              ICHOLD=ICH
              IGOLD =JGR
              CALL SET_ASYMM(MDOC,NMAX,NGR,ICHOLD,JGR,ICH,INC,MLT
     *                      ,IGOLD,NCSF,GID,IERR)
              IF(IERR.NE.0) GO TO 600
            ENDDO
          ENDDO
        ENDIF
      ENDIF
C ----
      IF(CP_PASS.EQ.1) GO TO 400
C --------------------------------------------------------
C
C     check and correct chain id
C
      CALL CHECK_CHAIN_ID(INEW)
      IF(INEW.GT.0) THEN
        LINE = ' WARNING: readPBD: Chain_list is not correct.'//
     *         ' Program changed it.'
        CALL MSGDOC(MDOC,LINE)
      ENDIF
C --------------------------------------------------------
      WRITE(LINE,'('' PDB_code : '',A4)') CP_CODE
      CALL MSGDOC(MDOC,LINE)
      CH4=CP_CODE
      RESULT(1)  = R4
      RESULT(2)  = NA
      RESULT(3)  = NAHOH
      RESULT(6)  = CP_CELL(1)
      RESULT(7)  = CP_CELL(2)
      RESULT(8)  = CP_CELL(3)
      CP_CELL(4) = (CP_CELL(4)*180.0)/PI
      CP_CELL(5) = (CP_CELL(5)*180.0)/PI
      CP_CELL(6) = (CP_CELL(6)*180.0)/PI
      RESULT(9)  = CP_CELL(4)
      RESULT(10) = CP_CELL(5)
      RESULT(11) = CP_CELL(6)
      IF(IPRROW.GE.20) THEN
        CH4=CP_SPGR(1:4)
        RESULT(12)=R4
        CH4=CP_SPGR(5:8)
        RESULT(13)=R4
        CH4=CP_SPGR(9:11)//' '
        RESULT(14) = R4
        RESULT(15) = NHATOM
        RESULT(16) = NCHAIN
        RESULT(17) = NCS
        RESULT(18) = CP_IGIVEN
        RESULT(19) = NRES_TOT
        RESULT(20) = MODEL_R
      ENDIF
      WRITE(LINE,'('' Cell: '',6F7.2)') 
     *  RESULT(6),RESULT(7),RESULT(8),RESULT(9)
     * ,RESULT(10),RESULT(11) 
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,'('' Space group : '',A)') CP_SPGR 
      CALL MSGDOC(MDOC,LINE)
      IF(CP_RESL(1:1).NE.'.') THEN
        READ(CP_RESL(13:16),'(F4.2)',ERR=700) RESULT(4)
        GO TO 710
  700   CONTINUE
        RESULT(4)=0.0
        CP_RESL(13:16)=' 0.0'
  710   CONTINUE
        WRITE(LINE,'('' Resolution: '',A4)') CP_RESL(13:16) 
        CALL MSGDOC(MDOC,LINE)
      ELSE
        RESULT(4)=0.0
      ENDIF
      IF(CP_RFAC(1:1).NE.'.') THEN
        READ(CP_RFAC(30:34),'(F4.2)',ERR=720) RESULT(5)
        GO TO 730
  720   CONTINUE
        RESULT(5)=0.0
        CP_RFAC(30:34)=' 0.0'
  730   CONTINUE
        WRITE(LINE,'('' R_factor  : '',A4)') CP_RFAC(30:34) 
        CALL MSGDOC(MDOC,LINE)
      ELSE
        RESULT(5)=0.0
      ENDIF

      WRITE(LINE,500) NA,NAHOH
  500 FORMAT(' Number of atoms:',I6,' ( ',I6,' water molecules)')
      CALL MSGDOC(MDOC,LINE)
      IF(MODEL_R.GT.0) THEN
        WRITE(LINE,522) MODEL_R
        CALL MSGDOC(MDOC,LINE)
  522   FORMAT(' Number of models:',I6)
      ENDIF
      WRITE(LINE,520) NCHAIN
  520 FORMAT(' Number of chains:',I6)
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,521) NRES_TOT
  521 FORMAT(' Number of residues:',I6)
      CALL MSGDOC(MDOC,LINE)
      IF(NHATOM.GT.0) THEN
        WRITE(LINE,510) NHATOM
  510   FORMAT(' Number of H-atoms:',I6)
        CALL MSGDOC(MDOC,LINE)
      ENDIF
      IF(NCS.GT.0) THEN
        WRITE(LINE,530) NCS
  530   FORMAT(' Number of NCS-operators:',I6)
        CALL MSGDOC(MDOC,LINE)
        IF(CP_IGIVEN.EQ.0) THEN
          CALL MSGDOC(MDOC,
     * '   use NCS-operators for to restore asymm. part of unit cell')
        ELSE
          CALL MSGDOC(MDOC,
     * '   PDB_file contents asymm. part of unit cell')
          CALL MSGDOC(MDOC,
     * '   NC-symmetry only for information')
        ENDIF
      ENDIF
      IF(NA.LE.0) THEN
        CALL MSGERR(MDOC,' ERR: Number of atoms = 0')
        IERR=1
      ENDIF
      STR_DATE  = CP_DATE
      STR_TITLE = CP_TITLE
      FILE      = FILE_OUT
      RETURN
C --------------------
  600 CONTINUE
      IERR=1
      CLOSE(IN)
      IF(CP_PASS.EQ.2) CLOSE(IOUT)
      RETURN
      END

      SUBROUTINE GETREC(MDOC,IN,IOUT
     *    ,REC,MODEL_I,MODEL_R,CHAIN,IERR,IEND)
C -----------------------------------------------
      INTEGER*4 MDOC,IERR,IEND
      CHARACTER REC*6
C -----------------------------------------------
C -----------------------------------------------
      COMMON/COM_PDB/ CP_CELL,CP_IA,CP_IRES,CP_ICH,CP_MODEL,CP_NAN
     *               ,CP_XYZ,CP_OCC,CP_BISO,CP_SCALE,CP_U,CP_ANIS
     *               ,CP_IGIVEN,CP_NCS,CP_PASS,CP_NSCALE,CP_NV
     *               ,CP_MOLECULE,CP_SURF,CP_SEG,CP_LINE
     *               ,CP_ANAME,CP_RNAME,CP_ASYMB,CP_ATYPE
     *               ,CP_PNUM,CP_CORR,CP_ALT,FLAG_CR,FLAG_SC
     *               ,CP_SPGR,FLAG_MT,CP_NAME,CP_DATE,CP_CODE
     *               ,CP_TITLE,CP_RESL,CP_RFAC,CP_BTYPE,CP_OXT
     *               ,CP_PNUM_OLD
      INTEGER   CP_IA,CP_IRES,CP_ICH,CP_MODEL,CP_NAN,CP_NCS,CP_PASS
      INTEGER   CP_IGIVEN
      REAL      CP_CELL(6),CP_XYZ(3),CP_OCC,CP_BISO,CP_SCALE(3,3)
      REAL      CP_U(3),CP_ANIS(6)
      REAL      CP_NSCALE(3,3),CP_NV(3)
      CHARACTER CP_PNUM*7,CP_ANAME*4,CP_RNAME*3,CP_ASYMB*4
      CHARACTER CP_ATYPE*4,CP_CORR*1,CP_ALT*1,FLAG_CR*1,FLAG_SC*1
      CHARACTER CP_SPGR*24,FLAG_MT*1,CP_NAME*40,CP_DATE*9,CP_CODE*4
      CHARACTER CP_TITLE*40,CP_RESL*36,CP_RFAC*36,CP_BTYPE*1,CP_OXT*1
      CHARACTER CP_PNUM_OLD*7
      INTEGER   CP_MOLECULE
      REAL      CP_SURF
      CHARACTER CP_SEG*4
      CHARACTER CP_LINE*80 
C --------------
      INCLUDE 'mr_crd_com.fh'
C --------------------------------------------------------------
      COMMON/STTCREC/ ICEND,JEND,KEND,ICH0,STR
      INTEGER   ICEND,JEND,KEND,ICH0
      CHARACTER STR*80,CHAIN*1
C ---
      REAL      PI,CELL(6)
      INTEGER*4 M,IN
      CHARACTER LINE*80
C -----------------------------------
      PI   = 4.0*ATAN(1.0)
      IERR = 0
      IEND = 0
      IF(REC.EQ.'START ') THEN
C ---
        CP_CELL(1) = 1.0
        CP_CELL(2) = 1.0
        CP_CELL(3) = 1.0
        CP_CELL(4) = PI/2.0
        CP_CELL(5) = PI/2.0
        CP_CELL(6) = PI/2.0
        CP_IA      = 0
        CP_IRES    = 0
        CP_ICH     = 0
        ICEND      = 0
        JEND       = 0
        KEND       = 0
        ICH0       =-1
        ICOMPND    = 0
        CP_OXT     = 'N'
        CP_MODEL   = 0
        CP_MOLECULE= 0
        CP_LINE    = ' '
C ===
        MODEL_R    = 0
C ===
        CR_FLAG_USER = 'I'
        CR_BTYPE  = '.'
        CP_BTYPE  = '.'

        CP_NAME  = '----'
        CP_DATE  = 'XX-XXX-XX'
        CP_CODE  = 'XXXX'
        CP_TITLE = '---'
        CP_RESL  = '.'
        CP_RFAC  = '.'
        IF(CP_PASS.EQ.1) THEN
          CP_NCS  = 0
          CP_IGIVEN=1
        ENDIF

        STR = ' '
        CALL GETLINE(IN,MDOC,STR,IERR,JEND)
        IMODE = 0
        CALL CHECK_LINE(IMODE,STR)
        CALL LENSTR_BL(STR,LEN)
        IF(LEN.GT.11.AND.
     *     (STR(1:11).EQ.'REMARK #MOL'.OR.
     *      STR(1:11).EQ.'REMARK #DOM')   ) THEN
          STR = STR(8:LEN)
        ENDIF
        ICEND = JEND
        IF(IERR.NE.0.OR.JEND.NE.0) THEN
          IEND=JEND
          RETURN
        ENDIF
        REC         = ' '
        
      ENDIF
C -----
  100 CONTINUE
      LINE=STR   
      IEND=ICEND
      IF(IEND.NE.0) THEN
        CLOSE(IN)
        RETURN
      ENDIF

      IF(KEND.NE.0) THEN
        JEND = KEND
        STR=' '
      ELSE
        STR = ' '
        CALL GETLINE(IN,MDOC,STR,IERR,KEND)
        IF(IERR.NE.0) THEN
          CLOSE(IN)
          RETURN
        ENDIF
        IMODE = 0
        CALL CHECK_LINE(IMODE,STR)
        CALL LENSTR_BL(STR,LEN)
        IF(LEN.GT.11.AND.
     *     (STR(1:11).EQ.'REMARK #MOL'.OR.
     *      STR(1:11).EQ.'REMARK #DOM')   ) THEN
          STR = STR(8:LEN)
        ENDIF
        IF(KEND.NE.0.AND.LEN.LE.0) THEN
          JEND = KEND
          STR=' '
        ELSE IF(KEND.NE.0) THEN

        ENDIF
      ENDIF
      ICEND= JEND
C ===
      IF(LINE(1:5).EQ.'MODEL') THEN
        CALL RDMODEL(LINE,MODEL)
        MODEL_R = MODEL

c       MODEL_R  = MODEL_R + 1

        CP_MODEL = MODEL_R
        CP_ICH   = 0
        CP_PNUM_OLD = '???????'
        GO TO 100
      ENDIF

      IF(LINE(1:9).EQ.'#MOLECULE'.OR.LINE(1:7).EQ.'#DOMAIN') THEN

C        WRITE(*,*) '-1:',LINE(1:20)
C        WRITE(*,*) '-2:',STR(1:20),IOUT,MODEL_I 

        IF((STR(1:9).EQ.'#MOLECULE'.OR.STR(1:1).EQ.' ').AND.
     *                             IOUT.GT.0.AND.MODEL_I.LE.0) THEN
          M       = 99
          MODE    = 1
          IENDW   = 0
          CR_LINE2 = ' '
          CR_LINE = LINE
          CALL WRCRD(M,IOUT,MODE,IENDW,IERR)
        ENDIF 

        CP_MOLECULE = 1
        CP_LINE     = LINE
        GO TO 100
      ENDIF

      IF(MODEL_I.GT.0.AND.MODEL_R.GT.MODEL_I) ICEND=1

      IF(MODEL_I.GT.0.AND.MODEL_R.GT.0.AND.MODEL_R.NE.MODEL_I) 
     *  GO TO 100
C ===

      IF(LINE(1:6).EQ.'HEADER') THEN
        CALL MOLREP_RDHEAD(LINE)
        GO TO 100        
      ELSE IF(LINE(1:6).EQ.'COMPND') THEN
        ICOMPND = ICOMPND + 1
        IF(ICOMPND.EQ.1) CALL RDCOMPND(LINE)
        GO TO 100
      ELSE IF(LINE(1:5).EQ.'TITLE') THEN
        ICOMPND = ICOMPND + 1
        CALL RDTITLE_PDB(LINE)
        GO TO 100
      ELSE IF(LINE(1:4).EQ.'CRYS') THEN
        CALL RDCRYST1(LINE)
        FLAG_CR='Y'
        GO TO 100
c      ELSE IF(LINE(1:6).EQ.'MODEL ') THEN
c        CALL RDMODEL(LINE,MODEL)
cC       IF(MODEL.GT.1) ICEND=1
c        GO TO 100
      ELSE IF(LINE(1:6).EQ.'HET   ') THEN
        CALL RDHET(LINE)
        GO TO 100
      ELSE IF(LINE(1:6).EQ.'FORMUL') THEN
        CALL RDFORMUL(LINE)
        GO TO 100
      ELSE IF(LINE(1:6).EQ.'REMARK') THEN
        CALL RDREMARK(LINE)
        GO TO 100
      ELSE IF(LINE(1:6).EQ.'SCALE1'.OR.
     *        LINE(1:6).EQ.'SCALE2'.OR.
     *        LINE(1:6).EQ.'SCALE3') THEN
c        CALL RDSCALE(LINE)
c        FLAG_SC='Y'
        GO TO 100
      ELSE IF(LINE(1:6).EQ.'MTRIX1'.OR.
     *        LINE(1:6).EQ.'MTRIX2'.OR.
     *        LINE(1:6).EQ.'MTRIX3') THEN
        CALL RDMTRIX(MDOC,LINE,IERR)
        IF(IERR.NE.0) RETURN
        GO TO 100
      ELSE IF(LINE(1:6).EQ.'TER   ') THEN
        REC='TER   '
      ELSE IF(LINE(1:6).EQ.'CONECT') THEN
        CALL RDCONECT(MDOC,LINE,IERR)
        REC='CONECT'
      ELSE IF(LINE(1:6).EQ.'SSBOND') THEN
        CALL RDSSBOND(MDOC,LINE,IERR)
        REC='USER_L'
      ELSE IF((LINE(1:5).EQ.'ATOM ').OR. 
     *        (LINE(1:5).EQ.'HETAT')) THEN
        CALL RDATOM(MDOC,LINE,REC,ICH0)
        REC='ATOM  '
        IF((STR(1:6).EQ.'SIGATM').OR.          
     *     (STR(1:6).EQ.'ANISOU').OR.          
     *     (STR(1:6).EQ.'USER_G').OR.          
     *     (STR(1:6).EQ.'SIGUIJ')) GO TO 100
      ELSE IF(LINE(1:6).EQ.'ANISOU') THEN

        CALL RDANISO(LINE)
        IF((STR(1:6).EQ.'SIGATM').OR.          
     *     (STR(1:6).EQ.'USER_G').OR.          
     *     (STR(1:6).EQ.'SIGUIJ')) GO TO 100
        REC='ATOM  '
      ELSE IF(LINE(1:6).EQ.'SIGATM') THEN
        CALL RDSIGAT(LINE)
        IF((STR(1:6).EQ.'ANISOU').OR.          
     *     (STR(1:6).EQ.'USER_G').OR.          
     *     (STR(1:6).EQ.'SIGUIJ')) GO TO 100
        REC='ATOM  '
      ELSE IF(LINE(1:6).EQ.'SIGUIJ') THEN
        CALL RDSIGUIJ(LINE)
        IF((STR(1:6).EQ.'SIGATM').OR.          
     *     (STR(1:6).EQ.'USER_G').OR.          
     *     (STR(1:6).EQ.'ANISOU')) GO TO 100          
        REC='ATOM  '
      ELSE
        GO TO 100
      ENDIF
C ===
      IF(CHAIN.NE.' '.AND.CHAIN.NE.','.AND.CP_PNUM(1:1).NE.CHAIN) 
     *  GO TO 100
C ===
      RETURN
C -----------------------------------
      END    

      SUBROUTINE RDATOM(MDOC,LINE,REC,ICH0)
C -------------------------------------------------------
C     RDATOM - reads record ATOM/HETATOM from PDB_file.
C 
C -------------------------------------------------------
C -----------------------------------------------
      COMMON/COM_PDB/ CP_CELL,CP_IA,CP_IRES,CP_ICH,CP_MODEL,CP_NAN
     *               ,CP_XYZ,CP_OCC,CP_BISO,CP_SCALE,CP_U,CP_ANIS
     *               ,CP_IGIVEN,CP_NCS,CP_PASS,CP_NSCALE,CP_NV
     *               ,CP_MOLECULE,CP_SURF,CP_SEG,CP_LINE
     *               ,CP_ANAME,CP_RNAME,CP_ASYMB,CP_ATYPE
     *               ,CP_PNUM,CP_CORR,CP_ALT,FLAG_CR,FLAG_SC
     *               ,CP_SPGR,FLAG_MT,CP_NAME,CP_DATE,CP_CODE
     *               ,CP_TITLE,CP_RESL,CP_RFAC,CP_BTYPE,CP_OXT
     *               ,CP_PNUM_OLD
      INTEGER   CP_IA,CP_IRES,CP_ICH,CP_MODEL,CP_NAN,CP_NCS,CP_PASS
      INTEGER   CP_IGIVEN
      REAL      CP_CELL(6),CP_XYZ(3),CP_OCC,CP_BISO,CP_SCALE(3,3)
      REAL      CP_U(3),CP_ANIS(6)
      REAL      CP_NSCALE(3,3),CP_NV(3)
      CHARACTER CP_PNUM*7,CP_ANAME*4,CP_RNAME*3,CP_ASYMB*4
      CHARACTER CP_ATYPE*4,CP_CORR*1,CP_ALT*1,FLAG_CR*1,FLAG_SC*1
      CHARACTER CP_SPGR*24,FLAG_MT*1,CP_NAME*40,CP_DATE*9,CP_CODE*4
      CHARACTER CP_TITLE*40,CP_RESL*36,CP_RFAC*36,CP_BTYPE*1,CP_OXT*1
      CHARACTER CP_PNUM_OLD*7
      INTEGER   CP_MOLECULE
      REAL      CP_SURF
      CHARACTER CP_SEG*4
      CHARACTER CP_LINE*80 
C --------------------------------------------------------------
      CHARACTER LINE*(*),REC*(*)
      INTEGER*4 ICH0
C -----------------------------------
      INTEGER*4 IA
      CHARACTER PNUM*7,TYPE1*1,TYPE2*1,CSURF*6
      CHARACTER FRMT*80,ANAME*4,RNAME*3,ASYMB*4,CTYPE*4,ACODE*4
      DATA FRMT/'(6X,I5,A1,A4,A1,A3,A7,3X,3F8.3,2F6.2,A6,A4,A4)'/
C ------------------------------------
      ASYMB='    '
      CALL LENSTR_BL(LINE,LEN_IN)
      READ(LINE,FRMT)
     *  IA,CP_CORR,ANAME,CP_ALT,RNAME,PNUM
     * ,CP_XYZ(1),CP_XYZ(2),CP_XYZ(3),CP_OCC,CP_BISO
     * ,CSURF,CP_SEG,ACODE

      IF(RNAME.EQ.'   ') THEN
        CALL MSGERR(MDOC,
     * ' WARNING: residue name is empty, default is "HOH"')
        RNAME='HOH'
      ENDIF

      IF(RNAME.EQ.'MSE') THEN
        LINE(1:6) = 'ATOM  '
      ENDIF
      IF(RNAME.EQ.'HYP') THEN
        LINE(1:6) = 'ATOM  '
      ENDIF

      CP_IA=IA
      IF(CP_CORR.EQ.' ') CP_CORR='.'
      IF(CP_ALT .EQ.' ') CP_ALT ='.'

      IF(CP_OCC.GT.1.0) THEN
        IF(FLAG_MT.EQ.'N') THEN
          IF(CP_PASS.EQ.1) THEN
            CALL MSGERR(MDOC,' WARNING: occupancy > 1.0')
          ENDIF
          FLAG_MT='Y'
        ENDIF 
        CP_OCC=1.0
      ENDIF

      CALL CORR_NAME(ANAME,RNAME,ASYMB,CTYPE)

      CALL CHKSMB(ACODE(1:1),TYPE1)
      CALL CHKSMB(ACODE(2:2),TYPE2)

      READ(CSURF,'(F6.2)') CP_SURF


      IF(TYPE1.NE.'D'.AND.TYPE2.NE.'D'.AND.TYPE2.NE.'B'.AND.
     *  LEN_IN.GE.77) THEN
        IF(ACODE(1:1).EQ.' ') THEN
          ACODE = ACODE(2:4)//' '
        ENDIF
        IF(ACODE(2:2).EQ.' ') THEN
          ACODE(2:4) = ACODE(3:4)//' '
          IF(ACODE(2:2).EQ.' ') ACODE(2:4) = ACODE(3:4)//' '
        ENDIF
        ASYMB = ACODE
      ENDIF

      CP_ANAME=ANAME
      CP_ASYMB=ASYMB
      CP_ATYPE=CTYPE
      CP_BTYPE='I'
      PNUM(1:1)=PNUM(2:2)
      PNUM(2:2)= ' '

      IF(REC(1:5).NE.LINE(1:5).AND.REC(1:5).NE.'ATOM ') THEN

        ICH0=ICH0+1
        IF(ICH0.GT.9) ICH0=0
        CP_OXT='N'

      ELSE IF(LINE(1:5).EQ.'HETAT'.AND.
     *     CP_PNUM(3:7).NE.PNUM(3:7))THEN
  
        IF(RNAME.NE.'HOH'.OR.CP_RNAME.NE.RNAME) THEN
          ICH0=ICH0+1
          IF(ICH0.GT.9) ICH0=0
        ENDIF
        CP_OXT='N'

      ELSE IF(LINE(1:5).EQ.'ATOM '.AND.REC(1:5).EQ.'ATOM '.AND.
     *     CP_PNUM(3:7).NE.PNUM(3:7).AND.CP_OXT.EQ.'Y')THEN
        ICH0=ICH0+1
        IF(ICH0.GT.9) ICH0=0
        CP_OXT='N'
      ELSE

        IF(RNAME.EQ.'HOH'.AND.CP_RNAME.NE.RNAME) THEN
          ICH0=ICH0+1
          IF(ICH0.GT.9) ICH0=0
          CP_OXT='N'
        ENDIF

      ENDIF

      CP_RNAME=RNAME
      
      WRITE(PNUM(2:2),'(I1)') ICH0
      IF(PNUM(2:2).EQ.'0'.AND.PNUM(1:1).NE.' ') PNUM(2:2)=' '
      CP_PNUM=PNUM
      IF(ANAME.EQ.'OXT ') CP_OXT='Y'
      RETURN
      END

      SUBROUTINE CORR_NAME(ANAME,RNAME,ASYMB,CTYPE)
C ----------------------------------------------
      PARAMETER (N_NAME = 95)
      CHARACTER ANAME*4,RNAME*3,ASYMB*4,CTYPE*4
C -----------------------------------------------
      CHARACTER TYPE*1,CH1*1,CH2*2,CH4*4
      CHARACTER NAME(N_NAME)*2
C ----
      DATA NAME/'CO','MG','CA','ZN','CU','FE','CL','BR','MN','PB',
     *          'HG','AL','GD','NA','CD','NI','SR','IN','HO','YB',
     *          'TE','LI','RB','BA','CS','SM','TL','PT','BE','SE',
     *          'MO','SI','I ','NE','AR','SC','TI','CR','GA','GE',
     *          'AS','KR','HE','ZR','NB','TC','RU','RH','PD','AG',
     *          'SN','SB','XE','LA','HF','TA','RE','OS','IR','AU',
     *          'BI','PO','AT','RN','FR','RA','AC','CE','PR','ND',
     *          'PM','EU','TB','DY','ER','TM','LU','TH','PA','NP',
     *          'PU','AM','CM','BK','CF','ES','FM','MD','NO','LR',
     *          'K ','V ','Y ','U ','W '                          /
C ---------------------------------------------
      IF(ANAME(1:1).NE.' ') THEN
        CH1=ANAME(1:1)
        CALL CHKSMB(CH1,TYPE)
        IF(TYPE.EQ.'D') THEN
          CALL LENSTR_BL(ANAME,LN)
          IF(LN.LE.1) THEN
            LN=2
            ANAME(2:2)='H'
          ENDIF
          ASYMB = ANAME(2:2)//'   '
          CH4='    '
          CH4(1:LN)=ANAME(2:LN)//CH1
          ANAME=CH4
C         CTYPE='H   '
          IF(ASYMB(1:1).EQ.'H') CTYPE='H   '
        ELSE IF(ANAME(4:4).EQ.' ') THEN
          CH2=ANAME(1:2)
          DO  I=1,N_NAME
            IF(NAME(I).EQ.CH2) THEN
              ASYMB=ANAME(1:2)//'  '
              CTYPE='$   '
              GO TO 100
            ENDIF
          ENDDO
          ASYMB=ANAME(2:2)//'   '
          CTYPE='C   '
          IF(ASYMB(1:1).EQ.'H') CTYPE='H   '
  100     CONTINUE
        ELSE
          ASYMB=ANAME(2:2)//'   '
          CTYPE='C   '
          IF(ASYMB(1:1).EQ.'H') CTYPE='H   '
        ENDIF  
      ELSE
        ASYMB=ANAME(2:2)//'   '
        IF(ASYMB(1:1).EQ.'M') ASYMB='C   '
        IF(ASYMB(1:1).EQ.'C'.OR.ASYMB(1:1).EQ.'N'.OR.
     *     ASYMB(1:1).EQ.'O'.OR.ASYMB(1:1).EQ.'B'.OR.
     *     ASYMB(1:1).EQ.'F'                         ) THEN
          CTYPE='C   '
        ELSE
          CTYPE='$   '
        ENDIF
        IF(ASYMB(1:1).EQ.'H') CTYPE='H   '
      ENDIF
      
      IF(ANAME(1:1).EQ.' ') THEN
        ANAME=ANAME(2:4)//' '
      ENDIF
      IF(ANAME(2:2).EQ.' ') THEN
        ANAME(2:4)=ANAME(3:4)//' '
        IF(ANAME(2:2).EQ.' ') ANAME(2:4)=ANAME(3:4)//' '
      ENDIF
C ---
      IF(RNAME(1:1).EQ.' ') THEN
        RNAME=RNAME(2:3)//' '
        IF(RNAME(1:1).EQ.' ') RNAME=RNAME(2:3)//' '
      ENDIF
      IF(RNAME.EQ.'WAT') RNAME='HOH'
      IF(RNAME.EQ.'DOD') RNAME='HOH'
      IF(RNAME.EQ.'CYT') RNAME='C'
      IF(RNAME.EQ.'ADE') RNAME='A'
      IF(RNAME.EQ.'THY') RNAME='T'
      IF(RNAME.EQ.'GUA') RNAME='G'
      IF(RNAME.EQ.'URI') RNAME='U'

      IF(RNAME(1:1).EQ.'''') RNAME(1:1)='*'
      IF(RNAME(2:2).EQ.'''') RNAME(2:2)='*'
      IF(RNAME(3:3).EQ.'''') RNAME(3:3)='*'
      IF(ANAME(1:1).EQ.'''') ANAME(1:1)='*'
      IF(ANAME(2:2).EQ.'''') ANAME(2:2)='*'
      IF(ANAME(3:3).EQ.'''') ANAME(3:3)='*'
      IF(ANAME(4:4).EQ.'''') ANAME(4:4)='*'

      IF(ANAME.EQ.'H0  ') THEN
        ANAME    = 'H   '
        CTYPE='H   '
      ENDIF
      IF(ASYMB.EQ.'D  ') THEN
        ASYMB    = 'H   '
        CTYPE='H   '
      ENDIF
      IF(ANAME.EQ.'HE21') THEN
        ASYMB    = 'H   '
        CTYPE='H   '
      ENDIF
      IF(ANAME.EQ.'HE22') THEN
        ASYMB    = 'H   '
        CTYPE='H   '
      ENDIF
      IF(ANAME.EQ.'HD21') THEN
        ASYMB    = 'H   '
        CTYPE='H   '
      ENDIF
      IF(ANAME.EQ.'HD22') THEN
        ASYMB    = 'H   '
        CTYPE='H   '
      ENDIF
      IF(ANAME.EQ.'HH11') THEN
        ASYMB    = 'H   '
        CTYPE='H   '
      ENDIF
      IF(ANAME.EQ.'HH12') THEN
        ASYMB    = 'H   '
        CTYPE='H   '
      ENDIF
      IF(ANAME.EQ.'HH21') THEN
        ASYMB    = 'H   '
        CTYPE='H   '
      ENDIF
      IF(ANAME.EQ.'HH22') THEN
        ASYMB    = 'H   '
        CTYPE='H   '
      ENDIF
      IF(ANAME.EQ.'HT1 ') THEN
        ANAME    = 'H1  '
        ASYMB    = 'H   '
        CTYPE    = 'H   '
      ENDIF
      IF(ANAME.EQ.'HT2 ') THEN
        ANAME    = 'H2  '
        ASYMB    = 'H   '
        CTYPE    = 'H   '
      ENDIF
      IF(ANAME.EQ.'HT3 ') THEN
        ANAME    = 'H3  '
        ASYMB    = 'H   '
        CTYPE    = 'H   '
      ENDIF

      IF(RNAME.EQ.'HOH') THEN
        IF(ASYMB(1:1).EQ.'O') THEN
          ANAME = 'O   '
          ASYMB = 'O   '
          CTYPE = 'C   '
        ELSE IF(ASYMB(1:1).EQ.'H'.OR.ASYMB(1:1).EQ.'D') THEN
          ASYMB = 'H   '
          CTYPE = 'H   '
        ENDIF
      ENDIF
C ---  special cases ---
      IF(RNAME.EQ.'IUM'.AND.CTYPE.EQ.'$   ') THEN
        RNAME = ANAME(1:2)
      ENDIF

      RETURN
      END


      SUBROUTINE MOLREP_RDHEAD(LINE)
C -------------------------------------------------------
C     MOLREP_RDHEAD - reads record HEADER from PDB_file.
C 
C -------------------------------------------------------
      CHARACTER LINE*(*)
C ---
C -----------------------------------------------
C -----------------------------------------------
      COMMON/COM_PDB/ CP_CELL,CP_IA,CP_IRES,CP_ICH,CP_MODEL,CP_NAN
     *               ,CP_XYZ,CP_OCC,CP_BISO,CP_SCALE,CP_U,CP_ANIS
     *               ,CP_IGIVEN,CP_NCS,CP_PASS,CP_NSCALE,CP_NV
     *               ,CP_MOLECULE,CP_SURF,CP_SEG,CP_LINE
     *               ,CP_ANAME,CP_RNAME,CP_ASYMB,CP_ATYPE
     *               ,CP_PNUM,CP_CORR,CP_ALT,FLAG_CR,FLAG_SC
     *               ,CP_SPGR,FLAG_MT,CP_NAME,CP_DATE,CP_CODE
     *               ,CP_TITLE,CP_RESL,CP_RFAC,CP_BTYPE,CP_OXT
     *               ,CP_PNUM_OLD
      INTEGER   CP_IA,CP_IRES,CP_ICH,CP_MODEL,CP_NAN,CP_NCS,CP_PASS
      INTEGER   CP_IGIVEN
      REAL      CP_CELL(6),CP_XYZ(3),CP_OCC,CP_BISO,CP_SCALE(3,3)
      REAL      CP_U(3),CP_ANIS(6)
      REAL      CP_NSCALE(3,3),CP_NV(3)
      CHARACTER CP_PNUM*7,CP_ANAME*4,CP_RNAME*3,CP_ASYMB*4
      CHARACTER CP_ATYPE*4,CP_CORR*1,CP_ALT*1,FLAG_CR*1,FLAG_SC*1
      CHARACTER CP_SPGR*24,FLAG_MT*1,CP_NAME*40,CP_DATE*9,CP_CODE*4
      CHARACTER CP_TITLE*40,CP_RESL*36,CP_RFAC*36,CP_BTYPE*1,CP_OXT*1
      CHARACTER CP_PNUM_OLD*7
      INTEGER   CP_MOLECULE
      REAL      CP_SURF
      CHARACTER CP_SEG*4
      CHARACTER CP_LINE*80 
C --------------------------------------------------------------
      CHARACTER FRMT*80,NAME_PDB*40,DATE_PDB*9,CD_PDB*4
      DATA FRMT/'(10X,A40,A9,3X,A4)'/
C ------------------------------------
      READ(LINE,FRMT) NAME_PDB,DATE_PDB,CD_PDB

      CALL LENSTR_BL(NAME_PDB,LEN)
      IF(LEN.LE.0) NAME_PDB='----'
      CALL LENSTR_BL(DATE_PDB,LEN)
      IF(LEN.LE.0) DATE_PDB='XX-XXX-XX'
      CALL LENSTR_BL(CD_PDB,LEN)
      IF(LEN.LE.0) CD_PDB='XXXX'

      CP_DATE = DATE_PDB
      CP_NAME = NAME_PDB
      CP_CODE = CD_PDB

      RETURN
      END

      SUBROUTINE RDCOMPND(LINE)
C -------------------------------------------------------
C     RDCOMPND - reads record COMPND from PDB_file.
C 
C -------------------------------------------------------
      CHARACTER LINE*(*)
C ---
C -----------------------------------------------
      COMMON/COM_PDB/ CP_CELL,CP_IA,CP_IRES,CP_ICH,CP_MODEL,CP_NAN
     *               ,CP_XYZ,CP_OCC,CP_BISO,CP_SCALE,CP_U,CP_ANIS
     *               ,CP_IGIVEN,CP_NCS,CP_PASS,CP_NSCALE,CP_NV
     *               ,CP_MOLECULE,CP_SURF,CP_SEG,CP_LINE
     *               ,CP_ANAME,CP_RNAME,CP_ASYMB,CP_ATYPE
     *               ,CP_PNUM,CP_CORR,CP_ALT,FLAG_CR,FLAG_SC
     *               ,CP_SPGR,FLAG_MT,CP_NAME,CP_DATE,CP_CODE
     *               ,CP_TITLE,CP_RESL,CP_RFAC,CP_BTYPE,CP_OXT
     *               ,CP_PNUM_OLD
      INTEGER   CP_IA,CP_IRES,CP_ICH,CP_MODEL,CP_NAN,CP_NCS,CP_PASS
      INTEGER   CP_IGIVEN
      REAL      CP_CELL(6),CP_XYZ(3),CP_OCC,CP_BISO,CP_SCALE(3,3)
      REAL      CP_U(3),CP_ANIS(6)
      REAL      CP_NSCALE(3,3),CP_NV(3)
      CHARACTER CP_PNUM*7,CP_ANAME*4,CP_RNAME*3,CP_ASYMB*4
      CHARACTER CP_ATYPE*4,CP_CORR*1,CP_ALT*1,FLAG_CR*1,FLAG_SC*1
      CHARACTER CP_SPGR*24,FLAG_MT*1,CP_NAME*40,CP_DATE*9,CP_CODE*4
      CHARACTER CP_TITLE*40,CP_RESL*36,CP_RFAC*36,CP_BTYPE*1,CP_OXT*1
      CHARACTER CP_PNUM_OLD*7
      INTEGER   CP_MOLECULE
      REAL      CP_SURF
      CHARACTER CP_SEG*4
      CHARACTER CP_LINE*80 
C --------------------------------------------------------------
      CHARACTER FRMT*80,TITLE*68
      DATA FRMT/'(10X,A68)'/
C ------------------------------------
      READ(LINE,FRMT) TITLE

      CALL LENSTR_BL(TITLE,LEN)
      IF(LEN.LE.0) TITLE='---'

      CP_TITLE = TITLE(1:40)

      RETURN
      END

      SUBROUTINE RDTITLE_PDB(LINE)
C -------------------------------------------------------
C     RDTITLE_PDB - reads record TITLE from PDB_file.
C 
C -------------------------------------------------------
      CHARACTER LINE*(*)
C ---
C -----------------------------------------------
      COMMON/COM_PDB/ CP_CELL,CP_IA,CP_IRES,CP_ICH,CP_MODEL,CP_NAN
     *               ,CP_XYZ,CP_OCC,CP_BISO,CP_SCALE,CP_U,CP_ANIS
     *               ,CP_IGIVEN,CP_NCS,CP_PASS,CP_NSCALE,CP_NV
     *               ,CP_MOLECULE,CP_SURF,CP_SEG,CP_LINE
     *               ,CP_ANAME,CP_RNAME,CP_ASYMB,CP_ATYPE
     *               ,CP_PNUM,CP_CORR,CP_ALT,FLAG_CR,FLAG_SC
     *               ,CP_SPGR,FLAG_MT,CP_NAME,CP_DATE,CP_CODE
     *               ,CP_TITLE,CP_RESL,CP_RFAC,CP_BTYPE,CP_OXT
     *               ,CP_PNUM_OLD
      INTEGER   CP_IA,CP_IRES,CP_ICH,CP_MODEL,CP_NAN,CP_NCS,CP_PASS
      INTEGER   CP_IGIVEN
      REAL      CP_CELL(6),CP_XYZ(3),CP_OCC,CP_BISO,CP_SCALE(3,3)
      REAL      CP_U(3),CP_ANIS(6)
      REAL      CP_NSCALE(3,3),CP_NV(3)
      CHARACTER CP_PNUM*7,CP_ANAME*4,CP_RNAME*3,CP_ASYMB*4
      CHARACTER CP_ATYPE*4,CP_CORR*1,CP_ALT*1,FLAG_CR*1,FLAG_SC*1
      CHARACTER CP_SPGR*24,FLAG_MT*1,CP_NAME*40,CP_DATE*9,CP_CODE*4
      CHARACTER CP_TITLE*40,CP_RESL*36,CP_RFAC*36,CP_BTYPE*1,CP_OXT*1
      CHARACTER CP_PNUM_OLD*7
      INTEGER   CP_MOLECULE
      REAL      CP_SURF
      CHARACTER CP_SEG*4
      CHARACTER CP_LINE*80 
C --------------------------------------------------------------
      CHARACTER FRMT*80,TITLE*68
      DATA FRMT/'(10X,A68)'/
C ------------------------------------
      READ(LINE,FRMT) TITLE

      CALL LENSTR_BL(TITLE,LEN)
      IF(LEN.LE.0) TITLE='---'

      CP_TITLE = TITLE(1:40)

      RETURN
      END

      SUBROUTINE RDMODEL(LINE,MODEL)
C -------------------------------------------------------
C     RDMODEL - reads record MODEL from PDB_file.
C 
C -------------------------------------------------------
      CHARACTER LINE*(*)
C ------------------------------------------------------
      CHARACTER FRMT*80
      DATA FRMT/'(10X,I4)'/
C ------------------------------------
      READ(LINE,FRMT) MODEL

      RETURN
      END

      SUBROUTINE RDREMARK(LINE)
C -------------------------------------------------------
C     RDREMARK - reads record REMARK from PDB_file.
C   
C 123456789 123456789 123456789 123456789 123456789 12
C            123456789 123456789 123456789 123456789 1 
C REMARK   4   WAVELENGTH OR WAVELENGTH RANGE : 1.54 A   
C REMARK  18  WAVELENGTH OR RANGE (A)        : 1.54
C -------------------------------------------------------
      CHARACTER LINE*(*)
C -----------------------------------------------
C -----------------------------------------------
      COMMON/COM_PDB/ CP_CELL,CP_IA,CP_IRES,CP_ICH,CP_MODEL,CP_NAN
     *               ,CP_XYZ,CP_OCC,CP_BISO,CP_SCALE,CP_U,CP_ANIS
     *               ,CP_IGIVEN,CP_NCS,CP_PASS,CP_NSCALE,CP_NV
     *               ,CP_MOLECULE,CP_SURF,CP_SEG,CP_LINE
     *               ,CP_ANAME,CP_RNAME,CP_ASYMB,CP_ATYPE
     *               ,CP_PNUM,CP_CORR,CP_ALT,FLAG_CR,FLAG_SC
     *               ,CP_SPGR,FLAG_MT,CP_NAME,CP_DATE,CP_CODE
     *               ,CP_TITLE,CP_RESL,CP_RFAC,CP_BTYPE,CP_OXT
     *               ,CP_PNUM_OLD
      INTEGER   CP_IA,CP_IRES,CP_ICH,CP_MODEL,CP_NAN,CP_NCS,CP_PASS
      INTEGER   CP_IGIVEN
      REAL      CP_CELL(6),CP_XYZ(3),CP_OCC,CP_BISO,CP_SCALE(3,3)
      REAL      CP_U(3),CP_ANIS(6)
      REAL      CP_NSCALE(3,3),CP_NV(3)
      CHARACTER CP_PNUM*7,CP_ANAME*4,CP_RNAME*3,CP_ASYMB*4
      CHARACTER CP_ATYPE*4,CP_CORR*1,CP_ALT*1,FLAG_CR*1,FLAG_SC*1
      CHARACTER CP_SPGR*24,FLAG_MT*1,CP_NAME*40,CP_DATE*9,CP_CODE*4
      CHARACTER CP_TITLE*40,CP_RESL*36,CP_RFAC*36,CP_BTYPE*1,CP_OXT*1
      CHARACTER CP_PNUM_OLD*7
      INTEGER   CP_MOLECULE
      REAL      CP_SURF
      CHARACTER CP_SEG*4
      CHARACTER CP_LINE*80 
C --------------------------------------------------------------
C -----------------------------------
      CHARACTER FRMT*80,CH36*36,CHAR*1,TYPE*1
      DATA FRMT/'(7X,I3,1X,A36)'/
C ------------------------------------
      CHAR=LINE(8:8)
      CALL CHKSMB(CHAR,TYPE)
      IF(TYPE.NE.'B'.AND.TYPE.NE.'D') GO TO 100
      CHAR=LINE(9:9)
      CALL CHKSMB(CHAR,TYPE)
      IF(TYPE.NE.'B'.AND.TYPE.NE.'D') GO TO 100
      CHAR=LINE(10:10)
      CALL CHKSMB(CHAR,TYPE)
      IF(TYPE.NE.'B'.AND.TYPE.NE.'D') GO TO 100

      READ(LINE,FRMT,ERR=100) I,CH36

      IF(I.EQ.2     .AND.CH36(1:10).EQ.'RESOLUTION') THEN
        CP_RESL    = CH36
      ELSE IF(I.EQ.3.AND.CH36(1:10).EQ.'  R VALUE ') THEN
        CP_RFAC    = CH36
      ENDIF

  100 CONTINUE
      RETURN
      END

      SUBROUTINE RDHET(LINE)
C -------------------------------------------------------
C     RDHET - reads record HET from PDB_file.
C 
C -------------------------------------------------------
      CHARACTER LINE*(*)
C ---
      CHARACTER FRMT*80,MON*3,NAME*40
      DATA FRMT/'(7X,A3,10X,I5,5X,A40)'/
C ------------------------------------
      READ(LINE,FRMT) MON,NA,NAME

      IF(MON(1:1).EQ.' ') THEN
        MON=MON(2:3)//' '
        IF(MON(1:1).EQ.' ') MON=MON(2:3)//' '
      ENDIF

      CALL LENSTR_BL(NAME,LEN)
     
      IF(LEN.GT.0) THEN
        DO I=1,LEN
          IF(NAME(I:I).EQ.' ')  NAME(I:I)='_'
          IF(NAME(I:I).EQ.'''') NAME(I:I)='*'
        ENDDO 
      ELSE
        NAME='.'
      ENDIF

      RETURN
      END

      SUBROUTINE RDFORMUL(LINE)
C -------------------------------------------------------
C     RDFORMUL - reads record FORMUL from PDB_file.
C  
C -------------------------------------------------------
      CHARACTER LINE*(*)
C ---
      CHARACTER FRMT*80,MON*3,FORMUL*40
      DATA FRMT/'(12X,A3,4X,A40)'/
C ------------------------------------
      READ(LINE,FRMT) MON,FORMUL

      IF(MON(1:1).EQ.' ') THEN
        MON=MON(2:3)//' '
        IF(MON(1:1).EQ.' ') MON=MON(2:3)//' '
      ENDIF

      RETURN
      END

      SUBROUTINE RDCRYST1(LINE)
C -------------------------------------------------------
C     RDCRYST1 - reads record CRYST1 from PDB_file.
C 
C -------------------------------------------------------
      CHARACTER LINE*(*)
C ---
C -----------------------------------------------
      COMMON/COM_PDB/ CP_CELL,CP_IA,CP_IRES,CP_ICH,CP_MODEL,CP_NAN
     *               ,CP_XYZ,CP_OCC,CP_BISO,CP_SCALE,CP_U,CP_ANIS
     *               ,CP_IGIVEN,CP_NCS,CP_PASS,CP_NSCALE,CP_NV
     *               ,CP_MOLECULE,CP_SURF,CP_SEG,CP_LINE
     *               ,CP_ANAME,CP_RNAME,CP_ASYMB,CP_ATYPE
     *               ,CP_PNUM,CP_CORR,CP_ALT,FLAG_CR,FLAG_SC
     *               ,CP_SPGR,FLAG_MT,CP_NAME,CP_DATE,CP_CODE
     *               ,CP_TITLE,CP_RESL,CP_RFAC,CP_BTYPE,CP_OXT
     *               ,CP_PNUM_OLD
      INTEGER   CP_IA,CP_IRES,CP_ICH,CP_MODEL,CP_NAN,CP_NCS,CP_PASS
      INTEGER   CP_IGIVEN
      REAL      CP_CELL(6),CP_XYZ(3),CP_OCC,CP_BISO,CP_SCALE(3,3)
      REAL      CP_U(3),CP_ANIS(6)
      REAL      CP_NSCALE(3,3),CP_NV(3)
      CHARACTER CP_PNUM*7,CP_ANAME*4,CP_RNAME*3,CP_ASYMB*4
      CHARACTER CP_ATYPE*4,CP_CORR*1,CP_ALT*1,FLAG_CR*1,FLAG_SC*1
      CHARACTER CP_SPGR*24,FLAG_MT*1,CP_NAME*40,CP_DATE*9,CP_CODE*4
      CHARACTER CP_TITLE*40,CP_RESL*36,CP_RFAC*36,CP_BTYPE*1,CP_OXT*1
      CHARACTER CP_PNUM_OLD*7,CHAR11*11,CHAR1*1
      INTEGER   CP_MOLECULE
      REAL      CP_SURF
      CHARACTER CP_SEG*4
      CHARACTER CP_LINE*80 
C --------------------------------------------------------------
      REAL CELL(6)
      CHARACTER FRMT*80
      CHARACTER SPGR*24
      DATA FRMT/'(6X,3F9.3,3F7.2,1X,A11)'/
C ------------------------------------
      PI    = 4.0*ATAN(1.0)
      TWOPI = 2.0*PI
      PI180 = PI/180.0
C
      READ(LINE,FRMT) CELL(1),CELL(2),CELL(3)
     *               ,CELL(4),CELL(5),CELL(6)
     *               ,CHAR11
      IMODE = 0
      CALL CHECK_LINE(IMODE,CHAR11)
      SPGR = CHAR11
C ---
      CP_CELL(1) =CELL(1)
      CP_CELL(2) =CELL(2)
      CP_CELL(3) =CELL(3)
      CP_CELL(4) =CELL(4)*PI180
      CP_CELL(5) =CELL(5)*PI180
      CP_CELL(6) =CELL(6)*PI180
C ---
      CALL LENSTR_BL(SPGR,LENS)
      IF(LENS.LE.0) THEN
        SPGR = ' '
        LENS = 1
      ELSE
        J  = 0
        NB =-11
        DO I=1,LENS
          IF(SPGR(I:I).EQ.' ') THEN
            NB = NB+1
            IF(NB.EQ.1) THEN
              J = J + 1
              SPGR(J:J) = SPGR(I:I)
            ENDIF
          ELSE
            NB = 0
            J  = J + 1
            SPGR(J:J) = SPGR(I:I)
          ENDIF
        ENDDO
        LENS = J
      ENDIF

      CP_SPGR = SPGR(1:LENS)

      RETURN
      END

      SUBROUTINE RDSCALE(LINE)
C -------------------------------------------------------
C     RDSCALE - reads record SCALE1 from PDB_file.
C
C -------------------------------------------------------
      CHARACTER LINE*(*)
C -----------------------------------------------
C -----------------------------------------------
      COMMON/COM_PDB/ CP_CELL,CP_IA,CP_IRES,CP_ICH,CP_MODEL,CP_NAN
     *               ,CP_XYZ,CP_OCC,CP_BISO,CP_SCALE,CP_U,CP_ANIS
     *               ,CP_IGIVEN,CP_NCS,CP_PASS,CP_NSCALE,CP_NV
     *               ,CP_MOLECULE,CP_SURF,CP_SEG,CP_LINE
     *               ,CP_ANAME,CP_RNAME,CP_ASYMB,CP_ATYPE
     *               ,CP_PNUM,CP_CORR,CP_ALT,FLAG_CR,FLAG_SC
     *               ,CP_SPGR,FLAG_MT,CP_NAME,CP_DATE,CP_CODE
     *               ,CP_TITLE,CP_RESL,CP_RFAC,CP_BTYPE,CP_OXT
     *               ,CP_PNUM_OLD
      INTEGER   CP_IA,CP_IRES,CP_ICH,CP_MODEL,CP_NAN,CP_NCS,CP_PASS
      INTEGER   CP_IGIVEN
      REAL      CP_CELL(6),CP_XYZ(3),CP_OCC,CP_BISO,CP_SCALE(3,3)
      REAL      CP_U(3),CP_ANIS(6)
      REAL      CP_NSCALE(3,3),CP_NV(3)
      CHARACTER CP_PNUM*7,CP_ANAME*4,CP_RNAME*3,CP_ASYMB*4
      CHARACTER CP_ATYPE*4,CP_CORR*1,CP_ALT*1,FLAG_CR*1,FLAG_SC*1
      CHARACTER CP_SPGR*24,FLAG_MT*1,CP_NAME*40,CP_DATE*9,CP_CODE*4
      CHARACTER CP_TITLE*40,CP_RESL*36,CP_RFAC*36,CP_BTYPE*1,CP_OXT*1
      CHARACTER CP_PNUM_OLD*7
      INTEGER   CP_MOLECULE
      REAL      CP_SURF
      CHARACTER CP_SEG*4
      CHARACTER CP_LINE*80 
C --------------------------------------------------------------
      CHARACTER FRMT*80,CH1*1
      DATA FRMT/'(5X,A1,4X,3F10.6,5X,F10.5)'/
C ------------------------------------
      READ(LINE,FRMT) CH1,S1,S2,S3,U

      I=1
      IF(CH1.EQ.'2') I=2
      IF(CH1.EQ.'3') I=3
      IF(I.EQ.1) THEN
        CP_SCALE(1,1)=S1
        CP_SCALE(2,1)=S2
        CP_SCALE(3,1)=S3
        CP_U(1)      =U  
      ELSE IF(I.EQ.2) THEN
        CP_SCALE(1,2)=S1
        CP_SCALE(2,2)=S2
        CP_SCALE(3,2)=S3
        CP_U(2)      =U  
      ELSE IF(I.EQ.3) THEN
        CP_SCALE(1,3)=S1
        CP_SCALE(2,3)=S2
        CP_SCALE(3,3)=S3
        CP_U(3)      =U  
      ENDIF
      RETURN
      END

      SUBROUTINE RDMTRIX(MDOC,LINE,IERR)
C -------------------------------------------------------
C     RDMTRIX - reads record MTRIX1 from PDB_file.
C   
C -------------------------------------------------------
      CHARACTER LINE*(*)
C -----------------------------------------------
C -----------------------------------------------
      COMMON/COM_PDB/ CP_CELL,CP_IA,CP_IRES,CP_ICH,CP_MODEL,CP_NAN
     *               ,CP_XYZ,CP_OCC,CP_BISO,CP_SCALE,CP_U,CP_ANIS
     *               ,CP_IGIVEN,CP_NCS,CP_PASS,CP_NSCALE,CP_NV
     *               ,CP_MOLECULE,CP_SURF,CP_SEG,CP_LINE
     *               ,CP_ANAME,CP_RNAME,CP_ASYMB,CP_ATYPE
     *               ,CP_PNUM,CP_CORR,CP_ALT,FLAG_CR,FLAG_SC
     *               ,CP_SPGR,FLAG_MT,CP_NAME,CP_DATE,CP_CODE
     *               ,CP_TITLE,CP_RESL,CP_RFAC,CP_BTYPE,CP_OXT
     *               ,CP_PNUM_OLD
      INTEGER   CP_IA,CP_IRES,CP_ICH,CP_MODEL,CP_NAN,CP_NCS,CP_PASS
      INTEGER   CP_IGIVEN
      REAL      CP_CELL(6),CP_XYZ(3),CP_OCC,CP_BISO,CP_SCALE(3,3)
      REAL      CP_U(3),CP_ANIS(6)
      REAL      CP_NSCALE(3,3),CP_NV(3)
      CHARACTER CP_PNUM*7,CP_ANAME*4,CP_RNAME*3,CP_ASYMB*4
      CHARACTER CP_ATYPE*4,CP_CORR*1,CP_ALT*1,FLAG_CR*1,FLAG_SC*1
      CHARACTER CP_SPGR*24,FLAG_MT*1,CP_NAME*40,CP_DATE*9,CP_CODE*4
      CHARACTER CP_TITLE*40,CP_RESL*36,CP_RFAC*36,CP_BTYPE*1,CP_OXT*1
      CHARACTER CP_PNUM_OLD*7
      INTEGER   CP_MOLECULE
      REAL      CP_SURF
      CHARACTER CP_SEG*4
      CHARACTER CP_LINE*80 
C --------------------------------------------------------------
      REAL FRTOCR(3,3),CRTOFR(3,3),V1(3),U(3),V2(3)
      REAL AM(3,3),BM(3,3),SI(3,3),S(3,3)
      CHARACTER FRMT*80,CH1*1,STR*80
      DATA FRMT/'(5X,A1,1X,I3,3F10.6,5X,F10.5,4X,I1)'/
C ------------------------------------
      PI=4.0*ATAN(1.0)
      READ(LINE,FRMT) CH1,ICS,S1,S2,S3,V,IGIVEN

      IF(CP_PASS.EQ.1) THEN
        I=1
        IF(CH1.EQ.'2') I=2
        IF(CH1.EQ.'3') I=3
        IF(I.EQ.1) THEN
          CP_NSCALE(1,1)=S1
          CP_NSCALE(2,1)=S2
          CP_NSCALE(3,1)=S3
          CP_NV(1)      =V  
        ELSE IF(I.EQ.2) THEN
          CP_NSCALE(1,2)=S1
          CP_NSCALE(2,2)=S2
          CP_NSCALE(3,2)=S3
          CP_NV(2)      =V  
        ELSE IF(I.EQ.3) THEN
          CP_NSCALE(1,3)=S1
          CP_NSCALE(2,3)=S2
          CP_NSCALE(3,3)=S3
          CP_NV(3)      =V  
          CP_NCS=CP_NCS+1                     
          CP_IGIVEN=IGIVEN


          CALL INVERT(CP_SCALE,SI,IERR)
          IF(IERR.NE.0) THEN
            CALL MSGERR(MDOC,' WARNING: problem with SCALE matrix')             
            IERR=0
            GO TO 200
          ENDIF

c          WRITE(STR,'('' MATRIX : '',3F12.4)') (CP_NSCALE(L,1),L=1,3)
c          CALL MSGDOC(MD,STR)
c          WRITE(STR,'(''          '',3F12.4)') (CP_NSCALE(L,2),L=1,3)
c          CALL MSGDOC(MD,STR)
c          WRITE(STR,'(''          '',3F12.4)') (CP_NSCALE(L,3),L=1,3)
c          CALL MSGDOC(MD,STR)
c
c          CALL MTOANG(CP_NSCALE,ALPHA,BETA,GAMMA)
c          WRITE(STR,100) ALPHA,BETA,GAMMA
c  100     FORMAT('EILER ANGLES : ALPHA BETA GAMMA :',3F10.4)
c          CALL MSGDOC(MD,STR)
c
c          ALPHA=ALPHA*PI/180.
c          BETA =BETA *PI/180.
c          GAMMA=GAMMA*PI/180.c
c
c          CALL EULERM(ALPHA,BETA,GAMMA,AM)
c
c          WRITE(STR,'('' MATRIX : '',3F12.4)') (AM(L,1),L=1,3)
c          CALL MSGDOC(MD,STR)
c          WRITE(STR,'(''          '',3F12.4)') (AM(L,2),L=1,3)
c          CALL MSGDOC(MD,STR)
c          WRITE(STR,'(''          '',3F12.4)') (AM(L,3),L=1,3)
c          CALL MSGDOC(MD,STR)


          CALL FRORTH(CP_CELL(1),CP_CELL(2),CP_CELL(3)
     *           ,CP_CELL(4),CP_CELL(5),CP_CELL(6)
     *                         ,FRTOCR,CRTOFR,IERR)
          CALL  MATMLT(SI,CRTOFR,AM)
          CALL  MATMLT(FRTOCR,CP_SCALE,BM)
          CALL  MATMLT(CP_NSCALE,AM,S)
          CALL  MATMLT(BM,S,CP_NSCALE)

          CALL  MVMULT(FRTOCR,CP_U,U)
          CALL  MVMULT(CP_NSCALE,U,V1)
          CALL  VADD(U,V1,V2)
          CALL  MVMULT(BM,CP_NV,V1)
          CALL  VADD(V1,V2,CP_NV)


c          WRITE(STR,'('' MATRIX : '',3F12.4)') (CP_NSCALE(L,1),L=1,3)
c          CALL MSGDOC(MD,STR)
c          WRITE(STR,'(''          '',3F12.4)') (CP_NSCALE(L,2),L=1,3)
c          CALL MSGDOC(MD,STR)
c          WRITE(STR,'(''          '',3F12.4)') (CP_NSCALE(L,3),L=1,3)
c          CALL MSGDOC(MD,STR)
c
c          CALL MTOANG(CP_NSCALE,ALPHA,BETA,GAMMA)
c          WRITE(STR,100) ALPHA,BETA,GAMMA
c          CALL MSGDOC(MD,STR)
c
c          ALPHA=ALPHA*PI/180.
c          BETA =BETA *PI/180.
c          GAMMA=GAMMA*PI/180.
c
c          CALL EULERM(ALPHA,BETA,GAMMA,AM)
c
c          WRITE(STR,'('' MATRIX : '',3F12.4)') (AM(L,1),L=1,3)
c          CALL MSGDOC(MD,STR)
c          WRITE(STR,'(''          '',3F12.4)') (AM(L,2),L=1,3)
c          CALL MSGDOC(MD,STR)
c          WRITE(STR,'(''          '',3F12.4)') (AM(L,3),L=1,3)
c          CALL MSGDOC(MD,STR)

          CALL SET_NCS(MDOC,NMAX,CP_NCS,CP_NSCALE,CP_NV,IERR)
 200      CONTINUE
        ENDIF
      ENDIF
      RETURN
      END

      SUBROUTINE RDSSBOND(MDOC,LINE,IERR)
      INTEGER*4 MDOC,IERR
      CHARACTER LINE*(*)
C ----------------------------------
      CHARACTER STR*80,CH1*1,CH2*1,CR1*5,CR2*5
      CHARACTER FRMT*80
      DATA FRMT/'(15X,A1,1X,A5,7X,A1,1X,A5)'/
C ------------------------------------
      READ(LINE,FRMT) CH1,CR1,CH2,CR2
C
      RETURN
      END

      SUBROUTINE RDCONECT(MDOC,LINE,IERR)
      INTEGER*4 MDOC,IERR
      CHARACTER LINE*(*)
      RETURN
      END


      SUBROUTINE RDANISO(LINE)
      CHARACTER LINE*(*)
C -----------------------------------------------
      COMMON/COM_PDB/ CP_CELL,CP_IA,CP_IRES,CP_ICH,CP_MODEL,CP_NAN
     *               ,CP_XYZ,CP_OCC,CP_BISO,CP_SCALE,CP_U,CP_ANIS
     *               ,CP_IGIVEN,CP_NCS,CP_PASS,CP_NSCALE,CP_NV
     *               ,CP_MOLECULE,CP_SURF,CP_SEG,CP_LINE
     *               ,CP_ANAME,CP_RNAME,CP_ASYMB,CP_ATYPE
     *               ,CP_PNUM,CP_CORR,CP_ALT,FLAG_CR,FLAG_SC
     *               ,CP_SPGR,FLAG_MT,CP_NAME,CP_DATE,CP_CODE
     *               ,CP_TITLE,CP_RESL,CP_RFAC,CP_BTYPE,CP_OXT
     *               ,CP_PNUM_OLD
      INTEGER   CP_IA,CP_IRES,CP_ICH,CP_MODEL,CP_NAN,CP_NCS,CP_PASS
      INTEGER   CP_IGIVEN
      REAL      CP_CELL(6),CP_XYZ(3),CP_OCC,CP_BISO,CP_SCALE(3,3)
      REAL      CP_U(3),CP_ANIS(6)
      REAL      CP_NSCALE(3,3),CP_NV(3)
      CHARACTER CP_PNUM*7,CP_ANAME*4,CP_RNAME*3,CP_ASYMB*4
      CHARACTER CP_ATYPE*4,CP_CORR*1,CP_ALT*1,FLAG_CR*1,FLAG_SC*1
      CHARACTER CP_SPGR*24,FLAG_MT*1,CP_NAME*40,CP_DATE*9,CP_CODE*4
      CHARACTER CP_TITLE*40,CP_RESL*36,CP_RFAC*36,CP_BTYPE*1,CP_OXT*1
      CHARACTER CP_PNUM_OLD*7
      INTEGER   CP_MOLECULE
      REAL      CP_SURF
      CHARACTER CP_SEG*4
      CHARACTER CP_LINE*80 
C --------------------------------------------------------------
C ******
C ------------------------------------------------------
      INTEGER*4 IANISO(6)
      CHARACTER FRMT*80
      DATA FRMT/'(28X,6I7)'/
C ------------------------------------

      READ(LINE,FRMT) (IANISO(I),I=1,6)

      DO I=1,6
        CP_ANIS(I) = IANISO(I)/10000.0
      ENDDO 

      CP_NAN    = 1
      CP_BTYPE  = 'A'

      RETURN
      END

      SUBROUTINE RDSIGAT(LINE)
      CHARACTER LINE*(*)
      RETURN
      END

      SUBROUTINE RDSIGUIJ(LINE)
      CHARACTER LINE*(*)
      RETURN
      END

      SUBROUTINE CHECK_ANAME(MON,ANAME)
C -----------------------------------------
C     CHECK_NAME - ATOM'S NAME
C 
C -----------------------------------------
      CHARACTER MON*3,ANAME*4
C ---
C --------------------------------
      IF(ANAME.EQ.'H0  ') THEN
        ANAME    = 'H   '
      ENDIF
      RETURN
      END     

      SUBROUTINE CP_CRD(MDOC,IOUT,IFIRST,FNAME,NAHOH,NHATOM,NA
     * ,ISYM,IPRSYM,IERR)
C -------------------------------------------------------
      INTEGER MDOC,IOUT,IERR,IFIRST
      CHARACTER FNAME*(*)
      INTEGER   IPRSYM
      INTEGER*2 ISYM(5,3,IPRSYM)
C -------------
C -----------------------------------------------
      COMMON/COM_PDB/ CP_CELL,CP_IA,CP_IRES,CP_ICH,CP_MODEL,CP_NAN
     *               ,CP_XYZ,CP_OCC,CP_BISO,CP_SCALE,CP_U,CP_ANIS
     *               ,CP_IGIVEN,CP_NCS,CP_PASS,CP_NSCALE,CP_NV
     *               ,CP_MOLECULE,CP_SURF,CP_SEG,CP_LINE
     *               ,CP_ANAME,CP_RNAME,CP_ASYMB,CP_ATYPE
     *               ,CP_PNUM,CP_CORR,CP_ALT,FLAG_CR,FLAG_SC
     *               ,CP_SPGR,FLAG_MT,CP_NAME,CP_DATE,CP_CODE
     *               ,CP_TITLE,CP_RESL,CP_RFAC,CP_BTYPE,CP_OXT
     *               ,CP_PNUM_OLD
      INTEGER   CP_IA,CP_IRES,CP_ICH,CP_MODEL,CP_NAN,CP_NCS,CP_PASS
      INTEGER   CP_IGIVEN
      REAL      CP_CELL(6),CP_XYZ(3),CP_OCC,CP_BISO,CP_SCALE(3,3)
      REAL      CP_U(3),CP_ANIS(6)
      REAL      CP_NSCALE(3,3),CP_NV(3)
      CHARACTER CP_PNUM*7,CP_ANAME*4,CP_RNAME*3,CP_ASYMB*4
      CHARACTER CP_ATYPE*4,CP_CORR*1,CP_ALT*1,FLAG_CR*1,FLAG_SC*1
      CHARACTER CP_SPGR*24,FLAG_MT*1,CP_NAME*40,CP_DATE*9,CP_CODE*4
      CHARACTER CP_TITLE*40,CP_RESL*36,CP_RFAC*36,CP_BTYPE*1,CP_OXT*1
      CHARACTER CP_PNUM_OLD*7
      INTEGER   CP_MOLECULE
      REAL      CP_SURF
      CHARACTER CP_SEG*4
      CHARACTER CP_LINE*80 
C --------------------------------------------------------------
      INCLUDE 'mr_crd_com.fh'
C -------------------------------------------------
      REAL      FRTOCR(3,3),CRTOFR(3,3),Y(3)
      CHARACTER CH4*4
      INTEGER   NOSPGR,ISETT,NSYM,NS
      CHARACTER SGNAME*24,SYMOP*26,LINE*80
      CHARACTER CHAR*1,TYPE*1,FNAME_OUT*256
C -------------------------
      PI    = 4.0*ATAN(1.0)
      PI180 = PI/180.0
      IERR  = 0
      M     = 99
      ISETT = 0
      IENDW = 0
      IF(IFIRST.EQ.0) THEN
        IF(FLAG_CR.NE.'Y') THEN
          IF(CP_PASS.LE.1) THEN
            CALL MSGERR(MDOC,
     *      ' INFO: card "CRYST1" is missing in PDB_file')
            CALL MSGERR(MDOC,
     *      '       default space group "P 1"')
            CALL MSGERR(MDOC,
     *      '       Default CELL: 100,100,100,90,90,90')
          ENDIF
          CP_CELL(1) = 100.0
          CP_CELL(2) = 100.0
          CP_CELL(3) = 100.0
          CP_CELL(4) = PI/2.0
          CP_CELL(5) = PI/2.0
          CP_CELL(6) = PI/2.0
          CP_SPGR    = 'P 1'
          LENS       = 3
          FLAG_SC    = 'N'          
        ENDIF

        IF(CP_CELL(1).LE.0.5.OR.CP_CELL(2).LE.0.5.OR.
     *     CP_CELL(3).LE.0.5.OR.CP_CELL(4).LE.0.001.OR.
     *     CP_CELL(5).LE.0.001.OR.CP_CELL(6).LE.0.001) THEN
          IF(CP_PASS.LE.1) THEN
            CALL MSGERR(MDOC,' WARNING: wrong CELL parameters')
            CALL MSGERR(MDOC,'          Default: 100,100,100,90,90,90')
          ENDIF
          CP_CELL(1) = 100.0
          CP_CELL(2) = 100.0
          CP_CELL(3) = 100.0
          CP_CELL(4) = PI/2.0
          CP_CELL(5) = PI/2.0
          CP_CELL(6) = PI/2.0
          FLAG_SC    = 'N'          
        ENDIF

        CALL LENSTR_BL(CP_SPGR,LENS)
        IF(LENS.LT.1.OR.LENS.GT.24) THEN
          IF(CP_PASS.LE.1) THEN
            CALL MSGERR(MDOC
     *      ,' WARNING: wrong card "CRYST1" of PDB_file..')
            CALL MSGERR(MDOC
     *      ,'          default space group "P 1"')
            CALL MSGERR(MDOC,
     *       '          default CELL: 100,100,100,90,90,90')
          ENDIF 
          CP_CELL(1) = 100.0
          CP_CELL(2) = 100.0
          CP_CELL(3) = 100.0
          CP_CELL(4) = PI/2.0
          CP_CELL(5) = PI/2.0
          CP_CELL(6) = PI/2.0
          CP_SPGR    = 'P 1'
          LENS       = 3
          FLAG_SC    = 'N'          
        ENDIF

        N = 0
        DO I=1,LENS
          IF(CP_SPGR(I:I).EQ.' ') N = N + 1
          IF(CP_SPGR(I:I).NE.' ') GO TO 600
        ENDDO

  600   CONTINUE

        IF(N.GT.0) THEN
          DO I=1,LENS-N
            CP_SPGR(I:I)=CP_SPGR(I+N:I+N)
          ENDDO
          DO I=1,N
            CP_SPGR(I+LENS-N:I+LENS-N)=' '
          ENDDO
        ENDIF

        IND=0
        DO I=1,LENS
          CHAR=CP_SPGR(I:I)
          CALL CHKSMB(CHAR,TYPE)
          IF(TYPE.NE.'B'.AND.TYPE.NE.'D') IND=1
        ENDDO

        IF(IND.EQ.0) THEN

          READ(CP_SPGR(1:LENS),*) NOSPGR

          IF(NOSPGR.GT.1000) THEN

            ISETT  = NOSPGR/1000
            NOSPGR = NOSPGR - ISETT*1000
            ISETT  = ISETT + 1
            NOSG   = NOSPGR

            IF(NOSG.EQ.3.OR.NOSG.EQ.4.OR.NOSG.EQ.146.OR.
     *         NOSG.EQ.155) THEN
              IF(ISETT.EQ.1) THEN
                ISETT = 2
              ELSE IF(ISETT.EQ.2) THEN  
                ISETT = 1
C              ELSE IF(ISTT.EQ.4) THEN  
C                ISTT = 3
              ENDIF
            ELSE IF(NOSG.EQ.  5) THEN
              IF(ISETT.EQ.1) THEN
                ISETT = 2
              ELSE IF(ISETT.EQ.2) THEN  
                ISETT = 1
C              ELSE IF(ISETT.EQ.3) THEN  
C                ISETT = 4
C              ELSE IF(ISETT.EQ.4) THEN  
C                ISETT = 3
              ENDIF
            ENDIF
          ENDIF

          IF(NOSPGR.LT.1.OR.NOSPGR.GT.230) THEN
            IF(CP_PASS.LE.1) THEN
              CALL MSGERR(MDOC
     *        ,' WARNING: wrong card "CRYST1" of PDB_file')
              CALL MSGERR(MDOC
     *        ,'          default space group: "P 1"')
            ENDIF
            NOSPGR = 1
          ENDIF
          IF(NOSPGR.EQ.146.OR.NOSPGR.EQ.155) THEN
            ISETT  = 1
            T= (PI*2.0)/3.0
            IF(ABS(CP_CELL(6)-T).LE.0.0001) ISETT=2
          ENDIF
          IF(NOSPGR.GE.3.AND.NOSPGR.LE.15) THEN
            IF(ISETT.LE.0) ISETT  = 2
            IF(ISETT.EQ.2) THEN
              T = PI/2.0
              IF(ABS(CP_CELL(6)-T).GT.0.0001) ISETT=1
            ELSE IF(ISETT.EQ.1) THEN
              T = PI/2.0
              IF(ABS(CP_CELL(5)-T).GT.0.0001) ISETT=2
            ENDIF
          ENDIF
          IF(ISETT.LE.0) ISETT  = 1
          NSYM   = 0
          SGNAME = ' '

        ELSE

          NOSPGR = 0
          ISETT  = 1
          NSYM   = 0
          SGNAME = CP_SPGR(1:LENS)
          IF((LENS.GE.3.AND.SGNAME(1:3).EQ.'R 3').OR.
     *       (LENS.GE.2.AND.SGNAME(1:2).EQ.'R3')) THEN
            T= (PI*2.0)/3.0
            IF(ABS(CP_CELL(6)-T).LE.0.0001) THEN
              ISETT       = 2
              SGNAME(1:1) = 'H'
            ENDIF
          ENDIF

C                sett 2     sett 1
C
C 3  P 2 P2      P 1 2 1   P 1 1 2
C 4  P21 P 21    P 1 21 1  P 1 1 21
C
C 5  B2  B 2               B 1 1 2
C 5  C2  C 2     C 1 2 1
C
C 
          IF(SGNAME.EQ.'P2' .OR.SGNAME.EQ.'P 2' .OR.
     *       SGNAME.EQ.'P21'.OR.SGNAME.EQ.'P 21'.OR.
     *       SGNAME.EQ.'B2' .OR.SGNAME.EQ.'B 2' .OR.
     *       SGNAME.EQ.'C2' .OR.SGNAME.EQ.'C 2'     ) THEN
            T  = PI/2.0
            ISETT = 2
            IF(ABS(CP_CELL(6)-T).GT.0.0001.AND.
     *       ABS(CP_CELL(5)-T).LE.0.0001     ) ISETT = 1
            IF(SGNAME.EQ.'P2'.OR.SGNAME.EQ.'P 2') THEN
              IF(ISETT.EQ.1) THEN
                SGNAME = 'P 1 1 2'
              ELSE
                SGNAME = 'P 1 2 1'
              ENDIF
            ELSE IF(SGNAME.EQ.'P21'.OR.SGNAME.EQ.'P 21') THEN
              IF(ISETT.EQ.1) THEN
                SGNAME = 'P 1 1 21'
              ELSE
                SGNAME = 'P 1 21 1'
              ENDIF
            ELSE IF(SGNAME.EQ.'B2'.OR.SGNAME.EQ.'B 2'.OR.
     *              SGNAME.EQ.'C2'.OR.SGNAME.EQ.'C 2'    ) THEN
              IF(ISETT.EQ.1) THEN
                SGNAME = 'B 1 1 2'
              ELSE
                SGNAME = 'C 1 2 1'
              ENDIF
            ENDIF
          ENDIF

        ENDIF

        CALL GET_SYMM(MDOC,NOSPGR,ISETT,SGNAME,NSYM,ISYM,IPRSYM,IERR)

        IF(IERR.GT.0) RETURN
        IF(IERR.LT.0) RETURN

        CP_SPGR = SGNAME
        DO I=1,6
          CR_CELL(I)=CP_CELL(I)
        ENDDO 


        CALL FRORTH(CR_CELL(1),CR_CELL(2),CR_CELL(3)
     *           ,CR_CELL(4),CR_CELL(5),CR_CELL(6)
     *                         ,FRTOCR,CRTOFR,IERR)

        IF(FLAG_SC.EQ.'Y') THEN
          DO I=1,3
            DO J=1,3
              CR_SCALE(I,J)=CP_SCALE(I,J)
            ENDDO
            CR_U(I)=CP_U(I)
          ENDDO
        ELSE
          DO I=1,3
            DO J=1,3
              CR_SCALE(I,J)=CRTOFR(I,J)
            ENDDO
          ENDDO
        ENDIF

        DO I=1,3
          DO J=1,3
            CR_ORT_TO_FRAC(I,J)=CRTOFR(I,J)
            CR_FRAC_TO_ORT(I,J)=FRTOCR(I,J)
          ENDDO
        ENDDO

C        CR_ORT_TO_FRAC(3,3)
C        CR_FRAC_TO_ORT(3,3)
C        CR_M_NCS(3,3)
C        CR_V_NCS(3)
C        CR_NCS

        CR_NSPGR    =NOSPGR
        CR_SETT     =ISETT
        CR_MULT_FLAG=0
        CR_MODEL    =CP_MODEL
        CR_CD_PDB   =CP_CODE
        CR_NAME_PDB =CP_CODE//CP_CODE//'    '//CP_NAME(1:28)
        CR_DATE_PDB =CP_DATE
        CR_TITLE    ='?   ?   '//CP_TITLE
        CR_RESL_PDB =CP_RESL
        CR_RFAC_PDB =CP_RFAC
        CR_SPGR     =SGNAME

        CALL C_AT_CR

        MD=-ABS(MDOC)-1
        IF(CP_PASS.EQ.2) THEN
          FNAME_OUT = FNAME
C         CALL REMOVE_PATH(FNAME_OUT)
          CALL LENSTR_BL(FNAME_OUT,LEN)
          IF(LEN.LE.0) THEN
            LINE = 'ERROR: readPDB: cannot open output file '
            IERR =1
            CALL MSGERR(MDOC,LINE)
            RETURN
          ENDIF
          IOUT = 11 
          CALL OWCRD(MD,IOUT,FNAME_OUT,NSYM,ISYM,IPRSYM,IERR)
          IF(IERR.NE.0) THEN
            CALL MSGERR(MDOC,
     *      ' ERROR: readPDB: cannot open output file')
            CLOSE(IOUT) 
            RETURN
          ENDIF
          FNAME = FNAME_OUT        
        ENDIF
        IENDW=-1
        IFIRST=1
      ENDIF

      IF(CP_PASS.EQ.2) THEN
        IF(CP_MOLECULE.GT.0) THEN
          MODE = 1
          CR_LINE2 = ' '
          CR_LINE = CP_LINE
          CALL WRCRD(M,IOUT,MODE,IENDW,IERR)
          CP_MOLECULE = 0
        ENDIF
        IF(CP_MODEL.GT.0) THEN
          MODE = 1
          CR_LINE2 = ' '
          WRITE(CR_LINE,'(A,I4)') '#MODEL ',CP_MODEL
          CALL WRCRD(M,IOUT,MODE,IENDW,IERR)
          CP_MODEL = 0
        ENDIF
      ENDIF

      MODE = 0
      IF(CP_NAN.EQ.1) CR_FLAG_USER='A'
      CR_PNUM  = CP_PNUM
      CR_IATOM = CP_IA
      CR_IRES  = CP_IRES
      CR_IATOLD= NA
      CR_IGROUP= CP_ICH
      WRITE(CH4,'(I4)') CP_ICH
      CR_CHAIN = CP_PNUM(1:2)
      CR_GROUP = CR_CHAIN//'  '
      CR_ALT   = CP_ALT
      CR_CORR  = '.'
      CR_ATYPE = '.'

      CALL MVMULT(CR_SCALE,CP_XYZ,Y)
      Y(1)=Y(1)+CR_U(1)
      Y(2)=Y(2)+CR_U(2)
      Y(3)=Y(3)+CR_U(3)
      CALL MVMULT(CR_FRAC_TO_ORT,Y,CP_XYZ)


      CR_XYZ(1)= CP_XYZ(1)
      CR_XYZ(2)= CP_XYZ(2)
      CR_XYZ(3)= CP_XYZ(3)
      CR_OCC   = CP_OCC
      CR_BISO  = CP_BISO
      IF(CR_BISO.LT.2.0) THEN
        CP_BTYPE = 'I'       
        CR_BISO  = 2.0
      ENDIF
      CR_ANAME = CP_ANAME
      CR_RNAME = CP_RNAME
      CR_ASYMB = CP_ASYMB
      CR_SURF  = CP_SURF
      CALL LENSTR_BL(CP_SEG,LG)
      IF(LG.LE.0) CP_SEG = '.'
      CR_SEG = CP_SEG
      IF(CP_ASYMB.EQ.'H   '.OR.CP_ASYMB.EQ.'D   ') NHATOM=NHATOM+1

      CR_BTYPE = CP_BTYPE 
      DO IAN=1,6
        CR_ANIS(IAN) = 0.0
      ENDDO
      IF(CP_BTYPE.EQ.'A') THEN
        DO IAN=1,6
          CR_ANIS(IAN) = CP_ANIS(IAN)
        ENDDO
      ENDIF
      CR_MULT_FACTOR =  1
C     IF(CR_ANAME.EQ.'O   '.AND.CR_RNAME.EQ.'HOH') NAHOH=NAHOH+1
      IF(CR_RNAME.EQ.'HOH'.OR.CR_RNAME.EQ.'DOD') THEN
        CR_ANAME='O   '
        NAHOH=NAHOH+1
      ENDIF
      IF(CP_PASS.EQ.2) THEN
        CALL WRCRD(M,IOUT,MODE,IENDW,IERR)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MDOC,' ERR: writePDB: WRITE OUTPUT_FILE')
          CLOSE(IOUT) 
          RETURN
        ENDIF
      ENDIF
      RETURN
      END

      SUBROUTINE RFCOEF_100(MDOC
     * ,NAMEF,NAMEO,INVER,BOFF,BADD,LINDEX
     * ,LMINR,NSYMZ
     * ,RESMIN,RESMXFR,RESLIM,ARAD
     * ,SH,ISYM,IPRSYM,IERR)
C ----------------------------------
      PARAMETER ( IPRBES = 600                 )
      PARAMETER ( IPRLMX = 100                 )
      PARAMETER ( IPRNMX = IPRLMX/2            )
      PARAMETER ( IPRLM1 = IPRLMX+1            )
      PARAMETER ( IPRLM2 = IPRLMX+2            )
      PARAMETER ( IPRL21 = 2*IPRLMX+1          )
      PARAMETER ( IPRNIN = 50                  )
C ---------
c      REAL      RPARAM_RCOEF(6)
      REAL      RESMIN,RESMXFR,RESMXF,ARAD,BOFF,BADD

      INTEGER   MDOC,IERR,NSYMZ,LINDEX
      CHARACTER NAMEF*(*),NAMEO*(*)
      CHARACTER INVER*1
C ---------
      INCLUDE 'molrep_lh_infor.fh'
c      COMMON/COM_LH_INFOR/ BOFF_LH,BADD_LH,BOFF_FOR_SCAL
c     *   ,CHECK_CONTRAST,CONTRAST_LIM
c     *   ,BCORR_LH,FILE_FOBS_LH,SCORE_FLAG,LH_LH,DB_LH
cC ---
c      REAL      CHECK_CONTRAST,CONTRAST_LIM
c      REAL      BOFF_FOR_SCAL,BOFF_LH,BADD_LH,BCORR_LH
c      CHARACTER LH_LH*1,SCORE_FLAG*1,DB_LH*1
c      CHARACTER FILE_FOBS_LH*256
C ----------------------------------
      REAL      RLATT(6),SH(3)
      INTEGER*2 ISYM(5,3,IPRSYM)

      PARAMETER ( IPRSM2 = 192 )
      INTEGER   IH(IPRSM2),IK(IPRSM2),IL(IPRSM2)
      REAL      FA(IPRSM2),FB(IPRSM2)


C      REAL      F2BES(IPRMEM),COTTH(IPRMEM),PHI(IPRMEM)
C      REAL      A(IPRMEM),RHSQ(IPRMEM),SINTH(IPRMEM)
C      REAL      B(IPRMEM)
C      REAL      PLM1(IPRMEM),PLM2(IPRMEM)

      real,      allocatable :: F2BES(:)
      real,      allocatable :: RHSQ(:)
      real,      allocatable :: SINTH(:)
      real,      allocatable :: COTTH(:)
      real,      allocatable :: PHI(:)
      real,      allocatable :: PLM1(:)
      real,      allocatable :: PLM2(:)
      real,      allocatable :: A(:)
      real,      allocatable :: B(:)
      real,      allocatable :: FAC4(:,:)

c      REAL      ALM(IPRALM),BLM(IPRALM)

      real,      allocatable :: ALM(:)
      real,      allocatable :: BLM(:)

      CHARACTER ITP*4,TYPE*4,LINE*80,TITLE*80,FOUR*1
C ------------------------------------------------------------------------
      INTEGER   NMAX  (IPRLM1),NBIN(50)
      REAL      FACT  (IPRL21)
      REAL      SBES  (IPRLM2,IPRBES)
      REAL      BZEROS(IPRNMX,IPRLM2)
      CHARACTER PATH*80,EXT*3

      INTEGER  IHR(7)
C ========================================================================
C     fobs_flag
      IFOBS_FLAG = 0
      IF(IERR.EQ.1) THEN
        IFOBS_FLAG = 1
      ENDIF
      IERR = 0
      MD    =-ABS(MDOC)-1
C ----
      IF(INVER.EQ.'y') INVER='Y'
      IF(INVER.EQ.'p') INVER='P'
      IF(INVER.NE.'Y'.AND.INVER.NE.'P') INVER='N'
C -
c      RESMIN  = RPARAM_RCOEF(1) 
c      RESMXFR = RPARAM_RCOEF(2) 
c      ARAD    = RPARAM_RCOEF(3) 
c      BOFF    = RPARAM_RCOEF(4) 
c      BADD    = RPARAM_RCOEF(5) 
c      RESLIM  = RPARAM_RCOEF(6) 
C -
      RESMXF = RESMXFR
C -------------------------------------
C
C     OPEN FILE :  F-MOD
C
      MT    = 10
      ITP   = '    '
      MD    =-ABS(MDOC)-1
      CALL ORFILE(MD,MT,NAMEF,ITP,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MD,' ERROR: in RFCOEF: OPEN FILE-IN')
        RETURN
      ENDIF
      IF(ITP.NE.'F   '.AND.ITP.NE.'FS  '.AND.ITP.NE.'COEF') THEN
        CALL MSGERR(MD,' ERROR: in RFCOEF: WRONG TYPE')
        CLOSE(MT)
        IERR=1
        RETURN
      ENDIF
      CALL GET_TITLE(MD,RLATT(1),RLATT(2),
     . RLATT(3),RLATT(4),RLATT(5),RLATT(6),F1,F2,RN,RX,IDM,IDM
     . ,IDM,IDM,IDM,TITLE,IERR)
      CALL C_RD_CR
      FOUR = 'N'
      IF(ITP.EQ.'COEF') THEN
        IF(TITLE(1:4).EQ.'PATT') THEN
          FOUR = 'P'
        ELSE
          FOUR = 'F'
        ENDIF
      ENDIF
C -----------------------------------------------------
C
C     RESOLUTION LIMITS
C
      IF(RESMIN.LE.0.0) RESMIN = RN
      IF(RESMXF.LE.0.0) RESMXF = RX
      IF(RESMIN.GT.RN)  RESMIN=RN
      IF(RESMIN.EQ.RESMXF) THEN
        CALL MSGERR(MDOC,' ERROR: in RFCOEF: RESMIN = RESMAX')
        IERR=1
        CLOSE(MT)
        RETURN
      ENDIF

C -----------------------------------------------------
C
C     RADIUS OF CUT-OFF SPHERE FOR PATTERSON
C
      IF(ARAD.LE.0.00001) ARAD=30.0
C -----------------------------------------------------
C
C  CALC REPROC-CELL: ASTAR,BSTAR,CSTAR,
C                    COS(ALPHA-STAR),COS(BETA-STAR),COS(GAMMA-STAR)
C
      CALL DSTARF(RLATT,AST,BST,CST,COALST,COBEST,COGAST,VOL)
C ----------------------------------------
      PI    = 4.0*ATAN(1.0)
      PIBY2 = PI/2.
      TWOPI = PI*2.
      PI180 = PI/180.
      SCALE = 3.0/(4.0*PI*ARAD*ARAD*ARAD)
C ------------------------------------------------
      LMAXP = 100
      NMAXP = 50
C --------------------------------------------------------------
       CALL GET_BZEROS_100(BZEROS,NMAXP,LMAXP,IERR)
C ----
C      REAL    BZ(30,*)
C      1 =<NMAXP=<30, 0=<LMAXP=<60
C ----
       IF(IERR.NE.0) THEN
         CALL MSGERR(MDOC,
     *' ERROR: rfcoef: wrong index Lmax or Nmax')
         RETURN
       ENDIF
C ------------------------------------------
      RESMAX_LIM  = (ARAD*TWOPI)/109.35

      WRITE(LINE,*) ' resmax_lim,lindex:',RESMAX_LIM,lindex
      CALL MSGDOC(MDOC,LINE)

      IF(LINDEX.GT.0.AND.LINDEX.LE.100) THEN
        L = LINDEX
        RMAX   = BZEROS(1,L+2) + 0.00001
        RESMAX = (ARAD*TWOPI)/RMAX
      ELSE
        RESMAX = RESMXF
        L      = 20
        RMAX   = BZEROS(1,L+2) + 0.00001
        RESMAX = (ARAD*TWOPI)/RMAX
        IF(RESMAX.GT.RESMXF) THEN
          RESMAX = RESMXF
        ENDIF
      ENDIF
      IF(RESMAX.LT.RESMAX_LIM) RESMAX = RESMAX_LIM
C -------
      RMAX = ARAD*TWOPI/RESMAX
      IF(RESMAX.GT.RESMXF) THEN
        RESMXF = RESMAX
      ENDIF
      RESLIM = RESMXF
      RHMAX  = 1.0/RESMXF
      RHMIN  = 1.0/RESMIN
C ----------------------------------------------------------
C     WRITE INPUT INFORMATION
C
      IF(ABS(COALST).GE.1.E-5) THEN
        T = SQRT(ABS(1.-COALST*COALST))/COALST
        T = ATAN(T)
      ELSE
        T = PIBY2
      ENDIF
      TAS = ABS(T)
      IF(ABS(COBEST).GE.1.E-5) THEN
        T = SQRT(ABS(1.-COBEST*COBEST))/COBEST
        T = ATAN(T)
      ELSE
        T = PIBY2
      ENDIF
      TBS = ABS(T)
      IF(ABS(COGAST).GE.1.E-5) THEN
        T = SQRT(ABS(1.-COGAST*COGAST))/COGAST
        T = ATAN(T)
      ELSE
        T = PIBY2
      ENDIF
      TCS = ABS(T)
C ----
      TTAS = TAS/PI180
      TTBS = TBS/PI180
      TTCS = TCS/PI180
      WRITE(LINE,2006) ARAD
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,2007) RESMIN,RESMXF
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,'(''BOFF,BADD :'',2F8.2)') BOFF,BADD
      CALL MSGDOC(MDOC,LINE)
      IF(LH_LH.NE.'N') THEN
        WRITE(LINE,'(''LH,IFOBS :'',A,I5)') LH_LH,IFOBS_FLAG
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,'(''BOFF_LH,BADD_LH :'',2F8.2)') BOFF_LH,BADD_LH
      ENDIF
      CALL MSGDOC(MDOC,LINE)
      IF(FOUR.EQ.'F') THEN
        WRITE(LINE,'(''Shift :'',3F8.4)') (SH(I),I=1,3)
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,'(''INVER :'',A)') INVER
        CALL MSGDOC(MDOC,LINE)
      ENDIF

      WRITE(LINE,2008) AST,BST,CST
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,2009) TTAS,TTBS,TTCS
      CALL MSGDOC(MDOC,LINE)

 2006 FORMAT('RADIUS OF CUT-OFF SPHERE ',F5.1,' ANGSTROMS')
 2007 FORMAT('DATA INCLUDED BETWEEN',F7.1,' AND ',F7.1,'( ANGSTROMS)')
 2008 FORMAT('ASTAR=',F8.5,' BSTAR=',F8.5,' CSTAR=',F8.5)
 2009 FORMAT('ALPHASTAR=',F8.4,' BETASTAR=',F8.4,' GAMMASTAR=',F8.4
     *      ,' (GRAD)')
 2010 FORMAT('FMOD OBOVE ',F8.1,' INCLUDED')
C --------------------------------------------------------------
      LMAX = 0
      IF(BZEROS(1,2).GT.RMAX) THEN
        WRITE(LINE,*) ' ERROR: in RFCOEF:  RMAX ',RMAX
        CALL MSGDOC(MDOC,LINE)
        CLOSE(MT)
        IERR=1
        RETURN
      ENDIF
      DO     L=2,LMAXP+2
        IF(BZEROS(1,L).GT.RMAX) GO TO 50
        LMAX=L-2
        DO     N=1,NMAXP
          IF(BZEROS(N,L).GT.RMAX) GO TO 60
          NMAX(L-1)=N
        ENDDO
   60   CONTINUE
      ENDDO
   50 LMAX = (LMAX/2)*2
      WRITE(LINE,2015) LMAX
      CALL MSGDOC(MDOC,LINE)
 2015 FORMAT(5X,' MAXIMUM L ORDER = ',I5)
      LMAX2 = LMAX+2
      LMAX1 = LMAX+1
C ---------------------------------------------
      LINDEX = LMAX
C ---------------------------------------------
      DO     L=2,LMAX2
        NN=NMAX(L-1)
        IF(L.EQ.2) THEN
          WRITE(LINE,*) ' NMAX ( for L=2 ):',NN
          CALL MSGDOC(MDOC,LINE)
        ENDIF
        DO     N=1,NN
          BZEROS(N,L)=BZEROS(N,L)/ARAD
        ENDDO
      ENDDO
C --------------------------------------------------------------------
      WRITE(LINE,'(''Nsym :'',I5)') NSYM
      CALL MSGDOC(MDOC,LINE)
      IF(FOUR.EQ.'F') THEN
         NSYMZ = 1
      ELSE
        IF(NSYMZ.LE.0) CALL GET_NSYMZ(NSYM,ISYM,NSYMZ)
        WRITE(LINE,'(''Symmetry axis Z in Patterson:'',I5)') NSYMZ
        CALL MSGDOC(MDOC,LINE)
      ENDIF
C ----------------------------------------------
      LSTP = 2
      IF(FOUR.EQ.'F'.AND.INVER.NE.'P') LSTP = 1
C ----------------------------------------------
      LINE = '                                                  '
      LINE(9:15) = ' L-MAX='
      WRITE(LINE(16:20),'(I3,I2)') LMAXP,LMAX
      LINE(1:4)='ALMN'
      IF(LSTP.EQ.2) THEN
        LINE(5:8) = ' PT '
      ELSE
        LINE(5:8) = ' FR '
      ENDIF
C -------
      MTOUT = 12
      IF(FOUR.EQ.'F'.AND.INVER.NE.'P') THEN
        TYPE  = 'ALMN'
      ELSE
        TYPE  = 'ALMS'
      ENDIF
      TYPE  = 'ALMN'
      SCAL  = ARAD
      BTEMP = NSYMZ
      MD    =-ABS(MDOC)-1
      CALL C_CR_WR
      CALL SET_TITLE(MD,RLATT(1),RLATT(2)
     . ,RLATT(3),RLATT(4),RLATT(5),RLATT(6),SCAL,BTEMP,RESMIN,RESMXF
     . ,IDM,IDM,IDM,IDM,IDM,LINE,IERR)

      CALL OWFILE(MD,MTOUT,NAMEO,TYPE,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERROR: OPEN OUTPUT_FILE /rfcoef/')
        CLOSE(MT)
        RETURN
      ENDIF
      NUMB3    = 0
      IEND3    =-1
      ALMN_MAX = 0.0
      BLMN_MAX = 0.0
C -----------------------------------------------
      A2PI    = TWOPI*ARAD
      A8PI    = 4.0*A2PI
      A42PI   = 2.0*SQRT(2.0*ARAD)*TWOPI
      FACT(1) = 0.0
      DO     I=1,IPRL21-1
        FACT(I+1) = FACT(I)+ALOG(FLOAT(I))
      ENDDO
C ------------------
      ARGMAX = RMAX+1.
      CALL SPHBES_RF(MDOC,LMAX,ARGMAX,SBES,IPRLM2,IPRBES,IERR)
      IF(IERR.GT.0) THEN
        CALL MSGERR(MDOC,' ERROR: in RFCOEF: SPHBES_RF')
        CLOSE(MT)
        CLOSE(MTOUT)
        IERR=1
        RETURN
      ENDIF
C ------------------
c      BETAST=TCS
c      CBETA =COS(BETAST)
c      SBETA =SIN(BETAST)

      LMAX1  = LMAX+1
      IND0   = 0
      NN_MAX = 0
      DO  LK=1,LMAX1,LSTP
        L    = LK-1
        MMAX = LK
        NN   = NMAX(LK)
        IF(NN.GT.NN_MAX) NN_MAX = NN
        DO  MM=1,MMAX
          M = MMAX-MM
          IF(MOD(M,NSYMZ).EQ.0) THEN
            IND0 = IND0+NN
          ENDIF
        ENDDO
      ENDDO

c      WRITE(*,'('' INDEX-MAX ='',I6)') IND0
c      WRITE(*,*) '--',NN_MAX
 
C
C      X --- A
C      Z --- C STAR
C
        SIALST = SIN(ACOS(COALST))
        SIBEST = SIN(ACOS(COBEST))
        SIGAST = SIN(ACOS(COGAST))

        TB11 = AST*SIGAST*SIBEST
        TB12 = AST*COGAST*SIBEST
        TB13 = AST*       COBEST
        TB22 = BST*SIALST
        TB23 = BST*COALST
        TB33 = CST
C ====================================
      FMIN = 1.0E30
      FMAX =-1.0E30
      DO K=1,50
        NBIN(K) = 0
      ENDDO
      NFOBS_INPUT  = 0
      NFOBS        = 0
      J    = 0
      IEND =-1
      NBL  = 0
C ----

C     check memory for fobs
  110 CONTINUE

      IF(IEND.GT.0) GO TO 120
      IF(ITP.EQ.'FS  ') THEN
        CALL RRD1(MT,IH(1),IK(1),IL(1),FA(1),FB(1),SDA,SDB
     *           ,NBL,IEND)
        IF(FA(1).LE.1.E-6.AND.FB(1).LE.1.E-6) GO TO 110
      ELSE
        CALL RD1(MT,IH(1),IK(1),IL(1),FA(1),FB(1),NBL,IEND)
      ENDIF
      IF(MT.LE.0) THEN
        CALL MSGERR(MDOC,' ERROR: in RFCOEF: read input file')
        CLOSE(MTOUT)
        IERR=1
        RETURN
      ENDIF
C -------------------------------------
      IF(IEND.GT.0) GO TO 120
      NFOBS_INPUT  = NFOBS_INPUT + 1

      CALL GENER_RF(ITP,FOUR,INF,IH,IK,IL,FA,FB,SH
     *                 ,NSYM,ISYM,IPRSYM)

      DO  I=1,INF
        TH = IH(I)
        TK = IK(I)
        TL = IL(I)
        IF(IL(I).LT.0) GO TO 130
        XX = TH*TB11
        YY = TH*TB12+TK*TB22
        ZZ = TH*TB13+TK*TB23+TL*TB33
        F2  = FA(I)
        F2B = FB(I)
        RSQ = XX*XX+YY*YY+ZZ*ZZ
        RH  = SQRT(RSQ)
        IF(RH.GT.RHMAX) GO TO 130
        IF(RH.LT.RHMIN) GO TO 130
        IF(RH.LT.1.E-7) GO TO 130

        IF(BOFF.GT.0.0) THEN
          BT    = BOFF/4.0
          CBOFF = 1.0-EXP(-BT*RSQ)
        ELSE
          CBOFF = 1.0
        ENDIF
        IF(ABS(BADD).GT.0.01) THEN
          BT    = BADD/4.0
          CBADD = EXP(-BT*RSQ)
        ELSE
          CBADD = 1.0
        ENDIF

        CBADDBOFF = CBADD*CBOFF

        IF(LH_LH.EQ.'Y'.OR.LH_LH.EQ.'T') THEN
          CBADDBOFF = 1.0
          IF(IFOBS_FLAG.EQ.1) THEN
            CBADDBOFF = 1.0
          ELSE
            IF(BOFF_LH.GT.0.0) THEN
              BT    = BOFF_LH/4.0
              CBOFF = 1.0-EXP(-BT*RSQ)
            ELSE
              CBOFF = 1.0
            ENDIF
            R2 =(RHMAX - RH)*(RHMAX - RH)
            IF(ABS(BCORR_LH).GT.0.00001) THEN
              BT=BCORR_LH/4.0
              CBADD=1.0 - EXP(-BT*R2)
            ELSE
              CBADD=1.0
            ENDIF
            CBADDBOFF = CBADD*CBOFF
            IF(LH_LH.EQ.'Y') CBADDBOFF = 1.0
          ENDIF
        ELSE IF(LH_LH.EQ.'V'.OR.LH_LH.EQ.'2') THEN
          IF(IFOBS_FLAG.EQ.1) THEN
            CBADDBOFF = 1.0
          ELSE
            IF(BOFF_LH.GT.0.0) THEN
              BT    = BOFF_LH/4.0
              CBOFF = 1.0-EXP(-BT*RSQ)
            ELSE
              CBOFF = 1.0
            ENDIF
            IF(ABS(BADD_LH).GT.0.01) THEN
              BT    = BADD_LH/4.0
              CBADD = EXP(-BT*RSQ)
            ELSE
              CBADD = 1.0
            ENDIF
            CBADDBOFF = CBADD*CBOFF
            IF(LH_LH.EQ.'V') CBADDBOFF = 1.0
          ENDIF
        ENDIF

        IF(ITP.EQ.'COEF') THEN
          F2  = F2 *CBADDBOFF
          F2B = F2B*CBADDBOFF
        ELSE
          F2  = F2*CBADDBOFF*CBADDBOFF
          F2B = SDA*CBADDBOFF*CBADDBOFF
        ENDIF

        IF(RH.LT.1.E-7) GO TO 130
        IF(ITP.NE.'COEF') THEN
          FM = SQRT(ABS(F2))
        ELSE
          IF(FOUR.EQ.'F') THEN
            FM = SQRT(F2*F2 + F2B*F2B)
          ELSE
            FM = SQRT(F2)
          ENDIF
        ENDIF
        IF(FM.GT.FMAX) FMAX = FM
        IF(FM.LT.FMIN) FMIN = FM
        J  = J + 1
  130   CONTINUE
      ENDDO
C ---
      GO TO 110
  120 CONTINUE
      IF(MT.GT.0) CLOSE(MT)
      NFOBS = J    
      WRITE(LINE,'('' N_refls(input):'',I8)') NFOBS_INPUT
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,'('' N_refls(gener):'',I8)') NFOBS
      CALL MSGDOC(MDOC,LINE)
      IF(NFOBS.LE.0) THEN
        CALL MSGERR(MDOC,'ERROR: in RFCOEF: Nfobs = 0.')
        CLOSE(MTOUT)
        IERR = 1
        RETURN
      ENDIF
C ---
      IF(FMAX.GT.0.0001) THEN
C ---
        MT    = 10
        ITP   = '    '
        MD    =-ABS(MDOC)-1
        CALL ORFILE(MD,MT,NAMEF,ITP,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MD,' ERROR: in RFCOEF: OPEN FILE-IN')
          CLOSE(MTOUT)
          RETURN
        ENDIF
C ----------
        DFB = (FMAX*0.5)/50.0
        J = 0
        IEND =-1
        NBL  = 0
  310   CONTINUE

        IF(IEND.GT.0) GO TO 320
        IF(ITP.EQ.'FS  ') THEN
          CALL RRD1(MT,IH(1),IK(1),IL(1),FA(1),FB(1),SDA,SDB
     *             ,NBL,IEND)
          IF(FA(1).LE.1.E-6.AND.FB(1).LE.1.E-6) GO TO 310
        ELSE
          CALL RD1(MT,IH(1),IK(1),IL(1),FA(1),FB(1),NBL,IEND)
        ENDIF
        IF(MT.LE.0) THEN
          CALL MSGERR(MDOC,' ERROR: in RFCOEF: read input file')
          CLOSE(MTOUT)
          IERR=1
          RETURN
        ENDIF
C -------------------------------------
        IF(IEND.GT.0) GO TO 320

        CALL GENER_RF(ITP,FOUR,INF,IH,IK,IL,FA,FB,SH
     *                 ,NSYM,ISYM,IPRSYM)

        DO  I=1,INF
          TH = IH(I)
          TK = IK(I)
          TL = IL(I)
          IF(IL(I).LT.0) GO TO 330
          XX = TH*TB11
          YY = TH*TB12+TK*TB22
          ZZ = TH*TB13+TK*TB23+TL*TB33
          F2  = FA(I)
          F2B = FB(I)
          RSQ = XX*XX+YY*YY+ZZ*ZZ
          RH  = SQRT(RSQ)
          IF(RH.GT.RHMAX) GO TO 330
          IF(RH.LT.RHMIN) GO TO 330
          IF(RH.LT.1.E-7) GO TO 330

          IF(BOFF.GT.0.0) THEN
            BT    = BOFF/4.0
            CBOFF = 1.0-EXP(-BT*RSQ)
          ELSE
            CBOFF = 1.0
          ENDIF
          IF(ABS(BADD).GT.0.01) THEN
            BT    = BADD/4.0
            CBADD = EXP(-BT*RSQ)
          ELSE
            CBADD = 1.0
          ENDIF

          CBADDBOFF = CBADD*CBOFF

          IF(LH_LH.EQ.'Y'.OR.LH_LH.EQ.'T') THEN
            CBADDBOFF = 1.0
            IF(IFOBS_FLAG.EQ.1) THEN
              CBADDBOFF = 1.0
            ELSE
              IF(BOFF_LH.GT.0.0) THEN
                BT    = BOFF_LH/4.0
                CBOFF = 1.0-EXP(-BT*RSQ)
              ELSE
                CBOFF = 1.0
              ENDIF
              R2 =(RHMAX - RH)*(RHMAX - RH)
              IF(ABS(BCORR_LH).GT.0.00001) THEN
                BT=BCORR_LH/4.0
                CBADD=1.0 - EXP(-BT*R2)
              ELSE
                CBADD=1.0
              ENDIF
              CBADDBOFF = CBADD*CBOFF
              IF(LH_LH.EQ.'Y') CBADDBOFF = 1.0
            ENDIF
          ELSE IF(LH_LH.EQ.'V'.OR.LH_LH.EQ.'2') THEN
            IF(IFOBS_FLAG.EQ.1) THEN
              CBADDBOFF = 1.0
            ELSE
              IF(BOFF_LH.GT.0.0) THEN
                BT    = BOFF_LH/4.0
                CBOFF = 1.0-EXP(-BT*RSQ)
              ELSE
                CBOFF = 1.0
              ENDIF
              IF(ABS(BADD_LH).GT.0.01) THEN
                BT    = BADD_LH/4.0
                CBADD = EXP(-BT*RSQ)
              ELSE
                CBADD = 1.0
              ENDIF
              CBADDBOFF = CBADD*CBOFF
              IF(LH_LH.EQ.'V') CBADDBOFF = 1.0
            ENDIF
          ENDIF

          IF(ITP.EQ.'COEF') THEN
            F2  = F2 *CBADDBOFF
            F2B = F2B*CBADDBOFF
          ELSE
            F2  = F2*CBADDBOFF*CBADDBOFF
            F2B = SDA*CBADDBOFF*CBADDBOFF
          ENDIF

          IF(RH.LT.1.E-7) GO TO 330
          IF(ITP.NE.'COEF') THEN
            FM = SQRT(ABS(F2))
          ELSE
            IF(FOUR.EQ.'F') THEN
              FM = SQRT(F2*F2 + F2B*F2B)
            ELSE
              FM = SQRT(F2)
            ENDIF
          ENDIF

          J = J + 1           

          IFM = FM/DFB
          IF(IFM.LT.0) IFM = 0
          IF(IFM.GT.49) IFM = 49
          IFM = IFM + 1
          NBIN(IFM) = NBIN(IFM) + 1

  330    CONTINUE
        ENDDO

      GO TO 310
  320 CONTINUE
      IF(MT.GT.0) CLOSE(MT)

        T = (NFOBS*0.5)/500000.0
        IF(T.GT.1.0) T = 1.0 
        NLIM = NFOBS*T*0.5 
        NSUM = 0.0
        DO K=1,50
          NSUM = NSUM + NBIN(K)
          IF(NSUM.GT.NLIM) THEN
            IF(K.GT.1) THEN
              FMIN = DFB*(K-1)
            ENDIF
            GO TO 400
          ENDIF
        ENDDO
 400    CONTINUE
        WRITE(LINE,'('' N,FMAX,FMIN:'',I10,2G16.4)') NFOBS,FMAX,FMIN
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,'('' NLIM:'',I10,F10.3)') NLIM,T
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,'(10I7)') (NBIN(K),K=1,10)         
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,'(10I7)') (NBIN(K),K=11,20)         
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,'(10I7)') (NBIN(K),K=21,30)         
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,'(10I7)') (NBIN(K),K=31,40)         
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,'(10I7)') (NBIN(K),K=41,50)         
        CALL MSGDOC(MDOC,LINE)
      ENDIF
C ---
      MT    = 10
      ITP   = '    '
      MD    =-ABS(MDOC)-1
      CALL ORFILE(MD,MT,NAMEF,ITP,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MD,' ERROR: in RFCOEF: OPEN FILE-IN')
        CLOSE(MTOUT)
        RETURN
      ENDIF
C ----------
c allocation
      NFOBS_MAX = NFOBS + 1000
      IT = 0
      allocate(F2BES(1:NFOBS_MAX),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(RHSQ(1:NFOBS_MAX),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(SINTH(1:NFOBS_MAX),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(COTTH(1:NFOBS_MAX),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(PHI(1:NFOBS_MAX),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(PLM1(1:NFOBS_MAX),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(PLM2(1:NFOBS_MAX),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(A(1:NFOBS_MAX),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(B(1:NFOBS_MAX),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      NNN_MAX = NN_MAX + 100
      allocate(FAC4(1:NNN_MAX,1:NFOBS_MAX),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      IF(IT.NE.0) THEN
        IERR = 1
        CALL MSGERR(MDOC,
     *    ' ERROR: in RFCOEF : problem with memory allocation')
        CALL MSGERR(MDOC,
     *    '                    try to change resolution')
        CLOSE(MTOUT)
        RETURN
      ENDIF
C ========================================
      IPRNT=2000
      IF(IPRNT.NE.0) THEN
        WRITE(LINE,1018)
        CALL MSGDOC(MDOC,LINE)
 1018   FORMAT('    N',4X,'H',4X,'K',4X,'L',8X,
     *  'SINTH',4X,'COTTH',6X,'PHI',7X,'   !F!')
      ENDIF
      N_FBIG = 0
      IEND   =-1
      NBL    = 0
      J      = 0
C ----
  100 CONTINUE
C
C     READ H K L F  ; END OF FILE IEND=1
C
      IF(IEND.GT.0.AND.J.EQ.0) GO TO 200
      IF(IEND.GT.0)            GO TO 300
      IF(ITP.EQ.'FS  ') THEN
        CALL RRD1(MT,IH(1),IK(1),IL(1),FA(1),FB(1),SDA,SDB
     *           ,NBL,IEND)
        IF(FA(1).LE.1.E-6.AND.FB(1).LE.1.E-6) GO TO 100
        IF(FA(1).GT.1.E-6.AND.FB(1).GT.1.E-6) THEN
          IF(SDA.LT.0.000001) SDA = 0.04*FA(1)
          IF(SDB.LT.0.000001) SDB = 0.04*FB(1)
          WT1 = 1./(SDA*SDA)
          WT2 = 1./(SDB*SDB)
          WT  = WT1+WT2
          FA(1)  = FA(1)*WT1+FB(1)*WT2
          FA(1)  = FA(1)/WT
          SDA = 1./SQRT(WT)
        ELSE IF(FB(1).GT.1.E-6) THEN
          FA(1)  = FB(1)
          SDA = SDB
        ENDIF
        SDA = 2.0*FA(1)*SDA
      ELSE
        SDA = 1.0
        SDB = 0.0
        CALL RD1(MT,IH(1),IK(1),IL(1),FA(1),FB(1),NBL,IEND)
        IF(FOUR.EQ.'F'.AND.INVER.EQ.'Y') THEN
          FB(1) =-FB(1)
        ELSE IF(FOUR.EQ.'P') THEN
          SDA = FB(1)
        ELSE IF(ITP.EQ.'F   ') THEN
          IF(IFOBS_FLAG.EQ.1.AND.LH_LH.NE.'N') THEN
            FA(1) = FB(1)
          ENDIF
          SDA = 2.0*FA(1)*FA(1)*0.04
        ENDIF
      ENDIF
      IF(MT.LE.0) THEN
        CALL MSGERR(MDOC,' ERROR: in RFCOEF: read input file')
        CLOSE(MTOUT)
        IERR=1
        GO TO 910
      ENDIF
C -------------------------------------
      IF(IEND.GT.0.AND.J.EQ.0) THEN
        CALL MSGERR(MDOC,' ERROR: in RFCOEF: Nrefls =0')
        CLOSE(MTOUT)
        IERR=1
        GO TO 910
      ENDIF
      IF(IEND.GT.0)            GO TO 300

      CALL GENER_RF(ITP,FOUR,INF,IH,IK,IL,FA,FB,SH
     *                 ,NSYM,ISYM,IPRSYM)

      DO  I=1,INF
        TH = IH(I)
        TK = IK(I)
        TL = IL(I)
        IF(IL(I).LT.0) GO TO 210
C......................
C        XX=TH*AST*SBETA
C        YY=TK*BST+TH*AST*CBETA
C        ZZ=TL*CST
C......MULTIPLY BY TRANSPOSE
        XX = TH*TB11
        YY = TH*TB12+TK*TB22
        ZZ = TH*TB13+TK*TB23+TL*TB33
C ---
        F2  = FA(I)
        F2B = FB(I)

        RSQ = XX*XX+YY*YY+ZZ*ZZ
        RH  = SQRT(RSQ)
        IF(RH.GT.RHMAX) GO TO 210
        IF(RH.LT.RHMIN) GO TO 210

        IF(BOFF.GT.0.0) THEN
          BT    = BOFF/4.0
          CBOFF = 1.0-EXP(-BT*RSQ)
        ELSE
          CBOFF = 1.0
        ENDIF
        IF(ABS(BADD).GT.0.01) THEN
          BT    = BADD/4.0
          CBADD = EXP(-BT*RSQ)
        ELSE
          CBADD = 1.0
        ENDIF

        CBADDBOFF = CBADD*CBOFF

        IF(LH_LH.EQ.'Y'.OR.LH_LH.EQ.'T') THEN
          CBADDBOFF = 1.0
          IF(IFOBS_FLAG.EQ.1) THEN
            CBADDBOFF = 1.0
          ELSE
            IF(BOFF_LH.GT.0.0) THEN
              BT    = BOFF_LH/4.0
              CBOFF = 1.0-EXP(-BT*RSQ)
            ELSE
              CBOFF = 1.0
            ENDIF
            R2 =(RHMAX - RH)*(RHMAX - RH)
            IF(ABS(BCORR_LH).GT.0.00001) THEN
              BT=BCORR_LH/4.0
              CBADD=1.0 - EXP(-BT*R2)
            ELSE
              CBADD=1.0
            ENDIF
            CBADDBOFF = CBADD*CBOFF
            IF(LH_LH.EQ.'Y') CBADDBOFF = 1.0
          ENDIF
        ELSE IF(LH_LH.EQ.'V'.OR.LH_LH.EQ.'2') THEN
          IF(IFOBS_FLAG.EQ.1) THEN
            CBADDBOFF = 1.0
          ELSE
            IF(BOFF_LH.GT.0.0) THEN
              BT    = BOFF_LH/4.0
              CBOFF = 1.0-EXP(-BT*RSQ)
            ELSE
              CBOFF = 1.0
            ENDIF
            IF(ABS(BADD_LH).GT.0.01) THEN
              BT    = BADD_LH/4.0
              CBADD = EXP(-BT*RSQ)
            ELSE
              CBADD = 1.0
            ENDIF
            CBADDBOFF = CBADD*CBOFF
            IF(LH_LH.EQ.'V') CBADDBOFF = 1.0
          ENDIF
        ENDIF

        IF(ITP.EQ.'COEF') THEN
          F2  = F2 *CBADDBOFF
          F2B = F2B*CBADDBOFF
        ELSE
          F2  = F2*CBADDBOFF*CBADDBOFF
          F2B = SDA*CBADDBOFF*CBADDBOFF
        ENDIF

        IF(RH.LT.1.E-7) GO TO 210
        IF(ITP.NE.'COEF') THEN
          FM = SQRT(ABS(F2))
        ELSE
          IF(FOUR.EQ.'F') THEN
            FM = SQRT(F2*F2 + F2B*F2B)
          ELSE
            FM = SQRT(F2)
          ENDIF
        ENDIF
        IF(FM.LT.FMIN) GO TO 210

        N_FBIG = N_FBIG + 1
        J  = J +1
        RHSQ (J) = RSQ
        SINTH(J) = SQRT(XX*XX+YY*YY)/RH
        COTTH(J) = 0.0
        PHI  (J) = 0.0
        IF((YY.NE.0.0).OR.(XX.NE.0.0)) THEN
          COTTH(J) = ZZ/(RH*SINTH(J))
          PHI  (J) = AATAN2(YY,XX)
        ENDIF
        PLM1(J) = 0.0
        PLM2(J) = 0.0

        IF(IPRNT.NE.0) THEN
          IF(MOD(J,IPRNT).EQ.0) THEN
            WRITE(LINE,1021) J,TH,TK,TL,SINTH(J),COTTH(J),PHI(J),FM
            CALL MSGDOC(MDOC,LINE)
 1021       FORMAT(I6,3F5.0,4X,3F9.3,G16.4)
          ENDIF
        ENDIF

        IF(INVER.EQ.'P') THEN
          FM = F2*F2 + F2B*F2B
          F2  = FM
C         F2B = 0.0
          F2B = 2.0*FM*FM*0.04
        ENDIF

        A(J) = F2
        B(J) = F2B

  210   CONTINUE
      ENDDO
      GO TO 100
C ========================================
  300 CONTINUE
      NFOBS = J
      IF(MT.GT.0) CLOSE(MT)
C ------    
      IND0=0
      DO     LK=1,LMAX1,LSTP
        L = LK-1
        MMAX   = L+1
        NN     = NMAX(LK)
        DO MM=1,MMAX
          M  = MMAX-MM
          M1 = M+1
          IF(MOD(M,NSYMZ).EQ.0) IND0=IND0 + NN
        ENDDO
      ENDDO
c ---
      INDMAX = IND0 + 100
      IT = 0
      allocate(ALM(1:INDMAX),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(BLM(1:INDMAX),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      IF(IT.NE.0) THEN
        IERR = 1
        CALL MSGERR(MDOC,
     *    ' ERROR: in RFCOEF : problem with memory allocation')
        CALL MSGERR(MDOC,
     *    '                    try to change resolution')
        CLOSE(MTOUT)
        GO TO 910
      ENDIF
      DO I=1,INDMAX
        ALM(I) = 0.0
        BLM(I) = 0.0
      ENDDO
C ---
      IND0=0
      CALL MSGDOC(MDOC,' ')
      DO     LK=1,LMAX1,LSTP
        L = LK-1
        WRITE(LINE,'('' L :'',I6)') L
        CALL MSGDOC(MDOC,LINE)
        PIBY2L = L*PIBY2
        MMAX   = L+1
        NN     = NMAX(LK)
        FAC    = 0.5*FACT(2*L+1)-FACT(L+1)

        DO     MB=1,NFOBS
          PLM1(MB) = 0.
          PLM2(MB) = 0.
          IF(LK.EQ.1) THEN
            PLM2(MB) = SQRT(0.5)
          ELSE
            IF(ABS(SINTH(MB)).GT.0.00001) PLM2(MB) =
     *      EXP(FAC+FLOAT(L)*ALOG(SINTH(MB)/2.0))*SQRT(FLOAT(L)+0.5)
          ENDIF
          ARG  = SQRT(RHSQ(MB))*A8PI+1.
          IARG = INT(ARG)
          FRAC = ARG-FLOAT(IARG)
          F2BES(MB) = ((1.-FRAC)*SBES(L+1,IARG)+FRAC*SBES(L+1,IARG+1))
          FAC3  = TWOPI*TWOPI*RHSQ(MB)
          DO N=1,NN
            IND = IND0+N
            BZ  = BZEROS(N,L+2)
            TT  = BZ*BZ-FAC3
            IF(ABS(TT).GE.0.00001) THEN
              T = BZ*F2BES(MB)/TT
              T = (T*SQRT(2.0))/ARAD
            ELSE
              ARG  = BZ*4.0*ARAD+1.0001
              IARG = ARG
              FRAC = ARG-IARG
              T = (1.-FRAC)*SBES(L+2,IARG) + 
     *                        FRAC*SBES(L+2,IARG+1)
              T = T*SQRT(2.0)
            ENDIF
            IF(MOD(LK,2).EQ.0)  T = -T
            FAC4(N,MB) = T
          ENDDO
        ENDDO

        DO MM=1,MMAX
          M  = MMAX-MM
          M1 = M+1
          IF(MM.NE.1) THEN
            FAC1 = 2.*FLOAT(M1)/SQRT(FLOAT((L+M1)*(L-M1+1)))
            FAC2 = SQRT(FLOAT((L-M1)*(L+M1+1))/FLOAT((L+M1)*(L-M1+1)))
          ENDIF

          DO MB=1,NFOBS

            IF(MM.NE.1) THEN
              TEMP     = PLM1(MB)
              PLM1(MB) = PLM2(MB)
              PLM2(MB) = FAC1*COTTH(MB)*PLM1(MB)-FAC2*TEMP
              IF(ABS(SINTH(MB)).LE.0.00001.AND.M.EQ.0) THEN
                PLM2(MB) = SQRT(FLOAT(L)+0.5)
              ENDIF
            ENDIF

            IF(MOD(M,NSYMZ).EQ.0) THEN
              PHASE = PIBY2L-M*PHI(MB)
              CPH   = COS(PHASE)
              SPH   = SIN(PHASE)  
              IF(MOD(LK,2).NE.0) THEN
                CALM = A(MB)*CPH*PLM2(MB)*SCALE
                CBLM = A(MB)*SPH*PLM2(MB)*SCALE
              ELSE
                CALM = B(MB)*SPH*PLM2(MB)*SCALE                
                CBLM =-B(MB)*CPH*PLM2(MB)*SCALE
              ENDIF
      
              DO N=1,NN
                IND = IND0+N
                ALM(IND) = ALM(IND) + FAC4(N,MB)*CALM
                BLM(IND) = BLM(IND) + FAC4(N,MB)*CBLM
                IF(ALMN_MAX.LT.ALM(IND)) ALMN_MAX = ALM(IND)
                IF(BLMN_MAX.LT.BLM(IND)) BLMN_MAX = BLM(IND)

C                if(mb.eq.100) 
C     *     write(*,*)'>',ind,ALM(IND),FAC4(N,MB),CALM

              ENDDO

            ENDIF
 410        CONTINUE
          ENDDO

          IF(MOD(M,NSYMZ).EQ.0) IND0=IND0 + NN
        ENDDO
      ENDDO

C ==============================================
  200 CONTINUE
      CLOSE(MT)
      WRITE(LINE,'('' N_refls  :'',I8)') NFOBS
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,'('' N > Fmin :'',I8)') N_FBIG
      CALL MSGDOC(MDOC,LINE) 
      WRITE(LINE,'('' Almn_max,Blmn_max:'',2G16.4)')
     *  ALMN_MAX,BLMN_MAX
      CALL MSGDOC(MDOC,LINE)

      IND0 = 0
      SC   = 1.0      
      SC1  = 1.0      

      DO  LK=1,LMAX1,LSTP
        L    = LK-1
        IF(LMINR.LT.0) THEN
          SIG = FLOAT(LMINR)
          X   = FLOAT(L)
          T   = 1.0/(2.0*SIG*SIG)
          SC  = 1.0 - EXP(-X*X*T)

c          SIG1 = FLOAT(LMAX)
c          T    = 1.0/(2.0*SIG1*SIG1)
c          SC1  = EXP(-X1*X1*T)

          SC = SC*SC1
        ENDIF

        MMAX = LK
        NN   = NMAX(LK)
        DO     MM=1,MMAX
          M = MMAX-MM
          IF(MOD(M,NSYMZ).EQ.0) THEN
            I1 = IND0+1
            I2 = IND0+NN
            DO  N=I1,I2
              JHH = N-I1+1
              JKK = M
              JLL = L
              FAA = ALM(N)*SC
              FBB = BLM(N)*SC

C              write(*,*) n,ALM(N),BLM(N),sc 
C              write(*,*)JHH,JKK,JLL,FAA,FBB 

              IF(TYPE.EQ.'ALMN') THEN
                CALL WRT(MTOUT,JHH,JKK,JLL,FAA,FBB,NUMB3,IEND3)
              ELSE
c                SDA = SLM(N)
c                SDB = SDA
c                CALL WABCD(MTOUT,JHH,JKK,JLL,FAA,FBB
c     *                                      ,SDA,SDB,NUMB3,IEND3)
              ENDIF
              IF(MTOUT.LE.0) THEN
                WRITE(LINE,*) ' ERR: write to output file'
                CALL MSGERR(MDOC,LINE)
                CLOSE(MTOUT)
                IERR=1
                GO TO 900
              ENDIF 
            ENDDO
            IND0 = IND0+NN
          ENDIF
        ENDDO
      ENDDO
      IEND3=2
      CALL WRT(MTOUT,JHH,JKK,JLL,FAA,FBB,NUMB3,IEND3)
      CLOSE(MTOUT)

  900 CONTINUE

      deallocate(ALM,STAT=ISTAT)
      deallocate(BLM,STAT=ISTAT)

  910 CONTINUE

      deallocate(F2BES,STAT=ISTAT)
      deallocate(RHSQ,STAT=ISTAT)
      deallocate(SINTH,STAT=ISTAT)
      deallocate(COTTH,STAT=ISTAT)
      deallocate(PHI,STAT=ISTAT)
      deallocate(PLM1,STAT=ISTAT)
      deallocate(PLM2,STAT=ISTAT)
      deallocate(A,STAT=ISTAT)
      deallocate(B,STAT=ISTAT)
      deallocate(FAC4,STAT=ISTAT)

      RETURN
C ----------------------------
      END

      SUBROUTINE RFCOEF_100_SAPTF(MDOC
     * ,NAMEF,NAMEO,INVER,BOFF,BADD,LINDEX
     * ,LMINR,NSYMZ
     * ,RESMIN,RESMXFR,RESLIM,ARAD
     * ,SH,NPEAK,NPEAKMAX,ISYM,IPRSYM,IERR)
C ----------------------------------
      PARAMETER ( IPRBES = 600                 )
      PARAMETER ( IPRLMX = 100                 )
      PARAMETER ( IPRNMX = IPRLMX/2            )
      PARAMETER ( IPRLM1 = IPRLMX+1            )
      PARAMETER ( IPRLM2 = IPRLMX+2            )
      PARAMETER ( IPRL21 = 2*IPRLMX+1          )
      PARAMETER ( IPRNIN = 50                  )
C ---------
c      REAL      RPARAM_RCOEF(6)
      REAL      RESMIN,RESMXFR,RESMXF,ARAD,BOFF,BADD

      INTEGER   MDOC,IERR,NSYMZ,LINDEX
      CHARACTER NAMEF*(*),NAMEO(NPEAKMAX)*256
      CHARACTER INVER*1
C ---------
      INCLUDE 'molrep_lh_infor.fh'
c      COMMON/COM_LH_INFOR/ BOFF_LH,BADD_LH,BOFF_FOR_SCAL
c     *   ,CHECK_CONTRAST,CONTRAST_LIM
c     *   ,BCORR_LH,FILE_FOBS_LH,SCORE_FLAG,LH_LH,DB_LH
cC ---
c      REAL      CHECK_CONTRAST,CONTRAST_LIM
c      REAL      BOFF_FOR_SCAL,BOFF_LH,BADD_LH,BCORR_LH
c      CHARACTER LH_LH*1,SCORE_FLAG*1,DB_LH*1
c      CHARACTER FILE_FOBS_LH*256
C ----------------------------------
      REAL      RLATT(6),SH(3,NPEAKMAX)
      INTEGER*2 ISYM(5,3,IPRSYM)

      PARAMETER ( IPRSM2 = 192 )
      INTEGER   IH(IPRSM2),IK(IPRSM2),IL(IPRSM2)
      REAL      FA(IPRSM2),FB(IPRSM2)

      REAL      SH_SCR(3)


C      REAL      F2BES(IPRMEM),COTTH(IPRMEM),PHI(IPRMEM)
C      REAL      A(IPRMEM),RHSQ(IPRMEM),SINTH(IPRMEM)
C      REAL      B(IPRMEM)
C      REAL      PLM1(IPRMEM),PLM2(IPRMEM)

      real,      allocatable :: F2BES(:)
      real,      allocatable :: RHSQ(:)
      real,      allocatable :: SINTH(:)
      real,      allocatable :: COTTH(:)
      real,      allocatable :: PHI(:)
      real,      allocatable :: PLM1(:)
      real,      allocatable :: PLM2(:)
      real,      allocatable :: A(:)
      real,      allocatable :: B(:)
      real,      allocatable :: FAC4(:,:)
      integer,   allocatable :: IH_INP(:)
      integer,   allocatable :: IK_INP(:)
      integer,   allocatable :: IL_INP(:)
c      REAL      ALM(IPRALM),BLM(IPRALM)

      real,      allocatable :: ALM(:,:)
      real,      allocatable :: BLM(:,:)

      CHARACTER ITP*4,TYPE*4,LINE*256,TITLE*80,FOUR*1
      CHARACTER FILES*256
C ------------------------------------------------------------------------
      INTEGER   NMAX  (IPRLM1),NBIN(50)
      REAL      FACT  (IPRL21)
      REAL      SBES  (IPRLM2,IPRBES)
      REAL      BZEROS(IPRNMX,IPRLM2)
      CHARACTER PATH*80,EXT*3

      INTEGER  IHR(7)
C ========================================================================
C     fobs_flag
      IFOBS_FLAG = 0
      IF(IERR.EQ.1) THEN
        IFOBS_FLAG = 1
      ENDIF
      IERR = 0
C ----
      IF(INVER.EQ.'y') INVER='Y'
      IF(INVER.EQ.'p') INVER='P'
      IF(INVER.NE.'Y'.AND.INVER.NE.'P') INVER='N'
C -
c      RESMIN  = RPARAM_RCOEF(1) 
c      RESMXFR = RPARAM_RCOEF(2) 
c      ARAD    = RPARAM_RCOEF(3) 
c      BOFF    = RPARAM_RCOEF(4) 
c      BADD    = RPARAM_RCOEF(5) 
c      RESLIM  = RPARAM_RCOEF(6) 
C -
      RESMXF = RESMXFR
C -------------------------------------
C
C     OPEN FILE :  F-MOD
C
      MT    = 10
      ITP   = '    '
      MD    =-ABS(MDOC)-1
      CALL ORFILE(MD,MT,NAMEF,ITP,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MD,' ERROR: in RFCOEF: OPEN FILE-IN')
        RETURN
      ENDIF
      IF(ITP.NE.'F   '.AND.ITP.NE.'FS  '.AND.ITP.NE.'COEF') THEN
        CALL MSGERR(MD,' ERROR: in RFCOEF: WRONG TYPE')
        CLOSE(MT)
        IERR=1
        RETURN
      ENDIF
      CALL GET_TITLE(MD,RLATT(1),RLATT(2),
     . RLATT(3),RLATT(4),RLATT(5),RLATT(6),F1,F2,RN,RX,IDM,IDM
     . ,IDM,IDM,IDM,TITLE,IERR)
      CALL C_RD_CR
      FOUR = 'N'
      IF(ITP.EQ.'COEF') THEN
        IF(TITLE(1:4).EQ.'PATT') THEN
          FOUR = 'P'
        ELSE
          FOUR = 'F'
        ENDIF
      ENDIF
C -----------------------------------------------------
C
C     RESOLUTION LIMITS
C
      IF(RESMIN.LE.0.0) RESMIN = RN
      IF(RESMXF.LE.0.0) RESMXF = RX
      IF(RESMIN.GT.RN)  RESMIN=RN
      IF(RESMIN.EQ.RESMXF) THEN
        CALL MSGERR(MDOC,' ERROR: in RFCOEF: RESMIN = RESMAX')
        IERR=1
        CLOSE(MT)
        RETURN
      ENDIF

C -----------------------------------------------------
C
C     RADIUS OF CUT-OFF SPHERE FOR PATTERSON
C
      IF(ARAD.LE.0.00001) ARAD=30.0
C -----------------------------------------------------
C
C  CALC REPROC-CELL: ASTAR,BSTAR,CSTAR,
C                    COS(ALPHA-STAR),COS(BETA-STAR),COS(GAMMA-STAR)
C
      CALL DSTARF(RLATT,AST,BST,CST,COALST,COBEST,COGAST,VOL)
C ----------------------------------------
      PI    = 4.0*ATAN(1.0)
      PIBY2 = PI/2.
      TWOPI = PI*2.
      PI180 = PI/180.
      SCALE = 3.0/(4.0*PI*ARAD*ARAD*ARAD)
C ------------------------------------------------
      LMAXP = 100
      NMAXP = 50
C --------------------------------------------------------------
       CALL GET_BZEROS_100(BZEROS,NMAXP,LMAXP,IERR)
C ----
C      REAL    BZ(30,*)
C      1 =<NMAXP=<30, 0=<LMAXP=<60
C ----
       IF(IERR.NE.0) THEN
         CALL MSGERR(MDOC,
     *' ERROR: rfcoef: wrong index Lmax or Nmax')
         RETURN
       ENDIF
C ------------------------------------------
      RESMAX_LIM  = (ARAD*TWOPI)/109.35

      WRITE(LINE,*) ' resmax_lim,lindex:',RESMAX_LIM,lindex
      CALL MSGDOC(MDOC,LINE)

      IF(LINDEX.GT.0.AND.LINDEX.LE.100) THEN
        L = LINDEX
        RMAX   = BZEROS(1,L+2) + 0.00001
        RESMAX = (ARAD*TWOPI)/RMAX
      ELSE
        RESMAX = RESMXF
        L      = 20
        RMAX   = BZEROS(1,L+2) + 0.00001
        RESMAX = (ARAD*TWOPI)/RMAX
        IF(RESMAX.GT.RESMXF) THEN
          RESMAX = RESMXF
        ENDIF
      ENDIF
      IF(RESMAX.LT.RESMAX_LIM) RESMAX = RESMAX_LIM
C -------
      RMAX = ARAD*TWOPI/RESMAX
      IF(RESMAX.GT.RESMXF) THEN
        RESMXF = RESMAX
      ENDIF
      RESLIM = RESMXF
      RHMAX  = 1.0/RESMXF
      RHMIN  = 1.0/RESMIN

      SH_SCR(1) = 0.0
      SH_SCR(2) = 0.0
      SH_SCR(3) = 0.0

C ----------------------------------------------------------
C     WRITE INPUT INFORMATION
C
      IF(ABS(COALST).GE.1.E-5) THEN
        T = SQRT(ABS(1.-COALST*COALST))/COALST
        T = ATAN(T)
      ELSE
        T = PIBY2
      ENDIF
      TAS = ABS(T)
      IF(ABS(COBEST).GE.1.E-5) THEN
        T = SQRT(ABS(1.-COBEST*COBEST))/COBEST
        T = ATAN(T)
      ELSE
        T = PIBY2
      ENDIF
      TBS = ABS(T)
      IF(ABS(COGAST).GE.1.E-5) THEN
        T = SQRT(ABS(1.-COGAST*COGAST))/COGAST
        T = ATAN(T)
      ELSE
        T = PIBY2
      ENDIF
      TCS = ABS(T)
C ----
      TTAS = TAS/PI180
      TTBS = TBS/PI180
      TTCS = TCS/PI180
      WRITE(LINE,2006) ARAD
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,2007) RESMIN,RESMXF
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,'(''BOFF,BADD :'',2F8.2)') BOFF,BADD
      CALL MSGDOC(MDOC,LINE)
      IF(LH_LH.NE.'N') THEN
        WRITE(LINE,'(''LH,IFOBS :'',A,I5)') LH_LH,IFOBS_FLAG
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,'(''BOFF_LH,BADD_LH :'',2F8.2)') BOFF_LH,BADD_LH
      ENDIF
      CALL MSGDOC(MDOC,LINE)
      IF(FOUR.EQ.'F') THEN
C        WRITE(LINE,'(''Shift :'',3F8.4)') (SH(I),I=1,3)
C        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,'(''INVER :'',A)') INVER
        CALL MSGDOC(MDOC,LINE)
      ENDIF

      WRITE(LINE,2008) AST,BST,CST
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,2009) TTAS,TTBS,TTCS
      CALL MSGDOC(MDOC,LINE)

 2006 FORMAT('RADIUS OF CUT-OFF SPHERE ',F5.1,' ANGSTROMS')
 2007 FORMAT('DATA INCLUDED BETWEEN',F7.1,' AND ',F7.1,'( ANGSTROMS)')
 2008 FORMAT('ASTAR=',F8.5,' BSTAR=',F8.5,' CSTAR=',F8.5)
 2009 FORMAT('ALPHASTAR=',F8.4,' BETASTAR=',F8.4,' GAMMASTAR=',F8.4
     *      ,' (GRAD)')
 2010 FORMAT('FMOD OBOVE ',F8.1,' INCLUDED')
C --------------------------------------------------------------
      LMAX = 0
      IF(BZEROS(1,2).GT.RMAX) THEN
        WRITE(LINE,*) ' ERROR: in RFCOEF:  RMAX ',RMAX
        CALL MSGDOC(MDOC,LINE)
        CLOSE(MT)
        IERR=1
        RETURN
      ENDIF
      DO     L=2,LMAXP+2
        IF(BZEROS(1,L).GT.RMAX) GO TO 50
        LMAX=L-2
        DO     N=1,NMAXP
          IF(BZEROS(N,L).GT.RMAX) GO TO 60
          NMAX(L-1)=N
        ENDDO
   60   CONTINUE
      ENDDO
   50 LMAX = (LMAX/2)*2
      WRITE(LINE,2015) LMAX
      CALL MSGDOC(MDOC,LINE)
 2015 FORMAT(5X,' MAXIMUM L ORDER = ',I5)
      LMAX2 = LMAX+2
      LMAX1 = LMAX+1
C ---------------------------------------------
      LINDEX = LMAX
C ---------------------------------------------
      DO     L=2,LMAX2
        NN=NMAX(L-1)
        IF(L.EQ.2) THEN
          WRITE(LINE,*) ' NMAX ( for L=2 ):',NN
          CALL MSGDOC(MDOC,LINE)
        ENDIF
        DO     N=1,NN
          BZEROS(N,L)=BZEROS(N,L)/ARAD
        ENDDO
      ENDDO
C --------------------------------------------------------------------
      WRITE(LINE,'(''Nsym :'',I5)') NSYM
      CALL MSGDOC(MDOC,LINE)
      IF(FOUR.EQ.'F') THEN
         NSYMZ = 1
        WRITE(LINE,'(''Symmetry axis Z:'',I5)') NSYMZ
        CALL MSGDOC(MDOC,LINE)
      ELSE
        IF(NSYMZ.LE.0) CALL GET_NSYMZ(NSYM,ISYM,NSYMZ)
        WRITE(LINE,'(''Symmetry axis Z in Patterson:'',I5)') NSYMZ
        CALL MSGDOC(MDOC,LINE)
      ENDIF
C ----------------------------------------------
      LSTP = 2
      IF(FOUR.EQ.'F'.AND.INVER.NE.'P') LSTP = 1
C ----------------------------------------------
      ALMN_MAX = 0.0
      BLMN_MAX = 0.0
C -----------------------------------------------
      A2PI    = TWOPI*ARAD
      A8PI    = 4.0*A2PI
      A42PI   = 2.0*SQRT(2.0*ARAD)*TWOPI
      FACT(1) = 0.0
      DO     I=1,IPRL21-1
        FACT(I+1) = FACT(I)+ALOG(FLOAT(I))
      ENDDO
C ------------------
      ARGMAX = RMAX+1.
      CALL SPHBES_RF(MDOC,LMAX,ARGMAX,SBES,IPRLM2,IPRBES,IERR)
      IF(IERR.GT.0) THEN
        CALL MSGERR(MDOC,' ERROR: in RFCOEF: SPHBES_RF')
        CLOSE(MT)
C///        CLOSE(MTOUT)
        IERR=1
        RETURN
      ENDIF
C ------------------
c      BETAST=TCS
c      CBETA =COS(BETAST)
c      SBETA =SIN(BETAST)

      LMAX1  = LMAX+1
      IND0   = 0
      NN_MAX = 0
      DO  LK=1,LMAX1,LSTP
        L    = LK-1
        MMAX = LK
        NN   = NMAX(LK)
        IF(NN.GT.NN_MAX) NN_MAX = NN
        DO  MM=1,MMAX
          M = MMAX-MM
          IF(MOD(M,NSYMZ).EQ.0) THEN
            IND0 = IND0+NN
          ENDIF
        ENDDO
      ENDDO

c      WRITE(*,'('' INDEX-MAX ='',I6)') IND0
c      WRITE(*,*) '--',NN_MAX
 
C
C      X --- A
C      Z --- C STAR
C
        SIALST = SIN(ACOS(COALST))
        SIBEST = SIN(ACOS(COBEST))
        SIGAST = SIN(ACOS(COGAST))

        TB11 = AST*SIGAST*SIBEST
        TB12 = AST*COGAST*SIBEST
        TB13 = AST*       COBEST
        TB22 = BST*SIALST
        TB23 = BST*COALST
        TB33 = CST
C ====================================
      FMIN = 1.0E30
      FMAX =-1.0E30
      DO K=1,50
        NBIN(K) = 0
      ENDDO
      NFOBS_INPUT  = 0
      NFOBS        = 0
      J    = 0
      IEND =-1
      NBL  = 0
C ----

C      CALL CLOCK(IHR)
cC     IH(2),IH(3),IH(4),    IH(5),IH(6),IH(7)
cC     sec   min  hour      day   month year
C      WRITE(*,*) 'time:',IHR(4),IHR(3),IHR(2)


C     check memory for fobs
  110 CONTINUE

      IF(IEND.GT.0) GO TO 120
      IF(ITP.EQ.'FS  ') THEN
        CALL RRD1(MT,IH(1),IK(1),IL(1),FA(1),FB(1),SDA,SDB
     *           ,NBL,IEND)
        IF(FA(1).LE.1.E-6.AND.FB(1).LE.1.E-6) GO TO 110
      ELSE
        CALL RD1(MT,IH(1),IK(1),IL(1),FA(1),FB(1),NBL,IEND)
      ENDIF
      IF(MT.LE.0) THEN
        CALL MSGERR(MDOC,' ERROR: in RFCOEF: read input file')
C ///        CLOSE(MTOUT)
        IERR=1
        RETURN
      ENDIF
C -------------------------------------
      IF(IEND.GT.0) GO TO 120
      NFOBS_INPUT  = NFOBS_INPUT + 1

      CALL GENER_RF(ITP,FOUR,INF,IH,IK,IL,FA,FB,SH_SCR
     *                 ,NSYM,ISYM,IPRSYM)
      DO  I=1,INF
        TH = IH(I)
        TK = IK(I)
        TL = IL(I)
        IF(IL(I).LT.0) GO TO 130
        XX = TH*TB11
        YY = TH*TB12+TK*TB22
        ZZ = TH*TB13+TK*TB23+TL*TB33
        F2  = FA(I)
        F2B = FB(I)
        RSQ = XX*XX+YY*YY+ZZ*ZZ
        RH  = SQRT(RSQ)
        IF(RH.GT.RHMAX) GO TO 130
        IF(RH.LT.RHMIN) GO TO 130
        IF(RH.LT.1.E-7) GO TO 130

        IF(BOFF.GT.0.0) THEN
          BT    = BOFF/4.0
          CBOFF = 1.0-EXP(-BT*RSQ)
        ELSE
          CBOFF = 1.0
        ENDIF
        IF(ABS(BADD).GT.0.01) THEN
          BT    = BADD/4.0
          CBADD = EXP(-BT*RSQ)
        ELSE
          CBADD = 1.0
        ENDIF

        CBADDBOFF = CBADD*CBOFF

        IF(LH_LH.EQ.'Y'.OR.LH_LH.EQ.'T') THEN
          CBADDBOFF = 1.0
          IF(IFOBS_FLAG.EQ.1) THEN
            CBADDBOFF = 1.0
          ELSE
            IF(BOFF_LH.GT.0.0) THEN
              BT    = BOFF_LH/4.0
              CBOFF = 1.0-EXP(-BT*RSQ)
            ELSE
              CBOFF = 1.0
            ENDIF
            R2 =(RHMAX - RH)*(RHMAX - RH)
            IF(ABS(BCORR_LH).GT.0.00001) THEN
              BT=BCORR_LH/4.0
              CBADD=1.0 - EXP(-BT*R2)
            ELSE
              CBADD=1.0
            ENDIF
            CBADDBOFF = CBADD*CBOFF
            IF(LH_LH.EQ.'Y') CBADDBOFF = 1.0
          ENDIF
        ELSE IF(LH_LH.EQ.'V'.OR.LH_LH.EQ.'2') THEN
          IF(IFOBS_FLAG.EQ.1) THEN
            CBADDBOFF = 1.0
          ELSE
            IF(BOFF_LH.GT.0.0) THEN
              BT    = BOFF_LH/4.0
              CBOFF = 1.0-EXP(-BT*RSQ)
            ELSE
              CBOFF = 1.0
            ENDIF
            IF(ABS(BADD_LH).GT.0.01) THEN
              BT    = BADD_LH/4.0
              CBADD = EXP(-BT*RSQ)
            ELSE
              CBADD = 1.0
            ENDIF
            CBADDBOFF = CBADD*CBOFF
            IF(LH_LH.EQ.'V') CBADDBOFF = 1.0
          ENDIF
        ENDIF

        IF(ITP.EQ.'COEF') THEN
          F2  = F2 *CBADDBOFF
          F2B = F2B*CBADDBOFF
        ELSE
          F2  = F2*CBADDBOFF*CBADDBOFF
          F2B = SDA*CBADDBOFF*CBADDBOFF
        ENDIF

        IF(RH.LT.1.E-7) GO TO 130
        IF(ITP.NE.'COEF') THEN
          FM = SQRT(ABS(F2))
        ELSE
          IF(FOUR.EQ.'F') THEN
            FM = SQRT(F2*F2 + F2B*F2B)
          ELSE
            FM = SQRT(F2)
          ENDIF
        ENDIF
        IF(FM.GT.FMAX) FMAX = FM
        IF(FM.LT.FMIN) FMIN = FM
        J  = J + 1
  130   CONTINUE
      ENDDO
C ---
      GO TO 110
  120 CONTINUE
      IF(MT.GT.0) CLOSE(MT)
      NFOBS = J    
      WRITE(LINE,'('' N_refls(input):'',I8)') NFOBS_INPUT
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,'('' N_refls(gener):'',I8)') NFOBS
      CALL MSGDOC(MDOC,LINE)
      IF(NFOBS.LE.0) THEN
        CALL MSGERR(MDOC,'ERROR: in RFCOEF: Nfobs = 0')
C ////        CLOSE(MTOUT)
        IERR = 1
        RETURN
      ENDIF
C ---
      IF(FMAX.GT.0.0001) THEN
C ---
        MT    = 10
        ITP   = '    '
        MD    =-ABS(MDOC)-1
        CALL ORFILE(MD,MT,NAMEF,ITP,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MD,' ERROR: in RFCOEF: OPEN FILE-IN')
          CLOSE(MTOUT)
          RETURN
        ENDIF
C ----------
        DFB = (FMAX*0.5)/50.0
        J = 0
        IEND =-1
        NBL  = 0
  310   CONTINUE

        IF(IEND.GT.0) GO TO 320
        IF(ITP.EQ.'FS  ') THEN
          CALL RRD1(MT,IH(1),IK(1),IL(1),FA(1),FB(1),SDA,SDB
     *             ,NBL,IEND)
          IF(FA(1).LE.1.E-6.AND.FB(1).LE.1.E-6) GO TO 310
        ELSE
          CALL RD1(MT,IH(1),IK(1),IL(1),FA(1),FB(1),NBL,IEND)
        ENDIF
        IF(MT.LE.0) THEN
          CALL MSGERR(MDOC,' ERROR: in RFCOEF: read input file')
C ///          CLOSE(MTOUT)
          IERR=1
          RETURN
        ENDIF
C -------------------------------------
        IF(IEND.GT.0) GO TO 320

        CALL GENER_RF(ITP,FOUR,INF,IH,IK,IL,FA,FB,SH_SCR
     *                 ,NSYM,ISYM,IPRSYM)
        DO  I=1,INF
          TH = IH(I)
          TK = IK(I)
          TL = IL(I)
          IF(IL(I).LT.0) GO TO 330
          XX = TH*TB11
          YY = TH*TB12+TK*TB22
          ZZ = TH*TB13+TK*TB23+TL*TB33
          F2  = FA(I)
          F2B = FB(I)
          RSQ = XX*XX+YY*YY+ZZ*ZZ
          RH  = SQRT(RSQ)
          IF(RH.GT.RHMAX) GO TO 330
          IF(RH.LT.RHMIN) GO TO 330
          IF(RH.LT.1.E-7) GO TO 330

          IF(BOFF.GT.0.0) THEN
            BT    = BOFF/4.0
            CBOFF = 1.0-EXP(-BT*RSQ)
          ELSE
            CBOFF = 1.0
          ENDIF
          IF(ABS(BADD).GT.0.01) THEN
            BT    = BADD/4.0
            CBADD = EXP(-BT*RSQ)
          ELSE
            CBADD = 1.0
          ENDIF

          CBADDBOFF = CBADD*CBOFF

          IF(LH_LH.EQ.'Y'.OR.LH_LH.EQ.'T') THEN
            CBADDBOFF = 1.0
            IF(IFOBS_FLAG.EQ.1) THEN
              CBADDBOFF = 1.0
            ELSE
              IF(BOFF_LH.GT.0.0) THEN
                BT    = BOFF_LH/4.0
                CBOFF = 1.0-EXP(-BT*RSQ)
              ELSE
                CBOFF = 1.0
              ENDIF
              R2 =(RHMAX - RH)*(RHMAX - RH)
              IF(ABS(BCORR_LH).GT.0.00001) THEN
                BT=BCORR_LH/4.0
                CBADD=1.0 - EXP(-BT*R2)
              ELSE
                CBADD=1.0
              ENDIF
              CBADDBOFF = CBADD*CBOFF
              IF(LH_LH.EQ.'Y') CBADDBOFF = 1.0
            ENDIF
          ELSE IF(LH_LH.EQ.'V'.OR.LH_LH.EQ.'2') THEN
            IF(IFOBS_FLAG.EQ.1) THEN
              CBADDBOFF = 1.0
            ELSE
              IF(BOFF_LH.GT.0.0) THEN
                BT    = BOFF_LH/4.0
                CBOFF = 1.0-EXP(-BT*RSQ)
              ELSE
                CBOFF = 1.0
              ENDIF
              IF(ABS(BADD_LH).GT.0.01) THEN
                BT    = BADD_LH/4.0
                CBADD = EXP(-BT*RSQ)
              ELSE
                CBADD = 1.0
              ENDIF
              CBADDBOFF = CBADD*CBOFF
              IF(LH_LH.EQ.'V') CBADDBOFF = 1.0
            ENDIF
          ENDIF

          IF(ITP.EQ.'COEF') THEN
            F2  = F2 *CBADDBOFF
            F2B = F2B*CBADDBOFF
          ELSE
            F2  = F2*CBADDBOFF*CBADDBOFF
            F2B = SDA*CBADDBOFF*CBADDBOFF
          ENDIF

          IF(RH.LT.1.E-7) GO TO 330
          IF(ITP.NE.'COEF') THEN
            FM = SQRT(ABS(F2))
          ELSE
            IF(FOUR.EQ.'F') THEN
              FM = SQRT(F2*F2 + F2B*F2B)
            ELSE
              FM = SQRT(F2)
            ENDIF
          ENDIF

          J = J + 1           

          IFM = FM/DFB
          IF(IFM.LT.0) IFM = 0
          IF(IFM.GT.49) IFM = 49
          IFM = IFM + 1
          NBIN(IFM) = NBIN(IFM) + 1

  330    CONTINUE
        ENDDO

      GO TO 310
  320 CONTINUE
      IF(MT.GT.0) CLOSE(MT)

        T = (NFOBS*0.5)/500000.0
        IF(T.GT.1.0) T = 1.0 
        NLIM = NFOBS*T*0.5 
        NSUM = 0.0
        DO K=1,50
          NSUM = NSUM + NBIN(K)
          IF(NSUM.GT.NLIM) THEN
            IF(K.GT.1) THEN
              FMIN = DFB*(K-1)
            ENDIF
            GO TO 400
          ENDIF
        ENDDO
 400    CONTINUE
        WRITE(LINE,'('' N,FMAX,FMIN:'',I10,2G16.4)') NFOBS,FMAX,FMIN
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,'('' NLIM:'',I10,F10.3)') NLIM,T
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,'(10I7)') (NBIN(K),K=1,10)         
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,'(10I7)') (NBIN(K),K=11,20)         
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,'(10I7)') (NBIN(K),K=21,30)         
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,'(10I7)') (NBIN(K),K=31,40)         
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,'(10I7)') (NBIN(K),K=41,50)         
        CALL MSGDOC(MDOC,LINE)
      ENDIF
C ---
      MT    = 10
      ITP   = '    '
      MD    =-ABS(MDOC)-1
      CALL ORFILE(MD,MT,NAMEF,ITP,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MD,' ERROR: in RFCOEF: OPEN FILE-IN')
C ///        CLOSE(MTOUT)
        RETURN
      ENDIF
C ----------
c allocation
      NFOBS_MAX = NFOBS + 100
      allocate(F2BES(1:NFOBS_MAX),STAT=ISTAT)
      allocate(RHSQ(1:NFOBS_MAX),STAT=ISTAT)
      allocate(SINTH(1:NFOBS_MAX),STAT=ISTAT)
      allocate(COTTH(1:NFOBS_MAX),STAT=ISTAT)
      allocate(PHI(1:NFOBS_MAX),STAT=ISTAT)
      allocate(PLM1(1:NFOBS_MAX),STAT=ISTAT)
      allocate(PLM2(1:NFOBS_MAX),STAT=ISTAT)
      allocate(A(1:NFOBS_MAX),STAT=ISTAT)
      allocate(B(1:NFOBS_MAX),STAT=ISTAT)
      allocate(FAC4(1:NN_MAX,1:NFOBS_MAX),STAT=ISTAT)
      allocate(IH_INP(1:NFOBS_MAX),STAT=ISTAT)
      allocate(IK_INP(1:NFOBS_MAX),STAT=ISTAT)
      allocate(IL_INP(1:NFOBS_MAX),STAT=ISTAT)
C ========================================
      IPRNT=2000
      IF(IPRNT.NE.0) THEN
        WRITE(LINE,1018)
        CALL MSGDOC(MDOC,LINE)
 1018   FORMAT('    N',4X,'H',4X,'K',4X,'L',8X,
     *  'SINTH',4X,'COTTH',6X,'PHI',7X,'   !F!')
      ENDIF
      N_FBIG = 0
      IEND   =-1
      NBL    = 0
      J      = 0
C ----
  100 CONTINUE
C
C     READ H K L F  ; END OF FILE IEND=1
C
      IF(IEND.GT.0.AND.J.EQ.0) THEN
        CALL MSGERR(MDOC,' ERROR: in RFCOEF: Nref=0')
        IERR=1
        GO TO 910
      ENDIF
      IF(IEND.GT.0)            GO TO 300
      IF(ITP.EQ.'FS  ') THEN
        CALL RRD1(MT,IH(1),IK(1),IL(1),FA(1),FB(1),SDA,SDB
     *           ,NBL,IEND)
        IF(FA(1).LE.1.E-6.AND.FB(1).LE.1.E-6) GO TO 100
        IF(FA(1).GT.1.E-6.AND.FB(1).GT.1.E-6) THEN
          IF(SDA.LT.0.000001) SDA = 0.04*FA(1)
          IF(SDB.LT.0.000001) SDB = 0.04*FB(1)
          WT1 = 1./(SDA*SDA)
          WT2 = 1./(SDB*SDB)
          WT  = WT1+WT2
          FA(1)  = FA(1)*WT1+FB(1)*WT2
          FA(1)  = FA(1)/WT
          SDA = 1./SQRT(WT)
        ELSE IF(FB(1).GT.1.E-6) THEN
          FA(1)  = FB(1)
          SDA = SDB
        ENDIF
        SDA = 2.0*FA(1)*SDA
      ELSE
        SDA = 1.0
        SDB = 0.0
        CALL RD1(MT,IH(1),IK(1),IL(1),FA(1),FB(1),NBL,IEND)
        IF(FOUR.EQ.'F'.AND.INVER.EQ.'Y') THEN
          FB(1) =-FB(1)
        ELSE IF(FOUR.EQ.'P') THEN
          SDA = FB(1)
        ELSE IF(ITP.EQ.'F   ') THEN
          IF(IFOBS_FLAG.EQ.1.AND.LH_LH.NE.'N') THEN
            FA(1) = FB(1)
          ENDIF
          SDA = 2.0*FA(1)*FA(1)*0.04
        ENDIF
      ENDIF
      IF(MT.LE.0) THEN
        CALL MSGERR(MDOC,' ERROR: in RFCOEF: read input file')
C ////        CLOSE(MTOUT)
        IERR=1
        GO TO 910
      ENDIF
C -------------------------------------
      IF(IEND.GT.0.AND.J.EQ.0) THEN
        CALL MSGERR(MDOC,' ERROR: in RFCOEF: Nref=0')
        IERR=1
        GO TO 910
      ENDIF
      IF(IEND.GT.0)            GO TO 300

      CALL GENER_RF(ITP,FOUR,INF,IH,IK,IL,FA,FB,SH_SCR
     *              ,NSYM,ISYM,IPRSYM)
      DO  I=1,INF
        TH = IH(I)
        TK = IK(I)
        TL = IL(I)
        IF(IL(I).LT.0) GO TO 210
C......................
C        XX=TH*AST*SBETA
C        YY=TK*BST+TH*AST*CBETA
C        ZZ=TL*CST
C......MULTIPLY BY TRANSPOSE
        XX = TH*TB11
        YY = TH*TB12+TK*TB22
        ZZ = TH*TB13+TK*TB23+TL*TB33
C ---
        F2  = FA(I)
        F2B = FB(I)

        RSQ = XX*XX+YY*YY+ZZ*ZZ
        RH  = SQRT(RSQ)
        IF(RH.GT.RHMAX) GO TO 210
        IF(RH.LT.RHMIN) GO TO 210

        IF(BOFF.GT.0.0) THEN
          BT    = BOFF/4.0
          CBOFF = 1.0-EXP(-BT*RSQ)
        ELSE
          CBOFF = 1.0
        ENDIF
        IF(ABS(BADD).GT.0.01) THEN
          BT    = BADD/4.0
          CBADD = EXP(-BT*RSQ)
        ELSE
          CBADD = 1.0
        ENDIF

        CBADDBOFF = CBADD*CBOFF

        IF(LH_LH.EQ.'Y'.OR.LH_LH.EQ.'T') THEN
          CBADDBOFF = 1.0
          IF(IFOBS_FLAG.EQ.1) THEN
            CBADDBOFF = 1.0
          ELSE
            IF(BOFF_LH.GT.0.0) THEN
              BT    = BOFF_LH/4.0
              CBOFF = 1.0-EXP(-BT*RSQ)
            ELSE
              CBOFF = 1.0
            ENDIF
            R2 =(RHMAX - RH)*(RHMAX - RH)
            IF(ABS(BCORR_LH).GT.0.00001) THEN
              BT=BCORR_LH/4.0
              CBADD=1.0 - EXP(-BT*R2)
            ELSE
              CBADD=1.0
            ENDIF
            CBADDBOFF = CBADD*CBOFF
            IF(LH_LH.EQ.'Y') CBADDBOFF = 1.0
          ENDIF
        ELSE IF(LH_LH.EQ.'V'.OR.LH_LH.EQ.'2') THEN
          IF(IFOBS_FLAG.EQ.1) THEN
            CBADDBOFF = 1.0
          ELSE
            IF(BOFF_LH.GT.0.0) THEN
              BT    = BOFF_LH/4.0
              CBOFF = 1.0-EXP(-BT*RSQ)
            ELSE
              CBOFF = 1.0
            ENDIF
            IF(ABS(BADD_LH).GT.0.01) THEN
              BT    = BADD_LH/4.0
              CBADD = EXP(-BT*RSQ)
            ELSE
              CBADD = 1.0
            ENDIF
            CBADDBOFF = CBADD*CBOFF
            IF(LH_LH.EQ.'V') CBADDBOFF = 1.0
          ENDIF
        ENDIF

        IF(ITP.EQ.'COEF') THEN
          F2  = F2 *CBADDBOFF
          F2B = F2B*CBADDBOFF
        ELSE
          F2  = F2*CBADDBOFF*CBADDBOFF
          F2B = SDA*CBADDBOFF*CBADDBOFF
        ENDIF

        IF(RH.LT.1.E-7) GO TO 210
        IF(ITP.NE.'COEF') THEN
          FM = SQRT(ABS(F2))
        ELSE
          IF(FOUR.EQ.'F') THEN
            FM = SQRT(F2*F2 + F2B*F2B)
          ELSE
            FM = SQRT(F2)
          ENDIF
        ENDIF
        IF(FM.LT.FMIN) GO TO 210

        N_FBIG = N_FBIG + 1
        J  = J +1
        RHSQ (J) = RSQ
        SINTH(J) = SQRT(XX*XX+YY*YY)/RH
        COTTH(J) = 0.0
        PHI  (J) = 0.0
        IF((YY.NE.0.0).OR.(XX.NE.0.0)) THEN
          COTTH(J) = ZZ/(RH*SINTH(J))
          PHI  (J) = AATAN2(YY,XX)
        ENDIF
        PLM1(J) = 0.0
        PLM2(J) = 0.0
        IH_INP(J) = IH(I)
        IK_INP(J) = IK(I)
        IL_INP(J) = IL(I)

        IF(IPRNT.NE.0) THEN
          IF(MOD(J,IPRNT).EQ.0) THEN
            WRITE(LINE,1021) J,TH,TK,TL,SINTH(J),COTTH(J),PHI(J),FM
            CALL MSGDOC(MDOC,LINE)
 1021       FORMAT(I6,3F5.0,4X,3F9.3,G16.4)
          ENDIF
        ENDIF

        IF(INVER.EQ.'P') THEN
          FM = F2*F2 + F2B*F2B
          F2  = FM
C         F2B = 0.0
          F2B = 2.0*FM*FM*0.04
        ENDIF

        A(J) = F2
        B(J) = F2B

  210   CONTINUE
      ENDDO
      GO TO 100
C ========================================
  300 CONTINUE
      NFOBS = J
C ------    
      IND0=0
      DO     LK=1,LMAX1,LSTP
        L = LK-1
        MMAX   = L+1
        NN     = NMAX(LK)
        DO MM=1,MMAX
          M  = MMAX-MM
          M1 = M+1
          IF(MOD(M,NSYMZ).EQ.0) IND0=IND0 + NN
        ENDDO
      ENDDO
c ---
      INDMAX = IND0 + 100
      allocate(ALM(1:INDMAX,1:NPEAK),STAT=ISTAT)
      allocate(BLM(1:INDMAX,1:NPEAK),STAT=ISTAT)
      DO IP=1,NPEAK
        DO I=1,INDMAX
          ALM(I,IP) = 0.0
          BLM(I,IP) = 0.0
        ENDDO
      ENDDO
C ---
      IND0=0
      CALL MSGDOC(MDOC,' ')
      DO     LK=1,LMAX1,LSTP
        L = LK-1
        WRITE(LINE,'('' L :'',I6)') L
        CALL MSGDOC(MDOC,LINE)
        PIBY2L = L*PIBY2
        MMAX   = L+1
        NN     = NMAX(LK)
        FAC    = 0.5*FACT(2*L+1)-FACT(L+1)

        DO     MB=1,NFOBS
          PLM1(MB) = 0.
          PLM2(MB) = 0.
          IF(LK.EQ.1) THEN
            PLM2(MB) = SQRT(0.5)
          ELSE
            IF(ABS(SINTH(MB)).GT.0.00001) PLM2(MB) =
     *      EXP(FAC+FLOAT(L)*ALOG(SINTH(MB)/2.0))*SQRT(FLOAT(L)+0.5)
          ENDIF
          ARG  = SQRT(RHSQ(MB))*A8PI+1.
          IARG = INT(ARG)
          FRAC = ARG-FLOAT(IARG)
          F2BES(MB) = ((1.-FRAC)*SBES(L+1,IARG)+FRAC*SBES(L+1,IARG+1))
          FAC3  = TWOPI*TWOPI*RHSQ(MB)
          DO N=1,NN
            IND = IND0+N
            BZ  = BZEROS(N,L+2)
            TT  = BZ*BZ-FAC3
            IF(ABS(TT).GE.0.00001) THEN
              T = BZ*F2BES(MB)/TT
              T = (T*SQRT(2.0))/ARAD
            ELSE
              ARG  = BZ*4.0*ARAD+1.0001
              IARG = ARG
              FRAC = ARG-IARG
              T = (1.-FRAC)*SBES(L+2,IARG) + 
     *                        FRAC*SBES(L+2,IARG+1)
              T = T*SQRT(2.0)
            ENDIF
            IF(MOD(LK,2).EQ.0)  T = -T
            FAC4(N,MB) = T
          ENDDO
        ENDDO

        DO MM=1,MMAX
          M  = MMAX-MM
          M1 = M+1
          IF(MM.NE.1) THEN
            FAC1 = 2.*FLOAT(M1)/SQRT(FLOAT((L+M1)*(L-M1+1)))
            FAC2 = SQRT(FLOAT((L-M1)*(L+M1+1))/FLOAT((L+M1)*(L-M1+1)))
          ENDIF

          DO MB=1,NFOBS

            IF(MM.NE.1) THEN
              TEMP     = PLM1(MB)
              PLM1(MB) = PLM2(MB)
              PLM2(MB) = FAC1*COTTH(MB)*PLM1(MB)-FAC2*TEMP
              IF(ABS(SINTH(MB)).LE.0.00001.AND.M.EQ.0) THEN
                PLM2(MB) = SQRT(FLOAT(L)+0.5)
              ENDIF
            ENDIF

            IF(MOD(M,NSYMZ).EQ.0) THEN
              PHASE = PIBY2L-M*PHI(MB)
              CPH   = COS(PHASE)
              SPH   = SIN(PHASE)  

              DO IP=1,NPEAK

                ARG = -(IH_INP(MB)*SH(1,IP) + 
     *                  IK_INP(MB)*SH(2,IP) + 
     *                  IL_INP(MB)*SH(3,IP)   )*TWOPI
                COSA  = COS(ARG)
                SINA  = SIN(ARG)
                FFAA  = A(MB)
                FFBB  = B(MB)
                T     = FFAA*COSA - FFBB*SINA
                FFBB  = FFAA*SINA + FFBB*COSA
                FFAA  = T

                IF(MOD(LK,2).NE.0) THEN
                  CALM = FFAA*CPH*PLM2(MB)*SCALE
                  CBLM = FFAA*SPH*PLM2(MB)*SCALE
                ELSE
                  CALM = FFBB*SPH*PLM2(MB)*SCALE                
                  CBLM =-FFBB*CPH*PLM2(MB)*SCALE
                ENDIF
      
                DO N=1,NN
                  IND = IND0+N
                  ALM(IND,IP) = ALM(IND,IP) + FAC4(N,MB)*CALM
                  BLM(IND,IP) = BLM(IND,IP) + FAC4(N,MB)*CBLM
                  IF(ALMN_MAX.LT.ALM(IND,IP)) ALMN_MAX = ALM(IND,IP)
                  IF(BLMN_MAX.LT.BLM(IND,IP)) BLMN_MAX = BLM(IND,IP)
                ENDDO

              ENDDO

            ENDIF
 410        CONTINUE
          ENDDO

          IF(MOD(M,NSYMZ).EQ.0) IND0=IND0 + NN
        ENDDO
      ENDDO

C ==============================================
  200 CONTINUE
      CLOSE(MT)
      WRITE(LINE,'('' N_refls  :'',I8)') NFOBS
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,'('' N > Fmin :'',I8)') N_FBIG
      CALL MSGDOC(MDOC,LINE) 
      WRITE(LINE,'('' Almn_max,Blmn_max:'',2G16.4)')
     *  ALMN_MAX,BLMN_MAX
      CALL MSGDOC(MDOC,LINE)

c      CALL CLOCK(IHR)
cC     IH(2),IH(3),IH(4),    IH(5),IH(6),IH(7)
cC     sec   min  hour      day   month year
c      WRITE(*,*) 'time:',IHR(4),IHR(3),IHR(2)
C --------------------------------------
      LINE = '                                                  '
      LINE(9:15) = ' L-MAX='
      WRITE(LINE(16:20),'(I3,I2)') LMAXP,LMAX
      LINE(1:4)='ALMN'
      IF(LSTP.EQ.2) THEN
        LINE(5:8) = ' PT '
      ELSE
        LINE(5:8) = ' FR '
      ENDIF
C -------
      IF(FOUR.EQ.'F'.AND.INVER.NE.'P') THEN
        TYPE  = 'ALMN'
      ELSE
        TYPE  = 'ALMS'
      ENDIF
      TYPE  = 'ALMN'
      SCAL  = ARAD
      BTEMP = NSYMZ
      MD    =-ABS(MDOC)-1
      CALL C_CR_WR
      CALL SET_TITLE(MD,RLATT(1),RLATT(2)
     . ,RLATT(3),RLATT(4),RLATT(5),RLATT(6),SCAL,BTEMP,RESMIN,RESMXF
     . ,IDM,IDM,IDM,IDM,IDM,LINE,IERR)

      DO IP=1,NPEAK

      MTOUT = 12
      FILES = NAMEO(IP)

      CALL OWFILE(MD,MTOUT,FILES,TYPE,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERROR: OPEN OUTPUT_FILE /rfcoef/')
        CLOSE(MT)
        RETURN
      ENDIF
      NUMB3    = 0
      IEND3    =-1

      IND0 = 0
      SC   = 1.0      
      SC1  = 1.0      

      DO  LK=1,LMAX1,LSTP
        L    = LK-1
        IF(LMINR.LT.0) THEN
          SIG = FLOAT(LMINR)
          X   = FLOAT(L)
          T   = 1.0/(2.0*SIG*SIG)
          SC  = 1.0 - EXP(-X*X*T)

c          SIG1 = FLOAT(LMAX)
c          T    = 1.0/(2.0*SIG1*SIG1)
c          SC1  = EXP(-X1*X1*T)

          SC = SC*SC1
        ENDIF

        MMAX = LK
        NN   = NMAX(LK)
        DO     MM=1,MMAX
          M = MMAX-MM
          IF(MOD(M,NSYMZ).EQ.0) THEN
            I1 = IND0+1
            I2 = IND0+NN
            DO  N=I1,I2
              JHH = N-I1+1
              JKK = M
              JLL = L
              FAA = ALM(N,IP)*SC
              FBB = BLM(N,IP)*SC
              IF(TYPE.EQ.'ALMN') THEN
                CALL WRT(MTOUT,JHH,JKK,JLL,FAA,FBB,NUMB3,IEND3)
              ELSE
c                SDA = SLM(N)
c                SDB = SDA
c                CALL WABCD(MTOUT,JHH,JKK,JLL,FAA,FBB
c     *                                      ,SDA,SDB,NUMB3,IEND3)
              ENDIF
              IF(MTOUT.LE.0) THEN
                WRITE(LINE,*) ' ERR: write to output file'
                CALL MSGERR(MDOC,LINE)
                CLOSE(MTOUT)
                IERR=1
                GO TO 900
              ENDIF 
            ENDDO
            IND0 = IND0+NN
          ENDIF
        ENDDO
      ENDDO
      IEND3=2
      CALL WRT(MTOUT,JHH,JKK,JLL,FAA,FBB,NUMB3,IEND3)
      CLOSE(MTOUT)

      ENDDO

  900 CONTINUE

      deallocate(ALM,STAT=ISTAT)
      deallocate(BLM,STAT=ISTAT)

  910 CONTINUE

      deallocate(F2BES,STAT=ISTAT)
      deallocate(RHSQ,STAT=ISTAT)
      deallocate(SINTH,STAT=ISTAT)
      deallocate(COTTH,STAT=ISTAT)
      deallocate(PHI,STAT=ISTAT)
      deallocate(PLM1,STAT=ISTAT)
      deallocate(PLM2,STAT=ISTAT)
      deallocate(A,STAT=ISTAT)
      deallocate(B,STAT=ISTAT)
      deallocate(FAC4,STAT=ISTAT)
      deallocate(IH_INP,STAT=ISTAT)
      deallocate(IK_INP,STAT=ISTAT)
      deallocate(IL_INP,STAT=ISTAT)

      RETURN
C ----------------------------
      END

      SUBROUTINE GENER_RF(ITP,FOUR,NGEN,IH,IK,IL,FA,FB,SH
     *                 ,NSYM,ISYM,IPRSYM)
C
C -------------------------------------------
      INTEGER*2 ISYM(5,3,IPRSYM)
      INTEGER   IH(IPRSYM),IK(IPRSYM),IL(IPRSYM)
      REAL      FA(IPRSYM),FB(IPRSYM),SH(3)
      COMMON/COM_FFT_RF/ COSD,SIND,TWOPI
      REAL      COSD(25),SIND(25)
      CHARACTER FOUR*1,ITP*4
C -----
      REAL      TWOPI
      INTEGER   IFIRST
      DATA      IFIRST/0/
C -------------------------------------------
      IF(IFIRST.EQ.0) THEN
        TWOPI   = 8.0*ATAN(1.0)
        AN      = TWOPI/24.
        CS      = COS(AN)
        SS      = SIN(AN)
        COSD(1) = 1.
        SIND(1) = 0.
        DO  I=2,25
          COSD(I) = COSD(I-1)*CS - SIND(I-1)*SS
          SIND(I) = SIND(I-1)*CS + COSD(I-1)*SS
        ENDDO
        IFIRST = 1
      ENDIF

      NGEN = 0

      IH1  = IH(1)     
      IK1  = IK(1)     
      IL1  = IL(1)     
      FB1  = FB(1)     
      FAA  = FA(1)

      IF(ITP.EQ.'COEF') THEN
        IF(FOUR.EQ.'F') THEN
          ITYPE = 0
        ELSE
          ITYPE = 1
          FB1   = 0
        ENDIF
      ELSE
        ITYPE = 1
C        IF(ABS(FAA).GT.1.E-6.AND.ABS(FB1).GT.1.E-6) THEN
C          T1 = FAA
C          T2 = FB1
C        ELSE IF(ABS(FB1).LT.1.E-6) THEN
C          T1 = FAA
C          T2 = FAA
C        ELSE IF(ABS(FAA).LT.1.E-6) THEN
C          T1 = FB1
C          T2 = FB1
C        ENDIF
C        FMOD  = (T1+T2)/2.

        FMOD  = FAA

        FAA   = FMOD*FMOD
        FB1   = 0.0
      ENDIF

      DO  I=1,NSYM

        JH  = ISYM(1,1,I)*IH1 +ISYM(1,2,I)*IK1 +ISYM(1,3,I)*IL1
        JK  = ISYM(2,1,I)*IH1 +ISYM(2,2,I)*IK1 +ISYM(2,3,I)*IL1
        JL  = ISYM(3,1,I)*IH1 +ISYM(3,2,I)*IK1 +ISYM(3,3,I)*IL1
        FBB = FB1      
        IT  = ISYM(4,1,I)*IH1 +ISYM(4,2,I)*IK1 +ISYM(4,3,I)*IL1

        IF(JL.LT.0) THEN
          JH  =-JH
          JK  =-JK
          JL  =-JL
          IT  =-IT        
          FBB =-FBB      
        ELSE IF(JL.EQ.0) THEN
          IF(JK.LT.0) THEN
            JH  =-JH
            JK  =-JK
            IT  =-IT        
            FBB =-FBB      
          ELSE IF(JK.EQ.0) THEN
            IF(JH.LT.0) THEN
              JH  =-JH
              IT  =-IT        
              FBB =-FBB      
            ENDIF
          ENDIF
        ENDIF

        IF(NGEN.GT.0) THEN                   
          DO     L=1,NGEN   
            IF(IH(L).EQ.JH.AND.IK(L).EQ.JK.AND.IL(L).EQ.JL) GO TO 100
          ENDDO
        ENDIF

        NGEN     = NGEN+1

        IH(NGEN) = JH
        IK(NGEN) = JK
        IL(NGEN) = JL

        IF(ITYPE.EQ.1.OR.I.EQ.1) THEN
          FFAA = FAA
          FFBB = FBB
        ELSE
          IF(IT.LT.0) THEN              
            IT = IABS(IT)   
            IT = 24-MOD(IT,24)                  
          ELSE
            IT = MOD(IT,24) 
          ENDIF
          IT       = IT + 1       
          FFAA = FAA*COSD(IT)+FBB*SIND(IT)
          FFBB = FBB*COSD(IT)-FAA*SIND(IT)
        ENDIF

        IF(ITYPE.EQ.0) THEN
          ARG   = -(JH*SH(1)+JK*SH(2)+JL*SH(3))*TWOPI
          COSA  = COS(ARG)
          SINA  = SIN(ARG)
          T     = FFAA*COSA - FFBB*SINA
          FFBB  = FFAA*SINA + FFBB*COSA
          FFAA  = T
        ENDIF

        FA(NGEN) = FFAA
        FB(NGEN) = FFBB

  100   CONTINUE      

      ENDDO

      RETURN
      END

      SUBROUTINE GENER_RF_SAPTF(ITP,FOUR,NGEN,IH,IK,IL,FA,FB,SH
     *                 SHA,SHB,NSYM,ISYM,IPRSYM)
C
C -------------------------------------------
      INTEGER*2 ISYM(5,3,IPRSYM)
      INTEGER   IH(IPRSYM),IK(IPRSYM),IL(IPRSYM)
      REAL      FA(IPRSYM),FB(IPRSYM),SH(3)
      REAL      SHA(IPRSYM),SHB(IPRSYM)
      COMMON/COM_FFT_RF/ COSD,SIND,TWOPI
      REAL      COSD(25),SIND(25)
      CHARACTER FOUR*1,ITP*4
C -----
      REAL      TWOPI
      INTEGER   IFIRST
      DATA      IFIRST/0/
C -------------------------------------------
      IF(IFIRST.EQ.0) THEN
        TWOPI   = 8.0*ATAN(1.0)
        AN      = TWOPI/24.
        CS      = COS(AN)
        SS      = SIN(AN)
        COSD(1) = 1.
        SIND(1) = 0.
        DO  I=2,25
          COSD(I) = COSD(I-1)*CS - SIND(I-1)*SS
          SIND(I) = SIND(I-1)*CS + COSD(I-1)*SS
        ENDDO
        IFIRST = 1
      ENDIF

      NGEN = 0

      IH1  = IH(1)     
      IK1  = IK(1)     
      IL1  = IL(1)     
      FB1  = FB(1)     
      FAA  = FA(1)

      IF(ITP.EQ.'COEF') THEN
        IF(FOUR.EQ.'F') THEN
          ITYPE = 0
        ELSE
          ITYPE = 1
          FB1   = 0
        ENDIF
      ELSE
        ITYPE = 1
C        IF(ABS(FAA).GT.1.E-6.AND.ABS(FB1).GT.1.E-6) THEN
C          T1 = FAA
C          T2 = FB1
C        ELSE IF(ABS(FB1).LT.1.E-6) THEN
C          T1 = FAA
C          T2 = FAA
C        ELSE IF(ABS(FAA).LT.1.E-6) THEN
C          T1 = FB1
C          T2 = FB1
C        ENDIF
C        FMOD  = (T1+T2)/2.

        FMOD  = FAA

        FAA   = FMOD*FMOD
        FB1   = 0.0
      ENDIF

      DO  I=1,NSYM

        JH  = ISYM(1,1,I)*IH1 +ISYM(1,2,I)*IK1 +ISYM(1,3,I)*IL1
        JK  = ISYM(2,1,I)*IH1 +ISYM(2,2,I)*IK1 +ISYM(2,3,I)*IL1
        JL  = ISYM(3,1,I)*IH1 +ISYM(3,2,I)*IK1 +ISYM(3,3,I)*IL1
        FBB = FB1      
        IT  = ISYM(4,1,I)*IH1 +ISYM(4,2,I)*IK1 +ISYM(4,3,I)*IL1

        IF(JL.LT.0) THEN
          JH  =-JH
          JK  =-JK
          JL  =-JL
          IT  =-IT        
          FBB =-FBB      
        ELSE IF(JL.EQ.0) THEN
          IF(JK.LT.0) THEN
            JH  =-JH
            JK  =-JK
            IT  =-IT        
            FBB =-FBB      
          ELSE IF(JK.EQ.0) THEN
            IF(JH.LT.0) THEN
              JH  =-JH
              IT  =-IT        
              FBB =-FBB      
            ENDIF
          ENDIF
        ENDIF

        IF(NGEN.GT.0) THEN                   
          DO     L=1,NGEN   
            IF(IH(L).EQ.JH.AND.IK(L).EQ.JK.AND.IL(L).EQ.JL) GO TO 100
          ENDDO
        ENDIF

        NGEN     = NGEN+1

        IH(NGEN) = JH
        IK(NGEN) = JK
        IL(NGEN) = JL

        IF(ITYPE.EQ.1.OR.I.EQ.1) THEN
          FFAA = FAA
          FFBB = FBB
        ELSE
          IF(IT.LT.0) THEN              
            IT = IABS(IT)   
            IT = 24-MOD(IT,24)                  
          ELSE
            IT = MOD(IT,24) 
          ENDIF
          IT       = IT + 1       
          FFAA = FAA*COSD(IT)+FBB*SIND(IT)
          FFBB = FBB*COSD(IT)-FAA*SIND(IT)
        ENDIF

        IF(ITYPE.EQ.0) THEN
          ARG   = -(JH*SH(1)+JK*SH(2)+JL*SH(3))*TWOPI
          SHA(NGEN)  = COS(ARG)
          SHB(NGEN)  = SIN(ARG)
        ENDIF

        FA(NGEN) = FFAA
        FB(NGEN) = FFBB

  100   CONTINUE      

      ENDDO

      RETURN
      END


      SUBROUTINE SPHBES_RF(MDOC,NMAX,ARGMAX,SBES,IPRLM2,IPRBES,IERR)
C
C     CALC BESSEL FUNCTION
C
      REAL      SBES  (IPRLM2,IPRBES)
      REAL*8 DELARG,ARG,ARG2,SA,CA,V1,V2,V3,DBL
      CHARACTER LINE*80
C -----------------------------------------------
      DELARG = 0.25
      MAXARG = ARGMAX/DELARG+2
      IF(MAXARG.GT.IPRBES) THEN
        WRITE(LINE,*) ' ERR: MAX-ARG OF BESSEL FUNCTION >',IPRBES
        CALL MSGERR(MDOC,LINE)
        IERR=1
        RETURN
      ENDIF
      NMAX1 = NMAX+1
      NMAX2 = NMAX+2
      DO  N=1,NMAX2
      DO  M=1,MAXARG
        SBES(N,M) = 0.0
      ENDDO
      ENDDO
      SBES(1,1) = 1.0
      ARG       = 0.0
      DO  I=2,MAXARG
        ARG  = ARG+DELARG
        ARG2 = ARG*ARG
        SA   = DSIN(ARG)
        CA   = DCOS(ARG)
        V1   = SA/ARG
        V2   = SA/ARG2-CA/ARG
        SBES(1,I) = V1
        SBES(2,I) = V2
        DO  NK=3,NMAX2
          N    = NK-1
          DBL  = 2*N-1
          V3   = DBL*V2/ARG-V1
          SBES(NK,I) = V3
          IF(DABS(V3).LE.1.D-6) GO TO 200
          V1 = V2
          V2 = V3
        ENDDO
  200   CONTINUE
      ENDDO
      RETURN
      END

      SUBROUTINE GET_BZEROS_100(BZ,NMAXP,LMAXP,IERR)
C ------------------------------------------------------
C      REAL    BZ(30,*)
C      1 =<NMAXP=<30, 0=<LMAXP=<60
C ------------------------------------------------------
C     IPRBES=200 --> T2=48.0 ; IPRBES=400 --> T2=98.0
C                    LMAXP=30                 LMAXP=60
C                    NMAXP=15                 NMAXP=30
C
C      PARAMETER ( IPRBES = 400                 )
C      PARAMETER ( IPRLMX = IPRBES*3/20   60    )
C      PARAMETER ( IPRNMX = IPRLMX/2      30    )
C      PARAMETER ( IPRLM2 = IPRLMX+2      62    )
C      REAL    BZEROS(IPRNMX,IPRLM2)
C -------------------------------------------------------
      INTEGER IERR,NMAXP,LMAXP
      REAL    BZ(50,*)
      REAL    BZEROS(50,102)
C -----------------------
      REAL  BZ__1(50),BZ__2(50),BZ__3(50),BZ__4(50),BZ__5(50)
      REAL  BZ__6(50),BZ__7(50),BZ__8(50),BZ__9(50),BZ_10(50)
      REAL  BZ_11(50),BZ_12(50),BZ_13(50),BZ_14(50),BZ_15(50)
      REAL  BZ_16(50),BZ_17(50),BZ_18(50),BZ_19(50),BZ_20(50)
      REAL  BZ_21(50),BZ_22(50),BZ_23(50),BZ_24(50),BZ_25(50)
      REAL  BZ_26(50),BZ_27(50),BZ_28(50),BZ_29(50),BZ_30(50)
      REAL  BZ_31(50),BZ_32(50),BZ_33(50),BZ_34(50),BZ_35(50)
      REAL  BZ_36(50),BZ_37(50),BZ_38(50),BZ_39(50),BZ_40(50)
      REAL  BZ_41(50),BZ_42(50),BZ_43(50),BZ_44(50),BZ_45(50)
      REAL  BZ_46(50),BZ_47(50),BZ_48(50),BZ_49(50),BZ_50(50)
      REAL  BZ_51(50),BZ_52(50),BZ_53(50),BZ_54(50),BZ_55(50)
      REAL  BZ_56(50),BZ_57(50),BZ_58(50),BZ_59(50),BZ_60(50)
      REAL  BZ_61(50),BZ_62(50),BZ_63(50),BZ_64(50),BZ_65(50)
      REAL  BZ_66(50),BZ_67(50),BZ_68(50),BZ_69(50),BZ_70(50)
      REAL  BZ_71(50),BZ_72(50),BZ_73(50),BZ_74(50),BZ_75(50)
      REAL  BZ_76(50),BZ_77(50),BZ_78(50),BZ_79(50),BZ_80(50)
      REAL  BZ_81(50),BZ_82(50),BZ_83(50),BZ_84(50),BZ_85(50)
      REAL  BZ_86(50),BZ_87(50),BZ_88(50),BZ_89(50),BZ_90(50)
      REAL  BZ_91(50),BZ_92(50),BZ_93(50),BZ_94(50),BZ_95(50)
      REAL  BZ_96(50),BZ_97(50),BZ_98(50),BZ_99(50),BZ100(50)
      REAL  BZ101(50),BZ102(50)
C ------------------------
C   L=   0
      DATA BZ__1 /
     *    1.570796,    4.712389,    7.853982,   10.995575,   14.137167,
     *   17.278761,   20.420353,   23.561945,   26.703539,   29.845131,
     *   32.986725,   36.128315,   39.269909,   42.411503,   45.553093,
     *   48.694687,   51.836281,   54.977875,   58.119465,   61.261059,
     *   64.402649,   67.544243,   70.685837,   73.827431,   76.969025,
     *   80.110619,   83.252205,   86.393799,   89.535393,   92.676987,
     *   95.818581,   98.960175,  102.101761,  105.243355,  108.384949,
     *  111.526543,  114.668137,  117.809731,  120.951317,  124.092911,
     *  127.234505,  130.376099,  133.517685,  136.659286,  139.800873,
     *  142.942474,  146.084061,  149.225662,  152.367249,  155.508835 
     * /
C   L=   1
      DATA BZ__2 /
     *    3.141593,    6.283185,    9.424778,   12.566371,   15.707963,
     *   18.849556,   21.991148,   25.132742,   28.274334,   31.415926,
     *   34.557518,   37.699112,   40.840706,   43.982296,   47.123890,
     *   50.265484,   53.407074,   56.548668,   59.690262,   62.831852,
     *   65.973442,   69.115036,   72.256630,   75.398224,   78.539818,
     *   81.681412,   84.822998,   87.964592,   91.106186,   94.247780,
     *   97.389374,  100.530968,  103.672554,  106.814148,  109.955742,
     *  113.097336,  116.238930,  119.380524,  122.522110,  125.663704,
     *  128.805298,  131.946884,  135.088486,  138.230072,  141.371674,
     *  144.513260,  147.654861,  150.796448,  153.938034,  157.079636 
     * /
C   L=   2
      DATA BZ__3 /
     *    4.493410,    7.725252,   10.904121,   14.066194,   17.220755,
     *   20.371304,   23.519453,   26.666054,   29.811600,   32.956390,
     *   36.100624,   39.244431,   42.387913,   45.531136,   48.674145,
     *   51.816982,   54.959679,   58.102253,   61.244732,   64.387123,
     *   67.529434,   70.671684,   73.813881,   76.956024,   80.098129,
     *   83.240196,   86.382225,   89.524223,   92.666191,   95.808136,
     *   98.950066,  102.091965,  105.233849,  108.375717,  111.517570,
     *  114.659409,  117.801239,  120.943047,  124.084854,  127.226646,
     *  130.368423,  133.510193,  136.651962,  139.793716,  142.935471,
     *  146.077209,  149.218948,  152.360687,  155.502411,  158.644119 
     * /
C   L=   3
      DATA BZ__4 /
     *    5.763459,    9.095012,   12.322941,   15.514603,   18.689035,
     *   21.853874,   25.012804,   28.167830,   31.320141,   34.470490,
     *   37.619366,   40.767117,   43.913982,   47.060143,   50.205727,
     *   53.350845,   56.495567,   59.639957,   62.784069,   65.927940,
     *   69.071602,   72.215088,   75.358414,   78.501602,   81.644661,
     *   84.787621,   87.930473,   91.073250,   94.215935,   97.358559,
     *  100.501114,  103.643616,  106.786057,  109.928452,  113.070801,
     *  116.213112,  119.355385,  122.497620,  125.639832,  128.781998,
     *  131.924149,  135.066269,  138.208374,  141.350449,  144.492493,
     *  147.634537,  150.776550,  153.918549,  157.060532,  160.202499 
     * /
C   L=   4
      DATA BZ__5 /
     *    6.987932,   10.417118,   13.698023,   16.923622,   20.121807,
     *   23.304247,   26.476763,   29.642605,   32.803734,   35.961407,
     *   39.116470,   42.269516,   45.420963,   48.571129,   51.720249,
     *   54.868500,   58.016029,   61.162945,   64.309341,   67.455284,
     *   70.600838,   73.746063,   76.890984,   80.035637,   83.180069,
     *   86.324287,   89.468323,   92.612190,   95.755913,   98.899498,
     *  102.042961,  105.186310,  108.329559,  111.472710,  114.615784,
     *  117.758774,  120.901688,  124.044540,  127.187325,  130.330063,
     *  133.472733,  136.615356,  139.757935,  142.900482,  146.042969,
     *  149.185425,  152.327850,  155.470245,  158.612595,  161.754929 
     * /
C   L=   5
      DATA BZ__6 /
     *    8.182562,   11.704907,   15.039664,   18.301256,   21.525417,
     *   24.727566,   27.915577,   31.093933,   34.265388,   37.431736,
     *   40.594189,   43.753605,   46.910606,   50.065651,   53.219097,
     *   56.371208,   59.522202,   62.672245,   65.821480,   68.970009,
     *   72.117935,   75.265335,   78.412262,   81.558777,   84.704926,
     *   87.850746,   90.996277,   94.141541,   97.286568,  100.431381,
     *  103.575996,  106.720436,  109.864716,  113.008842,  116.152824,
     *  119.296692,  122.440437,  125.584076,  128.727615,  131.871048,
     *  135.014420,  138.157684,  141.300888,  144.444031,  147.587097,
     *  150.730103,  153.873047,  157.015945,  160.158783,  163.301575 
     * /
C   L=   6
      DATA BZ__7 /
     *    9.355812,   12.966530,   16.354710,   19.653152,   22.904551,
     *   26.127750,   29.332563,   32.524662,   35.707577,   38.883633,
     *   42.054417,   45.221066,   48.384403,   51.545052,   54.703484,
     *   57.860062,   61.015083,   64.168777,   67.321335,   70.472900,
     *   73.623611,   76.773575,   79.922874,   83.071587,   86.219780,
     *   89.367500,   92.514809,   95.661736,   98.808327,  101.954605,
     *  105.100609,  108.246353,  111.391861,  114.537148,  117.682243,
     *  120.827156,  123.971901,  127.116486,  130.260925,  133.405243,
     *  136.549423,  139.693481,  142.837448,  145.981293,  149.125061,
     *  152.268723,  155.412308,  158.555817,  161.699249,  164.842606 
     * /
C   L=   7
      DATA BZ__8 /
     *   10.512836,   14.207393,   17.647974,   20.983463,   24.262768,
     *   27.507868,   30.730381,   33.937107,   37.132332,   40.318893,
     *   43.498756,   46.673332,   49.843655,   53.010502,   56.174477,
     *   59.336040,   62.495571,   65.653358,   68.809654,   71.964653,
     *   75.118515,   78.271385,   81.423378,   84.574593,   87.725121,
     *   90.875015,   94.024361,   97.173195,  100.321579,  103.469543,
     *  106.617134,  109.764374,  112.911308,  116.057945,  119.204315,
     *  122.350441,  125.496338,  128.642029,  131.787521,  134.932831,
     *  138.077972,  141.222946,  144.367783,  147.512482,  150.657043,
     *  153.801483,  156.945816,  160.090027,  163.234161,  166.378174 
     * /
C   L=   8
      DATA BZ__9 /
     *   11.657032,   15.431290,   18.922998,   22.295347,   25.602856,
     *   28.870373,   32.111195,   35.333195,   38.541367,   41.739052,
     *   44.928589,   48.111656,   51.289490,   54.463036,   57.633018,
     *   60.800011,   63.964458,   67.126732,   70.287132,   73.445900,
     *   76.603241,   79.759323,   82.914299,   86.068291,   89.221397,
     *   92.373718,   95.525330,   98.676292,  101.826675,  104.976524,
     *  108.125900,  111.274826,  114.423347,  117.571503,  120.719307,
     *  123.866798,  127.014000,  130.160919,  133.307602,  136.454041,
     *  139.600250,  142.746277,  145.892105,  149.037750,  152.183228,
     *  155.328537,  158.473709,  161.618744,  164.763641,  167.908432 
     * /
C   L=   9
      DATA BZ_10 /
     *   12.790782,   16.641003,   20.182470,   23.591274,   26.927040,
     *   30.217262,   33.476799,   36.714531,   39.936127,   43.145424,
     *   46.345104,   49.537117,   52.722900,   55.903564,   59.079952,
     *   62.252743,   65.422470,   68.589561,   71.754379,   74.917221,
     *   78.078323,   81.237892,   84.396111,   87.553123,   90.709045,
     *   93.864006,   97.018089,  100.171387,  103.323959,  106.475883,
     *  109.627205,  112.777985,  115.928261,  119.078079,  122.227470,
     *  125.376472,  128.525101,  131.673401,  134.821381,  137.969070,
     *  141.116486,  144.263657,  147.410583,  150.557281,  153.703766,
     *  156.850067,  159.996170,  163.142105,  166.287872,  169.433487 
     * /
C   L=  10
      DATA BZ_11 /
     *   13.915823,   17.838644,   21.428488,   24.873215,   28.237135,
     *   31.550188,   34.828697,   38.082478,   41.317863,   44.539146,
     *   47.749344,   50.950672,   54.144768,   57.332893,   60.516022,
     *   63.694931,   66.870239,   70.042450,   73.211967,   76.379143,
     *   79.544266,   82.707558,   85.869247,   89.029495,   92.188446,
     *   95.346245,   98.502998,  101.658806,  104.813744,  107.967903,
     *  111.121346,  114.274132,  117.426308,  120.577934,  123.729042,
     *  126.879684,  130.029877,  133.179672,  136.329071,  139.478119,
     *  142.626846,  145.775269,  148.923386,  152.071243,  155.218842,
     *  158.366196,  161.513336,  164.660248,  167.806976,  170.953506 
     * /
C   L=  11
      DATA BZ_12 /
     *   15.033469,   19.025854,   22.662720,   26.142767,   29.534634,
     *   32.870533,   36.168156,   39.438213,   42.687653,   45.921204,
     *   49.142220,   52.353165,   55.555870,   58.751751,   61.941906,
     *   65.127205,   68.308365,   71.485939,   74.660400,   77.832153,
     *   81.001511,   84.168747,   87.334114,   90.497795,   93.659966,
     *   96.820786,   99.980377,  103.138863,  106.296333,  109.452881,
     *  112.608582,  115.763512,  118.917732,  122.071297,  125.224251,
     *  128.376648,  131.528519,  134.679916,  137.830856,  140.981369,
     *  144.131500,  147.281265,  150.430695,  153.579788,  156.728577,
     *  159.877090,  163.025330,  166.173325,  169.321075,  172.468597 
     * /
C   L=  12
      DATA BZ_13 /
     *   16.144743,   20.203943,   23.886530,   27.401258,   30.820793,
     *   34.179474,   37.496273,   40.782745,   44.046425,   47.292465,
     *   50.524540,   53.745342,   56.956905,   60.160786,   63.358208,
     *   66.550140,   69.737373,   72.920532,   76.100159,   79.276688,
     *   82.450485,   85.621857,   88.791077,   91.958374,   95.123940,
     *   98.287941,  101.450531,  104.611839,  107.771988,  110.931068,
     *  114.089172,  117.246376,  120.402756,  123.558380,  126.713303,
     *  129.867569,  133.021225,  136.174332,  139.326904,  142.479004,
     *  145.630630,  148.781845,  151.932648,  155.083069,  158.233154,
     *  161.382889,  164.532318,  167.681458,  170.830307,  173.978897 
     * /
C   L=  13
      DATA BZ_14 /
     *   17.250454,   21.373972,   25.101038,   28.649796,   32.096676,
     *   35.478012,   38.813988,   42.116959,   45.395008,   48.653706,
     *   51.897018,   55.127880,   58.348499,   61.560585,   64.765480,
     *   67.964241,   71.157745,   74.346695,   77.531670,   80.713158,
     *   83.891571,   87.067253,   90.240494,   93.411560,   96.580673,
     *   99.748009,  102.913742,  106.078026,  109.240974,  112.402710,
     *  115.563339,  118.722946,  121.881607,  125.039406,  128.196396,
     *  131.352646,  134.508194,  137.663101,  140.817413,  143.971161,
     *  147.124390,  150.277115,  153.429398,  156.581238,  159.732666,
     *  162.883728,  166.034409,  169.184769,  172.334793,  175.484528 
     * /
C   L=  14
      DATA BZ_15 /
     *   18.351261,   22.536818,   26.307182,   29.889317,   33.363190,
     *   36.767017,   40.122124,   43.441624,   46.734131,   50.005600,
     *   53.260296,   56.501369,   59.731216,   62.951679,   66.164215,
     *   69.369987,   72.569939,   75.764839,   78.955330,   82.141945,
     *   85.325127,   88.505264,   91.682686,   94.857674,   98.030464,
     *  101.201271,  104.370277,  107.537651,  110.703537,  113.868057,
     *  117.031319,  120.193436,  123.354485,  126.514557,  129.673721,
     *  132.832047,  135.989578,  139.146393,  142.302521,  145.458008,
     *  148.612915,  151.767258,  154.921082,  158.074417,  161.227280,
     *  164.379715,  167.531738,  170.683380,  173.834656,  176.985580 
     * /
C   L=  15
      DATA BZ_16 /
     *   19.447702,   23.693209,   27.505753,   31.120621,   34.621124,
     *   38.047245,   41.421398,   44.757423,   48.064434,   51.348763,
     *   54.614948,   57.866364,   61.105572,   64.334557,   67.554886,
     *   70.767815,   73.974358,   77.175362,   80.371506,   83.563385,
     *   86.751488,   89.936218,   93.117950,   96.296982,   99.473587,
     *  102.647987,  105.820389,  108.990974,  112.159904,  115.327309,
     *  118.493317,  121.658043,  124.821587,  127.984032,  131.145462,
     *  134.305954,  137.465561,  140.624359,  143.782394,  146.939713,
     *  150.096375,  153.252396,  156.407837,  159.562744,  162.717117,
     *  165.871002,  169.024414,  172.177414,  175.329987,  178.482178 
     * /
C   L=  16
      DATA BZ_17 /
     *   20.540230,   24.843763,   28.697432,   32.344402,   35.871155,
     *   39.319355,   42.712452,   46.064964,   49.386501,   52.683739,
     *   55.961494,   59.223351,   62.472027,   65.709648,   68.937897,
     *   72.158104,   75.371376,   78.578606,   81.780540,   84.977814,
     *   88.170952,   91.360413,   94.546570,   97.729767,  100.910294,
     *  104.088402,  107.264305,  110.438210,  113.610283,  116.780678,
     *  119.949532,  123.116966,  126.283089,  129.447998,  132.611786,
     *  135.774521,  138.936295,  142.097153,  145.257172,  148.416397,
     *  151.574875,  154.732666,  157.889816,  161.046326,  164.202286,
     *  167.357681,  170.512573,  173.666962,  176.820908,  179.974411 
     * /
C   L=  17
      DATA BZ_18 /
     *   21.629221,   25.989008,   29.882799,   33.561264,   37.113884,
     *   40.583935,   43.995846,   47.364788,   50.700844,   54.011021,
     *   57.300404,   60.572769,   63.831009,   67.077370,   70.313637,
     *   73.541237,   76.761337,   79.974915,   83.182755,   86.385536,
     *   89.583824,   92.778107,   95.968803,   99.156273,  102.340836,
     *  105.522743,  108.702255,  111.879578,  115.054893,  118.228371,
     *  121.400154,  124.570389,  127.739174,  130.906631,  134.072861,
     *  137.237930,  140.401932,  143.564926,  146.727005,  149.888199,
     *  153.048584,  156.208206,  159.367096,  162.525314,  165.682907,
     *  168.839874,  171.996292,  175.152161,  178.307526,  181.462402 
     * /
C   L=  18
      DATA BZ_19 /
     *   22.715002,   27.129398,   31.062368,   34.771732,   38.349842,
     *   41.841507,   45.272083,   48.657387,   52.007927,   55.331059,
     *   58.632103,   61.915035,   65.182907,   68.438080,   71.682457,
     *   74.917534,   78.144577,   81.364586,   84.578430,   87.786812,
     *   90.990356,   94.189568,   97.384903,  100.576744,  103.765427,
     *  106.951241,  110.134445,  113.315269,  116.493919,  119.670563,
     *  122.845367,  126.018471,  129.190002,  132.360092,  135.528824,
     *  138.696304,  141.862610,  145.027832,  148.192032,  151.355270,
     *  154.517624,  157.679123,  160.839844,  163.999817,  167.159088,
     *  170.317703,  173.475693,  176.633087,  179.789917,  182.946228 
     * /
C   L=  19
      DATA BZ_20 /
     *   23.797850,   28.265329,   32.236580,   35.976273,   39.579498,
     *   43.092525,   46.541622,   49.943192,   53.308182,   56.644253,
     *   59.956978,   63.250519,   66.528069,   69.792130,   73.044678,
     *   76.287323,   79.521378,   82.747910,   85.967842,   89.181923,
     *   92.390808,   95.595039,   98.795097,  101.991394,  105.184280,
     *  108.374084,  111.561066,  114.745483,  117.927536,  121.107430,
     *  124.285332,  127.461388,  130.635742,  133.808533,  136.979843,
     *  140.149796,  143.318481,  146.485977,  149.652359,  152.817719,
     *  155.982086,  159.145538,  162.308136,  165.469925,  168.630951,
     *  171.791260,  174.950882,  178.109848,  181.268219,  184.425995 
     * /
C   L=  20
      DATA BZ_21 /
     *   24.878006,   29.397142,   33.405830,   37.175297,   40.803268,
     *   44.337414,   47.804863,   51.222599,   54.601982,   57.950977,
     *   61.275391,   64.579559,   67.866837,   71.139824,   74.400612,
     *   77.650887,   80.892021,   84.125160,   87.351250,   90.571106,
     *   93.785408,   96.994736,  100.199593,  103.400429,  106.597610,
     *  109.791473,  112.982315,  116.170387,  119.355934,  122.539146,
     *  125.720207,  128.899292,  132.076538,  135.252090,  138.426056,
     *  141.598541,  144.769669,  147.939499,  151.108139,  154.275650,
     *  157.442108,  160.607574,  163.772110,  166.935760,  170.098587,
     *  173.260635,  176.421936,  179.582535,  182.742477,  185.901794 
     * /
C   L=  21
      DATA BZ_22 /
     *   25.955681,   30.525146,   34.570461,   38.369175,   42.021530,
     *   45.576542,   49.062180,   52.495975,   55.889683,   59.251572,
     *   62.587662,   65.902473,   69.199501,   72.481461,   75.750534,
     *   79.008492,   82.256767,   85.496567,   88.728897,   91.954590,
     *   95.174377,   98.388878,  101.598610,  104.804047,  108.005592,
     *  111.203590,  114.398354,  117.590164,  120.779259,  123.965858,
     *  127.150154,  130.332336,  133.512527,  136.690903,  139.867584,
     *  143.042679,  146.216293,  149.388535,  152.559479,  155.729218,
     *  158.897812,  162.065338,  165.231857,  168.397430,  171.562103,
     *  174.725937,  177.888977,  181.051254,  184.212814,  187.373703 
     * /
C   L=  22
      DATA BZ_23 /
     *   27.031061,   31.649609,   35.730789,   39.558231,   43.234615,
     *   46.810253,   50.313900,   53.763641,   57.171604,   60.546341,
     *   63.894093,   67.219551,   70.526344,   73.817299,   77.094704,
     *   80.360382,   83.615860,   86.862381,   90.100990,   93.332596,
     *   96.557930,   99.777657,  102.992332,  106.202438,  109.408409,
     *  112.610603,  115.809357,  119.004967,  122.197678,  125.387726,
     *  128.575317,  131.760635,  134.943863,  138.125122,  141.304565,
     *  144.482315,  147.658493,  150.833176,  154.006485,  157.178482,
     *  160.349274,  163.518921,  166.687469,  169.855011,  173.021591,
     *  176.187271,  179.352081,  182.516083,  185.679306,  188.841797 
     * /
C   L=  23
      DATA BZ_24 /
     *   28.104313,   32.770767,   36.887089,   40.742771,   44.442837,
     *   48.038849,   51.560337,   55.025902,   58.448040,   61.835575,
     *   65.194962,   68.531067,   71.847626,   75.147606,   78.433357,
     *   81.706802,   84.969513,   88.222801,   91.467758,   94.705315,
     *   97.936256,  101.161270,  104.380943,  107.595779,  110.806229,
     *  114.012680,  117.215485,  120.414948,  123.611336,  126.804893,
     *  129.995834,  133.184357,  136.370651,  139.554855,  142.737122,
     *  145.917587,  149.096359,  152.273560,  155.449265,  158.623596,
     *  161.796631,  164.968430,  168.139069,  171.308624,  174.477142,
     *  177.644699,  180.811340,  183.977097,  187.142029,  190.306183 
     * /
C   L=  24
      DATA BZ_25 /
     *   29.175579,   33.888840,   38.039608,   41.923054,   45.646465,
     *   49.262611,   52.801769,   56.283028,   59.719257,   63.119537,
     *   66.490524,   69.837250,   73.163589,   76.472603,   79.766731,
     *   83.047974,   86.317955,   89.578041,   92.829384,   96.072937,
     *   99.309540,  102.539894,  105.764610,  108.984230,  112.199219,
     *  115.409981,  118.616890,  121.820251,  125.020370,  128.217484,
     *  131.411835,  134.603622,  137.793030,  140.980225,  144.165359,
     *  147.348587,  150.530014,  153.709763,  156.887939,  160.064636,
     *  163.239944,  166.413956,  169.586731,  172.758331,  175.928848,
     *  179.098328,  182.266815,  185.434387,  188.601074,  191.766907 
     * /
C   L=  25
      DATA BZ_26 /
     *   30.244991,   35.004017,   39.188576,   43.099331,   46.845757,
     *   50.481800,   54.038445,   57.535278,   60.985504,   64.398468,
     *   67.781021,   71.138351,   74.474464,   77.792511,   81.095032,
     *   84.384087,   87.661369,   90.928299,   94.186058,   97.435654,
     *  100.677956,  103.913689,  107.143501,  110.367950,  113.587524,
     *  116.802643,  120.013702,  123.221024,  126.424919,  129.625641,
     *  132.823441,  136.018539,  139.211121,  142.401352,  145.589417,
     *  148.775436,  151.959564,  155.141907,  158.322586,  161.501709,
     *  164.679337,  167.855591,  171.030533,  174.204254,  177.376785,
     *  180.548233,  183.718628,  186.888031,  190.056503,  193.224075 
     * /
C   L=  26
      DATA BZ_27 /
     *   31.312668,   36.116474,   40.334194,   44.271816,   48.040943,
     *   51.696644,   55.270603,   58.782879,   62.247013,   65.672592,
     *   69.066673,   72.434586,   75.780449,   79.107536,   82.418449,
     *   85.715340,   88.999947,   92.273743,   95.537949,   98.793625,
     *  102.041656,  105.282814,  108.517769,  111.747086,  114.971291,
     *  118.190819,  121.406067,  124.617393,  127.825111,  131.029495,
     *  134.230789,  137.429230,  140.625015,  143.818344,  147.009369,
     *  150.198242,  153.385117,  156.570099,  159.753326,  162.934891,
     *  166.114899,  169.293442,  172.470596,  175.646439,  178.821045,
     *  181.994492,  185.166824,  188.338104,  191.508392,  194.677734 
     * /
C   L=  27
      DATA BZ_28 /
     *   32.378712,   37.226368,   41.476646,   45.440716,   49.232231,
     *   52.907360,   56.498463,   60.026054,   63.503998,   66.942123,
     *   70.347679,   73.726135,   77.081749,   80.417862,   83.737183,
     *   87.041908,   90.333862,   93.614540,   96.885231,  100.147018,
     *  103.400818,  106.647430,  109.887550,  113.121788,  116.350655,
     *  119.574631,  122.794113,  126.009483,  129.221069,  132.429138,
     *  135.633972,  138.835815,  142.034866,  145.231308,  148.425339,
     *  151.617111,  154.806763,  157.994431,  161.180237,  164.364288,
     *  167.546707,  170.727570,  173.906967,  177.084991,  180.261703,
     *  183.437180,  186.611496,  189.784698,  192.956833,  196.127975 
     * /
C   L=  28
      DATA BZ_29 /
     *   33.443222,   38.333839,   42.616112,   46.606216,   50.419819,
     *   54.114147,   57.722225,   61.264999,   64.756653,   68.207260,
     *   71.624237,   75.013206,   78.378532,   81.723671,   85.051399,
     *   88.363976,   91.663277,   94.950867,   98.228058,  101.495972,
     *  104.755569,  108.007675,  111.252998,  114.492180,  117.725746,
     *  120.954201,  124.177963,  127.397415,  130.612900,  133.824707,
     *  137.033127,  140.238388,  143.440735,  146.640350,  149.837418,
     *  153.032104,  156.224579,  159.414963,  162.603394,  165.789993,
     *  168.974838,  172.158066,  175.339752,  178.519989,  181.698837,
     *  184.876389,  188.052704,  191.227844,  194.401886,  197.574860 
     * /
C   L=  29
      DATA BZ_30 /
     *   34.506287,   39.439030,   43.752735,   47.768490,   51.603882,
     *   55.317192,   58.942070,   62.499897,   66.005165,   69.468178,
     *   72.896523,   76.295967,   79.670990,   83.025139,   86.361259,
     *   89.681686,   92.988350,   96.282860,   99.566574,  102.840645,
     *  106.106056,  109.363678,  112.614243,  115.858391,  119.096703,
     *  122.329666,  125.557739,  128.781311,  132.000717,  135.216309,
     *  138.428329,  141.637070,  144.842743,  148.045547,  151.245697,
     *  154.443359,  157.638687,  160.831833,  164.022919,  167.212067,
     *  170.399399,  173.585022,  176.769028,  179.951492,  183.132523,
     *  186.312180,  189.490524,  192.667648,  195.843597,  199.018433 
     * /
C   L=  30
      DATA BZ_31 /
     *   35.567982,   40.542046,   44.886669,   48.927685,   52.784592,
     *   56.516659,   60.158173,   63.730927,   67.249710,   70.725044,
     *   74.164703,   77.574585,   80.959274,   84.322411,   87.666916,
     *   90.995201,   94.309227,   97.610672,  100.900917,  104.181160,
     *  107.452415,  110.715576,  113.971397,  117.220551,  120.463623,
     *  123.701134,  126.933540,  130.161255,  133.384644,  136.604034,
     *  139.819702,  143.031937,  146.240967,  149.447021,  152.650284,
     *  155.850937,  159.049149,  162.245087,  165.438858,  168.630600,
     *  171.820450,  175.008499,  178.194855,  181.379593,  184.562820,
     *  187.744614,  190.925034,  194.104172,  197.282059,  200.458786 
     * /
C   L=  31
      DATA BZ_32 /
     *   36.628380,   41.643009,   46.018040,   50.083954,   53.962093,
     *   57.712711,   61.370693,   64.958244,   68.490440,   71.978027,
     *   75.428940,   78.849213,   82.243538,   85.615639,   88.968529,
     *   92.304649,   95.626053,   98.934425,  102.231216,  105.517647,
     *  108.794769,  112.063484,  115.324585,  118.578766,  121.826630,
     *  125.068710,  128.305496,  131.537384,  134.764771,  137.987991,
     *  141.207336,  144.423111,  147.635529,  150.844849,  154.051254,
     *  157.254929,  160.456070,  163.654816,  166.851303,  170.045685,
     *  173.238068,  176.428574,  179.617310,  182.804352,  185.989807,
     *  189.173767,  192.356293,  195.537445,  198.717331,  201.895981 
     * /
C   L=  32
      DATA BZ_33 /
     *   37.687550,   42.742012,   47.146969,   51.237431,   55.136532,
     *   58.905495,   62.579781,   66.181999,   69.727509,   73.227272,
     *   76.689377,   80.119995,   83.523926,   86.904968,   90.266220,
     *   93.610184,   96.938950,  100.254265,  103.557610,  106.850235,
     *  110.133232,  113.407524,  116.673927,  119.933159,  123.185837,
     *  126.432510,  129.673676,  132.909775,  136.141190,  139.368271,
     *  142.591324,  145.810654,  149.026505,  152.239105,  155.448685,
     *  158.655426,  161.859512,  165.061096,  168.260345,  171.457382,
     *  174.652328,  177.845322,  181.036453,  184.225845,  187.413559,
     *  190.599701,  193.784348,  196.967575,  200.149460,  203.330048 
     * /
C   L=  33
      DATA BZ_34 /
     *   38.745548,   43.839157,   48.273571,   52.388233,   56.308044,
     *   60.095142,   63.785580,   67.402336,   70.961060,   74.472916,
     *   77.946152,   81.387070,   84.800568,   88.190536,   91.560127,
     *   94.911919,   98.248047,  101.570305,  104.880203,  108.179039,
     *  111.467918,  114.747803,  118.019524,  121.283821,  124.541336,
     *  127.792625,  131.038208,  134.278534,  137.513992,  140.744965,
     *  143.971756,  147.194656,  150.413956,  153.629883,  156.842667,
     *  160.052490,  163.259552,  166.464020,  169.666031,  172.865753,
     *  176.063309,  179.258820,  182.452377,  185.644119,  188.834122,
     *  192.022491,  195.209290,  198.394608,  201.578506,  204.761078 
     * /
C   L=  34
      DATA BZ_35 /
     *   39.802441,   44.934521,   49.397945,   53.536488,   57.476749,
     *   61.281788,   64.988213,   68.619385,   72.191223,   75.715088,
     *   79.199402,   82.650566,   86.073593,   89.472450,   92.850372,
     *   96.209976,   99.553459,  102.882660,  106.199120,  109.504166,
     *  112.798943,  116.084427,  119.361488,  122.630867,  125.893227,
     *  129.149155,  132.399185,  135.643753,  138.883286,  142.118164,
     *  145.348709,  148.575226,  151.798004,  155.017273,  158.233276,
     *  161.446213,  164.656281,  167.863647,  171.068466,  174.270889,
     *  177.471069,  180.669113,  183.865143,  187.059265,  190.251572,
     *  193.442184,  196.631149,  199.818588,  203.004547,  206.189102 
     * /
C   L=  35
      DATA BZ_36 /
     *   40.858273,   46.028191,   50.520199,   54.682293,   58.642761,
     *   62.465546,   66.187805,   69.833275,   73.418129,   76.953926,
     *   80.449242,   83.910606,   87.343124,   90.750847,   94.137070,
     *   97.504478,  100.855309,  104.191437,  107.514458,  110.825729,
     *  114.126404,  117.417503,  120.699905,  123.974380,  127.241615,
     *  130.502197,  133.756668,  137.005508,  140.249146,  143.487946,
     *  146.722275,  149.952423,  153.178696,  156.401337,  159.620590,
     *  162.836670,  166.049759,  169.260040,  172.467682,  175.672852,
     *  178.875671,  182.076279,  185.274780,  188.471313,  191.665970,
     *  194.858841,  198.050018,  201.239578,  204.427612,  207.614197 
     * /
C   L=  36
      DATA BZ_37 /
     *   41.913090,   47.120239,   51.640411,   55.825756,   59.806190,
     *   63.646534,   67.384476,   71.044113,   74.641884,   78.189537,
     *   81.695793,   85.167305,   88.609268,   92.025826,   95.420326,
     *   98.795525,  102.153694,  105.496750,  108.826332,  112.143814,
     *  115.450401,  118.747124,  122.034882,  125.314468,  128.586578,
     *  131.851837,  135.110779,  138.363907,  141.611649,  144.854401,
     *  148.092529,  151.326340,  154.556122,  157.782166,  161.004684,
     *  164.223907,  167.440048,  170.653275,  173.863770,  177.071701,
     *  180.277191,  183.480377,  186.681396,  189.880356,  193.077362,
     *  196.272522,  199.465912,  202.657639,  205.847778,  209.036407 
     * /
C   L=  37
      DATA BZ_38 /
     *   42.966946,   48.210735,   52.758675,   56.966965,   60.967133,
     *   64.824852,   68.578331,   72.252014,   75.862602,   79.422028,
     *   82.939163,   86.420776,   89.872147,   93.297508,   96.700264,
     *  100.083221,  103.448715,  106.798698,  110.134834,  113.458534,
     *  116.771034,  120.073380,  123.366501,  126.651207,  129.928223,
     *  133.198151,  136.461578,  139.719009,  142.970886,  146.217606,
     *  149.459549,  152.697021,  155.930359,  159.159805,  162.385620,
     *  165.608017,  168.827225,  172.043427,  175.256790,  178.467499,
     *  181.675674,  184.881470,  188.085022,  191.286423,  194.485809,
     *  197.683273,  200.878922,  204.072830,  207.265091,  210.455780 
     * /
C   L=  38
      DATA BZ_39 /
     *   44.019875,   49.299744,   53.875061,   58.106014,   62.125690,
     *   66.000595,   69.769463,   73.457085,   77.080391,   80.651512,
     *   84.179459,   87.671112,   91.131859,   94.565979,   97.976967,
     *  101.367668,  104.740471,  108.097366,  111.440056,  114.769974,
     *  118.088387,  121.396362,  124.694855,  127.984688,  131.266602,
     *  134.541229,  137.809158,  141.070908,  144.326920,  147.577637,
     *  150.823395,  154.064575,  157.301468,  160.534332,  163.763458,
     *  166.989059,  170.211365,  173.430542,  176.646805,  179.860306,
     *  183.071198,  186.279617,  189.485703,  192.689590,  195.891373,
     *  199.091171,  202.289078,  205.485199,  208.679596,  211.872360 
     * /
C   L=  39
      DATA BZ_40 /
     *   45.071922,   50.387325,   54.989651,   59.242981,   63.281944,
     *   67.173874,   70.957985,   74.659416,   78.295349,   81.878090,
     *   85.416779,   88.918427,   92.388489,   95.831345,   99.250534,
     *  102.648964,  106.029060,  109.392860,  112.742088,  116.078224,
     *  119.402542,  122.716156,  126.020020,  129.314987,  132.601822,
     *  135.881149,  139.153595,  142.419662,  145.679840,  148.934555,
     *  152.184174,  155.429047,  158.669510,  161.905838,  165.138290,
     *  168.367096,  171.592499,  174.814697,  178.033859,  181.250183,
     *  184.463806,  187.674866,  190.883530,  194.089905,  197.294113,
     *  200.496262,  203.696457,  206.894775,  210.091339,  213.286209 
     * /
C   L=  40
      DATA BZ_41 /
     *   46.123119,   51.473537,   56.102512,   60.377945,   64.435982,
     *   68.344757,   72.143974,   75.859108,   79.507568,   83.101837,
     *   86.651215,   90.162796,   93.642143,   97.093697,  100.521057,
     *  103.927193,  107.314568,  110.685257,  114.041016,  117.383362,
     *  120.713593,  124.032837,  127.342087,  130.642197,  133.933945,
     *  137.217987,  140.494949,  143.765366,  147.029709,  150.288437,
     *  153.541916,  156.790512,  160.034561,  163.274353,  166.510147,
     *  169.742203,  172.970718,  176.195938,  179.418030,  182.637192,
     *  185.853561,  189.067291,  192.278534,  195.487427,  198.694061,
     *  201.898575,  205.101074,  208.301636,  211.500366,  214.697357 
     * /
C   L=  41
      DATA BZ_42 /
     *   47.173500,   52.558434,   57.213707,   61.510983,   65.587891,
     *   69.513329,   73.327515,   77.056236,   80.717133,   84.322868,
     *   87.882858,   91.404327,   94.892906,   98.353119,  101.788628,
     *  105.202446,  108.597076,  111.974640,  115.336929,  118.685478,
     *  122.021614,  125.346497,  128.661118,  131.966370,  135.263046,
     *  138.551819,  141.833313,  145.108078,  148.376602,  151.639343,
     *  154.896698,  158.149048,  161.396698,  164.639954,  167.879120,
     *  171.114410,  174.346085,  177.574341,  180.799377,  184.021378,
     *  187.240509,  190.456924,  193.670776,  196.882187,  200.091278,
     *  203.298187,  206.502991,  209.705811,  212.906754,  216.105865 
     * /
C   L=  42
      DATA BZ_43 /
     *   48.223099,   53.642059,   58.323296,   62.642159,   66.737724,
     *   70.679680,   74.508705,   78.250893,   81.924133,   85.541245,
     *   89.111794,   92.643089,   96.140862,   99.609703,  103.053322,
     *  106.474792,  109.876671,  113.261093,  116.629890,  119.984642,
     *  123.326683,  126.657196,  129.977203,  133.287598,  136.589203,
     *  139.882706,  143.168732,  146.447845,  149.720581,  152.987350,
     *  156.248596,  159.504684,  162.755951,  166.002716,  169.245239,
     *  172.483795,  175.718628,  178.949936,  182.177933,  185.402802,
     *  188.624710,  191.843826,  195.060303,  198.274246,  201.485825,
     *  204.695129,  207.902267,  211.107361,  214.310501,  217.511780 
     * /
C   L=  43
      DATA BZ_44 /
     *   49.271946,   54.724468,   59.431339,   63.771538,   67.885574,
     *   71.843880,   75.687599,   79.443153,   83.128639,   86.757065,
     *   90.338097,   93.879166,   97.386093,  100.863518,  104.315224,
     *  107.744324,  111.153419,  114.544685,  117.919991,  121.280930,
     *  124.628868,  127.965004,  131.290390,  134.605942,  137.912476,
     *  141.210709,  144.501282,  147.784775,  151.061691,  154.332520,
     *  157.597656,  160.857513,  164.112411,  167.362671,  170.608582,
     *  173.850418,  177.088409,  180.322784,  183.553757,  186.781509,
     *  190.006226,  193.228058,  196.447159,  199.663666,  202.877716,
     *  206.089447,  209.298935,  212.506317,  215.711685,  218.915131 
     * /
C   L=  44
      DATA BZ_45 /
     *   50.320068,   55.805698,   60.537891,   64.899185,   69.031494,
     *   73.005989,   76.864281,   80.633095,   84.330742,   87.970390,
     *   91.561852,   95.112648,   98.628670,  102.114639,  105.574402,
     *  109.011108,  112.427399,  115.825500,  119.207298,  122.574409,
     *  125.928238,  129.270004,  132.600769,  135.921478,  139.232941,
     *  142.535904,  145.831024,  149.118896,  152.400024,  155.674896,
     *  158.943954,  162.207565,  165.466110,  168.719879,  171.969193,
     *  175.214310,  178.455490,  181.692963,  184.926910,  188.157562,
     *  191.385086,  194.609650,  197.831390,  201.050476,  204.267029,
     *  207.481186,  210.693054,  213.902740,  217.110352,  220.315979 
     * /
C   L=  45
      DATA BZ_46 /
     *   51.367493,   56.885796,   61.643005,   66.025154,   70.175552,
     *   74.166092,   78.038826,   81.820786,   85.530502,   89.181305,
     *   92.783127,   96.343590,   99.868668,  103.363152,  106.830933,
     *  110.275223,  113.698692,  117.103600,  120.491875,  123.865158,
     *  127.224869,  130.572250,  133.908401,  137.234253,  140.550659,
     *  143.858353,  147.158035,  150.450272,  153.735626,  157.014557,
     *  160.287521,  163.554916,  166.817108,  170.074417,  173.327133,
     *  176.575562,  179.819931,  183.060486,  186.297440,  189.531006,
     *  192.761353,  195.988647,  199.213058,  202.434738,  205.653809,
     *  208.870407,  212.084641,  215.296646,  218.506516,  221.714340 
     * /
C   L=  46
      DATA BZ_47 /
     *   52.414246,   57.964794,   62.746723,   67.149506,   71.317802,
     *   75.324234,   79.211288,   83.006294,   86.727989,   90.389870,
     *   94.001991,   97.572067,  101.106155,  104.609116,  108.084885,
     *  111.536728,  114.967354,  118.379059,  121.773796,  125.153229,
     *  128.518814,  131.871826,  135.213333,  138.544327,  141.865677,
     *  145.178116,  148.482346,  151.778976,  155.068542,  158.351547,
     *  161.628448,  164.899628,  168.165466,  171.426300,  174.682449,
     *  177.934174,  181.181763,  184.425430,  187.665390,  190.901871,
     *  194.135056,  197.365112,  200.592194,  203.816467,  207.038071,
     *  210.257126,  213.473770,  216.688095,  219.900238,  223.110275 
     * /
C   L=  47
      DATA BZ_48 /
     *   53.460346,   59.042740,   63.849094,   68.272285,   72.458305,
     *   76.480484,   80.381737,   84.189682,   87.923279,   91.596161,
     *   95.218513,   98.798149,  102.341209,  105.852600,  109.336327,
     *  112.795692,  116.233452,  119.651932,  123.053116,  126.438698,
     *  129.810150,  133.168762,  136.515640,  139.851791,  143.178070,
     *  146.495255,  149.804047,  153.105057,  156.398849,  159.685928,
     *  162.966751,  166.241730,  169.511230,  172.775620,  176.035187,
     *  179.290237,  182.541046,  185.787827,  189.030823,  192.270233,
     *  195.506256,  198.739075,  201.968857,  205.195740,  208.419876,
     *  211.641403,  214.860458,  218.077133,  221.291550,  224.503815 
     * /
C   L=  48
      DATA BZ_49 /
     *   54.505821,   60.119659,   64.950165,   69.393555,   73.597122,
     *   77.634895,   81.550224,   85.371010,   89.116417,   92.800232,
     *   96.432762,  100.021904,  103.573883,  107.093666,  110.585320,
     *  114.052185,  117.497055,  120.922287,  124.329903,  127.721619,
     *  131.098938,  134.463135,  137.815384,  141.156677,  144.487885,
     *  147.809814,  151.123154,  154.428558,  157.726578,  161.017746,
     *  164.302505,  167.581284,  170.854462,  174.122391,  177.385406,
     *  180.643784,  183.897812,  187.147720,  190.393753,  193.636108,
     *  196.875000,  200.110596,  203.343063,  206.572571,  209.799271,
     *  213.023285,  216.244751,  219.463776,  222.680496,  225.894989 
     * /
C   L=  49
      DATA BZ_50 /
     *   55.550690,   61.195591,   66.049973,   70.513344,   74.734291,
     *   78.787521,   82.716812,   86.550339,   90.307472,   94.002151,
     *   97.644791,  101.243385,  104.804237,  108.332382,  111.831924,
     *  115.306259,  118.758209,  122.190186,  125.604218,  129.002045,
     *  132.385208,  135.755005,  139.112610,  142.459030,  145.795181,
     *  149.121841,  152.439758,  155.749557,  159.051804,  162.347046,
     *  165.635742,  168.918335,  172.195190,  175.466690,  178.733154,
     *  181.994873,  185.252121,  188.505173,  191.754242,  194.999557,
     *  198.241302,  201.479691,  204.714874,  207.947021,  211.176285,
     *  214.402786,  217.626694,  220.848083,  224.067108,  227.283859 
     * /
C   L=  50
      DATA BZ_51 /
     *   56.594971,   62.270561,   67.148560,   71.631706,   75.869865,
     *   79.938423,   83.881554,   87.727730,   91.496506,   95.201965,
     *   98.854660,  102.462654,  106.032333,  109.568794,  113.076195,
     *  116.557976,  120.016991,  123.455681,  126.876106,  130.280045,
     *  133.669037,  137.044434,  140.407379,  143.758942,  147.100006,
     *  150.431412,  153.753891,  157.068069,  160.374573,  163.673889,
     *  166.966537,  170.252930,  173.533478,  176.808548,  180.078461,
     *  183.343521,  186.604019,  189.860214,  193.112335,  196.360611,
     *  199.605240,  202.846420,  206.084335,  209.319122,  212.550949,
     *  215.779968,  219.006302,  222.230087,  225.451431,  228.670441 
     * /
C   L=  51
      DATA BZ_52 /
     *   57.638687,   63.344608,   68.245964,   72.748688,   77.003899,
     *   81.087639,   85.044510,   88.903229,   92.683563,   96.399742,
     *  100.062424,  103.679771,  107.258232,  110.802979,  114.318199,
     *  117.807388,  121.273445,  124.718826,  128.145645,  131.555664,
     *  134.950485,  138.331451,  141.699738,  145.056427,  148.402420,
     *  151.738571,  155.065598,  158.384186,  161.694901,  164.998322,
     *  168.294922,  171.585129,  174.869370,  178.148010,  181.421371,
     *  184.689789,  187.953537,  191.212891,  194.468063,  197.719315,
     *  200.966843,  204.210831,  207.451462,  210.688904,  213.923325,
     *  217.154861,  220.383652,  223.609818,  226.833481,  230.054764 
     * /
C   L=  52
      DATA BZ_53 /
     *   58.681850,   64.417755,   69.342216,   73.864319,   78.136421,
     *   82.235229,   86.205711,   90.076889,   93.868698,   97.595528,
     *  101.268135,  104.894783,  108.481987,  112.034966,  115.557983,
     *  119.054558,  122.527626,  125.979683,  129.412857,  132.828964,
     *  136.229599,  139.616119,  142.989746,  146.351547,  149.702469,
     *  153.043350,  156.374939,  159.697906,  163.012878,  166.320389,
     *  169.620926,  172.914963,  176.202896,  179.485107,  182.761948,
     *  186.033722,  189.300735,  192.563232,  195.821487,  199.075714,
     *  202.326141,  205.572937,  208.816315,  212.056427,  215.293442,
     *  218.527496,  221.758743,  224.987305,  228.213318,  231.436874 
     * /
C   L=  53
      DATA BZ_54 /
     *   59.724483,   65.490028,   70.437355,   74.978653,   79.267494,
     *   83.381218,   87.365219,   91.248756,   95.051964,   98.789375,
     *  102.471855,  106.107750,  109.703644,  113.264824,  116.795601,
     *  120.299522,  123.779587,  127.238297,  130.677811,  134.099991,
     *  137.506409,  140.898483,  144.277451,  147.644363,  151.000198,
     *  154.345810,  157.681961,  161.009323,  164.328522,  167.640121,
     *  170.944626,  174.242477,  177.534119,  180.819916,  184.100220,
     *  187.375351,  190.645630,  193.911301,  197.172623,  200.429840,
     *  203.683167,  206.932800,  210.178909,  213.421692,  216.661316,
     *  219.897919,  223.131638,  226.362610,  229.590958,  232.816818 
     * /
C   L=  54
      DATA BZ_55 /
     *   60.766602,   66.561455,   71.531410,   76.091713,   80.397141,
     *   84.525673,   88.523071,   92.418877,   96.233406,   99.981331,
     *  103.673622,  107.318710,  110.923256,  114.492599,  118.031097,
     *  121.542351,  125.029373,  128.494720,  131.940567,  135.368774,
     *  138.780991,  142.178604,  145.562881,  148.934906,  152.295654,
     *  155.645996,  158.986694,  162.318451,  165.641891,  168.957581,
     *  172.266037,  175.567719,  178.863052,  182.152435,  185.436218,
     *  188.714737,  191.988281,  195.257126,  198.521530,  201.781738,
     *  205.037979,  208.290436,  211.539307,  214.784775,  218.027008,
     *  221.266144,  224.502335,  227.735733,  230.966446,  234.194595 
     * /
C   L=  55
      DATA BZ_56 /
     *   61.808220,   67.632057,   72.624413,   77.203537,   81.525406,
     *   85.668617,   89.679321,   93.587303,   97.413078,  101.171448,
     *  104.873482,  108.527718,  112.140877,  115.718346,  119.264526,
     *  122.783081,  126.277039,  129.748993,  133.201141,  136.635391,
     *  140.053375,  143.456528,  146.846115,  150.223236,  153.588898,
     *  156.943954,  160.289200,  163.625351,  166.953018,  170.272812,
     *  173.585220,  176.890732,  180.189774,  183.482742,  186.770004,
     *  190.051895,  193.328705,  196.600723,  199.868225,  203.131439,
     *  206.390594,  209.645889,  212.897522,  216.145676,  219.390533,
     *  222.632217,  225.870911,  229.106720,  232.339798,  235.570267 
     * /
C   L=  56
      DATA BZ_57 /
     *   62.849350,   68.701866,   73.716393,   78.314163,   82.652328,
     *   86.810097,   90.833992,   94.754074,   98.591011,  102.359764,
     *  106.071495,  109.734825,  113.356544,  116.942093,  120.495941,
     *  124.021751,  127.522629,  131.001175,  134.459610,  137.899872,
     *  141.323608,  144.732285,  148.127167,  151.509384,  154.879944,
     *  158.239716,  161.589508,  164.930054,  168.261963,  171.585831,
     *  174.902206,  178.211548,  181.514297,  184.810852,  188.101608,
     *  191.386871,  194.666962,  197.942169,  201.212753,  204.478973,
     *  207.741058,  210.999191,  214.253601,  217.504456,  220.751923,
     *  223.996185,  227.237366,  230.475616,  233.711075,  236.943848 
     * /
C   L=  57
      DATA BZ_58 /
     *   63.890007,   69.770897,   74.807373,   79.423630,   83.777946,
     *   87.950150,   91.987144,   95.919228,   99.767258,  103.546318,
     *  107.267693,  110.940063,  114.570305,  118.163902,  121.725372,
     *  125.258423,  128.766190,  132.251297,  135.716003,  139.162262,
     *  142.591736,  146.005920,  149.406097,  152.793396,  156.168839,
     *  159.533325,  162.887680,  166.232590,  169.568741,  172.896698,
     *  176.217026,  179.530197,  182.836655,  186.136826,  189.431046,
     *  192.719696,  196.003067,  199.281464,  202.555161,  205.824387,
     *  209.089401,  212.350388,  215.607574,  218.861130,  222.111237,
     *  225.358063,  228.601746,  231.842438,  235.080276,  238.315369 
     * /
C   L=  58
      DATA BZ_59 /
     *   64.930206,   70.839172,   75.897392,   80.531952,   84.902283,
     *   89.088806,   93.138802,   97.082802,  100.941856,  104.731163,
     *  108.462120,  112.143486,  115.782196,  119.383812,  122.952866,
     *  126.493126,  130.007751,  133.499405,  136.970367,  140.422592,
     *  143.857803,  147.277481,  150.682938,  154.075317,  157.455643,
     *  160.824844,  164.183716,  167.533020,  170.873398,  174.205460,
     *  177.529739,  180.846741,  184.156906,  187.460663,  190.758392,
     *  194.050415,  197.337082,  200.618668,  203.895462,  207.167709,
     *  210.435654,  213.699509,  216.959473,  220.215729,  223.468475,
     *  226.717880,  229.964066,  233.207214,  236.447433,  239.684875 
     * /
C   L=  59
      DATA BZ_60 /
     *   65.969963,   71.906715,   76.986465,   81.639168,   86.025375,
     *   90.226112,   94.289009,   98.244843,  102.114845,  105.914337,
     *  109.654816,  113.345131,  116.992271,  120.601860,  124.178467,
     *  127.725914,  131.247375,  134.745544,  138.222733,  141.680923,
     *  145.121857,  148.547012,  151.957733,  155.355179,  158.740387,
     *  162.114288,  165.477692,  168.831375,  172.175980,  175.512131,
     *  178.840363,  182.161194,  185.475082,  188.782440,  192.083649,
     *  195.379059,  198.669022,  201.953812,  205.233704,  208.508972,
     *  211.779861,  215.046570,  218.309326,  221.568298,  224.823700,
     *  228.075668,  231.324387,  234.569977,  237.812607,  241.052383 
     * /
C   L=  60
      DATA BZ_61 /
     *   67.009285,   72.973541,   78.074623,   82.745308,   87.147263,
     *   91.362091,   95.437798,   99.405388,  103.286255,  107.095871,
     *  110.845825,  114.545036,  118.200569,  121.818085,  125.402222,
     *  128.956818,  132.485077,  135.989746,  139.473160,  142.937302,
     *  146.383926,  149.814545,  153.230530,  156.633026,  160.023102,
     *  163.401688,  166.769638,  170.127686,  173.476517,  176.816757,
     *  180.148941,  183.473602,  186.791199,  190.102158,  193.406860,
     *  196.705673,  199.998917,  203.286896,  206.569916,  209.848206,
     *  213.122040,  216.391617,  219.657166,  222.918869,  226.176910,
     *  229.431473,  232.682709,  235.930756,  239.175781,  242.417908 
     * /
C   L=  61
      DATA BZ_62 /
     *   68.048187,   74.039673,   79.161880,   83.850395,   88.267967,
     *   92.496788,   96.585197,  100.564461,  104.456131,  108.275810,
     *  112.035179,  115.743240,  119.407120,  123.032532,  126.624161,
     *  130.185867,  133.720932,  137.232071,  140.721664,  144.191727,
     *  147.644043,  151.080124,  154.501343,  157.908890,  161.303833,
     *  164.687103,  168.059570,  171.421997,  174.775055,  178.119370,
     *  181.455521,  184.784012,  188.105316,  191.419876,  194.728073,
     *  198.030273,  201.326813,  204.617996,  207.904129,  211.185455,
     *  214.462219,  217.734680,  221.003021,  224.267441,  227.528152,
     *  230.785309,  234.039062,  237.289597,  240.537033,  243.781494 
     * /
C   L=  62
      DATA BZ_63 /
     *   69.086670,   75.105133,   80.248276,   84.954453,   89.387520,
     *   93.630219,   97.731247,  101.722099,  105.624512,  109.454185,
     *  113.222916,  116.939781,  120.611961,  124.245239,  127.844322,
     *  131.413132,  134.954941,  138.472534,  141.968292,  145.444275,
     *  148.902252,  152.343781,  155.770233,  159.182816,  162.582611,
     *  165.970566,  169.347549,  172.714340,  176.071609,  179.420013,
     *  182.760101,  186.092422,  189.417450,  192.735611,  196.047287,
     *  199.352890,  202.652725,  205.947128,  209.236359,  212.520721,
     *  215.800461,  219.075775,  222.346924,  225.614090,  228.877457,
     *  232.137192,  235.393494,  238.646500,  241.896347,  245.143173 
     * /
C   L=  63
      DATA BZ_64 /
     *   70.124763,   76.169930,   81.333817,   86.057518,   90.505943,
     *   94.762413,   98.875977,  102.878342,  106.791412,  110.631035,
     *  114.409073,  118.134689,  121.815140,  125.456238,  129.062744,
     *  132.638611,  136.187149,  139.711182,  143.213089,  146.694962,
     *  150.158600,  153.605560,  157.037231,  160.454834,  163.859482,
     *  167.252106,  170.633606,  174.004745,  177.366226,  180.718704,
     *  184.062759,  187.398911,  190.727631,  194.049393,  197.364578,
     *  200.673569,  203.976700,  207.274307,  210.566666,  213.854065,
     *  217.136749,  220.414963,  223.688904,  226.958801,  230.224838,
     *  233.487183,  236.746017,  240.001495,  243.253769,  246.502960 
     * /
C   L=  64
      DATA BZ_65 /
     *   71.162460,   77.234077,   82.418526,   87.159599,   91.623276,
     *   95.893417,  100.019409,  104.033218,  107.956886,  111.806381,
     *  115.593681,  119.328011,  123.016678,  126.665558,  130.279465,
     *  133.862366,  137.417618,  140.948044,  144.456085,  147.943832,
     *  151.413101,  154.865479,  158.302353,  161.724991,  165.134460,
     *  168.531754,  171.917755,  175.293243,  178.658936,  182.015503,
     *  185.363495,  188.703461,  192.035904,  195.361267,  198.679947,
     *  201.992325,  205.298767,  208.599579,  211.895065,  215.185501,
     *  218.471146,  221.752228,  225.028992,  228.301620,  231.570328,
     *  234.835281,  238.096664,  241.354630,  244.609329,  247.860886 
     * /
C   L=  65
      DATA BZ_66 /
     *   72.199783,   78.297600,   83.502434,   88.260735,   92.739525,
     *   97.023239,  101.161591,  105.186752,  109.120956,  112.980270,
     *  116.776772,  120.519768,  124.216621,  127.873245,  131.494507,
     *  135.084412,  138.646347,  142.183167,  145.697311,  149.190918,
     *  152.665802,  156.123581,  159.565659,  162.993286,  166.407593,
     *  169.809540,  173.200043,  176.579880,  179.949783,  183.310410,
     *  186.662354,  190.006149,  193.342300,  196.671249,  199.993423,
     *  203.309204,  206.618942,  209.922974,  213.221573,  216.515060,
     *  219.803665,  223.087631,  226.367203,  229.642578,  232.913956,
     *  236.181534,  239.445465,  242.705917,  245.963043,  249.216980 
     * /
C   L=  66
      DATA BZ_67 /
     *   73.236732,   79.360512,   84.585548,   89.360939,   93.854736,
     *   98.151917,  102.302528,  106.338982,  110.283646,  114.152725,
     *  117.958382,  121.709991,  125.414986,  129.079330,  132.707916,
     *  136.304794,  139.873383,  143.416565,  146.936813,  150.436249,
     *  153.916733,  157.379898,  160.827164,  164.259796,  167.678909,
     *  171.085510,  174.480484,  177.864670,  181.238785,  184.603470,
     *  187.959351,  191.306976,  194.646820,  197.979385,  201.305054,
     *  204.624222,  207.937271,  211.244507,  214.546234,  217.842758,
     *  221.134323,  224.421188,  227.703583,  230.981705,  234.255768,
     *  237.525940,  240.792435,  244.055374,  247.314926,  250.571259 
     * /
C   L=  67
      DATA BZ_68 /
     *   74.273323,   80.422829,   85.667892,   90.460228,   94.968918,
     *   99.279472,  103.442268,  107.489929,  111.445000,  115.323784,
     *  119.138542,  122.898727,  126.611816,  130.283844,  133.919724,
     *  137.523544,  141.098770,  144.648285,  148.174591,  151.679855,
     *  155.165924,  158.634460,  162.086899,  165.524521,  168.948425,
     *  172.359680,  175.759140,  179.147659,  182.525955,  185.894714,
     *  189.254532,  192.605972,  195.949539,  199.285690,  202.614853,
     *  205.937424,  209.253769,  212.564209,  215.869080,  219.168640,
     *  222.463181,  225.752930,  229.038132,  232.319016,  235.595749,
     *  238.868561,  242.137589,  245.403030,  248.665039,  251.923737 
     * /
C   L=  68
      DATA BZ_69 /
     *   75.309555,   81.484558,   86.749481,   91.558632,   96.082100,
     *  100.405930,  104.580826,  108.639626,  112.605026,  116.493462,
     *  120.317276,  124.085983,  127.807137,  131.486801,  135.129944,
     *  138.740692,  142.322525,  145.878342,  149.410706,  152.921768,
     *  156.413422,  159.887314,  163.344910,  166.787491,  170.216202,
     *  173.632080,  177.036026,  180.428864,  183.811356,  187.184174,
     *  190.547928,  193.903183,  197.250443,  200.590195,  203.922852,
     *  207.248810,  210.568466,  213.882126,  217.190109,  220.492722,
     *  223.790237,  227.082886,  230.370911,  233.654526,  236.933960,
     *  240.209381,  243.480988,  246.748917,  250.013367,  253.274460 
     * /
C   L=  69
      DATA BZ_70 /
     *   76.345451,   82.545723,   87.830338,   92.656166,   97.194305,
     *  101.531311,  105.718224,  109.788094,  113.763771,  117.661797,
     *  121.494614,  125.271812,  129.000992,  132.688248,  136.338623,
     *  139.956268,  143.544662,  147.106796,  150.645187,  154.162018,
     *  157.659225,  161.138474,  164.601212,  168.048752,  171.482254,
     *  174.902740,  178.311157,  181.708328,  185.095001,  188.471878,
     *  191.839554,  195.198624,  198.549591,  201.892929,  205.229065,
     *  208.558441,  211.881378,  215.198257,  218.509384,  221.815033,
     *  225.115509,  228.411057,  231.701904,  234.988281,  238.270401,
     *  241.548447,  244.822617,  248.093063,  251.359955,  254.623444 
     * /
C   L=  70
      DATA BZ_71 /
     *   77.381004,   83.606323,   88.910469,   93.752853,   98.305550,
     *  102.655640,  106.854492,  110.935364,  114.921249,  118.828819,
     *  122.670586,  126.456223,  130.193375,  133.888214,  137.545792,
     *  141.170303,  144.765259,  148.333649,  151.878036,  155.400650,
     *  158.903397,  162.387955,  165.855835,  169.308319,  172.746597,
     *  176.171707,  179.584579,  182.986069,  186.376923,  189.757843,
     *  193.129456,  196.492325,  199.846985,  203.193909,  206.533554,
     *  209.866302,  213.192566,  216.512650,  219.826904,  223.135605,
     *  226.439056,  229.737488,  233.031174,  236.320312,  239.605118,
     *  242.885788,  246.162521,  249.435471,  252.704819,  255.970703 
     * /
C   L=  71
      DATA BZ_72 /
     *   78.416237,   84.666382,   89.989906,   94.848709,   99.415855,
     *  103.778946,  107.989655,  112.081451,  116.077492,  119.994545,
     *  123.845215,  127.639252,  131.384354,  135.086731,  138.751480,
     *  142.382812,  145.984299,  149.558929,  153.109314,  156.637665,
     *  160.145935,  163.635818,  167.108810,  170.566238,  174.009277,
     *  177.438995,  180.856323,  184.262115,  187.657135,  191.042099,
     *  194.417633,  197.784302,  201.142670,  204.493179,  207.836304,
     *  211.172455,  214.502014,  217.825317,  221.142700,  224.454453,
     *  227.760864,  231.062210,  234.358719,  237.650604,  240.938110,
     *  244.221420,  247.500717,  250.776184,  254.047974,  257.316254 
     * /
C   L=  72
      DATA BZ_73 /
     *   79.451141,   85.725914,   91.068649,   95.943748,  100.525238,
     *  104.901245,  109.123726,  113.226387,  117.232513,  121.159004,
     *  125.018532,  128.820923,  132.573929,  136.283813,  139.955688,
     *  143.593842,  147.201813,  150.782684,  154.339035,  157.873108,
     *  161.386887,  164.882065,  168.360168,  171.822525,  175.270325,
     *  178.704636,  182.126404,  185.536499,  188.935684,  192.324677,
     *  195.704132,  199.074600,  202.436661,  205.790756,  209.137375,
     *  212.476913,  215.809769,  219.136276,  222.456787,  225.771606,
     *  229.080994,  232.385223,  235.684570,  238.979218,  242.269424,
     *  245.555359,  248.837219,  252.115204,  255.389465,  258.660156 
     * /
C   L=  73
      DATA BZ_74 /
     *   80.485733,   86.784920,   92.146721,   97.037994,  101.633736,
     *  106.022552,  110.256744,  114.370193,  118.386353,  122.322220,
     *  126.190567,  130.001266,  133.762131,  137.479492,  141.158478,
     *  144.803391,  148.417862,  152.004929,  155.567215,  159.107010,
     *  162.626282,  166.126740,  169.609940,  173.077209,  176.529739,
     *  179.968643,  183.394836,  186.809235,  190.212585,  193.605606,
     *  196.988968,  200.363251,  203.728973,  207.086670,  210.436768,
     *  213.779694,  217.115845,  220.445572,  223.769211,  227.087082,
     *  230.399445,  233.706573,  237.008743,  240.306168,  243.599060,
     *  246.887634,  250.172073,  253.452576,  256.729279,  260.002380 
     * /
C   L=  74
      DATA BZ_75 /
     *   81.520027,   87.843414,   93.224136,   98.131462,  102.741341,
     *  107.142899,  111.388718,  115.512894,  119.539024,  123.484222,
     *  127.361328,  131.180298,  134.949005,  138.673782,  142.359848,
     *  146.011520,  149.632431,  153.225677,  156.793900,  160.339386,
     *  163.864120,  167.369858,  170.858139,  174.330307,  177.787582,
     *  181.231049,  184.661682,  188.080353,  191.487854,  194.884918,
     *  198.272171,  201.650238,  205.019669,  208.380936,  211.734512,
     *  215.080841,  218.420288,  221.753220,  225.079987,  228.400894,
     *  231.716232,  235.026276,  238.331268,  241.631454,  244.927048,
     *  248.218262,  251.505280,  254.788300,  258.067474,  261.342987 
     * /
C   L=  75
      DATA BZ_76 /
     *   82.554016,   88.901421,   94.300903,   99.224167,  103.848091,
     *  108.262299,  112.519669,  116.654510,  120.690552,  124.645020,
     *  128.530853,  132.358047,  136.134552,  139.866730,  143.559845,
     *  147.218231,  150.845581,  154.444977,  158.019104,  161.570267,
     *  165.100464,  168.611450,  172.104782,  175.581848,  179.043839,
     *  182.491882,  185.926926,  189.349884,  192.761536,  196.162613,
     *  199.553772,  202.935623,  206.308731,  209.673584,  213.030640,
     *  216.380341,  219.723083,  223.059235,  226.389130,  229.713089,
     *  233.031403,  236.344345,  239.652176,  242.955124,  246.253418,
     *  249.547272,  252.836868,  256.122406,  259.404053,  262.681946 
     * /
C   L=  76
      DATA BZ_77 /
     *   83.587708,   89.958931,   95.377045,  100.316124,  104.953995,
     *  109.380760,  113.649612,  117.795059,  121.840958,  125.804649,
     *  129.699158,  133.534546,  137.318787,  141.058350,  144.758469,
     *  148.423569,  152.057312,  155.662842,  159.242859,  162.799667,
     *  166.335297,  169.851532,  173.349930,  176.831863,  180.298569,
     *  183.751160,  187.190613,  190.617844,  194.033630,  197.438721,
     *  200.833786,  204.219421,  207.596207,  210.964630,  214.325165,
     *  217.678253,  221.024292,  224.363647,  227.696671,  231.023682,
     *  234.344971,  237.660812,  240.971466,  244.277191,  247.578186,
     *  250.874664,  254.166855,  257.454895,  260.739014,  264.019348 
     * /
C   L=  77
      DATA BZ_78 /
     *   84.621117,   91.015968,   96.452560,  101.407349,  106.059074,
     *  110.498322,  114.778580,  118.934555,  122.990265,  126.963135,
     *  130.866257,  134.709793,  138.501770,  142.248657,  145.955765,
     *  149.627533,  153.267654,  156.879303,  160.465179,  164.027618,
     *  167.568680,  171.090134,  174.593567,  178.080368,  181.551773,
     *  185.008911,  188.452774,  191.884262,  195.304184,  198.713287,
     *  202.112228,  205.501648,  208.882095,  212.254089,  215.618103,
     *  218.974579,  222.323914,  225.666473,  229.002625,  232.332687,
     *  235.656952,  238.975693,  242.289185,  245.597656,  248.901367,
     *  252.200485,  255.495255,  258.785828,  262.072418,  265.355164 
     * /
C   L=  78
      DATA BZ_79 /
     *   85.654251,   92.072533,   97.527473,  102.497856,  107.163338,
     *  111.614990,  115.906586,  120.073036,  124.138489,  128.120483,
     *  132.032196,  135.883835,  139.683487,  143.437683,  147.151749,
     *  150.830154,  154.476639,  158.094376,  161.686096,  165.254166,
     *  168.800629,  172.327286,  175.835739,  179.327393,  182.803497,
     *  186.265167,  189.713425,  193.149155,  196.573196,  199.986313,
     *  203.389145,  206.782333,  210.166458,  213.542007,  216.909500,
     *  220.269348,  223.621964,  226.967743,  230.307022,  233.640121,
     *  236.967361,  240.289001,  243.605331,  246.916580,  250.222977,
     *  253.524750,  256.822113,  260.115204,  263.404266,  266.689423 
     * /
C   L=  79
      DATA BZ_80 /
     *   86.687103,   93.128647,   98.601791,  103.587662,  108.266808,
     *  112.730782,  117.033646,  121.210510,  125.285652,  129.276718,
     *  133.196976,  137.056686,  140.863983,  144.625443,  148.346451,
     *  152.031464,  155.684280,  159.308075,  162.905624,  166.479294,
     *  170.031143,  173.563004,  177.076477,  180.572968,  184.053741,
     *  187.519943,  190.972565,  194.412552,  197.840714,  201.257812,
     *  204.664536,  208.061493,  211.449280,  214.828400,  218.199356,
     *  221.562576,  224.918488,  228.267471,  231.609863,  234.946014,
     *  238.276230,  241.600769,  244.919937,  248.233948,  251.543060,
     *  254.847473,  258.147400,  261.443024,  264.734558,  268.022156 
     * /
C   L=  80
      DATA BZ_81 /
     *   87.719688,   94.184311,   99.675529,  104.676773,  109.369492,
     *  113.845711,  118.159782,  122.346992,  126.431778,  130.431870,
     *  134.360626,  138.228363,  142.043274,  145.811966,  149.539871,
     *  153.231476,  156.890594,  160.520447,  164.123795,  167.703033,
     *  171.260269,  174.797302,  178.315765,  181.817093,  185.302536,
     *  188.773254,  192.230255,  195.674484,  199.106750,  202.527832,
     *  205.938431,  209.339157,  212.730591,  216.113281,  219.487686,
     *  222.854294,  226.213486,  229.565674,  232.911194,  236.250381,
     *  239.583572,  242.911011,  246.233017,  249.549789,  252.861603,
     *  256.168671,  259.471191,  262.769348,  266.063354,  269.353363 
     * /
C   L=  81
      DATA BZ_82 /
     *   88.752007,   95.239532,  100.748703,  105.765213,  110.471420,
     *  114.959801,  119.285004,  123.482506,  127.576874,  131.585953,
     *  135.523163,  139.398880,  143.221375,  146.997269,  150.732040,
     *  154.430222,  158.095612,  161.731491,  165.340622,  168.925430,
     *  172.488022,  176.030228,  179.553665,  183.059799,  186.549896,
     *  190.025116,  193.486496,  196.934952,  200.371323,  203.796387,
     *  207.210846,  210.615326,  214.010422,  217.396667,  220.774536,
     *  224.144501,  227.506989,  230.862366,  234.211014,  237.553253,
     *  240.889404,  244.219757,  247.544586,  250.864136,  254.178650,
     *  257.488342,  260.793457,  264.094147,  267.390625,  270.683044 
     * /
C   L=  82
      DATA BZ_83 /
     *   89.784065,   96.294327,  101.821312,  106.852989,  111.572586,
     *  116.073059,  120.409332,  124.617065,  128.720963,  132.738983,
     *  136.684601,  140.568283,  144.398315,  148.181381,  151.922989,
     *  155.627701,  159.299362,  162.941238,  166.556137,  170.146484,
     *  173.714417,  177.261765,  180.790192,  184.301117,  187.795868,
     *  191.275574,  194.741302,  198.193970,  201.634445,  205.063492,
     *  208.481812,  211.890045,  215.288788,  218.678574,  222.059906,
     *  225.433243,  228.799011,  232.157593,  235.509354,  238.854630,
     *  242.193756,  245.527008,  248.854660,  252.176987,  255.494202,
     *  258.806549,  262.114258,  265.417480,  268.716431,  272.011292 
     * /
C   L=  83
      DATA BZ_84 /
     *   90.815880,   97.348694,  102.893372,  107.940109,  112.673019,
     *  117.185509,  121.532784,  125.750694,  129.864075,  133.890976,
     *  137.844955,  141.736557,  145.574097,  149.364319,  153.112732,
     *  156.823944,  160.501846,  164.149704,  167.770340,  171.366226,
     *  174.939484,  178.491959,  182.025345,  185.541061,  189.040436,
     *  192.524643,  195.994705,  199.451599,  202.896149,  206.329163,
     *  209.751343,  213.163330,  216.565720,  219.959045,  223.343826,
     *  226.720535,  230.089569,  233.451340,  236.806229,  240.154556,
     *  243.496643,  246.832794,  250.163284,  253.488373,  256.808289,
     *  260.123291,  263.433563,  266.739319,  270.040771,  273.338043 
     * /
C   L=  84
      DATA BZ_85 /
     *   91.847435,   98.402649,  103.964890,  109.026596,  113.772736,
     *  118.297165,  122.655373,  126.883400,  131.006210,  135.041946,
     *  139.004257,  142.903732,  146.748749,  150.546082,  154.301285,
     *  158.018982,  161.703094,  165.356903,  168.983276,  172.584671,
     *  176.163223,  179.720840,  183.259155,  186.779648,  190.283646,
     *  193.772324,  197.246735,  200.707825,  204.156464,  207.593430,
     *  211.019455,  214.435181,  217.841202,  221.238083,  224.626312,
     *  228.006378,  231.378693,  234.743652,  238.101654,  241.453018,
     *  244.798080,  248.137131,  251.470444,  254.798309,  258.120941,
     *  261.438568,  264.751434,  268.059723,  271.363647,  274.663361 
     * /
C   L=  85
      DATA BZ_86 /
     *   92.878754,   99.456200,  105.035889,  110.112450,  114.871735,
     *  119.408035,  123.777115,  128.015198,  132.147400,  136.191925,
     *  140.162537,  144.069839,  147.922302,  151.726715,  155.488663,
     *  159.212830,  162.903122,  166.562881,  170.194946,  173.801834,
     *  177.385681,  180.948395,  184.491638,  188.016907,  191.525513,
     *  195.018661,  198.497391,  201.962677,  205.415375,  208.856308,
     *  212.286179,  215.705627,  219.115295,  222.515717,  225.907394,
     *  229.290802,  232.666382,  236.034546,  239.395660,  242.750061,
     *  246.098083,  249.440033,  252.776184,  256.106812,  259.432129,
     *  262.752411,  266.067871,  269.378693,  272.685089,  275.987213 
     * /
C   L=  86
      DATA BZ_87 /
     *   93.909836,  100.509346,  106.106361,  111.197693,  115.970032,
     *  120.518135,  124.898026,  129.146118,  133.287643,  137.340927,
     *  141.319778,  145.234894,  149.094757,  152.906219,  156.674896,
     *  160.405502,  164.101959,  167.767624,  171.405396,  175.017746,
     *  178.606873,  182.174667,  185.722824,  189.252853,  192.766052,
     *  196.263641,  199.746689,  203.216171,  206.672943,  210.117813,
     *  213.551514,  216.974701,  220.388000,  223.791946,  227.187057,
     *  230.573822,  233.952682,  237.324036,  240.688248,  244.045685,
     *  247.396667,  250.741516,  254.080505,  257.413879,  260.741913,
     *  264.064850,  267.382904,  270.696259,  274.005127,  277.309692 
     * /
C   L=  87
      DATA BZ_88 /
     *   94.940674,  101.562103,  107.176331,  112.282333,  117.067650,
     *  121.627480,  126.018120,  130.276154,  134.426956,  138.488953,
     *  142.476013,  146.398895,  150.266129,  154.084610,  157.860001,
     *  161.597015,  165.299606,  168.971176,  172.614609,  176.232407,
     *  179.826797,  183.399673,  186.952728,  190.487488,  194.005280,
     *  197.507324,  200.994675,  204.468323,  207.929153,  211.377960,
     *  214.815491,  218.242416,  221.659317,  225.066803,  228.465347,
     *  231.855469,  235.237595,  238.612122,  241.979446,  245.339920,
     *  248.693878,  252.041611,  255.383423,  258.719574,  262.050323,
     *  265.375885,  268.696533,  272.012421,  275.323761,  278.630768 
     * /
C   L=  88
      DATA BZ_89 /
     *   95.971291,  102.614479,  108.245796,  113.366379,  118.164589,
     *  122.736076,  127.137405,  131.405350,  135.565384,  139.636032,
     *  143.631256,  147.561874,  151.436447,  155.261932,  159.043991,
     *  162.787384,  166.496094,  170.173538,  173.822617,  177.445862,
     *  181.045486,  184.623413,  188.181366,  191.720856,  195.243225,
     *  198.749695,  202.241348,  205.719162,  209.184036,  212.636780,
     *  216.078140,  219.508774,  222.929306,  226.340302,  229.742279,
     *  233.135742,  236.521133,  239.898834,  243.269272,  246.632782,
     *  249.989685,  253.340317,  256.684967,  260.023865,  263.357330,
     *  266.685547,  270.008759,  273.327179,  276.641022,  279.950439 
     * /
C   L=  89
      DATA BZ_90 /
     *   97.001678,  103.666473,  109.314774,  114.449837,  119.260872,
     *  123.843948,  128.255905,  132.533691,  136.702911,  140.782181,
     *  144.785538,  148.723846,  152.605728,  156.438171,  160.226883,
     *  163.976624,  167.691437,  171.374725,  175.029434,  178.658112,
     *  182.262955,  185.845932,  189.408768,  192.952957,  196.479889,
     *  199.990784,  203.486725,  206.968689,  210.437607,  213.894287,
     *  217.339447,  220.773788,  224.197937,  227.612457,  231.017868,
     *  234.414673,  237.803314,  241.184204,  244.557739,  247.924271,
     *  251.284149,  254.637665,  257.985138,  261.326813,  264.662964,
     *  267.993835,  271.319641,  274.640594,  277.956909,  281.268768 
     * /
C   L=  90
      DATA BZ_91 /
     *   98.031845,  104.718102,  110.383263,  115.532722,  120.356499,
     *  124.951103,  129.373627,  133.661194,  137.839554,  141.927414,
     *  145.938858,  149.884827,  153.773987,  157.613358,  161.408691,
     *  165.164764,  168.885651,  172.574783,  176.235092,  179.869171,
     *  183.479233,  187.067230,  190.634918,  194.183823,  197.715302,
     *  201.230606,  204.730820,  208.216949,  211.689896,  215.150482,
     *  218.599457,  222.037506,  225.465256,  228.883286,  232.292130,
     *  235.692276,  239.084167,  242.468231,  245.844864,  249.214432,
     *  252.577255,  255.933655,  259.283936,  262.628387,  265.967255,
     *  269.300751,  272.629150,  275.952637,  279.271423,  282.585724 
     * /
C   L=  91
      DATA BZ_92 /
     *   99.061798,  105.769363,  111.451286,  116.615044,  121.451485,
     *  126.057549,  130.490585,  134.787903,  138.975342,  143.071732,
     *  147.091232,  151.044830,  154.941238,  158.787506,  162.589432,
     *  166.351822,  170.078766,  173.773697,  177.439606,  181.079056,
     *  184.694321,  188.287338,  191.859863,  195.413452,  198.949478,
     *  202.469177,  205.973663,  209.463928,  212.940903,  216.405411,
     *  219.858185,  223.299927,  226.731277,  230.152817,  233.565079,
     *  236.968552,  240.363693,  243.750931,  247.130661,  250.503250,
     *  253.869034,  257.228333,  260.581451,  263.928650,  267.270203,
     *  270.606354,  273.937317,  277.263367,  280.584625,  283.901337 
     * /
C   L=  92
      DATA BZ_93 /
     *  100.091530,  106.820267,  112.518837,  117.696815,  122.545845,
     *  127.163300,  131.606796,  135.913788,  140.110291,  144.215164,
     *  148.242676,  152.203873,  156.107483,  159.960632,  163.769119,
     *  167.537811,  171.270767,  174.971497,  178.642975,  182.287796,
     *  185.908234,  189.506256,  193.083618,  196.641891,  200.182434,
     *  203.706528,  207.215271,  210.709671,  214.190659,  217.659058,
     *  221.115631,  224.561066,  227.996017,  231.421066,  234.836731,
     *  238.243530,  241.641922,  245.032333,  248.415161,  251.790756,
     *  255.159500,  258.521667,  261.877594,  265.227570,  268.571838,
     *  271.910614,  275.244171,  278.572754,  281.896484,  285.215637 
     * /
C   L=  93
      DATA BZ_94 /
     *  101.121056,  107.870819,  113.585938,  118.778038,  123.639587,
     *  128.268372,  132.722260,  137.038895,  141.244385,  145.357727,
     *  149.393219,  153.361954,  157.272766,  161.132751,  164.947784,
     *  168.722733,  172.461700,  176.168198,  179.845230,  183.495407,
     *  187.121002,  190.723999,  194.306183,  197.869125,  201.414185,
     *  204.942657,  208.455643,  211.954178,  215.439163,  218.911453,
     *  222.371826,  225.820953,  229.259491,  232.688019,  236.107101,
     *  239.517227,  242.918869,  246.312439,  249.698349,  253.076981,
     *  256.448669,  259.813721,  263.172485,  266.525208,  269.872162,
     *  273.213593,  276.549744,  279.880829,  283.207062,  286.528625 
     * /
C   L=  94
      DATA BZ_95 /
     *  102.150375,  108.921028,  114.652588,  119.858734,  124.732727,
     *  129.372772,  133.837006,  138.163223,  142.377670,  146.499420,
     *  150.542847,  154.519119,  158.437073,  162.303879,  166.125427,
     *  169.906601,  173.651566,  177.363815,  181.046387,  184.701889,
     *  188.332626,  191.940598,  195.527588,  199.095169,  202.644760,
     *  206.177582,  209.694809,  213.197464,  216.686447,  220.162628,
     *  223.626770,  227.079575,  230.521698,  233.953735,  237.376221,
     *  240.789658,  244.194534,  247.591263,  250.980270,  254.361908,
     *  257.736542,  261.104492,  264.466064,  267.821533,  271.171173,
     *  274.515259,  277.854004,  281.187622,  284.516327,  287.840332 
     * /
C   L=  95
      DATA BZ_96 /
     *  103.179489,  109.970894,  115.718788,  120.938896,  125.825264,
     *  130.476517,  134.951019,  139.286789,  143.510132,  147.640259,
     *  151.691589,  155.675354,  159.600433,  163.474030,  167.302063,
     *  171.089462,  174.840378,  178.558365,  182.246445,  185.907272,
     *  189.543137,  193.156067,  196.747849,  200.320068,  203.874146,
     *  207.411331,  210.932785,  214.439545,  217.932526,  221.412582,
     *  224.880493,  228.336975,  231.782684,  235.218185,  238.644073,
     *  242.060837,  245.468948,  248.868835,  252.260925,  255.645569,
     *  259.023163,  262.393982,  265.758362,  269.116577,  272.468933,
     *  275.815643,  279.156982,  282.493134,  285.824310,  289.150757 
     * /
C   L=  96
      DATA BZ_97 /
     *  104.208412,  111.020432,  116.784561,  122.018539,  126.917206,
     *  131.579605,  136.064346,  140.409592,  144.641815,  148.780258,
     *  152.839462,  156.830688,  160.762863,  164.643219,  168.477722,
     *  172.271301,  176.028168,  179.751846,  183.445435,  187.111557,
     *  190.752548,  194.370407,  197.966980,  201.543823,  205.102371,
     *  208.643921,  212.169586,  215.680435,  219.177399,  222.661331,
     *  226.133011,  229.593155,  233.042435,  236.481430,  239.910706,
     *  243.330780,  246.742111,  250.145157,  253.540329,  256.927979,
     *  260.308502,  263.682220,  267.049408,  270.410400,  273.765442,
     *  277.114777,  280.458679,  283.797363,  287.131042,  290.459900 
     * /
C   L=  97
      DATA BZ_98 /
     *  105.237129,  112.069633,  117.849899,  123.097679,  128.008575,
     *  132.682053,  137.176971,  141.531662,  145.772705,  149.919449,
     *  153.986481,  157.985123,  161.924362,  165.811447,  169.652390,
     *  173.452148,  177.214920,  180.944305,  184.643372,  188.314774,
     *  191.960861,  195.583649,  199.184982,  202.766434,  206.329468,
     *  209.875336,  213.405228,  216.920151,  220.421097,  223.908890,
     *  227.384323,  230.848145,  234.300980,  237.743439,  241.176117,
     *  244.599487,  248.014053,  251.420258,  254.818497,  258.209167,
     *  261.592621,  264.969208,  268.339203,  271.702942,  275.060669,
     *  278.412659,  281.759155,  285.100372,  288.436523,  291.767822 
     * /
C   L=  98
      DATA BZ_99 /
     *  106.265663,  113.118523,  118.914825,  124.176308,  129.099380,
     *  133.783859,  138.288910,  142.653000,  146.902817,  151.057816,
     *  155.132645,  159.138687,  163.084946,  166.978760,  170.826111,
     *  174.632004,  178.400681,  182.135742,  185.840256,  189.516922,
     *  193.168091,  196.795807,  200.401886,  203.987946,  207.555435,
     *  211.105637,  214.639709,  218.158722,  221.663620,  225.155273,
     *  228.634460,  232.101929,  235.558319,  239.004272,  242.440323,
     *  245.866989,  249.284775,  252.694122,  256.095428,  259.489105,
     *  262.875519,  266.254974,  269.627777,  272.994263,  276.354675,
     *  279.709290,  283.058380,  286.402100,  289.740753,  293.074463 
     * /
C   L=  99
      DATA BZ100 /
     *  107.294006,  114.167084,  119.979332,  125.254456,  130.189606,
     *  134.885056,  139.400177,  143.773605,  148.032166,  152.195389,
     *  156.277985,  160.291382,  164.244644,  168.145126,  171.998871,
     *  175.810898,  179.585449,  183.326157,  187.036118,  190.718033,
     *  194.374268,  198.006882,  201.617691,  205.208344,  208.780273,
     *  212.334793,  215.873062,  219.396149,  222.904999,  226.400497,
     *  229.883438,  233.354553,  236.814499,  240.263901,  243.703339,
     *  247.133301,  250.554306,  253.966797,  257.371185,  260.767853,
     *  264.157196,  267.539490,  270.915131,  274.284363,  277.647461,
     *  281.004730,  284.356384,  287.702637,  291.043762,  294.379913 
     * /
C   L= 100
      DATA BZ101 /
     *  108.322159,  115.215340,  121.043434,  126.332108,  131.279297,
     *  135.985657,  140.510788,  144.893524,  149.160782,  153.332169,
     *  157.422485,  161.443222,  165.403458,  169.310593,  173.170700,
     *  176.988831,  180.769241,  184.515579,  188.230957,  191.918121,
     *  195.579391,  199.216888,  202.832428,  206.427658,  210.004028,
     *  213.562851,  217.105301,  220.632431,  224.145233,  227.644577,
     *  231.131256,  234.606003,  238.069504,  241.522369,  244.965164,
     *  248.398438,  251.822647,  255.238281,  258.645721,  262.045410,
     *  265.437653,  268.822845,  272.201263,  275.573242,  278.939056,
     *  282.298950,  285.653168,  289.001953,  292.345551,  295.684113 
     * /
C   L= 101
      DATA BZ102 /
     *  109.350128,  116.263290,  122.107132,  127.409286,  132.368439,
     *  137.085632,  141.620743,  146.012726,  150.288635,  154.468185,
     *  158.566193,  162.594208,  166.561401,  170.475174,  174.341614,
     *  178.165817,  181.952057,  185.704010,  189.424805,  193.117172,
     *  196.783493,  200.425858,  204.046112,  207.645905,  211.226700,
     *  214.789810,  218.336426,  221.867615,  225.384354,  228.887527,
     *  232.377930,  235.856323,  239.323364,  242.779678,  246.225845,
     *  249.662399,  253.089828,  256.508575,  259.919098,  263.321777,
     *  266.716949,  270.105011,  273.486237,  276.860962,  280.229431,
     *  283.591949,  286.948761,  290.300079,  293.646118,  296.987122 
     * /
C -------------------------
      IERR = 0
      IF(NMAXP.LE.0.OR.NMAXP.GT.50.OR.LMAXP.LE.0.OR.LMAXP.GT.100) THEN
        IERR = 1
        RETURN
      ENDIF
      LMAX2 = LMAXP + 2

      DO J=1,NMAXP

        BZEROS(J,1) = BZ__1(J)
        BZEROS(J,2) = BZ__2(J)
        BZEROS(J,3) = BZ__3(J)
        BZEROS(J,4) = BZ__4(J)
        BZEROS(J,5) = BZ__5(J)
        BZEROS(J,6) = BZ__6(J)
        BZEROS(J,7) = BZ__7(J)
        BZEROS(J,8) = BZ__8(J)
        BZEROS(J,9) = BZ__9(J)

        BZEROS(J,10) = BZ_10(J)
        BZEROS(J,11) = BZ_11(J)
        BZEROS(J,12) = BZ_12(J)
        BZEROS(J,13) = BZ_13(J)
        BZEROS(J,14) = BZ_14(J)
        BZEROS(J,15) = BZ_15(J)
        BZEROS(J,16) = BZ_16(J)
        BZEROS(J,17) = BZ_17(J)
        BZEROS(J,18) = BZ_18(J)
        BZEROS(J,19) = BZ_19(J)

        BZEROS(J,20) = BZ_20(J)
        BZEROS(J,21) = BZ_21(J)
        BZEROS(J,22) = BZ_22(J)
        BZEROS(J,23) = BZ_23(J)
        BZEROS(J,24) = BZ_24(J)
        BZEROS(J,25) = BZ_25(J)
        BZEROS(J,26) = BZ_26(J)
        BZEROS(J,27) = BZ_27(J)
        BZEROS(J,28) = BZ_28(J)
        BZEROS(J,29) = BZ_29(J)

        BZEROS(J,30) = BZ_30(J)
        BZEROS(J,31) = BZ_31(J)
        BZEROS(J,32) = BZ_32(J)
        BZEROS(J,33) = BZ_33(J)
        BZEROS(J,34) = BZ_34(J)
        BZEROS(J,35) = BZ_35(J)
        BZEROS(J,36) = BZ_36(J)
        BZEROS(J,37) = BZ_37(J)
        BZEROS(J,38) = BZ_38(J)
        BZEROS(J,39) = BZ_39(J)

        BZEROS(J,40) = BZ_40(J)
        BZEROS(J,41) = BZ_41(J)
        BZEROS(J,42) = BZ_42(J)
        BZEROS(J,43) = BZ_43(J)
        BZEROS(J,44) = BZ_44(J)
        BZEROS(J,45) = BZ_45(J)
        BZEROS(J,46) = BZ_46(J)
        BZEROS(J,47) = BZ_47(J)
        BZEROS(J,48) = BZ_48(J)
        BZEROS(J,49) = BZ_49(J)

        BZEROS(J,50) = BZ_50(J)
        BZEROS(J,51) = BZ_51(J)
        BZEROS(J,52) = BZ_52(J)
        BZEROS(J,53) = BZ_53(J)
        BZEROS(J,54) = BZ_54(J)
        BZEROS(J,55) = BZ_55(J)
        BZEROS(J,56) = BZ_56(J)
        BZEROS(J,57) = BZ_57(J)
        BZEROS(J,58) = BZ_58(J)
        BZEROS(J,59) = BZ_59(J)

        BZEROS(J,60) = BZ_60(J)
        BZEROS(J,61) = BZ_61(J)
        BZEROS(J,62) = BZ_62(J)
        BZEROS(J,63) = BZ_63(J)
        BZEROS(J,64) = BZ_64(J)
        BZEROS(J,65) = BZ_65(J)
        BZEROS(J,66) = BZ_66(J)
        BZEROS(J,67) = BZ_67(J)
        BZEROS(J,68) = BZ_68(J)
        BZEROS(J,69) = BZ_69(J)

        BZEROS(J,70) = BZ_70(J)
        BZEROS(J,71) = BZ_71(J)
        BZEROS(J,72) = BZ_72(J)
        BZEROS(J,73) = BZ_73(J)
        BZEROS(J,74) = BZ_74(J)
        BZEROS(J,75) = BZ_75(J)
        BZEROS(J,76) = BZ_76(J)
        BZEROS(J,77) = BZ_77(J)
        BZEROS(J,78) = BZ_78(J)
        BZEROS(J,79) = BZ_79(J)

        BZEROS(J,80) = BZ_80(J)
        BZEROS(J,81) = BZ_81(J)
        BZEROS(J,82) = BZ_82(J)
        BZEROS(J,83) = BZ_83(J)
        BZEROS(J,84) = BZ_84(J)
        BZEROS(J,85) = BZ_85(J)
        BZEROS(J,86) = BZ_86(J)
        BZEROS(J,87) = BZ_87(J)
        BZEROS(J,88) = BZ_88(J)
        BZEROS(J,89) = BZ_89(J)

        BZEROS(J,90) = BZ_90(J)
        BZEROS(J,91) = BZ_91(J)
        BZEROS(J,92) = BZ_92(J)
        BZEROS(J,93) = BZ_93(J)
        BZEROS(J,94) = BZ_94(J)
        BZEROS(J,95) = BZ_95(J)
        BZEROS(J,96) = BZ_96(J)
        BZEROS(J,97) = BZ_97(J)
        BZEROS(J,98) = BZ_98(J)
        BZEROS(J,99) = BZ_99(J)

        BZEROS(J,100) = BZ100(J)
        BZEROS(J,101) = BZ101(J)
        BZEROS(J,102) = BZ102(J)

      ENDDO
C ------------------------
      DO J=1,NMAXP
      DO I=1,LMAX2
        BZ(J,I) = BZEROS(J,I)
      ENDDO
      ENDDO
C -------------------------
      RETURN
      END

      SUBROUTINE SRFRES(MDOC,NAME1,NAME2,NAMEO
     * ,BETMINR,BETMAXR,BETDELR
     * ,DLMN8,CLMM,FMM,FACT,PCOT,PSIN
     * ,DLMM,AR,AI,BR,BI,NMAX
     * ,IPRLMX,IPRLM1,IPRL21,IPRMEM,IPRALM,IPRGAM,IPRNMX
     * ,RF_MAX,LMAXR,LMINR,ISYM,IPRSYM,IERR)
C --------------------------------------------------------------------
C ---------
      INTEGER*2 ISYM(5,3,IPRSYM)
      REAL*8    DLMN8(IPRLM1,IPRL21)
      REAL      DLMM (IPRLM1,IPRL21)
      REAL*8    FACT(IPRL21),PCOT(IPRL21),PSIN(IPRL21)
      COMPLEX   CLMM(IPRMEM),FMM(IPRALM,IPRGAM)

c      REAL      SCLMM(100000)
c      REAL      SFMM(144,144)

      COMPLEX   CA,CB
      REAL*8    ANG,DLCTB2,CTB2,DSANG,CCB,VS,dlca,dlsa
      REAL      AR(IPRLM1,IPRNMX),AI(IPRLM1,IPRNMX)
      REAL      BR(IPRLM1,IPRNMX),BI(IPRLM1,IPRNMX)
      INTEGER   NMAX(IPRLM1)

c      REAL      SA(122,62),SB(122,62)

      INTEGER   ID(3)
      REAL      RLATT(6),RF_MAX(4)
      CHARACTER NAME1*(*),NAME2*(*),NAMEO*(*)
      CHARACTER TITLE1*80,TYPE*4,TYPE2*4,TITLE2*80
      CHARACTER MSG*1,MSGL*1,LINE*80
C -------------------------------------------------------------
      MD     = -ABS(MDOC)-1

      md = mdoc

      IPRLM2 = IPRLMX+2   
      IERR   = 0
C ----------------
      MSGL = 'Y'
C     MSGL = 'N'

      NBASC = 0
      APT   = 0.0
      BPT   = 0.0

      BETMIN = BETMINR
      BETMAX = BETMAXR
      BETDEL = BETDELR
C ----------------
      MT1   = 10
      MT2   = 0
      TYPE  = '    '
      CALL ORFILE(MD,MT1,NAME1,TYPE,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MD,' ERR: OPEN ALMN_FILE-1.')
        RETURN
      ENDIF
      IF(TYPE.NE.'ALMN'.AND.TYPE.NE.'ALMS') THEN
        CALL MSGERR(MD,' ERR: OPEN ALMN_FILE-1: wrong file type')
        IERR = 1
        RETURN
      ENDIF
      CALL GET_TITLE(MD,RLATT(1),RLATT(2),
     . RLATT(3),RLATT(4),RLATT(5),RLATT(6),CF,BT,RN1,RX1,IDM,IDM
     . ,IDM,IDM,IDM,TITLE1,IERR)
      CALL C_RD_CR
C -----------------
      ARAD1 = CF
      NSYM1 = BT+.1
      IEND1 = -1
      NUMB1 = 0
      IF(TITLE1(5:8).EQ.' PT ') THEN
        LSTP=2
      ELSE
        LSTP=1
      ENDIF
      ILOLD=-111
      IF(TYPE.EQ.'ALMN') THEN
        CALL RD1(MT1,IN,IM,IL,FA,FB,NUMB1,IEND1)
        SFA = FA*0.04
        SFB = FB*0.04
      ELSE
        CALL RABCD(MT1,IN,IM,IL,FA,FB,SFA,SFB,NUMB1,IEND1)
      ENDIF
      IF(MT1.LE.0) THEN
        CALL MSGERR(MDOC,' ERR : READ ALMN_FILE-1')
        CLOSE(MT1)
        IERR=1
        RETURN
      ENDIF
      IF(IEND1.GT.0) THEN
        CALL MSGERR(MDOC,' ERR : EMPTY ALMN_FILE-1')
        IERR=1
        RETURN
      ENDIF
C -------------------------------------------------------------
      MSG = 'Y'
      CALL LENSTR_BL(NAME2,LEN)
      IF(LEN.GT.0.AND.NAME2(1:1).NE.','.AND.NAME2(1:1).NE.' ') THEN
        IERR  = 0
        MT2   = 11
        TYPE2 = '    '
        CALL ORFILE(MD,MT2,NAME2,TYPE2,NSM2,FMM,IPRSYM,IERR)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MD,' ERR: OPEN ALMN_FILE-2')
          CLOSE(MT1)
          RETURN
        ENDIF
        IF(TYPE2.NE.'ALMN'.AND.TYPE2.NE.'ALMS') THEN
          CALL MSGERR(MD,' ERR: OPEN ALMN_FILE-2: wrong file type')
          IERR = 1
          RETURN
        ENDIF
        MSG = 'N'
        CALL GET_TITLE(MD,RLATT(1),RLATT(2),
     .  RLATT(3),RLATT(4),RLATT(5),RLATT(6),CF,BT,RN2,RX2,IDM,IDM
     .  ,IDM,IDM,IDM,TITLE2,IERR)

        ARAD2 = CF
        IF(ARAD2.NE.ARAD1) THEN
          CALL MSGERR(MDOC,' ERR : RAD-1 # RAD-2')
          IERR=1
          CLOSE(MT1)
          CLOSE(MT2)
          RETURN
        ENDIF
        NSYM2 = BT+.1
        IEND2 = -1
        NUMB2 = 0
        JLOLD = -111
  510   IF(TYPE2.EQ.'ALMN') THEN
          CALL RD2(MT2,JN,JM,JL,GA,GB,NUMB2,IEND2)
          SGA = GA*0.04
          SGB = GB*0.04

C         write(*,*) '><<>ga,gb:',JN,JM,JL,GA,GB

        ELSE
          CALL RABCD1(MT2,JN,JM,JL,GA,GB,SGA,SGB,NUMB2,IEND2)
        ENDIF
        IF(MT2.LE.0) THEN
          CALL MSGERR(MDOC,' ERR : READ ALMN_FILE-2')
          CLOSE(MT1)
          CLOSE(MT2)
          IERR=1
          RETURN
        ENDIF
        IF(IEND2.GT.0) THEN
          CALL MSGERR(MDOC,' ERR : EMPTY ALMN_FILE-2')
          CLOSE(MT1)
          RETURN
        ENDIF
        IF(MSGL.EQ.'N'.AND.JL.EQ.0) GO TO 510
      ELSE
        BETMAX = 180.
      ENDIF
C -------------------------------------------------------------
      L_MAX = -1
      L_MIN = IPRLMX + 1
      IF(MSG.NE.'N') NSYM2=NSYM1
C =============================================================
  100 CONTINUE
      IF(IEND1.GT.0) GO TO 200
      IF(IL.NE.ILOLD.AND.ILOLD.NE.-111) THEN
        GO TO 200
      ENDIF
  110 L =IL
      IF(L.GT.IPRLMX.or.l.lt.0) THEN
        WRITE(LINE,*) ' ERR: L >',IPRLMX
        CALL MSGERR(MDOC,LINE)
        CLOSE(MT1)
        IF(MT2.GT.0) CLOSE(MT2)
        IERR=1
        RETURN
      ENDIF
      M =IM
      N =IN
      IF(m.lt.0) THEN
        WRITE(LINE,*) ' ERR: m < 0 '
         CALL MSGERR(MDOC,LINE)
        stop
      endif

      IF(N.GT.IPRNMX.or.n.le.0) THEN
        WRITE(LINE,*) ' ERR: N >',IPRNMX
        CALL MSGERR(MDOC,LINE)
        CLOSE(MT1)
        IF(MT2.GT.0) CLOSE(MT2)
        IERR=1
        RETURN
      ENDIF
      MMAX     = L+1
      M1       = IM+1
      AR(M1,N) = FA
      AI(M1,N) = FB

c     SA(M1,N) = SFA

      NMAX1    = N
      ILOLD    = IL
      IF(TYPE.EQ.'ALMN') THEN
        CALL RD1(MT1,IN,IM,IL,FA,FB,NUMB1,IEND1)
        SFA = FA*0.04
        SFB = FB*0.04
      ELSE
        CALL RABCD(MT1,IN,IM,IL,FA,FB,SFA,SFB,NUMB1,IEND1)
      ENDIF
C     CALL RD1(MT1,IN,IM,IL,FA,FB,NUMB1,IEND1)
      IF(MT1.LE.0) THEN
        CALL MSGERR(MDOC,' ERR : READ ALMN FILE-1')
        IF(MT2.GT.0) CLOSE(MT2)
        IERR=1
        RETURN
      ENDIF
c      IF(IL.EQ.0) THEN
c        FA=0.0
c        FB=0.0
c      ENDIF
      GO TO 100
C --------------
  200 IF(MSG.EQ.'N') THEN
        JLOLD=L
  300   CONTINUE
        IF(IEND2.GT.0 ) GO TO 400
        IF(JL.NE.JLOLD) THEN
          GO TO 400
        ENDIF
        IF(JL.NE.L) THEN
          WRITE(LINE,*) ' ERR: L - FILE-1 # L - FILE-2 :',L,JL
          CALL MSGERR(MDOC,LINE)
          IF(IEND1.EQ.0) CLOSE(MT1)
          CLOSE(MT2)
          IERR=1
          RETURN
        ENDIF
        M = JM
        N = JN
       IF(m.lt.0) THEN
         WRITE(LINE,*) ' ERR: m < 0 '
          CALL MSGERR(MDOC,LINE)
         stop
       endif

        IF(N.GT.IPRNMX.or.n.le.0) THEN
          WRITE(LINE,*) ' ERR: N >',IPRNMX
          CALL MSGERR(MDOC,LINE)
          IF(IEND1.EQ.0) CLOSE(MT1)
          CLOSE(MT2)
          IERR=1
          RETURN
        ENDIF
        MMAX     = L+1
        M1       = JM+1
        BR(M1,N) = GA
        BI(M1,N) = GB


c        SB(M1,N) = SGA

        NMAX2    = N
        JLOLD    = JL
        IF(TYPE2.EQ.'ALMN') THEN
          CALL RD2(MT2,JN,JM,JL,GA,GB,NUMB2,IEND2)


          SGA = GA*0.04
          SGB = GB*0.04
        ELSE
          CALL RABCD1(MT2,JN,JM,JL,GA,GB,SGA,SGB,NUMB2,IEND2)
        ENDIF
C       CALL RD2(MT2,JN,JM,JL,GA,GB,NUMB2,IEND2)
        IF(MT2.LE.0) THEN
          CALL MSGERR(MDOC,' ERR : READ ALMN FILE-2')
          IF(IEND1.EQ.0) CLOSE(MT1)
          IERR=1
          RETURN
        ENDIF
c        IF(JL.EQ.0) THEN
c          GA=0.0
c          GB=0.0
c        ENDIF
        GO TO 300
      ENDIF
C --------------------------------------------
  400 CONTINUE
      IF(NMAX1.NE.NMAX2.AND.MSG.EQ.'N') THEN
        WRITE(LINE,*) 
     *  ' ERR: NMAX1 # NMAX2 ;L,NMAX1,NMAX2:',L,NMAX1,NMAX2
        CALL MSGERR(MDOC,LINE)
        IF(IEND1.EQ.0.AND.MT1.GT.0) CLOSE(MT1)
        IF(IEND2.EQ.0.AND.MT2.GT.0) CLOSE(MT2)
        IERR=1
        RETURN
      ENDIF
      LK      = L+1
      MMAX    = LK
      NN      = NMAX1
      NMAX(LK)= NN
      LS1     = L/NSYM2+1
      L1      = L/NSYM1+1
      L21     = 2*(L/NSYM2)+1
      LMBLOK  = L1*L21
      DO     M1=1,L1
        MA=NSYM1*(M1-1)+1
        DO     MDASH1=1,L21
          MB   = IABS((MDASH1-LS1)*NSYM2)+1
          ISGN = MOD((MB-1),2)
          INDC = NBASC+(M1-1)*L21+MDASH1
          IF(INDC.GT.IPRMEM.or.INDC.le.0) THEN
            WRITE(LINE,*) ' ERR: ARRAY CLMM : INDEX >',IPRMEM
            CALL MSGERR(MDOC,LINE)
            IF(IEND1.EQ.0.AND.MT1.GT.0) CLOSE(MT1)
            IF(IEND2.EQ.0.AND.MT2.GT.0) CLOSE(MT2)
            IERR=1
            RETURN
          ENDIF
          IF(L.GE.LMINR.AND.L.LE.LMAXR) THEN
            IF(L.LE.L_MIN) L_MIN=L      
            IF(L.GE.L_MAX) L_MAX=L      
            CLMM(INDC)=CMPLX(APT,BPT)
c            SCLMM(INDC) = 0.0
          ELSE
            CLMM(INDC)  = 0.0
c            SCLMM(INDC) = 0.0
          ENDIF
          DO     KN=1,NN
            CA=CMPLX(AR(MA,KN),-AI(MA,KN))
            IF(MSG.NE.'N') THEN
              CB=CMPLX(AR(MB,KN),AI(MB,KN))
            ELSE
              CB=CMPLX(BR(MB,KN),BI(MB,KN))
            ENDIF
            IF((MDASH1-LS1).LT.0) THEN
              CB=CONJG(CB)
              IF(ISGN.EQ.1) CB=-CB
            ENDIF
            IF(L.GE.LMINR.AND.L.LE.LMAXR) THEN
              CLMM(INDC)  = CLMM(INDC)  + CA*CB

c              AM = SQRT(AR(MB,KN)*AR(MB,KN)+AI(MB,KN)*AI(MB,KN))
c              BM = SQRT(BR(MB,KN)*BR(MB,KN)+BI(MB,KN)*BI(MB,KN))
c              SCLMM(INDC) = SCLMM(INDC) + 
c     *                      (BM*SA(MB,KN)+AM*SB(MB,KN))
            ELSE
              CLMM(INDC)  = 0.0
c              SCLMM(INDC) = 0.0
           ENDIF
          ENDDO
        ENDDO
      ENDDO
      NBASC=NBASC+LMBLOK
      IF(IEND1.NE.IEND2.AND.MSG.EQ.'N') THEN
        WRITE(LINE,*) ' ERR: EOF FILE-1 OR FILE-2 :',IEND1,IEND2
        CALL MSGERR(MDOC,LINE)
        IF(IEND1.EQ.0.AND.MT1.GT.0) CLOSE(MT1)
        IF(IEND2.EQ.0.AND.MT2.GT.0) CLOSE(MT2)
        IERR=1
        RETURN
      ENDIF

C      if(l.gt.6) stop

      IF(IEND1.EQ.0) GO TO 110
C =================================================================
      IF(MT1.GT.0) CLOSE(MT1)
      IF(MT2.GT.0) CLOSE(MT2)
      LMAX   = L
      LMAX1  = LMAX+1
      LMAX2  = LMAX*2
      LMAX21 = LMAX*2+1
      IF(LMAX21.GE.IPRGAM) THEN
        WRITE(LINE,*) ' ERR: LMAX*2+1 >',IPRGAM
        CALL MSGERR(MDOC,LINE)
        IERR=1
        RETURN
      ENDIF
C ------------------------------------------
      RF_MAX(1) = 0.0
      RF_MAX(2) = 0.0
      RF_MAX(3) = 0.0
      RF_MAX(4) =-1.0E30 
      NBETA=0
      IF(BETMAX.LT.BETMIN) THEN
        STOR   = BETMAX
        BETMAX = BETMIN
        BETMIN = STOR
      ENDIF
      IF(BETMAX.GT.180.0) BETMAX = 180.
      BETDEL = ABS(BETDEL)
      IF(BETDEL.LT.1.E-7) BETDEL = 5.0
      IF(BETMAX.LT.1.E-7) THEN
        BETMAX = 180.0
      ENDIF
      IF(BETMIN.GT.180.)  BETMIN=180.0
      WRITE(LINE,'('' BETA MIN,MAX,DELTA:'',3F8.2)')
     .                   BETMIN,BETMAX,BETDEL
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,'('' L-MAX,LMIN :'',2I5)')
     .                   L_MAX,L_MIN
      CALL MSGDOC(MDOC,LINE)
      APT = 0.
      BPT = 0.
      NNB = (BETMAX-BETMIN)/BETDEL+1.1
      CALL MSGDOC(MDOC,' ')
      IEND = 0
C      CLOSE(MT1)
C      IF(MSG.EQ.'N') CLOSE(MT2)
C -------------------------------------------
      MT =-1
      DO     NB=1,NNB
        BETA = BETMIN+BETDEL*(NB-1)
        IF(BETA.GT.180.)  BETA=180.
        IF(NB.EQ.NNB) IEND = 1
        BET = BETA*3.1415926/180.
        FACT(1)=0.
        DO     L=1,LMAX2
c         FACT(L+1) = FACT(L)+DLOG(DFLOAT(L))
          FACT(L+1) = FACT(L)+LOG(DFLOAT(L))
        ENDDO
C ////
      IF(BETA.GT.0.0.AND.BETA.LT.180.0) THEN
        ANG = (BETA*3.1415926)/180.0
        CCB = COS(ANG)
        VS = -LOG(.5D0*SIN(ANG))
        KS = VS
        VS = MOD(VS,1D0)
        IF (VS.GT.0D0) THEN
          KS = KS+1
          VS = VS-1
        ENDIF
        VS = EXP(VS)
C
        ANG = .5D0*ANG
        DLCA = LOG(COS(ANG))
        DLSA = LOG(SIN(ANG))
        PCOt(1) = 0D0
        PSIN(1) = 0D0
        DO L = 1,LMAX2
          PCOt(L+1) = PCOt(L)+DLCA
          PSIN(L+1) = PSIN(L)+DLSA
        ENDDO
      ENDIF
C ////
 

c        IF(ABS(BETA).GE.0.000001) THEN
c          BET2   = BET/2.
c          ANG    = DBLE(BET2)
c          CTB2   = DCOS(ANG)/DSIN(ANG)
c          DSANG  = DSIN(ANG)
cC MS      DLCTB2 = DLOG(CTB2)
c          DLCTB2 = LOG(CTB2)
c          IF(BETA.EQ.180.) DSANG=1.0
c          PCOT(1)= 0.
c          PSIN(1)= 0.
c          IF(BETA.EQ.180.) ANG =0.
c          DO     IP=1,LMAX2
c            PCOT(IP+1) = PCOT(IP)+DLCTB2
cC MS        PSIN(IP+1) = PSIN(IP)+DLOG(DSANG)
c            PSIN(IP+1) = PSIN(IP)+LOG(DSANG)
c          ENDDO
c        ENDIF
C -------------------

        IPRGAM2=IPRGAM
        IF(NSYM1.GT.NSYM2.AND.NSYM2.EQ.1) IPRGAM2=IPRGAM*2
c
c        WRITE(*,*) '11 ',IPRALM,IPRGAM,IPRGAM2,NSYM1,NSYM2
C        IF(IPRGAM2.GT.144) IPRGAM2=IPRGAM
C
        IPRGAM2=IPRGAM
c

        DO     I=1,IPRALM
C        DO     J=1,IPRGAM2
        DO     J=1,IPRGAM
          FMM(I,J)=CMPLX(APT,BPT)
        ENDDO
        ENDDO
C -------------------
        IND=2
        DO     L=1,LMAX
          IF(MOD(L,LSTP).EQ.0) THEN
            L1 =L/NSYM1+1
            LS1=L/NSYM2+1
            L21=2*(L/NSYM2)+1
c            CALL CDLMM(L,BETa,FACT,PCOT,PSIN,CTB2,DLMM,DLMN8,
c     *                 IPRL21,IPRLM1)
            CALL DLMMs(BETa,l,cCb,ks,vs,FACT,PCOT,PSIN,DLMM,DLMN8,dlmm,
     *                 IPRL21,IPRLM1)
            DO  M1=1,L1
              MA=(M1-1)*NSYM1+1
              DO  MDASH1=1,L21
                MD1=MDASH1-LS1
                MB=MD1*NSYM2+1+L
                MD1=MD1+1
                IF(MD1.LE.0)  MD1=IPRGAM2+MD1

c                SC = SCLMM(IND)
c                IF(SC.LT.0.0001) SC=1.0
c                WT = 1.0/SC
c                FMM(M1,MD1)=FMM(M1,MD1)+CLMM(IND)*DLMM(MA,MB)*WT
c
c         sfmm(m1,md1) = sfmm(m1,md1)+abs(sCLMM(IND)*DLMM(MA,MB)) 

                FMM(M1,MD1)=FMM(M1,MD1)+CLMM(IND)*DLMM(MA,MB)
                IND=IND+1
              ENDDO
            ENDDO
          ENDIF
        ENDDO
C -------------------

c        sfmax = -1.0e30
c        sfmin =  1.0e30
c        DO     I=1,IPRALM
c        DO     J=1,IPRGAM
c          if(sfmm(i,j).gt.sfmax) sfmax = sfmm(i,j)      
c          if(sfmm(i,j).lt.sfmin) sfmin = sfmm(i,j)      
c        ENDDO
c        ENDDO
c
c        write(*,*) '--sf min,max:',sfmin,sfmax
c                IF(Sfmin.LT.0.0001) Sfmin=1.0
c
c        DO     I=1,IPRALM
c        DO     J=1,IPRGAM
c          SC = SFMM(I,j)
c          IF(SC.LT.0.0001) SC=1.0
c          WT = sfmin/SC
c          FMM(i,j)=FMM(i,j)*wt
c        ENDDO
c        ENDDO

        ID(1)=IPRALM
c        ID(2)=IPRGAM2
        ID(2)=IPRGAM
        ID(3)=0
        CALL MDHFT(FMM,ID,IERR)
        IF(IERR.NE.0) THEN
          WRITE(LINE,*) ' ERR: ERROR IN MDHFT'
          CALL MSGERR(MDOC,LINE)
          IF(MT.GT.0) CLOSE(MT)
          IERR=1
          RETURN
        ENDIF
C -------------------
        CALL RFOUT(MDOC,MT,NAMEO,FMM,BETA,BETMIN,BETMAX,BETDEL
     *  ,RF_MAX,NSYM1,NSYM2,MSG,TITLE1,TITLE2,ARAD1,RN1,RX1,IPRGAM
     *  ,IPRGAM2,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.GT.0) RETURN
        NBETA=NBETA+1
      ENDDO
C ---
c        RF_MAX(1) alpha /grad/
c        RF_MAX(2) beta
c        RF_MAX(3) gamma
c        RF_MAX(4) RF 

      CALL LENSTR_BL(NAMEO,LEN)
      IF(LEN.LE.0.OR.NAMEO(1:1).EQ.','.OR.NAMEO(1:1).EQ.' ')THEN

        BETA   = RF_MAX(2) 
        BETMIN = BETA - BETDEL  
        BETMAX = BETA + BETDEL 
        BETDEL = BETDEL/4 
        RF_MAX(1) = 0.0
        RF_MAX(2) = 0.0
        RF_MAX(3) = 0.0
        RF_MAX(4) =-1.0E30 
        NBETA=0
        IF(BETMIN.LT.  0.0) BETMIN = 0.0
        IF(BETMAX.GT.180.0) BETMAX = 180.0
        WRITE(LINE,'('' BETA MIN,MAX,DELTA:'',3F8.2)')
     .                   BETMIN,BETMAX,BETDEL
        CALL MSGDOC(MDOC,LINE)
        APT = 0.0
        BPT = 0.0
        NNB = (BETMAX-BETMIN)/BETDEL+1.1
        CALL MSGDOC(MDOC,' ')
        IEND = 0
C -------------------------------------------
        MT =-1
        DO     NB=1,NNB
          BETA = BETMIN+BETDEL*(NB-1)
          IF(BETA.GT.180.)  BETA=180.
          IF(NB.EQ.NNB) IEND = 1
          BET = BETA*3.1415926/180.
          FACT(1)=0.
          DO     L=1,LMAX2
            FACT(L+1) = FACT(L)+LOG(DFLOAT(L))
          ENDDO
C ////
       IF(BETA.GT.0.0.AND.BETA.LT.180.0) THEN
        ANG = (BETA*3.1415926)/180.0
        CCB = COS(ANG)
        VS = -LOG(.5D0*SIN(ANG))
        KS = VS
        VS = MOD(VS,1D0)
        IF (VS.GT.0D0) THEN
          KS = KS+1
          VS = VS-1
        ENDIF
        VS = EXP(VS)
C
        ANG = .5D0*ANG
        DLCA = LOG(COS(ANG))
        DLSA = LOG(SIN(ANG))
        PCOt(1) = 0D0
        PSIN(1) = 0D0
        DO L = 1,LMAX2
          PCOt(L+1) = PCOt(L)+DLCA
          PSIN(L+1) = PSIN(L)+DLSA
        ENDDO
       ENDIF
C ////
c          IF(ABS(BETA).GE.0.000001) THEN
c            BET2   = BET/2.
c            ANG    = DBLE(BET2)
c            CTB2   = DCOS(ANG)/DSIN(ANG)
c            DSANG  = DSIN(ANG)
cC MS        DLCTB2 = DLOG(CTB2)
c            DLCTB2 = LOG(CTB2)
c            IF(BETA.EQ.180.) DSANG=1.0
c            PCOT(1) = 0.0
c            PSIN(1) = 0.0
c            IF(BETA.EQ.180.) ANG =0.0
c            DO     IP=1,LMAX2
c              PCOT(IP+1) = PCOT(IP)+DLCTB2
cC MS          PSIN(IP+1) = PSIN(IP)+DLOG(DSANG)
c              PSIN(IP+1) = PSIN(IP)+LOG(DSANG)
c            ENDDO
c          ENDIF
C -------------------
          IPRGAM2=IPRGAM
          IF(NSYM1.GT.NSYM2.AND.NSYM2.EQ.1) IPRGAM2=IPRGAM*2
          IPRGAM2=IPRGAM
          DO     I=1,IPRALM
          DO     J=1,IPRGAM
            FMM(I,J)=CMPLX(APT,BPT)
          ENDDO
          ENDDO
C -------------------
          IND=2
          DO L=1,LMAX
            IF(MOD(L,LSTP).EQ.0) THEN
              L1  = L/NSYM1+1
              LS1 = L/NSYM2+1
              L21 = 2*(L/NSYM2)+1
c             CALL CDLMM(L,BETa,FACT,PCOT,PSIN,CTB2,DLMM,DLMN8,
c    *                 IPRL21,IPRLM1)
         CALL DLMMs(BETa,l,Ccb,ks,vs,FACT,PCOT,PSIN,DLMM,DLMN8,dlmm,
     *                 IPRL21,IPRLM1)
              DO M1=1,L1
                MA = (M1-1)*NSYM1+1
                DO  MDASH1=1,L21
                  MD1 = MDASH1-LS1
                  MB  = MD1*NSYM2+1+L
                  MD1 = MD1+1
                  IF(MD1.LE.0) MD1 = IPRGAM2 + MD1
c                SC = SCLMM(IND)
c                IF(SC.LT.0.0001) SC=1.0
c                WT = 1.0/SC
c                  FMM(M1,MD1) = FMM(M1,MD1) + 
c     *                          CLMM(IND)*DLMM(MA,MB)*WT
                  FMM(M1,MD1) = FMM(M1,MD1) + 
     *                          CLMM(IND)*DLMM(MA,MB)
                  IND = IND + 1
                ENDDO
              ENDDO
            ENDIF
          ENDDO
C -------------------
          ID(1)=IPRALM
          ID(2)=IPRGAM
          ID(3)=0

          CALL MDHFT(FMM,ID,IERR)
          IF(IERR.NE.0) THEN
            WRITE(LINE,*) ' ERR: ERROR IN MDHFT'
            CALL MSGERR(MDOC,LINE)
            IF(MT.GT.0) CLOSE(MT)
            IERR=1
            RETURN
          ENDIF
C -------------------
          CALL RFOUT(MDOC,MT,NAMEO,FMM,BETA,BETMIN,BETMAX,BETDEL
     *  ,RF_MAX,NSYM1,NSYM2,MSG,TITLE1,TITLE2,ARAD1,RN1,RX1,IPRGAM
     *    ,IPRGAM2,NSYM,ISYM,IPRSYM,IERR)
          IF(IERR.GT.0) RETURN
          NBETA=NBETA+1
        ENDDO
      ENDIF
C ---
      RETURN
      END

C --- RFRES1.FOR ---
      SUBROUTINE RFOUT(MDOC,MT,NAMEO,FMM,BETA,BETMIN,BETMAX,BETDEL
     * ,RF_MAX,NSYM1,NSYM2,MSG,TITLE1,TITLE2,ARAD,RN,RX,IPRGAM
     * ,IPRGAM2,NSYM,ISYM,IPRSYM,IERR)
C ------------------------------------------------
      INTEGER*2 ISYM(5,3,IPRSYM)
c      REAL      FMM(IPRGAM,IPRGAM2),RFMAX(5)
      REAL      FMM(IPRGAM,IPRGAM),RFMAX(5),RF_MAX(4)
      COMMON/COM_RFR/ RRMAX,RRMIN,IANGLEA(400),IANGLEG(400)
     *               ,IX0,IY0,IZ0,ITR
     *               ,ICNTZ,NX,NY,NZ,IZMIN,IZMAX,RESMAX,VOL2
      REAL      IANGLE
      CHARACTER NAMEO*(*),TITLE1*(*),TITLE2*(*)
      CHARACTER ITP*4,MSG*1,TITLE*80
      CHARACTER LINE1*80,LINE2*80,LINE*80
C====================================================================
      MD=-ABS(MDOC)-1
      IF(MT.LT.0) THEN
        MT=0
        PI=4.0*ATAN(1.0)
C        VOL2=(4.0*PI*ARAD*ARAD*ARAD)/3.0
C        VOL2=VOL2*VOL2
        VOL2=1.0
        RRMAX=-1.E30
        RRMIN= 1.E30
        A=ARAD*10.
        B=RN  *10.
        C=RX  *10.
        AL=PI/(2.*FLOAT(NSYM1))
        BE=PI/(2.*FLOAT(NSYM2))
        GA=PI/2.
        TITLE(9:80)=TITLE1(9:80)
        IF(MSG.EQ.'N') THEN
          LINE1=TITLE1
          LINE2=TITLE2
          TITLE=LINE1(1:30)//' & '//LINE2(9:24)
        ENDIF
        TITLE(5:8)='ABG '
        TITLE(1:4)='RF: '
        NX=IPRGAM
c       NY=IPRGAM2
        NY=IPRGAM
c
c        write(*,*) ' nx,ny',nx,ny
c
        NZ=180./BETDEL+1.
        DELALP=360.0/NX
        DELGAM=360.0/NY
        IZMIN=BETMIN/BETDEL
        IZMAX=BETMAX/BETDEL

        DELB=(BETDEL*PI)/180.0
        RESMAX=DELB
        DELA=(2.0*PI)/(NX*NSYM1)      
        DELG=(2.0*PI)/(NY*NSYM2)
        IF(RESMAX.LT.DELA) RESMAX=DELA      
        IF(RESMAX.LT.DELG) RESMAX=DELG      
        RESMAX=(RESMAX*180.0)/PI

        ITR=0
        IX0=0
        IY0=0
        IZ0=0
        ITP='RI  '
        CALL LENSTR_BL(NAMEO,LEN)
        IF(LEN.GT.0.AND.NAMEO(1:1).NE.','.AND.NAMEO(1:1).NE.' ') 
     *  THEN
          IERR = 0
          MT   = 17
          F1   = 0.0
          F2   = 0.0
          F3   = 0.0
          F4   = 0.0
          CALL C_CR_WR
          CALL SET_TITLE(MD,A,B,C,AL,BE,GA
     *    ,F1,F2,F3,F4,NX,NY,NZ,IZMIN,IZMAX,TITLE,IERR)
          CALL OWFILE(MD,MT,NAMEO,ITP,NSYM,ISYM,IPRSYM,IERR)
          IF(IERR.NE.0) THEN
            CALL MSGERR(MDOC,' ERR: OPEN OUTPUT FILE')
            RETURN
          ENDIF
        ENDIF
        ICNTZ=-999
        DO     I=1,NX
          II=((FLOAT(I)-1.)*DELALP/FLOAT(NSYM1))*10
          IANGLEA(I)=II+0.000001
        ENDDO
        DO     I=1,NY
          II=((FLOAT(I)-1.)*DELGAM/FLOAT(NSYM2))*10
          IANGLEG(I)=II+0.000001
        ENDDO
        WRITE(LINE,10)
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,20)
        CALL MSGDOC(MDOC,LINE)
      ENDIF
C -------------------------------------
      RFMAX(4)=-1.E30
      RFMAX(5)= 1.E30
      IMAX    = 0
      JMAX    = 0 

      DO     I=1,NX
      DO     J=1,NY

        IF(ABS(FMM(I,J)).GT.1.E30) THEN
          CALL MSGERR(MDOC,
     *    ' ERROR: in RFROT: RF overflow')
          IERR=1
          RETURN
        ENDIF

        RF=FMM(I,J)/VOL2
        FMM(I,J)=RF
        IF(RF.GT.RFMAX(4)) THEN
          RFMAX(1)=BETA
          RFMAX(2)=IANGLEA(I)/10.0
          RFMAX(3)=IANGLEG(J)/10.0
          RFMAX(4)=RF
          IMAX    = I
          JMAX    = J
        ENDIF
        IF(RF.LT.RFMAX(5)) RFMAX(5)=RF
        IF(RF.GT.RRMAX)    RRMAX   =RF
        IF(RF.LT.RRMIN)    RRMIN   =RF
      ENDDO
      ENDDO
C     RF=FMM(I,J)/VOL2 --> RFMAX(4)  
C     alpha-x-i(NX) --> RFMAX(2)       
      IF(IMAX.GT.1.AND.IMAX.LT.NX) THEN
        D1 = FMM(IMAX-1,JMAX)
        D2 = FMM(IMAX  ,JMAX)
        D3 = FMM(IMAX+1,JMAX)
        CALL RFR_PARAB(D1,D2,D3,X_PR,C_PR,D_PR)
      ELSE
        X_PR = 0.0
        C_PR = 0.0
        D_PR = RFMAX(4)
      ENDIF

      IF(X_PR.GE.0.0) THEN
        I1 = IMAX
        I2 = IMAX
        IF(IMAX.LT.NX) I2 = IMAX + 1 
        FX = X_PR
      ELSE 
        I1 = IMAX 
        I2 = IMAX 
        IF(IMAX.GT.1) I1 = IMAX - 1 
        FX = 1.0 + X_PR
      ENDIF

C      gamma-Y-J(NY) --> RFMAX(3)         

      IF(JMAX.GT.1.AND.JMAX.LT.NY) THEN
        D1  = FMM(IMAX,JMAX-1)
        D2  = FMM(IMAX,JMAX  )
        D3  = FMM(IMAX,JMAX+1)
        CALL RFR_PARAB(D1,D2,D3,X_PR,C_PR,D_PR)
      ELSE
        X_PR = 0.0
        C_PR = 0.0
        D_PR = RFMAX(4)
      ENDIF

      IF(X_PR.GE.0.0) THEN
        J1 = JMAX
        J2 = JMAX
        IF(JMAX.LT.NY) J2 = JMAX + 1 
        FY = X_PR
      ELSE 
        J1 = JMAX 
        J2 = JMAX 
        IF(JMAX.GT.1) J1 = JMAX - 1 
        FY = 1.0 + X_PR
      ENDIF

      D1  = FMM(I1,J1)
      D2  = FMM(I2,J1)
      DD1 = FX*(D2-D1) + D1
      D1  = FMM(I1,J2)
      D2  = FMM(I2,J2)
      DD2 = FX*(D2-D1) + D1
      RFMAX(4) = FY*(DD2-DD1) + DD1

      D1 = IANGLEA(I1)/10.0
      D2 = IANGLEA(I2)/10.0
      RFMAX(2)= FX*(D2-D1) + D1 
      D1 = IANGLEG(J1)/10.0
      D2 = IANGLEG(J2)/10.0
      RFMAX(3)= FY*(D2-D1) + D1 
C --------------------
      MMD=99
      IF(MT.GT.0) THEN
        CALL WDENS(MT,MMD,ICNTZ,NX,NY,NZ,IZMIN,IZMAX,RRMAX,RRMIN,
     *           FMM,RESMAX,IX0,IY0,IZ0,ITR)
        IF(MT.LE.0) THEN
          CALL MSGERR(MDOC,' ERR: WRITE OUTPUT_FILE')
          IERR=1
          RETURN
        ENDIF
      ENDIF
C --------------------

      IF(RF_MAX(4).LT.RFMAX(4)) THEN
        RF_MAX(1) = RFMAX(2)
        RF_MAX(2) = RFMAX(1)
        RF_MAX(3) = RFMAX(3)
        RF_MAX(4) = RFMAX(4)
      ENDIF


      WRITE(LINE,30) RFMAX(2),RFMAX(1),RFMAX(3),RFMAX(4),RFMAX(5)
      CALL MSGDOC(MDOC,LINE)
   10 FORMAT(5X,' MAX VALUE OF ROT FUNCTION ON EACH BETA SECTION')
   20 FORMAT(2X,'ALPHA - X ',7X,'BETA - Z',6X,'GAMMA -Y')
   30 FORMAT(1X,F6.1,5X,F6.1,5X,F6.1,5X,E12.4,2X,E12.4)
      RETURN
      END

      SUBROUTINE RFR_PARAB(F_1,F0,F1,X_PR,C_PR,D_PR)
      IF(F1.GT.F0.OR.F_1.GT.F0) GO TO 100
      C_PR = F0 - (F_1 + F1 )/2.0
      IF(C_PR.LE.0.00001)       GO TO 100
      X_PR = (F1 - F_1)/(4.0*C_PR)
      IF(ABS(X_PR).GE.1.0)      GO TO 100
      D_PR = F0 + C_PR*X_PR*X_PR
      RETURN
 100  CONTINUE
      X_PR = 0.0
      C_PR = 0.0
      D_PR = F0
      RETURN
      END

      SUBROUTINE DLMMS(OMEG,L,CB,KS,VS,FACT,PCOS,PSIN,SDLMM,DLMM,IEXP
     *    ,IPRL21,IPRLM1)
C      IMPLICIT NONE
      INTEGER K0,K1,KS,L,M1,M1S,M2,M2S,MDL,MDL2,MM1,MM2,IPRL21,IPRLM1
      REAL OMEG,DTR,PI
      REAL*8 CB,E0,E1,V0,V1,VS,W0,W1
C
      PARAMETER(MDL=100, MDL2=2*MDL, PI=3.141592654D0, DTR=PI/180.)
C
      INTEGER IEXP(IPRLM1,IPRL21)
      REAL*8 DLMM(IPRLM1,IPRL21),FACT(IPRL21),PCOS(IPRL21),PSIN(IPRL21)
      REAL   SDLMM(IPRLM1,IPRL21) 
      REAL*8 ANORM(101),DNORM
      CHARACTER LINE*80
C
      DATA E0/.2718281828459045D1/, E1/.3678794411714423D0/
C --------------------------------------
      DO M1 = 0,L
        MM1 = M1 + 1
        DO M2 = -L,L
          MM2 = M2 + L + 1
          IEXP(MM1,MM2) = 0
          DLMM(MM1,MM2) = 0D0
        ENDDO
      ENDDO
C
      IF (OMEG.LE.0.0001) THEN
        DO M1 = 0,L
          MM1 = M1 + 1
          MM2 = M1 + L + 1
          DLMM(MM1,MM2) = 1D0
        ENDDO
C
      ELSEIF (OMEG.GE.179.99) THEN
        M1S = 1
        DO M1 = 0,L
          MM1 = M1 + 1
          MM2 = -M1 + L + 1
          DLMM(MM1,MM2) = DBLE(M1S)
          M1S = -M1S
        ENDDO
C
      ELSE

       DO M2 = -L,L
          W0 = (FACT(2*L+1)-FACT(L+M2+1)-FACT(L-M2+1))/2 + 
     *          PCOS(L+M2+1)+PSIN(L-M2+1)
          K0 = W0
          W0 = MOD(W0,1D0)
C
          IF (W0.GT.0D0) THEN
            K0 = K0+1
            W0 = W0-1
          ENDIF
C
          MM2 = M2 + L + 1
          IEXP(L+1,MM2) = K0
          DLMM(L+1,MM2) = EXP(W0)
        ENDDO
C
        W0 = VS/SQRT(DBLE(2*L))
C
        DO M2 = -L+1,L-1
          MM2 = M2 + L + 1
          K0 = IEXP(L+1,MM2)+KS
          V1 = (DBLE(L)*CB-DBLE(M2))*W0*DLMM(L+1,MM2)
          V0 = ABS(V1)
C
          IF (V0.GT.1D0) THEN
1           K0 = K0+1
            V0 = E1*V0
            IF (V0.GT.1D0) GOTO 1
          ENDIF
C
          IF (V0.LT.E1) THEN
2           K0 = K0-1
            V0 = E0*V0
            IF (V0.LT.E1) GOTO 2
          ENDIF
C             
          IEXP(L,MM2) = K0
          DLMM(L,MM2) = SIGN(V0,V1)
        ENDDO
C
        IF(L.GT.1) THEN
        DO M1 = L-1,1,-1
          MM1 = M1 + 1
          W0 = VS/SQRT(DBLE((L-M1+1)*(L+M1)))
          W1 = SQRT(DBLE((L+M1+1)*(L-M1))/DBLE((L-M1+1)*(L+M1)))
C
          DO M2 = -M1+1,M1-1
            MM2 = M2 + L + 1
            K1 = IEXP(MM1+1,MM2)
            V1 = DLMM(MM1+1,MM2)
            K0 = IEXP(MM1,MM2)+KS
            V0 = DLMM(MM1,MM2)
C
            IF (K0.GT.K1) THEN
              V1 = EXP(DBLE(K1-K0))*V1
            ELSEIF (K1.GT.K0) THEN
              V0 = EXP(DBLE(K0-K1))*V0
              K0 = K1
            ENDIF
C
            V1 = (DBLE(M1)*CB-DBLE(M2))*W0*V0-W1*V1
            V0 = ABS(V1)
C
            IF (V0.GT.1D0) THEN
3             K0 = K0+1
              V0 = E1*V0
              IF (V0.GT.1D0) GOTO 3
            ENDIF
C
            IF (V0.LT.E1) THEN
4             K0 = K0-1
              V0 = E0*V0
              IF (V0.LT.E1) GOTO 4
            ENDIF
C
            IEXP(MM1-1,MM2) = K0
            DLMM(MM1-1,MM2) = SIGN(V0,V1)
          ENDDO
        ENDDO
        ENDIF
      ENDIF
C
      M1S = -1
      DO M1 = 1,L
        M2S = M1S
        M1S = -M1S
        DO M2 = 0,M1-1
          MM1 = M1 + L + 1
          MM2 = M2 + L + 1
c ---  6.07.03  bug in red hat 7.2
          WRITE(LINE,*) '--L,M1,M2',L,M1,M2
c ---
          IEXP(M2+1,MM1) = IEXP(M1+1,MM2)
          DLMM(M2+1,MM1) = DBLE(M2S)*DLMM(M1+1,MM2)
          MM1 = -M1 + L + 1
          MM2 = -M2 + L + 1
          IEXP(M2+1,MM1) = IEXP(M1+1,MM2)
          DLMM(M2+1,MM1) = DLMM(M1+1,MM2)
          M2S = -M2S
        ENDDO
      ENDDO
C
      DO M1 = 0,L
        DO M2 = -L,L
          MM2 = M2 + L + 1
          DLMM(M1+1,MM2) = EXP(DBLE(IEXP(M1+1,MM2)))*DLMM(M1+1,MM2)
        ENDDO
      ENDDO
      DO M1=0,L
      DO M2=-L,L
        MM1 = M1 + 1
        MM2 = M2 + L + 1
        SDLMM(MM1,MM2) =DLMM(MM1,MM2)
      ENDDO
      ENDDO

c ----
c      DO M1=0,L
c        DNORM = 0.0
c        DO M2=-L,L
c          MM1 = M1 + 1
c          MM2 = M2 + L + 1
c          IF(ABS(DLMM(MM1,MM2)).GT.1.D-5)
c     *      DNORM = DNORM + DLMM(MM1,MM2)*DLMM(MM1,MM2)
c        ENDDO
c        ANORM(MM1) = DNORM
c      ENDDO
c      WRITE(*,*) ' L=',L,' BETA=',OMEG
c      WRITE(*,'(1X,5D15.8)') (ANORM(MM1),MM1=1,L+1) 
c ----

      RETURN
      END
C
     
      SUBROUTINE CDLMM(L,BETA,FACT,PCOT,PSIN,CTB2,SDLMM,DLMM,
     *                 IPRL21,IPRLM1)
C ------------------------------------------------------------------
CMS     : DLMM,SDLMM
      REAL*8    DLMM (IPRLM1,IPRL21)
      REAL      SDLMM(IPRLM1,IPRL21)
      REAL*8    FACT(IPRL21),PCOT(IPRL21),PSIN(IPRL21),CTB2
C ---
      REAL*8    D
      REAL*8    ANORM(101),dnorm
C ------------------------------------------------------------------
      L1 =L+1
      L21=2*L+1
C ---
      DO     I1=1,L1
      DO     I2=1,L21
        SDLMM(I1,I2)=0.
        DLMM (I1,I2)=0.
      ENDDO
      ENDDO
C ---
      IF(BETA.EQ.0.0) THEN
        DO     M1=1,L1
          M2=M1+L
          DLMM(M1,M2)=1.0 D 0
        ENDDO
      ELSE
        DO     M1=1,L21
          M  =M1-L-1
          LOM=L-M
          LAM=L+M
          D=0.5*(FACT(2*L+1)-FACT(LAM+1)-FACT(LOM+1))+
     *      PCOT(LAM+1)+PSIN(2*L+1)
          IF(D.GE.-150.D0) THEN
            DLMM(L1,M1)=DEXP(D)
          ENDIF
        ENDDO
C ------
        DO     I2=1,L
          M2  =L-I2
          MI2 =M2+1
          M221=2*M2+1
          DO     I1=1,M221
            M1 =I1-M2-1
            MI1=M1+L1
            DLMM(MI2,MI1)=(DFLOAT(M2-M1+1)*CTB2*DLMM(MI2+1,MI1)
     *             -DSQRT(DFLOAT((L+M1)*(L-M1+1)))*DLMM(MI2+1,MI1-1))/
     *              DSQRT(DFLOAT((L+M2+1)*(L-M2)))
          ENDDO
        ENDDO
C ------
        DO     J2=2,L1
          M2=J2-1
          DO     J1=1,M2
            M1=1-J1
            I1=L1+M1
            M7=1-M1
            M8=L1-M2
            DLMM(M7,M8)=DLMM(J2,I1)
          ENDDO
        ENDDO
C -----
        DO     J2=2,L1
          M2=J2-1
          DO     J1=1,M2
            M1=J1-1
            L1BM1=L1+M1
            L1AM2=L1+M2
            DLMM(J1,L1AM2)=DLMM(J2,L1BM1)
            IF(MOD(M1+M2,2).NE.0) DLMM(J1,L1AM2)=-DLMM(J1,L1AM2)
          ENDDO
        ENDDO
      ENDIF
C --------------------------
      DO     M1=1,L1
      DO     M2=1,L21
C       SDLMM(M1,M2) = SNGL(DLMM(M1,M2))
        SDLMM(M1,M2) = DLMM(M1,M2)
      ENDDO
      ENDDO
C ---------------------------
      DO     I2=1,L1
        dNORM=0.0
        DO     I1=1,L21
          IF(DABS(DLMM(I2,I1)).GT.1.D-5)
     *           dNORM=dNORM+DLMM(I2,I1)*DLMM(I2,I1)
        ENDDO
        ANORM(I2)=dNORM
      ENDDO
C ------------------------------------------------------
      WRITE(*,10) L,BETA
   10 FORMAT(/,'    L=',I5,'  BETA=',F5.1)
      WRITE(*,20) (ANORM(I2),I2=1,L1)
   20 FORMAT(1X,5D15.8)
C -------------------------------------------------------
      RETURN
      END

      SUBROUTINE SRFROT(MDOC,NAME1,NAMEO,ALPHA,BETA,GAMMA
     * ,DLMN8,CLMM,FMM,FACT,PCOT,PSIN
     * ,DLMM,AR,AI,BR,BI,NMAX
     * ,IPRLMX,IPRLM1,IPRL21,IPRMEM,IPRALM,IPRGAM,IPRNMX
     * ,LMINR,LMAXR
     * ,ISYM,IPRSYM,IERR)
C --------------------------------------------------------------------
C ---------
      INTEGER*2 ISYM(5,3,IPRSYM)

      REAL*8    DLMN8(IPRLM1,IPRL21)
      REAL      DLMM (IPRLM1,IPRL21)
      REAL*8    FACT(IPRL21),PCOT(IPRL21),PSIN(IPRL21)
      COMPLEX   CLMM(IPRMEM),FMM(IPRALM,IPRGAM)
      REAL      AR(IPRLM1,IPRNMX),AI(IPRLM1,IPRNMX)
      REAL      BR(IPRLM1,IPRNMX),BI(IPRLM1,IPRNMX)
      INTEGER   NMAX(IPRLM1)

      COMPLEX   CA,CB
      REAL*8    ANG,DLCTB2,CTB2,DSANG,CCB,VS,dlca,dlsa
      INTEGER   ID(3)
      REAL      RLATT(6)
      CHARACTER NAME1*(*),NAMEO*(*)
C     CHARACTER NAME2*256
      CHARACTER TITLE1*80,TYPE*4,TITLE2*80
      CHARACTER MSG*1,MSGL*1,LINE*80
C -------------------------------------------------------------
      IPRLM2 = IPRLMX+2   
      IERR   = 0
      MD     =-ABS(MDOC)-1
      M      = 99

      MSGL   = 'Y'

      NBASC  = 0
      APT    = 0.
      BPT    = 0.
C --------------
      MT1   = 10
      TYPE  = 'ALMN'
      CALL ORFILE(MD,MT1,NAME1,TYPE,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MD,' ERR: OPEN INPUT ALMN_FILE')
        RETURN
      ENDIF
      CALL GET_TITLE(MD,RLATT(1),RLATT(2),
     . RLATT(3),RLATT(4),RLATT(5),RLATT(6),CF,BT,RN1,RX1,IDM,IDM
     . ,IDM,IDM,IDM,TITLE1,IERR)
      CALL C_RD_CR
C ----------------
      CALL C_CR_WR
      CALL SET_TITLE(MD,RLATT(1),RLATT(2),
     . RLATT(3),RLATT(4),RLATT(5),RLATT(6),CF,BT,RN1,RX1,IDM,IDM
     . ,IDM,IDM,IDM,TITLE1,IERR)
      MT2   =11
      TYPE  ='ALMN'
      CALL OWFILE(MD,MT2,NAMEO,TYPE,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MD,' ERR: OPEN OUTPUT ALMN_FILE')
        RETURN
      ENDIF
      IEND2 =-1
      NUMB2 = 0
C -----------------
      ARAD1 = CF
      NSYM1 = BT+.1
      IEND1 =-1
      NUMB1 = 0
      IF(TITLE1(5:8).EQ.' PT ') THEN
        LSTP = 2
      ELSE
        LSTP = 1
      ENDIF
C -------------------------------------------------------------
C      LMINR= 0
C      LMAXR = 60

      IF(LMINR.LE.0) LMINR = 0
      IF(LMAXR.LE.0) LMAXR = 100

      LMAX  = iprlmx
      LMAX2 = LMAX*2
C ---------------------------
      PI   = 4.0*ATAN(1.0)
C     
C     Rotation corresponds to solution RFRES and TRANS-program
C     i.e.:   RFRES: (a,b,g) peak for file_1: model1 
C                                     file_2: model2
C             TRANS: model2 --> model1: angle: a,b,g
C             RFROT: model2 --> model1: angle: a,b,g 
C
      IF(BETA.LE.-180.0) THEN
        BETA = BETA + 360.0         
      ENDIF
      IF(BETA.GT.180.0) THEN
        BETA = BETA - 360.0 
      ENDIF
      IF(BETA.LT.0.0) THEN
        BETA  =-BETA
        ALPHA = ALPHA + 180.0
        GAMMA = GAMMA + 180.0
      ENDIF

      IF(BETA.EQ.180.0) THEN
        BETA  = 0.0
        GAMMA = -GAMMA 
      ENDIF

      ALP = ALPHA*PI/180.
      BET = BETA *PI/180.
      GAM = GAMMA*PI/180.
      IF(BETA.GT.180.)  BETA=180.

      FACT(1)=0.
      DO     L=1,LMAX2
c        FACT(L+1)=FACT(L)+DLOG(DFLOAT(L))
        FACT(L+1) = FACT(L)+LOG(DFLOAT(L))
      ENDDO
C ////
      IF(BETA.GT.0.0.AND.BETA.LT.180.0) THEN
        ANG = (BETA*3.1415926)/180.0
        CCB = COS(ANG)
        VS = -LOG(.5D0*SIN(ANG))
        KS = VS
        VS = MOD(VS,1D0)
        IF (VS.GT.0D0) THEN
          KS = KS+1
          VS = VS-1
        ENDIF
        VS = EXP(VS)
C
        ANG = .5D0*ANG
        DLCA = LOG(COS(ANG))
        DLSA = LOG(SIN(ANG))
        PCOt(1) = 0D0
        PSIN(1) = 0D0
        DO L = 1,LMAX2
          PCOt(L+1) = PCOt(L)+DLCA
          PSIN(L+1) = PSIN(L)+DLSA
        ENDDO
      ENDIF
C ////
 

c        IF(ABS(BETA).GE.0.000001) THEN
c          BET2   = BET/2.
c          ANG    = DBLE(BET2)
c          CTB2   = DCOS(ANG)/DSIN(ANG)
c          DSANG  = DSIN(ANG)
cC MS      DLCTB2 = DLOG(CTB2)
c          DLCTB2 = LOG(CTB2)
c          IF(BETA.EQ.180.) DSANG=1.0
c          PCOT(1) = 0.
c          PSIN(1) = 0.
c          IF(BETA.EQ.180.) ANG =0.
c          DO     IP=1,LMAX2
c            PCOT(IP+1) = PCOT(IP)+DLCTB2
cC MS        PSIN(IP+1) = PSIN(IP)+DLOG(DSANG)
c            PSIN(IP+1) = PSIN(IP)+LOG(DSANG)
c          ENDDO
c        ENDIF
C ----------------
c        DO     L=1,LMAX
c          IF(MOD(L,LSTP).EQ.0) THEN
c            CALL CDLMM_ROT(L,BET,FACT,PCOT,PSIN,CTB2,DLMM,DLMN8,
c     *                 IPRL21,IPRLM1)
c          ENDIF 
c        ENDDO
C =============================================================
      ILOLD=-111
 500  CONTINUE
      CALL RD1(MT1,IN,IM,IL,FA,FB,NUMB1,IEND1)
      IF(MT1.LE.0) THEN
        CALL MSGERR(MDOC,' ERR : READ ALMN_FILE-1')
        CLOSE(MT1)
        IERR=1
        RETURN
      ENDIF
      IF(IEND1.GT.0) THEN
        CALL MSGERR(MDOC,' ERR : EMPTY ALMN_FILE-1')
        IERR=1
        RETURN
      ENDIF
C -----------------------------------------------
  100 CONTINUE
      IF(IEND1.GT.0)                    GO TO 200
      IF(IL.NE.ILOLD.AND.ILOLD.NE.-111) THEN
        GO TO 200
      ENDIF
  110 L =IL
      IF(L.GT.IPRLMX) THEN
        WRITE(LINE,*) ' ERR: L >',IPRLMX
        CALL MSGERR(MDOC,LINE)
        CLOSE(MT1)
        CLOSE(MT2)
        IERR=1
        RETURN
      ENDIF
      M = IM
      N = IN
      IF(N.GT.IPRNMX) THEN
        WRITE(LINE,*) ' ERR: N >',IPRNMX
        CALL MSGERR(MDOC,LINE)
        CLOSE(MT1)
        CLOSE(MT2)
        IERR=1
        RETURN
      ENDIF
      MMAX     = L+1
      M1       = IM+1
      AR(M1,N) = FA
      AI(M1,N) = FB
      NMAX1    = N
      ILOLD    = IL
      CALL RD1(MT1,IN,IM,IL,FA,FB,NUMB1,IEND1)
      IF(MT1.LE.0) THEN
        CALL MSGERR(MDOC,' ERR : READ ALMN ')
        CLOSE(MT2)
        IERR=1
        RETURN
      ENDIF
      GO TO 100
C --------------
  200 CONTINUE

      LK   = L+1
      MMAX = LK
      NN   = NMAX1
      LS1  = L/NSYM1+1
      L1   = L/NSYM1+1
      L21  = 2*(L/NSYM1)+1

      IF(L.GE.LMINR.AND.L.LE.LMAXR) THEN
      
c      CALL CDLMM_ROT(L,BET,FACT,PCOT,PSIN,CTB2,DLMM,DLMN8,
c     *                 IPRL21,IPRLM1)
         CALL DLMMs(BETa,l,Ccb,ks,vs,FACT,PCOT,PSIN,DLMM,DLMN8,dlmm,
     *                 IPRL21,IPRLM1)

      DO  M1=1,L1
        MA=NSYM1*(M1-1)+1
        DO KN=1,NN
          BR(MA,KN) = 0.0
          BI(MA,KN) = 0.0
        ENDDO
        DO MDASH1=1,L21
          MB   = IABS((MDASH1-LS1)*NSYM1)+1
          ISGN = MOD((MB-1),2)
          MBB  = (MDASH1-LS1)*NSYM1+1+L
          DO  KN=1,NN
            AAR = AR(MB,KN)
            AAI = AI(MB,KN)
            IF((MDASH1-LS1).LT.0) THEN
              AAI =-AAI
              IF(ISGN.EQ.1) THEN
                AAR =-AAR
                AAI =-AAI
              ENDIF
            ENDIF
            DLM = DLMM(MA,MBB)
C            ARG=(M1-1)*NSYM1*GAM+(MDASH1-LS1)*NSYM1*ALP
C
C            11.04.96
C
            ARG  =-((M1-1)*NSYM1*ALP+(MDASH1-LS1)*NSYM1*GAM)
            SING = SIN(ARG)
            COSG = COS(ARG)
            BBR  = (AAR*COSG-AAI*SING)*DLM
            BBI  = (AAI*COSG+AAR*SING)*DLM
            BR(MA,KN) = BR(MA,KN)+BBR
            BI(MA,KN) = BI(MA,KN)+BBI
          ENDDO
        ENDDO
      ENDDO

      ELSE

C ---
      DO  MM1=1,L1
        M1 = L1-MM1+1
        M  = (M1-1)*NSYM1 
        MA = NSYM1*(M1-1)+1
c        IF(MOD(M,NSYM1).EQ.0) THEN
          DO     KN=1,NN
            BR(MA,KN) = 0.0
            BI(MA,KN) = 0.0
          ENDDO
c        ENDIF
      ENDDO

      ENDIF
C ---
      DO  MM1=1,L1
        M1 = L1-MM1+1
        M  = (M1-1)*NSYM1 
        MA = NSYM1*(M1-1)+1
c        IF(MOD(M,NSYM1).EQ.0) THEN
          DO     KN=1,NN
            JHH = KN
            JKK = M
            JLL = L
            FAA = BR(MA,KN) 
            FBB = BI(MA,KN)
            CALL WRT(MT2,JHH,JKK,JLL,FAA,FBB,NUMB2,IEND2)
            IF(MT2.LT.0) THEN
              CALL MSGERR(MDOC,' ERR: write to output file')
              IERR=1
              RETURN
            ENDIF    
          ENDDO
c        ENDIF
      ENDDO
C ---
      IF(IEND1.EQ.0) GO TO 110
C =================================================================
      IEND2=2
      CALL WRT(MT2,JHH,JKK,JLL,FAA,FBB,NUMB2,IEND2)
      CLOSE(MT1)
      CLOSE(MT2)
      RETURN
      END


      SUBROUTINE CDLMM_ROT(L,BETA,FACT,PCOT,PSIN,CTB2,SDLMM,DLMM,
     *                 IPRL21,IPRLM1)
C ------------------------------------------------------------------
      REAL*8    DLMM (IPRLM1,IPRL21)
      REAL      SDLMM(IPRLM1,IPRL21)
      REAL*8    FACT(IPRL21),PCOT(IPRL21),PSIN(IPRL21),CTB2
C ---
      REAL*8    D
c      REAL*8    ANORM(61)
C ------------------------------------------------------------------
      L1 =L+1
      L21=2*L+1
C ---
      DO     I1=1,L1
      DO     I2=1,L21
        SDLMM(I1,I2)=0.
        DLMM (I1,I2)=0.
      ENDDO
      ENDDO
C ---
      IF(BETA.EQ.0.0) THEN
        DO     M1=1,L1
          M2=M1+L
          DLMM(M1,M2)=1.0 D 0
        ENDDO
      ELSE
        DO     M1=1,L21
          M  =M1-L-1
          LOM=L-M
          LAM=L+M
          D=0.5*(FACT(2*L+1)-FACT(LAM+1)-FACT(LOM+1))+
     *      PCOT(LAM+1)+PSIN(2*L+1)
          IF(D.GE.-150.D0) THEN
            DLMM(L1,M1)=DEXP(D)
          ENDIF
        ENDDO
C ------
        DO     I2=1,L
          M2  =L-I2
          MI2 =M2+1
          M221=2*M2+1
          DO     I1=1,M221
            M1 =I1-M2-1
            MI1=M1+L1
            DLMM(MI2,MI1)=(DFLOAT(M2-M1+1)*CTB2*DLMM(MI2+1,MI1)
     *             -DSQRT(DFLOAT((L+M1)*(L-M1+1)))*DLMM(MI2+1,MI1-1))/
     *              DSQRT(DFLOAT((L+M2+1)*(L-M2)))
          ENDDO
        ENDDO
C ------
        DO     J2=2,L1
          M2=J2-1
          DO     J1=1,M2
            M1=1-J1
            I1=L1+M1
            M7=1-M1
            M8=L1-M2
            DLMM(M7,M8)=DLMM(J2,I1)
          ENDDO
        ENDDO
C -----
        DO     J2=2,L1
          M2=J2-1
          DO     J1=1,M2
            M1=J1-1
            L1BM1=L1+M1
            L1AM2=L1+M2
            DLMM(J1,L1AM2)=DLMM(J2,L1BM1)
            IF(MOD(M1+M2,2).NE.0) DLMM(J1,L1AM2)=-DLMM(J1,L1AM2)
          ENDDO
        ENDDO
      ENDIF
C --------------------------
      DO     M1=1,L1
      DO     M2=1,L21
C       SDLMM(M1,M2) = SNGL(DLMM(M1,M2))
        SDLMM(M1,M2) = DLMM(M1,M2)
      ENDDO
      ENDDO
C ---------------------------
c      DO     I2=1,L1
c        NORM=0
c        DO     I1=1,L21
c          IF(DABS(DLMM(I2,I1)).GT.1.D-5)
c     *            NORM=NORM+DLMM(I2,I1)*DLMM(I2,I1)
c        ENDDO
c        ANORM(I2)=NORM
c      ENDDO
C ------------------------------------------------------
c      WRITE(*,10) L,BETA
c   10 FORMAT(/,'    L=',I5,'  BETA=',F5.1)
c      WRITE(*,20) (ANORM(I2),I2=1,L1)
c   20 FORMAT(1X,5D15.8)
C -------------------------------------------------------
      RETURN
      END

      SUBROUTINE SRFADD(MDOC,NAME1,NAME2,NAMEO,SCALE
     * ,DLMN8,CLMM,FMM,FACT,PCOT,PSIN
     * ,DLMM,AR,AI,BR,BI,NMAX
     * ,IPRLMX,IPRLM1,IPRL21,IPRMEM,IPRALM,IPRGAM,IPRNMX
     * ,ISYM,IPRSYM,IERR)
C --------------------------------------------------------------------
C ---------
      INTEGER*2 ISYM(5,3,IPRSYM)
      REAL*8    DLMN8(IPRLM1,IPRL21)
      REAL      DLMM (IPRLM1,IPRL21)
      REAL*8    FACT(IPRL21),PCOT(IPRL21),PSIN(IPRL21)
      COMPLEX   CLMM(IPRMEM),FMM(IPRALM,IPRGAM)
      COMPLEX   CA,CB
      REAL*8    ANG,DLCTB2,CTB2
      REAL      AR(IPRLM1,IPRNMX),AI(IPRLM1,IPRNMX)
      REAL      BR(IPRLM1,IPRNMX),BI(IPRLM1,IPRNMX)
      INTEGER   NMAX(IPRLM1)
      INTEGER   ID(3)
      REAL      RLATT(6)
      CHARACTER NAME1*(*),NAME2*(*),NAMEO*(*)
      CHARACTER TITLE1*80,TYPE*4,TITLE2*80
      CHARACTER MSG*1,MSGL*1,LINE*80
C -------------------------------------------------------------
      IPRLM2=IPRLMX+2   
      IERR=0
      IF(ABS(SCALE).LE.0.0000001) SCALE=1.0
      MSGL='Y'

      NBASC=0
      APT=0.
      BPT=0.
C ----------------
      MT1   =10
      MT2   =11
      MTOUT =13
      TYPE  ='ALMN'
      MD=-ABS(MDOC)-1
      CALL ORFILE(MD,MT1,NAME1,TYPE,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MD,' ERR: OPEN ALMN_FILE-1')
        RETURN
      ENDIF
      CALL GET_TITLE(MD,RLATT(1),RLATT(2),
     . RLATT(3),RLATT(4),RLATT(5),RLATT(6),CF,BT,RN1,RX1,IDM,IDM
     . ,IDM,IDM,IDM,TITLE1,IERR)
      CALL C_RD_CR
C -----------------
      ARAD1=CF
      NSYM1=BT+.1
      IEND1=-1
      NUMB1=0
      IF(TITLE1(5:8).EQ.' PT ') THEN
        LSTP=2
      ELSE
        LSTP=1
      ENDIF
      ILOLD=-111
 500  CONTINUE
      CALL RD1(MT1,IN,IM,IL,FA,FB,NUMB1,IEND1)
      IF(MT1.LE.0) THEN
        CALL MSGERR(MDOC,' ERR : READ ALMN_FILE-1')
        CLOSE(MT1)
        IERR=1
        RETURN
      ENDIF
      IF(IEND1.GT.0) THEN
        CALL MSGERR(MDOC,' ERR : EMPTY ALMN_FILE-1')
        IERR=1
        RETURN
      ENDIF
C -------------------------------------------------------------
      IERR=0
      TYPE  ='ALMN'
      MD=-ABS(MDOC)-1
      CALL ORFILE(MD,MT2,NAME2,TYPE,NSM2,FMM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MD,' ERR: OPEN ALMN_FILE-2')
        CLOSE(MT1)
        RETURN
      ENDIF
      MSG='N'
      CALL GET_TITLE(MD,RLATT(1),RLATT(2),
     .  RLATT(3),RLATT(4),RLATT(5),RLATT(6),CF,BT,RN2,RX2,IDM,IDM
     .  ,IDM,IDM,IDM,TITLE2,IERR)

      ARAD2=CF
      IF(ARAD2.NE.ARAD1) THEN
        CALL MSGERR(MDOC,' ERR : RAD-1 # RAD-2')
        IERR=1
        CLOSE(MT1)
        CLOSE(MT2)
        RETURN
      ENDIF
      NSYM2=BT+.1
      IF(NSYM2.NE.NSYM1) THEN
        CALL MSGERR(MDOC,' ERR : NSYM-1 # NSYM-2')
        IERR=1
        CLOSE(MT1)
        CLOSE(MT2)
        RETURN
      ENDIF
      IEND2=-1
      NUMB2=0
      JLOLD=-111
  510 CALL RD2(MT2,JN,JM,JL,GA,GB,NUMB2,IEND2)
      IF(MT2.LE.0) THEN
        CALL MSGERR(MDOC,' ERR : READ ALMN_FILE-2')
        CLOSE(MT1)
        CLOSE(MT2)
        IERR=1
        RETURN
      ENDIF
      IF(IEND2.GT.0) THEN
        CALL MSGERR(MDOC,' ERR : EMPTY ALMN_FILE-2')
        CLOSE(MT1)
        RETURN
      ENDIF
C ------------------------------------------------------------
      CALL C_CR_WR
      CALL SET_TITLE(MD,RLATT(1),RLATT(2),
     . RLATT(3),RLATT(4),RLATT(5),RLATT(6),CF,BT,RN1,RX1,IDM,IDM
     . ,IDM,IDM,IDM,TITLE1,IERR)
      TYPE  ='ALMN'
      CALL OWFILE(MD,MTOUT,NAMEO,TYPE,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MD,' ERR: OPEN OUTPUT ALMN_FILE')
        RETURN
      ENDIF
      IENDW=-1
      NUMBW=0

C -------------------------------------------------------------
      LMINR=0
      LMAXR=100
C =============================================================
  100 CONTINUE
      IF(IEND1.GT.0)                    GO TO 200
      IF(IL.NE.ILOLD.AND.ILOLD.NE.-111) THEN
        GO TO 200
      ENDIF
  110 L =IL
      IF(L.GT.IPRLMX) THEN
        WRITE(LINE,*) ' ERR: L >',IPRLMX
        CALL MSGERR(MDOC,LINE)
        CLOSE(MT1)
        CLOSE(MT2)
        CLOSE(MTOUT)
        IERR=1
        RETURN
      ENDIF
      M =IM
      N =IN
      IF(N.GT.IPRNMX) THEN
        WRITE(LINE,*) ' ERR: N >',IPRNMX
        CALL MSGERR(MDOC,LINE)
        CLOSE(MT1)
        CLOSE(MT2)
        CLOSE(MTOUT)
        IERR=1
        RETURN
      ENDIF
      MMAX=L+1
      M1=IM+1
      AR(M1,N)=FA
      AI(M1,N)=FB
      NMAX1=N
      ILOLD=IL
      CALL RD1(MT1,IN,IM,IL,FA,FB,NUMB1,IEND1)
      IF(MT1.LE.0) THEN
        CALL MSGERR(MDOC,' ERR : READ ALMN FILE-1')
        CLOSE(MT2)
        CLOSE(MTOUT)
        IERR=1
        RETURN
      ENDIF
c      IF(IL.EQ.0) THEN
c        FA=0.0
c        FB=0.0
c      ENDIF
      GO TO 100
C --------------
  200 IF(MSG.EQ.'N') THEN
        JLOLD=L
  300   CONTINUE
        IF(IEND2.GT.0 ) GO TO 400
        IF(JL.NE.JLOLD) THEN
          GO TO 400
        ENDIF
        IF(JL.NE.L) THEN
          WRITE(LINE,*) ' ERR: L - FILE-1 # L - FILE-2 :',L,JL
          CALL MSGERR(MDOC,LINE)
          IF(IEND1.EQ.0) CLOSE(MT1)
          CLOSE(MT2)
          CLOSE(MTOUT)
          IERR=1
          RETURN
        ENDIF
        M =JM
        N =JN
        IF(N.GT.IPRNMX) THEN
          WRITE(LINE,*) ' ERR: N >',IPRNMX
          CALL MSGERR(MDOC,LINE)
          IF(IEND1.EQ.0) CLOSE(MT1)
          CLOSE(MT2)
          CLOSE(MTOUT)
          IERR=1
          RETURN
        ENDIF
        MMAX=L+1
        M1=JM+1
        BR(M1,N)=GA
        BI(M1,N)=GB
        NMAX2=N
        JLOLD=JL
        CALL RD2(MT2,JN,JM,JL,GA,GB,NUMB2,IEND2)
        IF(MT2.LE.0) THEN
          CALL MSGERR(MDOC,' ERR : READ ALMN FILE-2')
          IF(IEND1.EQ.0) CLOSE(MT1)
          CLOSE(MTOUT)
          IERR=1
          RETURN
        ENDIF
c        IF(JL.EQ.0) THEN
c          GA=0.0
c          GB=0.0
c        ENDIF
        GO TO 300
      ENDIF
C --------------------------------------------
  400 CONTINUE
      IF(NMAX1.NE.NMAX2.AND.MSG.EQ.'N') THEN
        WRITE(LINE,*) 
     *  ' RFadd: ERR: NMAX1 # NMAX2 ;L,NMAX1,NMAX2:',L,NMAX1,NMAX2
        CALL MSGERR(MDOC,LINE)
        CLOSE(MT1)
        CLOSE(MT2)
        CLOSE(MTOUT)
        IERR=1
        RETURN
      ENDIF
      LK  =L+1
      MMAX=LK
      NN  =NMAX1
      NMAX(LK)=NN
      LS1 =L/NSYM2+1
      L1  =L/NSYM1+1
      L21 =2*(L/NSYM2)+1

C ---
      DO  MM1=1,L1
        M1=L1-MM1+1
        M =(M1-1)*NSYM1 
        MA=NSYM1*(M1-1)+1
c        IF(MOD(M,NSYM1).EQ.0) THEN
          DO     KN=1,NN
            JHH=KN
            JKK=M
            JLL=L
            FAA=AR(MA,KN)+BR(MA,KN)*SCALE
            FBB=AI(MA,KN)+BI(MA,KN)*SCALE
            CALL WRT(MTOUT,JHH,JKK,JLL,FAA,FBB,NUMBW,IENDW)
            IF(MTOUT.LT.0) THEN
              CALL MSGERR(MDOC,' ERR: write to output file')
              CLOSE(MT1)
              CLOSE(MT2)
              IERR=1
              RETURN
            ENDIF    
          ENDDO
c        ENDIF
      ENDDO
C ---
      IF(IEND1.NE.IEND2) THEN
        WRITE(LINE,*) ' ERR: EOF FILE-1 OR FILE-2 :',IEND1,IEND2
        CALL MSGERR(MDOC,LINE)
        IF(IEND1.EQ.0) CLOSE(MT1)
        IF(IEND2.EQ.0) CLOSE(MT2)
        CLOSE(MTOUT)
        IERR=1
        RETURN
      ENDIF
      IF(IEND1.EQ.0) GO TO 110
C =================================================================
      IENDW=2
      CALL WRT(MTOUT,JHH,JKK,JLL,FAA,FBB,NUMBW,IENDW)
      CLOSE(MT1)
      CLOSE(MT2)
      RETURN
      END

      SUBROUTINE TRANS(MDOC,NAME1,NAME2,SH1,SH2
     *    ,MOD_IN,AM,ALPHA,BETA,GAMMA,RESULT,ISYM,IPRSYM,IERR)
C --------------------------------------
C -P- 
C TRANS    ortogonal transformation of atomic coordinates.
C            X"-new = [R] * ( X-old + sh1 ) + sh2 
C              [R]      - rotation matrix
C              sh1, sh2 - vectors of shift  
C          Gives also information about position of molecule and radius
C          of inertia.
C -S-
C           Rotation corresponds to solution RFRES and RFROT-program
C           i.e.:   RFRES: (a,b,g) peak for file_1: model1 
C                                           file_2: model2
C             TRANS: model2 --> model1: angle: a,b,g
C             RFROT: model2 --> model1: angle: a,b,g 
C
C   Dialogue and Batch:
C  
C    FILE_IN:       - name input_file  / without extention "crd"/
C    FILE_O: <" ">  - name output_file / without extention "crd"/
C            Translation:
C    SMODE:  <O>/F  -  O - shifts in orthogonal system
C                      F - shifts in fractional
C    SH1:   <0,0,0> -  vector of shift /before rotation/
C    SH2:   <0,0,0> -  vector of shift /after rotation/
C            Rotation:
C    MODE:  <E>/P/R -  E - for input Eiler angles
C                      P - for input polar angles
C                      R - for input rotation matrix
C    ANGLE: <0,0,0> -  angles of rotation
C            [R]    -  rotation matrix
C    R1:    <1,0,0> -  R(1,1),R(2,1),R(3,1)
C    R2:    <0,1,0> -  R(1,2),R(2,2),R(3,2)
C    R3:    <0,0,1> -  R(1,3),R(2,3),R(3,3)
C
C  Parameters of subroutine TRANS: 
C
C      SUBROUTINE TRANS(MDOC,NAME1,NAME2,SH1,SH2
C     *     ,MOD,AM,ALPHA,BETA,GAMMA,RESULT,ISYM,IPRSYM,IERR)
C
C    MDOC  - mode of writing messages to DOC-file
C            0 - only terminal , < - 0 only file, 0 < < 99 - both
C            >= 99 - don't write  
C    NAME1             - input file name, without extention.
C    NAME2             - output file name, without extention.
C    IERR /input/      - if IERR = abs(999) shifts in frational
C    SH1 /real(3)/     -  vector of shift /before rotation/
C    SH2 /real(3)/     -  vector of shift /after rotation/
C    MOD /character*1/   <E>/P/R -  E - for Eiler angles
C                                   P - for polar angles
C                                   R - for rotation matrix 
C    AM  /real(3,3)/   - rotation matrix
C    ALPHA,BETA,GAMMA  - angles of rotation
C    ISYM              - integer*2 array for cryst.symmetry operators 
C    IPRSYM            - dimension of integer*2 array ISYM(5,3,IPRSYM)
C                        You need not to define contents of arrays ISYM
C                        Here is only reservation of memory.
C    IERR              - output signal of error / =1 -error , =o - OK / 
C
C    real RESULT(11) - array for output information:
C
C      RESULT(1) = NTOT
C      RESULT(2) = XMIN
C      RESULT(3) = XMAX
C      RESULT(4) = YMIN
C      RESULT(5) = YMAX
C      RESULT(6) = ZMIN
C      RESULT(7) = ZMAX
C      RESULT(8) = XS
C      RESULT(9) = YS
C      RESULT(10)= ZS
C      RESULT(11)= RI
C      RESULT(12)= MODEL
C      RESULT(13)= NMODEL
C
C        NTOT       - number of atoms
C        XMIN,XMAX  - MIN and MAX value of X,Y,Z
C        YMIN,YMAX
C        ZMIN,ZMAX
C        XS,YS,ZS   - center of atoms: XS = Sum(X)/N
C        RI         - Radius of inertia
C -I-
C --------------------------------------
      INTEGER   MDOC,IERR
      REAL      RESULT(*)
      CHARACTER NAME1*(*),NAME2*(*),MOD_IN*(*),SMOD*1,MOD*1
      INTEGER   IPRSYM
      INTEGER*2 ISYM(5,3,IPRSYM)
      REAL             AM(3,3),SH1(3),SH2(3)
      REAL             ALPHA,BETA,GAMMA
C ---
      INCLUDE 'mr_crd_com.fh'
C ------------------------------------------------------------
      COMMON/COM_MAT/  ACELL,BCELL,CCELL,AANGL,BANGL,GANGL
     *                ,AST,BST,CST,COALST,COBEST,COGAST
     *                ,FRTOCR,CRTOFR
      REAL        FRTOCR(3,3),CRTOFR(3,3)
C ----
      INTEGER   MODE,NSYM
      REAL      X(3),Y(3),Z(3),TRNCS(3),U(3),V(3)
      REAL      AMNCS(3,3),AMAT(3,3),TMAT(3,3),AMNEW(3,3)
      REAL      SH1F(3),SH2F(3),RLATT(6),UA(6),UR(6)
      CHARACTER LINE*80
C=====================================================================
      MODEL = ABS(IERR)
      IORDER = 0
      IF(IERR.LT.0) IORDER = 1
      SMOD  = 'C'
      MOD   = MOD_IN(1:1)
      CALL LENSTR_BL(MOD_IN,LEN)
      IF(LEN.GT.1.AND.(MOD_IN(2:2).EQ.'f'.OR.MOD_IN(2:2).EQ.'F')) THEN
        SMOD = 'F'
      ENDIF
      ISURF = 0
      IF(LEN.GT.2.AND.MOD_IN(3:3).EQ.'S') THEN
        ISURF = 1
      ENDIF
      IFLAG = 0
C ---
      IERR = 0
      PI   = 4.0*ATAN(1.0)
C ---
      XS   = 0.
      YS   = 0.
      ZS   = 0.
      XS2  = 0.
      YS2  = 0.
      ZS2  = 0.
      XMAX =-1.E 30
      YMAX =-1.E 30
      ZMAX =-1.E 30
      XMIN = 1.E 30
      YMIN = 1.E 30
      ZMIN = 1.E 30
      NMODEL = 0
      NANISO = 0
      NINSIDE= 0
C -----------------------------------------------------------------
      MD =-ABS(MDOC)-1
      M  = 99
      IN = 10
      CALL ORCRD(MD,IN,NAME1,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERR: OPEN INPUT_FILE')
        CLOSE(IN) 
        RETURN
      ENDIF
      CALL C_AT_CR
      ACELL = CR_CELL(1)
      BCELL = CR_CELL(2)
      CCELL = CR_CELL(3)
      AANGL = CR_CELL(4)
      BANGL = CR_CELL(5)
      GANGL = CR_CELL(6)
      CALL FRORTH(CR_CELL(1),CR_CELL(2),CR_CELL(3)
     *           ,CR_CELL(4),CR_CELL(5),CR_CELL(6)
     *                            ,FRTOCR,CRTOFR,IERR)
      RLATT(1) = ACELL
      RLATT(2) = BCELL
      RLATT(3) = CCELL
      RLATT(4) = AANGL
      RLATT(5) = BANGL
      RLATT(6) = GANGL
      CALL DSTARF(RLATT,AST,BST,CST,COALST,COBEST,COGAST,VOL)
C -------------------------------------------
      IF(MOD.EQ.'r') MOD='R'
      IF(MOD.EQ.'p') MOD='P'
      IF(MOD.NE.'P'.AND.MOD.NE.'R') MOD='E'

      IF(MOD.EQ.'R') THEN

      ELSE IF(MOD.EQ.'P') THEN
        RALD = ALPHA*PI/180.
        RBED = BETA *PI/180.
        RGAD = GAMMA*PI/180.
        CALL POLTOM(RALD,RBED,RGAD,AM)
      ELSE
        ALPHA = ALPHA*PI/180.
        BETA  = BETA *PI/180.
        GAMMA = GAMMA*PI/180.
        CALL EULERM(ALPHA,BETA,GAMMA,AM)
      ENDIF

      IF(SMOD.EQ.'F') THEN
        CALL VCOPY(SH1,SH1F)
        CALL VCOPY(SH2,SH2F)
        CALL FTOO(SH1F,SH1,IERR)
        CALL FTOO(SH2F,SH2,IERR)
      ELSE
        CALL OTOF(SH1,SH1F,IERR)
        CALL OTOF(SH2,SH2F,IERR)
      ENDIF



      WRITE(LINE,'('' SHIFT-1:'',3F8.3)') SH1(1),SH1(2),SH1(3)
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,'(''  /frac/:'',3F8.3)') SH1F(1),SH1F(2),SH1F(3)
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,'('' SHIFT-2:'',3F8.3)') SH2(1),SH2(2),SH2(3)
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,'(''  /frac/:'',3F8.3)') SH2F(1),SH2F(2),SH2F(3)
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,'('' MATRIX : '',3F12.4)') (AM(L,1),L=1,3)
      CALL MSGDOC(MD,LINE)
      WRITE(LINE,'(''          '',3F12.4)') (AM(L,2),L=1,3)
      CALL MSGDOC(MD,LINE)
      WRITE(LINE,'(''          '',3F12.4)') (AM(L,3),L=1,3)
      CALL MSGDOC(MD,LINE)
      CALL MTOANG(AM,ALPHA,BETA,GAMMA)
      WRITE(LINE,100) ALPHA,BETA,GAMMA
  100 FORMAT('EILER ANGLES : ALPHA BETA GAMMA :',3F10.5)
      CALL MSGDOC(MDOC,LINE)
      CALL MTOPOL(AM,THETA,PHI,CHI)
      WRITE(LINE,102) THETA,PHI,CHI
  102 FORMAT('SPHERICAL POLARS : THETA PHI CHI    :',3F10.5)
      CALL MSGDOC(MDOC,LINE)
C -------------------------------------------
      IF(IFLAG.EQ.1) GO TO 400
      NCSOP=0
      CALL GET_NCS(MDOC,NCMAX,NCSOP,AMNCS,TRNCS,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC
     * ,' WARNING: subroutine TRANS : wrong NCS description.')
        CALL MSGERR(MDOC,'          NCS description will be ignored.')
        IERR=0
      ENDIF      
      IF(NCSOP.GT.0) THEN
          DO I=1,NCSOP

            CALL GET_NCS(MDOC,NCMAX,I,AMNCS,TRNCS,IERR)
            IF(IERR.NE.0) RETURN      
C                                -1
C     [Mncs]_new = [M]*[Mncs]*[M]    
C
C     Tncs_new=-[Mncs]_new*T2-[M]*[Mncs]*T1+[M]*T1+[M]*Tncs+T2 
C
            CALL MTRANS(AM,TMAT)
            CALL MATMLT(AM,AMNCS,AMAT)
            CALL MATMLT(AMAT,TMAT,AMNEW)

            CALL MVMULT(AMNEW,SH2  ,X)
            CALL MVMULT(AMAT ,SH1  ,Y)
            CALL MVMULT(AM   ,SH1  ,Z)
            CALL MVMULT(AM   ,TRNCS,U)
            CALL VADD(SH2,U,V)
            CALL VADD(X,Y,U)
            CALL VSUB(V,U,X)
            CALL VADD(X,Z,V)
        
            CALL SET_NCS(MDOC,NCMAX,I,AMNEW,V,IERR)
            IF(IERR.NE.0) RETURN      

          ENDDO

      ENDIF
 400  CONTINUE
C -------------------------------------------------
      CALL LENSTR_BL(NAME2,LEN)
      IF(LEN.GT.0.AND.NAME2(1:1).NE.' '.AND.NAME2(1:1).NE.',') THEN
        IOUT=11
        CALL OWCRD(MD,IOUT,NAME2,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MDOC,' ERR: OPEN OUTPUT_FILE')
          CLOSE(IN) 
          CLOSE(IOUT) 
          RETURN
        ENDIF
      ELSE
        IOUT=0
      ENDIF
C -----------------------------------------------------------
      NA    = 0
      NTOT  = 0
      IEND  =-1
      IENDW =-1
      CR_MODEL_OLD =-1
C ----------------------
 200  CONTINUE
        CALL RDCRD(M,IN,MODE,IEND,IERR)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MDOC,' ERR: READ INPUT_FILE')
          CLOSE(IN)
          CLOSE(IOUT)
          RETURN
        ENDIF
        IF(IEND.NE.0) GO TO 300
        IF(MODE.EQ.0) THEN

          IF(CR_MODEL.NE.CR_MODEL_OLD) NMODEL = NMODEL + 1
          CR_MODEL_OLD = CR_MODEL 

          IF(IORDER.LE.0) THEN
            IF(MODEL.GT.0.AND.CR_MODEL.NE.MODEL) GO TO 200
          ELSE
            IF(MODEL.GT.0.AND.NMODEL.NE.MODEL) GO TO 200
          ENDIF

          X(1) = CR_XYZ(1) + SH1(1)
          X(2) = CR_XYZ(2) + SH1(2)
          X(3) = CR_XYZ(3) + SH1(3)
          NA   = NA + 1
          CALL MVMULT(AM,X,Y)
          X(1) = Y(1) + SH2(1)
          X(2) = Y(2) + SH2(2)
          X(3) = Y(3) + SH2(3)

          IF(CR_BTYPE.EQ.'A') THEN
            UA(1)=CR_ANIS(1)
            UA(2)=CR_ANIS(2)
            UA(3)=CR_ANIS(3)
            UA(4)=CR_ANIS(4)
            UA(5)=CR_ANIS(5)
            UA(6)=CR_ANIS(6)

            CALL MDET2(UA,DET)
     
            IF(DET.LT.0.0000001) THEN

              WRITE(LINE,*) 
     *        ' WARNING: TRANS: Determinant(U) =< 0 :',DET
              CALL MSGERR(MDOC,LINE)
              WRITE(LINE,*) 
     *        '          for atom: ',CR_ANAME,', res:'
     *        ,CR_IRES,', CHAIN:',CR_IGROUP
              CALL MSGERR(MDOC,LINE)
              WRITE(LINE,'(''          U:'',6F9.5)')
     *         CR_ANIS(1),CR_ANIS(2),CR_ANIS(3)
     *        ,CR_ANIS(4),CR_ANIS(5),CR_ANIS(6)
              CALL MSGERR(MDOC,LINE)

              CR_BTYPE='I'

            ELSE

            NANISO=NANISO+1

            CALL UO_TO_B(UA,UA)
            CALL B_SYM(UA,UR,AM)
            CALL B_TO_UO(UR,CR_ANIS)

            ENDIF

          ENDIF 

          IF((CR_ATYPE .EQ.' '.OR.CR_ATYPE .EQ.'.'.OR.
     *        CR_ATYPE .EQ.'y'.OR.CR_ATYPE .EQ.'Y'.OR.
     *        CR_ATYPE .EQ.'r'.OR.CR_ATYPE .EQ.'R').AND.
     *        CR_OCC .GT.0.0001                        ) THEN

            IF(X(1).GT.XMAX) XMAX=X(1)
            IF(X(2).GT.YMAX) YMAX=X(2)
            IF(X(3).GT.ZMAX) ZMAX=X(3)
            IF(X(1).LT.XMIN) XMIN=X(1)
            IF(X(2).LT.YMIN) YMIN=X(2)
            IF(X(3).LT.ZMIN) ZMIN=X(3)
            XS   = XS+X(1)
            YS   = YS+X(2)
            ZS   = ZS+X(3)
            XS2  = XS2+X(1)*X(1)
            YS2  = YS2+X(2)*X(2)
            ZS2  = ZS2+X(3)*X(3)
            NTOT = NTOT+1

            IF(CR_SURF.LE.15.001) NINSIDE = NINSIDE + 1

          ENDIF

          CR_XYZ(1) = X(1)
          CR_XYZ(2) = X(2)
          CR_XYZ(3) = X(3)
      
          IF(ISURF.EQ.1) CR_BISO = CR_SURF

          IF(IOUT.GT.0) THEN
            CALL WRCRD(M,IOUT,MODE,IENDW,IERR)
            IF(IERR.NE.0) THEN
              CALL MSGERR(MDOC,' ERR: WRITE OUTPUT_FILE')
              CLOSE(IN) 
              CLOSE(IOUT) 
              RETURN
            ENDIF
          ENDIF

        ELSE

c          IF(MODEL.GT.0.AND.CR_MODEL.NE.MODEL) GO TO 200

          IF(MODEL.GT.0) GO TO 200

          IF(IOUT.GT.0) THEN
            CALL WRCRD(M,IOUT,MODE,IENDW,IERR)
            IF(IERR.NE.0) THEN
              CALL MSGERR(MDOC,' ERR: WRITE OUTPUT_FILE')
              CLOSE(IN) 
              CLOSE(IOUT) 
              RETURN
            ENDIF
          ENDIF

        ENDIF

      GO TO 200
C ---------------------------------------------------------
  300 CONTINUE
      CLOSE(IN)
      WRITE(LINE,'('' NUMBER OF COORDS :'',I6)') NA
      CALL MSGDOC(MDOC,LINE)
      IF(NANISO.GT.0) THEN
        WRITE(LINE,'('' Naniso           :'',I6)') NANISO
        CALL MSGDOC(MDOC,LINE)
      ENDIF

C     NMODEL = CR_MODEL

      IF(IOUT.GT.0) THEN
        IENDW=1
        MODE=0     
        CALL WRCRD(MDOC,IOUT,MODE,IENDW,IERR)
      ENDIF
      IF(NA.LE.0) THEN
        CALL MSGERR(MDOC,' ERR: TRANS: N-ATOMS = 0')
        IERR=1
        RETURN
      ENDIF
      IF(NTOT.GT.0) THEN
        XS  = XS/NTOT
        YS  = YS/NTOT
        ZS  = ZS/NTOT
        XS2 = XS2/NTOT
        YS2 = YS2/NTOT
        ZS2 = ZS2/NTOT
        WRITE(LINE,'('' X :'',2F10.3)') XMIN,XMAX
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,'('' Y :'',2F10.3)') YMIN,YMAX
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,'('' Z :'',2F10.3)') ZMIN,ZMAX
        CALL MSGDOC(MDOC,LINE)
        RAD = (XMAX-XMIN)
        RT  = (YMAX-YMIN)
        IF(RAD.LT.RT) RAD=RT
        RT  = (ZMAX-ZMIN)
        IF(RAD.LT.RT) RAD=RT
        WRITE(LINE,'('' SIZE_max         :'',F10.3)') RAD
        CALL MSGDOC(MDOC,LINE)
C --
        WRITE(LINE,'('' Centre of coords :'',3F10.3)') XS,YS,ZS
        CALL MSGDOC(MDOC,LINE)
C --
        X(1) = XS
        X(2) = YS
        X(3) = ZS
        CALL OTOF(X,Y,IERR)
        WRITE(LINE,'('' Centre of coords /fract/ :'',3F10.3)') 
     *  Y(1),Y(2),Y(3)
        CALL MSGDOC(MDOC,LINE)
C -------       
        RX = XS2-XS*XS
        RY = YS2-YS*YS
        RZ = ZS2-ZS*ZS
        RI = SQRT(ABS(RX+RY+RZ))
        WRITE(LINE,'('' Radius of inertia :'',F10.3)') RI
        CALL MSGDOC(MDOC,LINE)
C ---
      ENDIF

      RESULT(1) = NTOT
      RESULT(2) = XMIN
      RESULT(3) = XMAX
      RESULT(4) = YMIN
      RESULT(5) = YMAX
      RESULT(6) = ZMIN
      RESULT(7) = ZMAX
      RESULT(8) = XS
      RESULT(9) = YS
      RESULT(10)= ZS
      RESULT(11)= RI
      RESULT(12)= MODEL
      RESULT(13)= NMODEL
      RESULT(14)= NINSIDE

      WRITE(LINE,'('' Model, Number of models :'',2I5)') MODEL,NMODEL
      CALL MSGDOC(MDOC,LINE)

C -------------------------------------------
      RETURN
      END

C -I-
      SUBROUTINE JOINCRD(MDOC,NAMEC,NAMEC2,NAMEO
     * ,ISYM,IPRSYM,IERR)
C ----------------------------------------------------------
C -P- JOINCRD - join two files of coordinates. 
C -S-
C
C  Dialog and Batch: 
C
C    FILE_C  - input file-1 of coordinates.
C    FILE_2  - input file-2 of coordinates.
C    FILE_O  - output file.
C
C  Parameters of subroutine JOINCRD: 
C
C      SUBROUTINE JOINCRD(MDOC,NAMEC,NAMEC2,NAMEO
C     * ,ISYM,IPRSYM,IERR)
C
C    MDOC   - mode of writting messages to DOC-file
C             0 - only terminal , < - 0 only file, 0 < < 99 - both
C             >= 99 - don't write  
C    NAMEC  - name of input file-1 without extention.
C    NAMEC2 - name of input file-2 without extention.
C    NAMEO  - name of output file without extention.
C    ISYM   - integer*2 array for cryst.symmetry operators.
C    IPRSYM - dimension of integer*2 array ISYM(5,3,IPRSYM),
C             number of cryst. symm. operators.
C    IERR   - output signal of error / = 1 -error , = 0 - OK / 
C -I-
C ----------------------------------------------------------
      INTEGER     MDOC,IPRSYM,IERR
      INTEGER*2   ISYM(5,3,IPRSYM)
      CHARACTER   NAMEC*(*),NAMEC2*(*),NAMEO*(*)
C ----------------------------------------------------------------
C ---
      INCLUDE 'mr_crd_com.fh'
C ========================================================================
      INTEGER   NMAX,NGR,NCH,IGR,ICH,INC,MLT,IATM
      CHARACTER NCSF*1,GID*4
      CHARACTER LINE*80,CH5*5,CH2*2
C==================================================================
      NUM_MOL=IERR
      IF(NUM_MOL.EQ.0) NUM_MOL=2 
      IERR= 0
C -------
      PI  = 4.0*ATAN(1.0)
      MD  = -ABS(MDOC)-1
      M   = 99
C --------
      IN  = 10
      CALL ORCRD(MD,IN,NAMEC,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERROR: JOINCRD: cannot open input file_1')
        RETURN
      ENDIF
C --------
      IN2  = 11
      CALL ORCRD2(MD,IN2,NAMEC2,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERROR: JOINCRD: cannot open input file_2')
        RETURN
      ENDIF
      CLOSE(IN2)
      CALL JOIN_LIST_CHAIN(NGR1,NGR2,NGR_SUM)
C
C      write(*,*)' --joincrd:',NGR1,NGR2,NGR_SUM
C
C --------
      CALL LENSTR_BL(NAMEO,LEN)
      IF(LEN.GT.0.AND.NAMEO(1:1).NE.','.AND.NAMEO(1:1).NE.' ') THEN 
        IOUT=11
        CALL OWCRD(MD,IOUT,NAMEO,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MDOC,' ERROR: JOINCRD: cannot open output file')
          CLOSE(IN) 
          RETURN
        ENDIF
      ELSE
        IOUT=0
      ENDIF
C -------------------------------------------------
      NATOM = 0
      IEND  =-1
      IENDW =-1
C     WRITE(*,*) ' READ CRD'
C --------------------------------
 200  CONTINUE

      CALL RDCRD(M,IN,MODE,IEND,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERROR: JOINCRD: reading input file_1')
        CLOSE(IOUT)
        RETURN
      ENDIF
      IF(IEND.NE.0) GO TO 300
      IF(MODE.EQ.0) THEN

C        IF(CR_ATYPE.NE.'.'.AND.CR_ATYPE.NE.' '.AND.
C     *     CR_ATYPE.NE.'y'.AND.CR_ATYPE.NE.'Y'.AND.
C     *     CR_ATYPE.NE.'r'.AND.CR_ATYPE.NE.'R')
C     *    GO TO 1000

        NATOM=NATOM+1

      ENDIF      
C ----

      IF(IOUT.GT.0) THEN
        CALL WRCRD(MD,IOUT,MODE,IENDW,IERR)
        IF(IERR.NE.0) THEN
          CLOSE(IN) 
          RETURN
        ENDIF
      ENDIF
      GO TO 200
C ------------------------------------------------------
 300  CONTINUE
      CLOSE(IN) 
C --------
      CALL ORCRD(MD,IN,NAMEC2,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERROR: JOINCRD: cannot open input file_2.')
        RETURN
      ENDIF
C --------
      CR_LINE2 = ' '
      IF(NUM_MOL.GT.0) THEN
        WRITE(CH5,'(I5)') NUM_MOL
        CR_LINE='#MOLECULE '//CH5
        MODE=1
        IF(IOUT.GT.0) THEN
          CALL WRCRD(MD,IOUT,MODE,IENDW,IERR)
          IF(IERR.NE.0) THEN
            CLOSE(IN) 
            RETURN
          ENDIF
        ENDIF
      ENDIF
      IEND  =-1
C --------------------------------
C
C
C      write(*,*)' --joincrd:',NGR1
C

 400  CONTINUE

      CALL RDCRD(M,IN,MODE,IEND,IERR)
      IF(IERR.NE.0) THEN
        CLOSE(IOUT)
        RETURN
      ENDIF
      IF(IEND.NE.0) GO TO 500
      IF(MODE.EQ.0) THEN

C        IF(CR_ATYPE.NE.'.'.AND.CR_ATYPE.NE.' '.AND.
C     *     CR_ATYPE.NE.'y'.AND.CR_ATYPE.NE.'Y'.AND.
C     *     CR_ATYPE.NE.'r'.AND.CR_ATYPE.NE.'R')
C     *    GO TO 1000

        CR_IGROUP = CR_IGROUP + NGR1

        NATOM = NATOM+1
C
C      write(*,*)'  -----j:',NGR1, CR_IGROUP, NATOM
C
      ENDIF      
C ----

      IF(IOUT.GT.0) THEN
        CALL WRCRD(MD,IOUT,MODE,IENDW,IERR)
        IF(IERR.NE.0) THEN
          CLOSE(IN) 
          RETURN
        ENDIF
      ENDIF
      GO TO 400
C ------------------------------------------------------
 500  CONTINUE
      CLOSE(IN) 

      WRITE(LINE,'('' Number of atoms :'',I8)') NATOM
      CALL MSGDOC(MDOC,LINE)

      IENDW=1
      MODE=0     
      CALL WRCRD(MDOC,IOUT,MODE,IENDW,IERR)
C --------------------------------------
      RETURN
      END

C -I-
      SUBROUTINE PEAKSRCH(MDOC,NAME,NAMEO,ALEVEL,DIST_LIM,SPEC
     *   ,NPMAX,ISYM,IPRSYM,RESULT,IPRMAX,IPRROW,IERR)
C ---------------------------------------------------
C 
C -P- PEAKSRCH : searchs the peaks in the electron density map or Patterson or
C -P-            Rotation function map.
C -S-   
C      Dialog and Batch:
C
C   FILE_D:  input file of density.
C   FILE_O:  output file of coordinates of peaks /if you want it/.
C   NPMAX:   <all> - max number of peaks to write to output file.
C   LEVEL:   <1.0> - times of sigma.
C   DIST:    minimal distance between two peaks (in angstrom or grad) 
C               default is RESMAX
C   SPEC: <Y>/N/P/A/S  -  Y  means to use peaks in special  position.
C                         N  not use peaks in special position for fourie
C                         P  not use peaks in special position for Patterson
C                         A  peaks search without interpolation, without
C                            DIST and use all peaks
C                         S  calc symmetry related peaks for RF (see doc-file)
C                            
C      It possible to use subroutine PEAKSRCH by program:
C
C      SUBROUTINE PEAKSRCH(MDOC,NAME,NAMEO,ALEVEL,DIST_LIM,SPEC
C     *   ,NPMAX,POOL,MEMORY,ISYM,IPRSYM,RESULT,IPRMAX,IPRROW,IERR)
C
C  Parameters: 
C
C    MDOC  - mode of writting messages to DOC-file
C            0 - only terminal , < - 0 only file, 0 < < 99 - both
C            >= 99 - don't write  
C    NAME    - input file of density.
C    NAMEO   - output file of coordinates.
C    ALEVEL  -  <1.0> - times of sigma.
C    DIST_LIM - minimal distance between two peaks (in angstrom or grad) 
C               default is RESMAX
C    SPEC    - /character*1/  see above.
C    NPMAX   -  max number of peaks to write to output file.
C    POOL    - working array / real /. Dimension is equal MEMORY.
C    MEMORY  - dimension or array POOL, for 3 sections of density
C    ISYM    - integer*2 array for cryst.symmetry operators.
C    IPRSYM  - dimension of integer*2 array ISYM(5,3,IPRSYM),
C              number of cryst. symm. operators.
C    IERR    - output signal of error / =1 -error , =0 - OK / 
C
C      RESULT - array for output information:
C      REAL RESULT(IPRMAX,IPRROW)  IPRMAX - max number of peaks
C                                  IPRROW >= 12
C  RESULT(i,1) IX 
C  RESULT(i,2) IY
C  RESULT(i,3) IZ
C  RESULT(i,4) Dens
C  RESULT(i,5) sigma
C  RESULT(i,6) alpha      Xort
C  RESULT(i,7) beta   or  Yort
C  RESULT(i,8) gamma      Zort
C  RESULT(i,9)  Xfrac
C  RESULT(i,10) Yfrac
C  RESULT(i,11) Zfrac
C  RESULT(1,12)  number of peaks
C
C -I-
C ------------------------------
      REAL      RESULT(IPRMAX,IPRROW)
      INTEGER*2 ISYM(5,3,IPRSYM)
      CHARACTER NAME*(*),NAMEO*(*),SPEC*1
      REAL      ALEVEL,DIST_LIM
C --------------------------------------------------------------
      CALL PKSRCH(MDOC,NAME,NAMEO,ALEVEL,DIST_LIM,SPEC
     * ,NPMAX,ISYM,IPRSYM,RESULT,IPRMAX,IPRROW,IERR)
C -----
      RETURN
      END


      SUBROUTINE WRT_PEAKS(MDOC,NAMEO,NPEAK,NPMAX,RESULT,IPRMAX,IPRROW
     *  ,NSYM,ISYM,IPRSYM,IERR)
      REAL      RESULT(IPRMAX,IPRROW)
      INTEGER*2 ISYM(5,3,IPRSYM)
      CHARACTER NAMEO*(*)
C ------
      COMMON/CRYSTL/ A_CELL,B_CELL,C_CELL,AL_CELL,BE_CELL,GA_CELL
     *              ,A_STAR,B_STAR,C_STAR,COALST,COBEST,COGAST
     *              ,SIALST,SIBEST,SIGAST
     *              ,FRTOCR,CRTOFR,VOLUME
     *              ,PDB_SCALE,PDB_U
     *              ,NSP_GROUP,N_SETT,PDB_MODEL
     *              ,PDB_CODE,PDB_NAME,PDB_DATE
     *              ,PDB_RESL,PDB_RFAC
     *              ,SP_GROUP,USER_TITLE
C -
      REAL      FRTOCR(3,3),CRTOFR(3,3),VOLUME
      REAL      PDB_SCALE(3,3),PDB_U(3) 
      INTEGER*4 NSP_GROUP,N_SETT,PDB_MODEL
      CHARACTER PDB_CODE*4,PDB_NAME*40,PDB_DATE*9 
      CHARACTER PDB_RESL*40,PDB_RFAC*40
      CHARACTER SP_GROUP*24,USER_TITLE*80
C -------
      CHARACTER NCSF*1,GID*4
      CHARACTER SGNAME*24
C ---
      INCLUDE 'mr_crd_com.fh'
C -------------------------------------------------
      MD =-ABS(MDOC)-1
      M  = 99
      SGNAME = ' '
      CALL LENSTR_BL(NAMEO,LEN)
      IF(LEN.GT.0.AND.NAMEO(1:1).NE.','.AND.NAMEO(1:1).NE.' ') THEN
        IF(NPMAX.LE.0) NPMAX=NPEAK
        NPW = NPEAK
        IF(NPMAX.LT.NPW) NPW=NPMAX 
        IF(NSYM.EQ.1.AND.SGNAME(1:3).NE.'P 1') THEN
          ISETT  = N_SETT
          NOSPGR = NSP_GROUP
          SGNAME = SP_GROUP
C -------
          CALL GET_SYMM(MDOC,NOSPGR,ISETT,SGNAME,NSYMN,ISYM
     *                                              ,IPRSYM,IERR)
          IF(IERR.EQ.0) THEN
            NSYM=NSYMN
          ELSE
            IERR=0
          ENDIF    
        ENDIF
        IOUT=11
        CALL C_CR_AT

        IGR = 0
        CALL SET_ASYMM(MDOC,NMAX,NGR,ICHOLD,IGR,ICH,INC,MLT
     *                     ,IGOLD,NCSF,GID,IERR)
        NCHAIN = 1
        IGR    = NCHAIN
        ICH    = IGR
        IGOLD  = IGR
        ICHOLD = IGR
        INC    = 0
        MLT    = 0
        IATM   = 0
        NCSF   = '.'
        GID    = 'AA  '
        CALL SET_ASYMM(MDOC,NMAX,NGR,ICHOLD,IGR,ICH,INC,MLT
     *                     ,IGOLD,NCSF,GID,IERR)


        CALL OWCRD(MD,IOUT,NAMEO,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MDOC,' ERR: OPEN OUTPUT_FILE/CRD/')
          RETURN
        ENDIF
        IENDW =-1
        MODE  = 0
        COEF  =-1.E30
        DO I=1,NPW
          IF(RESULT(I,5).GT.COEF) COEF = RESULT(I,5)
        ENDDO
        IF(COEF.LE.0.0) COEF=1.0
        DO I=1,NPW
          CR_ANAME = 'O   '
          CR_RNAME = 'HOH'
          CR_IATOLD= I
          CR_IRES  = I
          CR_IGROUP= 1
          CR_ASYMB = 'O   '
          CR_ATYPE ='.'
          CR_ALT   ='.'
          CR_CORR  ='.'  
          CR_XYZ(1)= RESULT(I,6)
          CR_XYZ(2)= RESULT(I,7)
          CR_XYZ(3)= RESULT(I,8)
          CR_BISO  = 20.0
          CR_OCC   = RESULT(I,5)/COEF
          CR_SURF  = 0.0
          CALL WRCRD(M,IOUT,MODE,IENDW,IERR)
          IF(IERR.NE.0) THEN
            RETURN
          ENDIF
        ENDDO
        IENDW = 1
        MODE  = 0     
        CALL WRCRD(M,IOUT,MODE,IENDW,IERR)
      ENDIF
      NPMAX = NPW 
      RETURN
      END

      SUBROUTINE PSTORE(MDOC,NPEAK,D,RMS,IX,IY,IZ,DIST_LIM
     *   ,FX,FY,FZ
     *   ,IXPEAK,IYPEAK,IZPEAK,PEAK
     *   ,SIGPK,DM1,DM2,DM3,INDPK       
     *   ,IPRMAX,IPRROW
     *   ,SOR,NORIG,NSYM,ISYM,IPRSYM,TYPE,IERR)
C ---------------------------------------------------------------
      INTEGER*2 ISYM(5,3,IPRSYM)
      REAL      SOR(3,*)
      INTEGER  IXPEAK(*),IYPEAK(*),IZPEAK(*),INDPK(*)
      REAL     PEAK(*),SIGPK(*),DM1(*),DM2(*),DM3(*)
      CHARACTER TYPE*1       
C ---------------------------------------------------------------
c      GO TO 400
      IF(NPEAK.GT.0) THEN      

        IF(NPEAK.GE.IPRMAX) THEN
          INDM=INDPK(IPRMAX)
          IF(PEAK(INDM).GE.D) RETURN
        ENDIF

        DO I=1,NPEAK
          IND  = INDPK(I)
C         DIST = 1000.0
          JX   = IXPEAK(IND)
          JY   = IYPEAK(IND)
          JZ   = IZPEAK(IND)
          FJX  = DM1(IND)
          FJY  = DM2(IND)
          FJZ  = DM3(IND)
          SIGI = SIGPK(IND)         
          
          IF(DIST_LIM.GE.0.0) THEN
            CALL CALC_DST(IX,IY,IZ,JX,JY,JZ
     *      ,FX,FY,FZ,FJX,FJY,FJZ,DIST
     *      ,SOR,NORIG,NSYM,ISYM,IPRSYM,IERR)
          ELSE
            DIST = 0.0
          ENDIF
          IF(DIST.LE.DIST_LIM) THEN
            IF(PEAK(IND).GE.D) RETURN
            PEAK(IND)   = D
            IXPEAK(IND) = IX
            IYPEAK(IND) = IY
            IZPEAK(IND) = IZ
            DM1   (IND) = FX
            DM2   (IND) = FY
            DM3   (IND) = FZ
            SIGPK (IND) = RMS
            IF(I.EQ.1) RETURN
C           SORT FROM I TO 1           
            DO J=I,2,-1
              IND1 = INDPK(J )
              IND2 = INDPK(J-1)
              IF(PEAK(IND1).GT.PEAK(IND2)) THEN
                IT         = INDPK(J)
                INDPK(J)   = INDPK(J-1)
                INDPK(J-1) = IT
              ELSE
                GO TO 200
              ENDIF
            ENDDO
 200        CONTINUE
            RETURN
          ELSE
C            IF(TYPE.EQ.'H') THEN
C              DEL = ABS(SIGI-RMS)
C              IF(DEL.LT.0.001) RETURN
C            ENDIF
          ENDIF 
        ENDDO
      ENDIF   
 400  CONTINUE
      IF(NPEAK.LT.IPRMAX) THEN
        NPEAK        = NPEAK+1
        INDPK(NPEAK) = NPEAK
        IND          = NPEAK
        PEAK(IND)    = D
        IXPEAK(IND)  = IX
        IYPEAK(IND)  = IY
        IZPEAK(IND)  = IZ
        DM1   (IND)  = FX
        DM2   (IND)  = FY
        DM3   (IND)  = FZ
        SIGPK (IND)  = RMS
      ELSE
        IND = INDPK(IPRMAX)
        IF(PEAK(IND).GE.D) RETURN
        PEAK  (IND) = D
        IXPEAK(IND) = IX
        IYPEAK(IND) = IY
        IZPEAK(IND) = IZ
        DM1   (IND) = FX
        DM2   (IND) = FY
        DM3   (IND) = FZ
        SIGPK (IND) = RMS
      ENDIF
      IF(NPEAK.GT.1) THEN
        DO I=NPEAK,2,-1
          IND1 = INDPK(I )
          IND2 = INDPK(I-1)
          IF(PEAK(IND1).GT.PEAK(IND2)) THEN
            IT         = INDPK(I)
            INDPK(I)   = INDPK(I-1)
            INDPK(I-1) = IT
          ELSE
            GO TO 100
          ENDIF
        ENDDO
 100    CONTINUE
      ENDIF
      RETURN
      END

      SUBROUTINE RES_PRINT(MDOC,NPEAK,NPMAX
     *  ,IXPEAK,IYPEAK,IZPEAK,PEAK
     *  ,SIGPK,DXA,DYB,DZG,INDPK,DM1,DM2,DM3
     *  ,SPEC,IPRMAX,IPRROW,NSYM,ISYM,IPRSYM,IERR)
C ---------------------------------------------------------------
      INTEGER   IXPEAK(*),IYPEAK(*),IZPEAK(*),INDPK(*)
      REAL      PEAK(*),SIGPK(*),DXA(*),DYB(*),DZG(*)
      REAL      DM1(*),DM2(*),DM3(*)
      INTEGER*2 ISYM(5,3,IPRSYM)       
C ---------------------------------------------------------------
C --
      COMMON/COM_SRPK/ FRTOCR,CRTOFR,NX,NY,NZ,IZMIN,IZMAX,
     *                 DELA,DELG,DELB,TYPE
      REAL      FRTOCR(3,3),CRTOFR(3,3)
      CHARACTER TYPE*1,SPEC*1
C ---
      INTEGER INDSYM(192)  
      REAL    AM(3,3),AM1(3,3),AMJ(3,3),AMIJ(3,3),XF(3),XC(3),XC2(3)
      REAL    SM(3,3),AM2(3,3)
C -------------------------------------------------------------
      CHARACTER LINE*80
C ---------------------------------------------------------------
      MD   =-ABS(MDOC)-10
      PI = 4.0*ATAN(1.0)
C ---
      WRITE(LINE,'('' Number of peaks :'',I8)') NPEAK 
      CALL MSGDOC(MDOC,LINE)

      NPEAK_PRT = NPEAK
      IF(NPEAK_PRT.GT.NPMAX.AND.NPMAX.GT.0) NPEAK_PRT = NPMAX


      IF(NPEAK_PRT.GT.0) THEN      

        IF(TYPE.EQ.'R') THEN
C          CALL MSGDOC(MDOC,
C     * '       alpha   beta   gamma    theta    phi    chi         Rf   R
C     *f/sigma')

          LINE = '            alpha    beta   gamma   theta    ph'//
     *           'i    chi        Rf    Rf/sigma'   
          CALL MSGDOC(MDOC,LINE)

        ELSE
          CALL MSGDOC(MDOC,
     * '      IX  IY  IZ  Xfrac  Yfrac  Zfrac  Xort   Yort    Zort   Den
     *s Dens/sigma')
        ENDIF

        DO I=1,NPEAK_PRT
          IND = INDPK (I)
          IX  = IXPEAK(IND)
          IY  = IYPEAK(IND)
          IZ  = IZPEAK(IND)
          FX  = DXA   (IND)
          FY  = DYB   (IND)
          FZ  = DZG   (IND)
          PK  = PEAK  (IND)
          SIG = SIGPK (IND)

          IF(TYPE.EQ.'R') THEN
c            A=IX*DELA
c            G=IY*DELG
c            B=IZ*DELB
            A        = FX*DELA
            G        = FY*DELG
            B        = FZ*DELB
            DM1(IND) = FX
            DM2(IND) = FY
            DM3(IND) = FZ
c
c            write(*,*) ix,iy,iz
c            write(*,*) fx,fy,fz
c
            CALL EULERM(A,B,G,AM)
            CALL MTOPOL(AM,THETA,PHI,CHI)
            A        = (A*180.0)/PI
            B        = (B*180.0)/PI
            G        = (G*180.0)/PI

            DXA(IND) = A
            DYB(IND) = B
            DZG(IND) = G

            WRITE(LINE,200) I,A,B,G,THETA,PHI,CHI
     *      ,PK,SIG
C200        FORMAT(I3,6F8.2,G14.4,F6.2)
 200        FORMAT('Sol_RF',I3,1X,6F8.2,G14.4,F6.2)
           CALL MSGDOC(MDOC,LINE)

          ELSE

            XF(1) = FX/FLOAT(NX)
            XF(2) = FY/FLOAT(NY)
            XF(3) = FZ/FLOAT(NZ)
C            XF(1)=IX/FLOAT(NX)
C            XF(2)=IY/FLOAT(NY)
C            XF(3)=IZ/FLOAT(NZ)
            DXA(IND) = XF(1)
            DYB(IND) = XF(2)
            DZG(IND) = XF(3)
            CALL MVMULT(FRTOCR,XF,XC)

            WRITE(LINE,100) I,IX,IY,IZ,XF(1),XF(2),XF(3)
     *      ,XC(1),XC(2),XC(3)
     *      ,PK,SIG
 100        FORMAT(4I4,3F7.3,3F7.2,G12.4,F6.2)
            CALL MSGDOC(MDOC,LINE)

          ENDIF

        ENDDO

C --------------------------
        NPMAX_PRT = NPMAX
        IF(NPMAX_PRT.LE.0) NPMAX_PRT = 20
        IF(NPEAK_PRT.LT.NPMAX_PRT) NPMAX_PRT=NPEAK_PRT
        IF(NPMAX_PRT.GT.1.AND.TYPE.EQ.'R'.AND.ABS(MDOC).NE.2) THEN
c          CALL MSGDOC(MDOC,' ')
c          CALL MSGDOC(MDOC,
c     *    ' !!! You can find more information in DOC-file.')
c          CALL MSGDOC(MDOC,' ')

          IF(TYPE.EQ.'R') THEN
            CALL MSGDOC(MD,
     * '     I --> J      theta   phi    chi      RFi         RFj')
            INDSYM(1) = 1
            IF(NSYM.GT.1) THEN           
              DO I=2,NSYM
                INDSYM(I) = 1
                DO J=1,I-1
                  DO     L=1,3
                  DO     K=1,3
                    IF(ISYM(L,K,I).NE.ISYM(L,K,J)) GO TO 300
                  ENDDO
                  ENDDO
                  INDSYM(I) = 0
                  GO TO 310
 300              CONTINUE
                ENDDO
 310            CONTINUE
              ENDDO
            ENDIF


          ELSE
c            CALL MSGDOC(MD,
c     * '     I --> J      Dist       DENSi       DENSj')
          ENDIF

          DO I=1,NPMAX_PRT-1
            IND = INDPK(I)
            IX  = IXPEAK(IND)
            IY  = IYPEAK(IND)
            IZ  = IZPEAK(IND)
            FX  = DM1   (IND)
            FY  = DM2   (IND)
            FZ  = DM3   (IND)
            PK  = PEAK  (IND)
            SIG = SIGPK (IND)

            IF(TYPE.EQ.'R') THEN
C
C             X * R(I) --> R(J) :   X =  R(J) *  R(I)'
C
C             X * Sym * R(I) --> R(J) :   SR = Sym * R(I) 
C                                         X =  R(J) * SR'
C             
              A = FX*DELA
              G = FY*DELG
              B = FZ*DELB
              CALL EULERM(A,B,G,AM)
              CALL INVERT(AM,AM1,IERR)
C
C             AM' = R(I)' 
C
              NS = NSYM
              IF(SPEC.NE.'S') NS = 1
              DO IS=1,NS
                IF(INDSYM(IS).GT.0) THEN
                  IF(SPEC.EQ.'S') THEN
                    SM(1,1) = ISYM(1,1,IS)
                    SM(2,1) = ISYM(2,1,IS)
                    SM(3,1) = ISYM(3,1,IS)
                    SM(1,2) = ISYM(1,2,IS)
                    SM(2,2) = ISYM(2,2,IS)
                    SM(3,2) = ISYM(3,2,IS)
                    SM(1,3) = ISYM(1,3,IS)
                    SM(2,3) = ISYM(2,3,IS)
                    SM(3,3) = ISYM(3,3,IS)
C
C                   AM2 = SR
C
                    CALL MATMLT(SM,AM,AM2)
                    CALL MTOPOL(AM2,THETA,PHI,CHI)
                    WRITE(LINE,220) IS,THETA,PHI,CHI
 220                FORMAT
     *('     ----> Isym: R(sym) * R(I) :',I4,2X,3F8.2,' (tpc)')
                    CALL MSGDOC(MD,LINE)
                    CALL MTOANG(AM2,A,B,G)
                    WRITE(LINE,221) A,B,G
 221                FORMAT
     *('                                ',6X,3F8.2,' (abg)')
                    CALL MSGDOC(MD,LINE)
                    CALL INVERT(AM2,AM1,IERR)
C                   AM1 = SR'       
                  ELSE

                  ENDIF             
                  DO J=I+1,NPMAX_PRT
                    JND  = INDPK (J)
                    JX   = IXPEAK(JND)
                    JY   = IYPEAK(JND)
                    JZ   = IZPEAK(JND)
                    FX   = DM1   (JND)
                    FY   = DM2   (JND)
                    FZ   = DM3   (JND)
                    PKJ  = PEAK  (JND)
                    SIGJ = SIGPK (JND)
                    A    = FX*DELA
                    G    = FY*DELG
                    B    = FZ*DELB
                    CALL EULERM(A,B,G,AMJ)
                    CALL MATMLT(AMJ,AM1,AMIJ)
                    CALL MTOPOL(AMIJ,THETA,PHI,CHI)
                    WRITE(LINE,210) I,J,THETA,PHI,CHI,PK,PKJ
 210                FORMAT(2I6,2X,3F8.2,2G12.4)
                    CALL MSGDOC(MD,LINE)
                  ENDDO
                ENDIF
              ENDDO

            ELSE

              XF(1) = IX/FLOAT(NX)
              XF(2) = IY/FLOAT(NY)
              XF(3) = IZ/FLOAT(NZ)
              CALL MVMULT(FRTOCR,XF,XC)
              DO J=I+1,NPMAX_PRT
                JND   = INDPK (J)
                JX    = IXPEAK(JND)
                JY    = IYPEAK(JND)
                JZ    = IZPEAK(JND)
                PKJ   = PEAK  (JND)
                SIGJ  = SIGPK (JND)
                XF(1) = JX/FLOAT(NX)
                XF(2) = JY/FLOAT(NY)
                XF(3) = JZ/FLOAT(NZ)
                CALL MVMULT(FRTOCR,XF,XC2)
                DX  = XC(1)-XC2(1)  
                DY  = XC(2)-XC2(2)  
                DZ  = XC(3)-XC2(3)
                DST = SQRT(DX*DX+DY*DY+DZ*DZ)  
c                WRITE(LINE,110) I,J,DST,PK,PKJ
 110            FORMAT(2I6,2X,3G12.4)
c                CALL MSGDOC(MD,LINE)
              ENDDO
            ENDIF
          ENDDO
        ENDIF
      ENDIF
      RETURN
      END

      SUBROUTINE CALC_DST(IX,IY,IZ,JX,JY,JZ
     *   ,FIX,FIY,FIZ,FJX,FJY,FJZ,DIST
     *   ,SOR,NORIG,NSYM,ISYM,IPRSYM,IERR)
C -------------------------------------------------------------
      INTEGER*2 ISYM(5,3,IPRSYM)
      REAL      SOR(3,*)
C --
      COMMON/COM_SRPK/ FRTOCR,CRTOFR,NX,NY,NZ,IZMIN,IZMAX,
     *                 DELA,DELG,DELB,TYPE
      REAL      FRTOCR(3,3),CRTOFR(3,3)
      CHARACTER TYPE*1
C ---
      REAL X(3),Y(3),Z(3),XX(3),AM1(3,3),AM2(3,3),AM3(3,3),SM(3,3)
      REAL AM4(3,3),YY(3),W(3),WW(3)
C -------------------------------------------------------------

      DIST = 1.E20
      IF(TYPE.EQ.'R') THEN
        PI = 4.0*ATAN(1.0)
        N  = NSYM

C        A =IX*DELA
C        G =IY*DELG
C        B =IZ*DELB
C        AA=JX*DELA
C        GG=JY*DELG
C        BB=JZ*DELB
        A  = FIX*DELA
        G  = FIY*DELG
        B  = FIZ*DELB
        AA = FJX*DELA
        GG = FJY*DELG
        BB = FJZ*DELB

        CALL EULERM(A,B,G,AM1)
        CALL EULERM(AA,BB,GG,AM2)

        DO     IS=1,N
          SM(1,1)=ISYM(1,1,IS)
          SM(2,1)=ISYM(2,1,IS)
          SM(3,1)=ISYM(3,1,IS)
          SM(1,2)=ISYM(1,2,IS)
          SM(2,2)=ISYM(2,2,IS)
          SM(3,2)=ISYM(3,2,IS)
          SM(1,3)=ISYM(1,3,IS)
          SM(2,3)=ISYM(2,3,IS)
          SM(3,3)=ISYM(3,3,IS)
C    
c          CALL MATMLT(AM1,SM,AM3)
c          CALL INVERT(AM3,AM4,IERR)
c          CALL MATMLT(AM2,AM4,AM3)
c          CALL MTOPOL(AM3,THETA,PHI,CHI)

           CALL MATMLT(SM,AM1,AM3)
           CALL INVERT(AM3,AM4,IERR)
           CALL MATMLT(AM2,AM4,AM3)
           CALL MTOPOL(AM3,THETA,PHI,CHI)

c          tt=theta
c          pp=phi
c          cc=chi 
c          aA1=(A*180.0)/PI
c          bB1=(B*180.0)/PI
c          gG1=(G*180.0)/PI
c          write(*,'(i3,9f8.2)') is,aa,bb,gg,aa1,bb1,gg1,tt,pp,cc
          CHI = (PI*CHI)/180.0
          DST = ABS(CHI)
          IF(DST.GT.PI  ) DST  = ABS(2.0*PI-DST)
          IF(DST.LT.DIST) DIST = DST
        ENDDO
      ELSE

C        YY(1)=FLOAT(IX)/NX
C        YY(2)=FLOAT(IY)/NY
C        YY(3)=FLOAT(IZ)/NZ
C        WW(1)=FLOAT(JX)/NX
C        WW(2)=FLOAT(JY)/NY
C        WW(3)=FLOAT(JZ)/NZ

        YY(1) = FIX/NX
        YY(2) = FIY/NY
        YY(3) = FIZ/NZ
        WW(1) = FJX/NX
        WW(2) = FJY/NY
        WW(3) = FJZ/NZ

        N  = 1
        NN = NSYM

        INVERSI=1
C       IF(TYPE.EQ.'P') INVERSI=2
c        IF(TYPE.EQ.'P') INVERSI=1
c        IF(TYPE.EQ.'H') INVERSI=1

        INVERSJ=1
        IF(TYPE.EQ.'P') INVERSJ=2
        IF(TYPE.EQ.'H') INVERSJ=2

        ITRS=2
        ITRF=2
        IF(TYPE.EQ.'P') THEN
          ITRS=1
          ITRF=1
        ENDIF

        JTRS=2
        JTRF=2
        IF(TYPE.EQ.'P') THEN
          JTRS=1
          JTRF=1
        ENDIF
  
        DO IS=1,N


          DO I=1,INVERSI
            IF(I.EQ.2) THEN
              W(1)=-WW(1)
              W(2)=-WW(2)
              W(3)=-WW(3)
            ELSE
              W(1)=WW(1)
              W(2)=WW(2)
              W(3)=WW(3)
            ENDIF

            Z(1)=W(1)*ISYM(1,1,IS)+W(2)*ISYM(2,1,IS)+W(3)*ISYM(3,1,IS)
            TTX= REAL(ISYM(4,1,IS))/REAL(ISYM(5,1,IS))
            Z(2)=W(1)*ISYM(1,2,IS)+W(2)*ISYM(2,2,IS)+W(3)*ISYM(3,2,IS)
            TTY= REAL(ISYM(4,2,IS))/REAL(ISYM(5,2,IS))
            Z(3)=W(1)*ISYM(1,3,IS)+W(2)*ISYM(2,3,IS)+W(3)*ISYM(3,3,IS)
            TTZ= REAL(ISYM(4,3,IS))/REAL(ISYM(5,3,IS))

            DO ITR=ITRS,ITRF

              IF(ITR.EQ.2) THEN
                Z(1)=Z(1)+TTX
                Z(2)=Z(2)+TTY
                Z(3)=Z(3)+TTZ
              ENDIF

              DO     JS=1,NN

                DO J=1,INVERSJ
                  DO IOR=1,NORIG
                  
                    IF(J.EQ.2) THEN
                      Y(1)=-YY(1)+SOR(1,IOR)
                      Y(2)=-YY(2)+SOR(2,IOR)
                      Y(3)=-YY(3)+SOR(3,IOR)
                    ELSE
                      Y(1)=YY(1)+SOR(1,IOR)
                      Y(2)=YY(2)+SOR(2,IOR)
                      Y(3)=YY(3)+SOR(3,IOR)
                    ENDIF

          X1= Y(1)*ISYM(1,1,JS)+Y(2)*ISYM(2,1,JS)+Y(3)*ISYM(3,1,JS)
          TX=REAL(ISYM(4,1,JS))/REAL(ISYM(5,1,JS))
          X2= Y(1)*ISYM(1,2,JS)+Y(2)*ISYM(2,2,JS)+Y(3)*ISYM(3,2,JS)
          TY=REAL(ISYM(4,2,JS))/REAL(ISYM(5,2,JS))
          X3= Y(1)*ISYM(1,3,JS)+Y(2)*ISYM(2,3,JS)+Y(3)*ISYM(3,3,JS)
          TZ=REAL(ISYM(4,3,JS))/REAL(ISYM(5,3,JS))



                    DO JTR=JTRS,JTRF

                      IF(JTR.EQ.2) THEN
                        X1=X1+TX
                        X2=X2+TY
                        X3=X3+TZ
                      ENDIF

                      XX(1)=X1-Z(1)
                      XX(2)=X2-Z(2)
                      XX(3)=X3-Z(3)

 10       CONTINUE
          IF(XX(1).GE.0.5)THEN
            XX(1)=XX(1)-1.0
            GO TO 10
          ENDIF
 20       CONTINUE
          IF(XX(1).LT.-0.5)THEN
            XX(1)=XX(1)+1.0
            GO TO 20
          ENDIF
 30       CONTINUE
          IF(XX(2).GE.0.5)THEN
            XX(2)=XX(2)-1.0
            GO TO 30
          ENDIF
 40       CONTINUE
          IF(XX(2).LT.-0.5)THEN
            XX(2)=XX(2)+1.0
            GO TO 40
          ENDIF
 50       CONTINUE
          IF(XX(3).GE.0.5)THEN
            XX(3)=XX(3)-1.0
            GO TO 50
          ENDIF
 60       CONTINUE
          IF(XX(3).LT.-0.5)THEN
            XX(3)=XX(3)+1.0
            GO TO 60
          ENDIF

                      CALL MVMULT(FRTOCR,XX,X)
                      D2=X(1)*X(1)+X(2)*X(2)+X(3)*X(3)
                      IF(D2.LT.DIST) DIST=D2

                    ENDDO
C JTR
                  ENDDO
C ORIGINE
                ENDDO
C J
              ENDDO
C JS

            ENDDO
C ITR
          ENDDO
C I
        ENDDO
C IS
        DIST=SQRT(DIST)

      ENDIF
      RETURN
      END

      SUBROUTINE DEF_SPEC_POS(IX,IY,IZ,DIST_LIM,MODE,ISPEC
     *   ,SOR,NORIG,NSYM,ISYM,IPRSYM,IERR)
C -------------------------------------------------------------
      INTEGER*2 ISYM(5,3,IPRSYM)
      REAL      SOR(3,*)
C --
      COMMON/COM_SRPK/ FRTOCR,CRTOFR,NX,NY,NZ,IZMIN,IZMAX,
     *                 DELA,DELG,DELB,TYPE
      REAL      FRTOCR(3,3),CRTOFR(3,3)
      CHARACTER TYPE*1,MODE*1
C ---
      REAL X(3),Y(3),Z(3),XX(3),AM1(3,3),AM2(3,3),AM3(3,3),SM(3,3)
      REAL AM4(3,3),YY(3),W(3),WW(3)
C -------------------------------------------------------------
      CALL CHECK_REF(NSYM,ISYM,IFX,IFY,IFZ)             

      DIST_LIM2 = DIST_LIM*DIST_LIM

      DIST  = 1.E20
      ISPEC = 0

      IF(MODE.EQ.'R') THEN
        PI = 4.0*ATAN(1.0)

C        N=NSYM
C        A=JX*DELA
C        G=JY*DELG
C        B=JZ*DELB
c        aA=(A*180.0)/PI
c        bB=(B*180.0)/PI
c        gG=(G*180.0)/PI
C        CALL EULERM(A,B,G,AM2)
C        A=IX*DELA
C        G=IY*DELG
C        B=IZ*DELB
C        CALL EULERM(A,B,G,AM1)
C        DO     IS=1,1
C          SM(1,1)=ISYM(1,1,IS)
C          SM(2,1)=ISYM(2,1,IS)
C          SM(3,1)=ISYM(3,1,IS)
C          SM(1,2)=ISYM(1,2,IS)
C          SM(2,2)=ISYM(2,2,IS)
C          SM(3,2)=ISYM(3,2,IS)
C          SM(1,3)=ISYM(1,3,IS)
C          SM(2,3)=ISYM(2,3,IS)
C          SM(3,3)=ISYM(3,3,IS)
C    
c          CALL MATMLT(AM1,SM,AM3)
c          CALL INVERT(AM3,AM4,IERR)
c          CALL MATMLT(AM2,AM4,AM3)
c          CALL MTOPOL(AM3,THETA,PHI,CHI)
C
C           CALL MATMLT(SM,AM1,AM3)
C           CALL INVERT(AM3,AM4,IERR)
C           CALL MATMLT(AM2,AM4,AM3)
C           CALL MTOPOL(AM3,THETA,PHI,CHI)
C
c          tt=theta
c          pp=phi
c          cc=chi 
c          aA1=(A*180.0)/PI
c          bB1=(B*180.0)/PI
c          gG1=(G*180.0)/PI
c          write(*,'(i3,9f8.2)') is,aa,bb,gg,aa1,bb1,gg1,tt,pp,cc
C          CHI=(PI*CHI)/180.0
C          DST=ABS(CHI)
C          IF(DST.GT.PI) DST=ABS(2.0*PI-DST)
C          IF(DST.LT.DIST) DIST=DST
C        ENDDO

      ELSE

        YY(1) = FLOAT(IX)/NX
        YY(2) = FLOAT(IY)/NY
        YY(3) = FLOAT(IZ)/NZ


        WW(1) = YY(1)
        WW(2) = YY(2)
        WW(3) = YY(3)

        N  = 1
        NN = NSYM

        INVERSI = 1

        INVERSJ = 1

c molrep 
        IF(MODE.EQ.'P') INVERSJ = 2
C
        IF(MODE.EQ.'H') INVERSJ = 2

        ITRS = 2
        ITRF = 2
        IF(MODE.EQ.'P') THEN
          ITRS = 1
          ITRF = 1
        ENDIF

        JTRS = 2
        JTRF = 2
        IF(MODE.EQ.'P') THEN
          JTRS = 1
          JTRF = 1
        ENDIF
  
        DO IS=1,N

          DO I=1,INVERSI
            IF(I.EQ.2) THEN
              W(1) =-WW(1)
              W(2) =-WW(2)
              W(3) =-WW(3)
            ELSE
              W(1) = WW(1)
              W(2) = WW(2)
              W(3) = WW(3)
            ENDIF

            Z(1)=W(1)*ISYM(1,1,IS)+W(2)*ISYM(2,1,IS)+W(3)*ISYM(3,1,IS)
            TTX= REAL(ISYM(4,1,IS))/REAL(ISYM(5,1,IS))
            Z(2)=W(1)*ISYM(1,2,IS)+W(2)*ISYM(2,2,IS)+W(3)*ISYM(3,2,IS)
            TTY= REAL(ISYM(4,2,IS))/REAL(ISYM(5,2,IS))
            Z(3)=W(1)*ISYM(1,3,IS)+W(2)*ISYM(2,3,IS)+W(3)*ISYM(3,3,IS)
            TTZ= REAL(ISYM(4,3,IS))/REAL(ISYM(5,3,IS))

            DO ITR=ITRS,ITRF

              IF(ITR.EQ.2) THEN
                Z(1) = Z(1)+TTX
                Z(2) = Z(2)+TTY
                Z(3) = Z(3)+TTZ
              ENDIF

C molrep      
              DO     JS=1,NN
C
C pealsrch    DO     JS=2,NN

                DO J=1,INVERSJ

                  DO IOR=1,NORIG
                  
                    IF(J.EQ.2) THEN
                      Y(1) =-YY(1)+SOR(1,IOR)
                      Y(2) =-YY(2)+SOR(2,IOR)
                      Y(3) =-YY(3)+SOR(3,IOR)
                    ELSE
                      Y(1) = YY(1)+SOR(1,IOR)
                      Y(2) = YY(2)+SOR(2,IOR)
                      Y(3) = YY(3)+SOR(3,IOR)
                    ENDIF

          X1= Y(1)*ISYM(1,1,JS)+Y(2)*ISYM(2,1,JS)+Y(3)*ISYM(3,1,JS)
          TX=REAL(ISYM(4,1,JS))/REAL(ISYM(5,1,JS))
          X2= Y(1)*ISYM(1,2,JS)+Y(2)*ISYM(2,2,JS)+Y(3)*ISYM(3,2,JS)
          TY=REAL(ISYM(4,2,JS))/REAL(ISYM(5,2,JS))
          X3= Y(1)*ISYM(1,3,JS)+Y(2)*ISYM(2,3,JS)+Y(3)*ISYM(3,3,JS)
          TZ=REAL(ISYM(4,3,JS))/REAL(ISYM(5,3,JS))



                    DO JTR=JTRS,JTRF

                      IF(JTR.EQ.2) THEN
                        X1 = X1+TX
                        X2 = X2+TY
                        X3 = X3+TZ
                      ENDIF

                      XX(1) = X1-Z(1)
                      XX(2) = X2-Z(2)
                      XX(3) = X3-Z(3)

 10                   CONTINUE
                      IF(XX(1).GE.0.5)THEN
                        XX(1) = XX(1)-1.0
                        GO TO 10
                      ENDIF
 20                   CONTINUE
                      IF(XX(1).LT.-0.5)THEN
                        XX(1) = XX(1)+1.0
                        GO TO 20
                      ENDIF
 30                   CONTINUE
                      IF(XX(2).GE.0.5)THEN
                        XX(2) = XX(2)-1.0
                        GO TO 30
                      ENDIF
 40                   CONTINUE
                      IF(XX(2).LT.-0.5)THEN
                        XX(2) = XX(2)+1.0
                        GO TO 40
                      ENDIF
 50                   CONTINUE
                      IF(XX(3).GE.0.5)THEN
                        XX(3) = XX(3)-1.0
                        GO TO 50
                      ENDIF
 60                   CONTINUE
                      IF(XX(3).LT.-0.5)THEN
                        XX(3) = XX(3)+1.0
                        GO TO 60
                      ENDIF

                      CALL MVMULT(FRTOCR,XX,X)

                      IF(IFX.EQ.0) THEN
                        D2 = X(2)*X(2)+X(3)*X(3)
                      ELSE IF(IFY.EQ.0) THEN
                        D2 = X(1)*X(1)+X(3)*X(3)
                      ELSE IF(IFZ.EQ.0) THEN
                        D2 = X(1)*X(1)+X(2)*X(2)
                      ELSE
                        D2 = X(1)*X(1)+X(2)*X(2)+X(3)*X(3)
                      ENDIF

                      IF(JS.NE.1.OR.J.NE.1.OR.IOR.NE.1) THEN
                        IF(D2.LT.DIST_LIM2) THEN
                          ISPEC = 1
                          RETURN
                        ENDIF
                      ENDIF

                    ENDDO
C JTR
                  ENDDO
C ORIGINE
                ENDDO
C J
              ENDDO
C JS

            ENDDO
C ITR
          ENDDO
C I
        ENDDO
C IS
C       DIST = SQRT(DIST)

      ENDIF
      RETURN
      END

      SUBROUTINE PARAB(F_1,F0,F1,X_PR,C_PR,D_PR)
      IF(F1.GT.F0.OR.F_1.GT.F0) GO TO 100
      C_PR = F0 - (F_1 + F1 )/2.0
      IF(C_PR.LE.0.00001)       GO TO 100
      X_PR = (F1 - F_1)/(4.0*C_PR)
      IF(ABS(X_PR).GE.1.0)      GO TO 100
      D_PR = F0 + C_PR*X_PR*X_PR
      RETURN
 100  CONTINUE
      X_PR = 0.0
      C_PR = 0.0
      D_PR = F0
      RETURN
      END

      SUBROUTINE STRPACK(MDOC,MDOC_LIST,LIST,MOD2P,PST,SPST
     * ,NAME,ISYM,IPRSYM
     * ,POOL_SCR,MEMORY_SCR
     * ,PACK_MIN,PACK_MAX,RESULT,IPRMAX,IPRROW
     * ,SMOOTHr,ITEST_Pr,IERR)
C ---------------------------------------------------------
      REAL      POOL_SCR(*)
C ---
c      REAL      FA_CF(IPRCF),FB_CF(IPRCF)
c      INTEGER*2 IH_CF(IPRCF),IK_CF(IPRCF),IL_CF(IPRCF),IEND_CF(IPRCF)

      real,      allocatable :: FA_CF(:)
      real,      allocatable :: FB_CF(:)
      integer*2, allocatable :: IH_CF(:)
      integer*2, allocatable :: IK_CF(:)
      integer*2, allocatable :: IL_CF(:)
      integer*2, allocatable :: IEND_CF(:)

c      INTEGER   IPACK(IPRMEM)
c      REAL      FAPACK(IPRMEM),FBPACK(IPRMEM)

      integer,   allocatable :: IPACK(:)
      real,      allocatable :: FAPACK(:)
      real,      allocatable :: FBPACK(:)
C ---
      INTEGER*2 ISYM(5,3,IPRSYM)

c      INTEGER*2 INDIJ(IPRSYM,IPRSYM)
c      INTEGER*2 JHS(IPRSYM),JKS(IPRSYM),JLS(IPRSYM),IGSYM(IPRSYM)
c      INTEGER*2 IHT(IPRSYM),IKT(IPRSYM),ILT(IPRSYM)
c      REAL      SFA(IPRSYM),SFB(IPRSYM)
c      REAL      SFA2(IPRSYM),SFB2(IPRSYM)

      integer*2,   allocatable :: INDIJ(:,:)
      integer*2,   allocatable :: JHS(:)
      integer*2,   allocatable :: JKS(:)
      integer*2,   allocatable :: JLS(:)
      integer*2,   allocatable :: IHT(:)
      integer*2,   allocatable :: IKT(:)
      integer*2,   allocatable :: ILT(:)
      integer*2,   allocatable :: IGSYM(:)
      real,        allocatable :: SFA(:)
      real,        allocatable :: SFB(:)
      real,        allocatable :: SFA2(:)
      real,        allocatable :: SFB2(:)

      INTEGER   IPRSYM
      CHARACTER MOD2P*1,PST*1

      REAL      RESULT (IPRMAX,IPRROW),SPST(3)

      CHARACTER NAME(12)*256

      CHARACTER NAMEF1*256,NAMEPH1*256,NAMEF2*256,NAMEPH2*256
      CHARACTER NAMEF1_PK*256,NAMEPH1_PK*256,NAMEF2_PK*256
      CHARACTER NAMEI*256,NAMEI_PK*256,NAMEPH2_PK*256
      CHARACTER NAMES*256,NAMED*256

C ---
      COMMON/CMPAR/ TWOPI,RAD1,RAD2,COEF,BTMP,RHMIN,RHMAX,FMIN,SCALE
     *             ,IPRINT,INVERS,ISELF
     *             ,MTN,MTIN1,MTIN2,MTIN3,MTIN4,MTOUT
     *             ,IHMAX,IKMAX,LMAX,NX,NY,NZ,IZMIN,IZMAX
     *             ,VOL,PERC1,PERC2,IOP1,IOP2
     *             ,SCALE1,SCALE2,BETMIN,BETMAX,RESMIN,RESMAX
     *      ,MSG,MSG1,MSGB,MSG2,MSG3,MOD2,FUNC,REMOV,INVER,ACCUM,GAUSS
      REAL*8 TWOPI
      CHARACTER MSG*1,MSG1*1,MSGB*1,MSG2*1,MSG3*1
      CHARACTER MOD2*1,FUNC*1,REMOV*1,INVER*1,ACCUM*1,GAUSS*1
C ---
      COMMON/CNSFAC/ FOBS0,FM01,FM02,SH,SH2
     *       ,NADDM,SH3,SFOBS2,SFMOD2,SFMODP
      REAL FOBS0,FM01,FM02,SH(3),SH2(3),SH3(3,10)
     *       ,SFOBS2,SFMOD2,SFMODP
C ---
      COMMON/COM_TRP_WRT/ IEND_WRT,NUMB1_WRT,IFIRST_WRT
C ---
      COMMON/COM_TRP_TEST/ SMOOTH,ITEST_P
C ---
      REAL*8 FAW

      REAL      RLATT(6),FOBS2,FOBSB,RLATT_WRT(6)

      CHARACTER MSGG*1,ITP*4,TITLE*80,MODE*1,MOD2_OLD*1,LIST*1
      CHARACTER LINE*80,PATH*80,EXT*3,STR*80
C =====================================================================
      MD =-ABS(MDOC)-10
      M  = 99
      FOBS0 = 0.0
      FM01  = 0.0
      FM02  = 0.0

      IF(LIST.EQ.'T') MD = MDOC
c ---
      SMOOTH  = SMOOTHr 
      ITEST_P = ITEST_Pr

      NAMEF1     = NAME( 1)
      NAMEPH1    = NAME( 2)
      NAMEF2     = NAME( 3)
      NAMEPH2    = NAME( 4)
      NAMEI      = NAME( 5)
      NAMEF1_PK  = NAME( 6)
      NAMEPH1_PK = NAME( 7)
      NAMEF2_PK  = NAME( 8)
      NAMEPH2_PK = NAME( 9)
      NAMEI_PK   = NAME(10)
      NAMES      = NAME(11)
      NAMED      = NAME(12)

      TITLE  = '                                          '
      STR    = '                                          '
      IERR   = 0
      TWOPI  = 6.2831852
      IFIRST_WRT = 0
      PACK_MIN   = 0.0
      PACK_MAX   = 0.0
      JERR       = 0
      KERR       = 0
      LERR       = 0
      IND_MAX    = 0
C ------------------------------------------------------
      IF(ACCUM.EQ.'m') ACCUM='M'
      IF(ACCUM.EQ.'n') ACCUM='N'
      IF(ACCUM.NE.'M'.AND.ACCUM.NE.'N') ACCUM='A'

      IF(GAUSS.EQ.'y') GAUSS='Y'
      IF(GAUSS.NE.'Y') GAUSS='N'

      IF(FUNC.EQ.'n')  FUNC='N'
      IF(FUNC.EQ.'s')  FUNC='S'
      IF(FUNC.NE.'N'.AND.FUNC.NE.'S')  FUNC='Y'

      IF(MOD2P.EQ.'n') MOD2P='N'
      IF(MOD2P.NE.'N') MOD2P='Y'

      IF(MSG.EQ.'m') MSG='M'
      IF(MSG.EQ.'p') MSG='P'
      IF(MSG.EQ.'d') MSG='D'
      IF(MSG.EQ.'s') MSG='S'
      IF(MSG.NE.'P'.AND.MSG.NE.'D'.AND.MSG.NE.'M'.AND.MSG.NE.'S')MSG='T'
C ---------------------------------------------------
      IF(MSG.EQ.'T') THEN
        CALL MSGDOC(MD,' --- TRANSLATION FUNCTION FOR PATTERSON ---')
      ELSE IF(MSG.EQ.'D') THEN
        CALL MSGDOC(MD,' --- TRANSLATION FUNCTION FOR DENSITY ---')
      ELSE IF(MSG.EQ.'M') THEN
        CALL MSGDOC(MD,' --- TM FUNCTION  --- ')
      ELSE IF(MSG.EQ.'S') THEN
        CALL MSGDOC(MD,' --- CREATE SCRATCH_FILE ONLY --- ')
      ELSE
        CALL MSGDOC(MD,' --- PACKING FUNCTION --- ')
      ENDIF
      IF(MSG.EQ.'S') FUNC  = 'N'
      IF(MSG.EQ.'M') ACCUM = 'M'
      MOD2_OLD = MOD2
      IF(LIST.EQ.'T') THEN
        WRITE(*,*) 'PST:',PST,SPST(1),SPST(2),SPST(3)
        WRITE(*,*) 'func,msg:',func,msg
      ENDIF
C ---------------------------------------------------
      allocate(INDIJ(1:IPRSYM,1:IPRSYM),STAT=ISTAT)
      allocate(JHS(1:IPRSYM),STAT=ISTAT)
      allocate(JKS(1:IPRSYM),STAT=ISTAT)
      allocate(JLS(1:IPRSYM),STAT=ISTAT)
      allocate(IHT(1:IPRSYM),STAT=ISTAT)
      allocate(IKT(1:IPRSYM),STAT=ISTAT)
      allocate(ILT(1:IPRSYM),STAT=ISTAT)
      allocate(IGSYM(1:IPRSYM),STAT=ISTAT)
      allocate(SFA(1:IPRSYM),STAT=ISTAT)
      allocate(SFB(1:IPRSYM),STAT=ISTAT)
      allocate(SFA2(1:IPRSYM),STAT=ISTAT)
      allocate(SFB2(1:IPRSYM),STAT=ISTAT)

      IPRCF = 0
      RESMIN_I = RESMIN
      RESMAX_I = RESMAX
      LERR     = 0
      IF(FUNC.EQ.'Y'.OR.FUNC.EQ.'S'.OR.MSG.EQ.'P') THEN
        MODE     = 'P' 
        MOD2 = MOD2P 
        CALL FILES_TRP(MDOC,MODE,ITP,RLATT,NSYM,ISYM,IPRSYM
     *   ,NAMEF1_PK,NAMEPH1_PK,NAMEF2_PK,NAMEPH2_PK,NAMEI_PK
     *   ,RESMIN_TRP,RESMAX_TRP,TITLE,STR,IERR)
        IF(IERR.GT.0) THEN
          GO TO 100
        ENDIF

C ---
        CALL SPGRP(MDOC,NSYM,ISYM,INDIJ,IPRSYM,IERR)
        IF(IERR.GT.0) THEN
          GO TO 100
        ENDIF
C ---
        CALL READER_TRP(MDOC,MODE,ITP,MTS,NUMB,RLATT,NSYM,ISYM,INDIJ
     *  ,JHS,JKS,JLS,IGSYM,IHT,IKT,ILT,SFA,SFB,SFA2,SFB2,FOBS2,FOBSB
     *  ,POOL_SCR,MEMORY_SCR,IND_SCR,IND_MAX
     *  ,IPRSYM,JERR,KERR,IERR)
        IF(IERR.GT.0) THEN
          GO TO 100
        ENDIF
        IF(JERR.GT.0.OR.KERR.GT.0) THEN          
          CALL MSGERR(MDOC,' ERROR: in subroutine READER_TRP')
          WRITE(*,*) 'KERR,JERR,IND_SCR,IND_MAX,MEMORY_SCR:',
     *                KERR,JERR,IND_SCR,IND_MAX,MEMORY_SCR
          GO TO 900
        ENDIF
c       write(*,*) 'IND_SCR=',IND_SCR
c--   03.03.2010
        IF(LIST.EQ.'T') THEN
          WRITE(*,*) '--2--fm01_2,nsym:',fm01,fm02,nsym
        ENDIF
        FM01 = FM01*0.955
        FM02 = FM02*0.955
        IF(LIST.EQ.'T') THEN
          WRITE(*,*) '--22--fm01_2:',fm01,fm02
        ENDIF
c--   03.03.2010
C ----

c       allocation  IPACK
c--------alloc--Find sizes:
        r1 = 1/(2.0*rhmax)
        call limhkl(r1,m1,m2,m3,nn1,nn2,nn3)
        IPRMEM = (2*m1+1)*(2*m2+1)*(m3+1)
c--------------------------
        IT = 0
        allocate(IPACK(1:IPRMEM),STAT=ISTAT)
        IT = IT + ABS(ISTAT)
        allocate(FAPACK(1:IPRMEM),STAT=ISTAT)
        IT = IT + ABS(ISTAT)
        allocate(FBPACK(1:IPRMEM),STAT=ISTAT)
        IT = IT + ABS(ISTAT)
C        IF(MSG.EQ.'P') THEN
C          IPRCF = IPRMEM + 10
C        ELSE
          IPRCF = 2*IPRMEM + 10
C        ENDIF
        IF(LIST.EQ.'T') THEN
          WRITE(*,*) '-1-',r1
          WRITE(*,*) '-1-',IPRMEM
          WRITE(*,*) '-1-',IPRCF
        ENDIF
        allocate(FA_CF(1:IPRCF),STAT=ISTAT)
        IT = IT + ABS(ISTAT)
        allocate(FB_CF(1:IPRCF),STAT=ISTAT)
        IT = IT + ABS(ISTAT)
        allocate(IH_CF(1:IPRCF),STAT=ISTAT)
        IT = IT + ABS(ISTAT)
        allocate(IK_CF(1:IPRCF),STAT=ISTAT)
        IT = IT + ABS(ISTAT)
        allocate(IL_CF(1:IPRCF),STAT=ISTAT)
        IT = IT + ABS(ISTAT)
        allocate(IEND_CF(1:IPRCF),STAT=ISTAT)
        IT = IT + ABS(ISTAT)
        IF(IT.GT.0) THEN
          GO TO 900
        ENDIF
c--------------------------
        MJ   = 0
        MK   = 0
        MSGG = 'P'

        IF(LIST.EQ.'T') THEN
          write(*,*) 'MSG,MSGG:',MSG,MSGG
        ENDIF

        CALL MSGDOC(MD,' --> PACK')
C       REWIND MTS
        CALL TTRPACK(MDOC,MD,MTS,MSGG,NUMB,NTOT,NOUT,FAW,MJ,MK
     *  ,PST,SPST
     *  ,JHS,JKS,JLS,IGSYM,SFA,SFB,SFA2,SFB2,RLATT,FOBS2,FOBSB
     *  ,IPACK,FAPACK,FBPACK,IPRMEM
     *  ,POOL_SCR,MEMORY_SCR
     *  ,FAS,FBS,NSYM,ISYM,INDIJ,IPRSYM,IERR)
        IF(IERR.GT.0) THEN
          deallocate(IPACK,STAT=ISTAT)
          deallocate(FAPACK,STAT=ISTAT)
          deallocate(FBPACK,STAT=ISTAT)
          deallocate(FA_CF,STAT=ISTAT)
          deallocate(FB_CF,STAT=ISTAT)
          deallocate(IH_CF,STAT=ISTAT)
          deallocate(IK_CF,STAT=ISTAT)
          deallocate(IL_CF,STAT=ISTAT)
          deallocate(IEND_CF,STAT=ISTAT)
          GO TO 100
        ENDIF
        IMOD = 1
        FAS  = 0.0
        FBS  = 0.0

        CALL WRITER_TRP(MDOC,MSGG,IMOD,FAW,NOUT,MJ,MK,FAS,FBS
     *                 ,FA_CF,FB_CF,IH_CF,IK_CF,IL_CF,IEND_CF,IPRCF
     *                 ,IPACK,FAPACK,FBPACK,IPRMEM,LERR)

        IF(MSG.EQ.'P') THEN
          IMOD = 2
          NOUT = 0
          MJ   = 0
          MK   = 0
          CALL WRITER_TRP(MDOC,MSGG,IMOD,FAW,NOUT,MJ,MK,FAS,FBS
     *                 ,FA_CF,FB_CF,IH_CF,IK_CF,IL_CF,IEND_CF,IPRCF
     *                 ,IPACK,FAPACK,FBPACK,IPRMEM,LERR)
          IF(LERR.GT.0) THEN
            CALL MSGERR(MDOC,' ERROR: in subroutine WRITE_TRP')
            deallocate(IPACK,STAT=ISTAT)
            deallocate(FAPACK,STAT=ISTAT)
            deallocate(FBPACK,STAT=ISTAT)
            deallocate(FA_CF,STAT=ISTAT)
            deallocate(FB_CF,STAT=ISTAT)
            deallocate(IH_CF,STAT=ISTAT)
            deallocate(IK_CF,STAT=ISTAT)
            deallocate(IL_CF,STAT=ISTAT)
            deallocate(IEND_CF,STAT=ISTAT)
            GO TO 900
          ENDIF
          deallocate(IPACK,STAT=ISTAT)
          deallocate(FAPACK,STAT=ISTAT)
          deallocate(FBPACK,STAT=ISTAT)
          GO TO 200
        ENDIF


c       deallocation IPACK

        deallocate(IPACK,STAT=ISTAT)
        deallocate(FAPACK,STAT=ISTAT)
        deallocate(FBPACK,STAT=ISTAT)

      ENDIF
C ---------------------------------------------------
      MOD2   = MOD2_OLD
      MODE   = MSG
      RESMIN = RESMIN_I
      RESMAX = RESMAX_I
      LERR   = 0
      CALL FILES_TRP(MDOC,MODE,ITP,RLATT,NSYM,ISYM,IPRSYM
     * ,NAMEF1,NAMEPH1,NAMEF2,NAMEPH2,NAMEI
     * ,RESMIN_TRP,RESMAX_TRP,TITLE,STR,IERR)
      IF(IERR.GT.0) THEN
        IF(IPRCF.GT.0) THEN
          deallocate(FA_CF,STAT=ISTAT)
          deallocate(FB_CF,STAT=ISTAT)
          deallocate(IH_CF,STAT=ISTAT)
          deallocate(IK_CF,STAT=ISTAT)
          deallocate(IL_CF,STAT=ISTAT)
          deallocate(IEND_CF,STAT=ISTAT)
        ENDIF
        GO TO 100
      ENDIF
C ---
      CALL SPGRP(MDOC,NSYM,ISYM,INDIJ,IPRSYM,IERR)
      IF(IERR.GT.0) THEN
        IF(IPRCF.GT.0) THEN
          deallocate(FA_CF,STAT=ISTAT)
          deallocate(FB_CF,STAT=ISTAT)
          deallocate(IH_CF,STAT=ISTAT)
          deallocate(IK_CF,STAT=ISTAT)
          deallocate(IL_CF,STAT=ISTAT)
          deallocate(IEND_CF,STAT=ISTAT)
        ENDIF
        GO TO 100
      ENDIF
C ---
      CALL READER_TRP(MDOC,MODE,ITP,MTS,NUMB,RLATT,NSYM,ISYM,INDIJ
     * ,JHS,JKS,JLS,IGSYM,IHT,IKT,ILT,SFA,SFB,SFA2,SFB2,FOBS2,FOBSB
     * ,POOL_SCR,MEMORY_SCR,IND_SCR,IND_MAX
     * ,IPRSYM,JERR,KERR,IERR)
      IF(IERR.GT.0) THEN
        IF(IPRCF.GT.0) THEN
          deallocate(FA_CF,STAT=ISTAT)
          deallocate(FB_CF,STAT=ISTAT)
          deallocate(IH_CF,STAT=ISTAT)
          deallocate(IK_CF,STAT=ISTAT)
          deallocate(IL_CF,STAT=ISTAT)
          deallocate(IEND_CF,STAT=ISTAT)
        ENDIF
        GO TO 100
      ENDIF

      IF(JERR.GT.0.OR.KERR.GT.0) THEN
        CALL MSGERR(MDOC,' ERROR: in subroutine: READER_TRP:')
        WRITE(*,*) 'KERR,JERR,IND_SCR,IND_MAX,MEMORY_SCR:',
     *              KERR,JERR,IND_SCR,IND_MAX,MEMORY_SCR
        IF(IPRCF.GT.0) THEN
          deallocate(FA_CF,STAT=ISTAT)
          deallocate(FB_CF,STAT=ISTAT)
          deallocate(IH_CF,STAT=ISTAT)
          deallocate(IK_CF,STAT=ISTAT)
          deallocate(IL_CF,STAT=ISTAT)
          deallocate(IEND_CF,STAT=ISTAT)
        ENDIF
        GO TO 900
      ENDIF
C     write(*,*) 'IND_SCR=',IND_SCR
      IND_SCR_MAX = IND_SCR 
C --------------------------------------------------------
c -------------------------------
c RSQ.LT.0.0  end of scratch_array
c FLH = RSQ
c MODE.NE.'D'
c  FOBS2  fobs
c  FOBSB   0
c  FOBS2.LT.0.0 missing (-1.0) out_resmin (-2.0)
c  LH.EQ.'Y'.OR.LH.EQ.'V'.OR.LH.EQ.'2' use FLH
c MODE.EQ.'D'
c  FOBS2  cos
c  FOBSB  sin
c  FOBS2 = FOBSB = 0 missing or out_resmin
c  FLH = 0
c -------------------------------
      IF(LIST.EQ.'T') THEN
        WRITE(*,*) 'IND_SCR,NSYM:',IND_SCR,NSYM
        WRITE(*,*) '>>',NAMES
      ENDIF
      IF(IND_SCR.GT.1) THEN

        CALL LENSTR_BL(NAMES,LEN)
        IF(LEN.LE.0.OR.NAMES(1:1).EQ.' '.OR.NAMES(1:1).EQ.',') THEN

        ELSE
C ----
          MTS  = 18
          IERR = 0
          PATH = ' '
          EXT  = ' '
          CALL OPENUW(MTS,M,PATH,NAMES,EXT,IERR)
          IF(IERR.GT.0) THEN
            CALL MSGERR(MDOC,
     *          ' ERROR: trpack: can not open SCRATCH-FILE')
            IF(IPRCF.GT.0) THEN
              deallocate(FA_CF,STAT=ISTAT)
              deallocate(FB_CF,STAT=ISTAT)
              deallocate(IH_CF,STAT=ISTAT)
              deallocate(IK_CF,STAT=ISTAT)
              deallocate(IL_CF,STAT=ISTAT)
              deallocate(IEND_CF,STAT=ISTAT)
            ENDIF
            GO TO 100
          ENDIF

          IND_SCR   = 0
          MODE_WRT  = POOL_SCR(IND_SCR + 1) 
          IND_SCR   = IND_SCR + 1
          DO L=1,6
            RLATT_WRT(L) = POOL_SCR(IND_SCR + 1)   
            IND_SCR      = IND_SCR + 1
          ENDDO
          RESMIN_WRT = POOL_SCR(IND_SCR + 1) 
          IND_SCR    = IND_SCR + 1
          RESMAX_WRT = POOL_SCR(IND_SCR + 1) 
          IND_SCR    = IND_SCR + 1
          NSYM_WRT   = POOL_SCR(IND_SCR + 1)
          IND_SCR    = IND_SCR + 1
          BETMIN_WRT = POOL_SCR(IND_SCR + 1) 
          IND_SCR    = IND_SCR + 1
          BETMAX_WRT = POOL_SCR(IND_SCR + 1) 
          IND_SCR    = IND_SCR + 1
          PERC1_WRT  = POOL_SCR(IND_SCR + 1) 
          IND_SCR    = IND_SCR + 1
          PERC2_WRT  = POOL_SCR(IND_SCR + 1)
          IND_SCR    = IND_SCR + 1
  
          WRITE(MTS) MODE_WRT,(RLATT_WRT(L),L=1,6)
     *     ,RESMIN_WRT,RESMAX_WRT,NSYM_WRT
     *     ,BETMIN_WRT,BETMAX_WRT,PERC1_WRT,PERC2_WRT      

 400      CONTINUE

          RSQ     = POOL_SCR(IND_SCR + 1) 

          IF(RSQ.LT.0.0) THEN
            GO TO 500 
          ENDIF

          IND_SCR = IND_SCR + 1
          FOBS2   = POOL_SCR(IND_SCR + 1)
          IND_SCR = IND_SCR + 1
          FOBSB   = POOL_SCR(IND_SCR + 1)
          IND_SCR = IND_SCR + 1

          IF(MODE_WRT.EQ.1) THEN

            DO L=1,NSYM_WRT
              JHS(L)   = POOL_SCR(IND_SCR + 1)  
              JHS(L)   = JHS(L) - 1000
              IND_SCR  = IND_SCR + 1
              JKS(L)   = POOL_SCR(IND_SCR + 1) 
              JKS(L)   = JKS(L) - 1000
              IND_SCR  = IND_SCR + 1
              JLS(L)   = POOL_SCR(IND_SCR + 1)  
              JLS(L)   = JLS(L) - 1000
              IND_SCR  = IND_SCR + 1
              IGSYM(L) = POOL_SCR(IND_SCR + 1) 
              IGSYM(L) = IGSYM(L) - 1000
              IND_SCR  = IND_SCR + 1
              SFA(L)   = POOL_SCR(IND_SCR + 1) 
              IND_SCR  = IND_SCR + 1
              SFB(L)   = POOL_SCR(IND_SCR + 1)  
              IND_SCR  = IND_SCR + 1
              SFA2(L)  = POOL_SCR(IND_SCR + 1)
              IND_SCR  = IND_SCR + 1
              SFB2(L)  = POOL_SCR(IND_SCR + 1)
              IND_SCR  = IND_SCR + 1
            ENDDO

            WRITE(MTS)
     *        RSQ,FOBS2,FOBSB,(JHS(L),JKS(L),JLS(L)
     *       ,IGSYM(L),SFA(L),SFB(L),SFA2(L),SFB2(L),L=1,NSYM_WRT)

          ELSE
           
            DO L=1,NSYM_WRT
              JHS(L)   = POOL_SCR(IND_SCR + 1)
              JHS(L)   = JHS(L) - 1000
              IND_SCR  = IND_SCR + 1
              JKS(L)   = POOL_SCR(IND_SCR + 1)
              JKS(L)   = JKS(L) - 1000
              IND_SCR  = IND_SCR + 1
              JLS(L)   = POOL_SCR(IND_SCR + 1)
              JLS(L)   = JLS(L) - 1000
              IND_SCR  = IND_SCR + 1
              IGSYM(L) = POOL_SCR(IND_SCR + 1) 
              IGSYM(L) = IGSYM(L) - 1000
              IND_SCR  = IND_SCR + 1
              SFA(L)   = POOL_SCR(IND_SCR + 1) 
              IND_SCR  = IND_SCR + 1
              SFB(L)   = POOL_SCR(IND_SCR + 1)  
              IND_SCR  = IND_SCR + 1
            ENDDO

            WRITE(MTS)
     *        RSQ,FOBS2,FOBSB,(JHS(L),JKS(L),JLS(L)
     *       ,IGSYM(L),SFA(L),SFB(L),L=1,NSYM_WRT)

          ENDIF

          GO TO 400
 500      CONTINUE

          END FILE MTS
          CLOSE(MTS)

        ENDIF
           
      ENDIF

      IF(MODE.EQ.'S') THEN
        IF(IPRCF.GT.0) THEN
          deallocate(FA_CF,STAT=ISTAT)
          deallocate(FB_CF,STAT=ISTAT)
          deallocate(IH_CF,STAT=ISTAT)
          deallocate(IK_CF,STAT=ISTAT)
          deallocate(IL_CF,STAT=ISTAT)
          deallocate(IEND_CF,STAT=ISTAT)
        ENDIF
        GO TO 300
      ENDIF
C -----------------------------------
c     allocation IPACK
c--------alloc--Find sizes:
        r1 = 1/(2.0*rhmax)
        call limhkl(r1,m1,m2,m3,nn1,nn2,nn3)
        IPRMEM = (2*m1+1)*(2*m2+1)*(m3+1)
c--------------------------
      allocate(IPACK(1:IPRMEM),STAT=ISTAT)
      allocate(FAPACK(1:IPRMEM),STAT=ISTAT)
      allocate(FBPACK(1:IPRMEM),STAT=ISTAT)
      IF(IPRCF.LE.0) THEN
C        IF(MSG.EQ.'P') THEN
C          IPRCF = IPRMEM + 10
C        ELSE
          IPRCF = 2*IPRMEM + 10
C        ENDIF
        IF(LIST.EQ.'T') THEN
          WRITE(*,*) '-11-',r1
          WRITE(*,*) '-11-',IPRMEM
          WRITE(*,*) '-11-',IPRCF
        ENDIF
        IT = 0
        allocate(FA_CF(1:IPRCF),STAT=ISTAT)
        IT = IT + ABS(ISTAT)
        allocate(FB_CF(1:IPRCF),STAT=ISTAT)
        IT = IT + ABS(ISTAT)
        allocate(IH_CF(1:IPRCF),STAT=ISTAT)
        IT = IT + ABS(ISTAT)
        allocate(IK_CF(1:IPRCF),STAT=ISTAT)
        IT = IT + ABS(ISTAT)
        allocate(IL_CF(1:IPRCF),STAT=ISTAT)
        IT = IT + ABS(ISTAT)
        allocate(IEND_CF(1:IPRCF),STAT=ISTAT)
        IT = IT + ABS(ISTAT)
        IF(IT.GT.0) THEN
          WRITE(*,*) '-11-it-',it
          GO TO 900
        ENDIF

      ENDIF
c      IF(MSG.NE.'M') THEN
        MJ = 0
        MK = 0
        WRITE(LINE,*) ' --> TRANS:',MSG
        CALL MSGDOC(MD,LINE)
        MSGG = MSG
        CALL TTRPACK(MDOC,MD,MTS,MSGG,NUMB,NTOT,NOUT,FAW,MJ,MK
     *    ,PST,SPST
     *    ,JHS,JKS,JLS,IGSYM,SFA,SFB,SFA2,SFB2,RLATT,FOBS2,FOBSB
     *    ,IPACK,FAPACK,FBPACK,IPRMEM
     *    ,POOL_SCR,MEMORY_SCR
     *    ,FAS,FBS,NSYM,ISYM,INDIJ,IPRSYM,IERR)
        IF(IERR.GT.0) THEN
          CALL MSGERR(MDOC,' ERROR: in subroutine TTRPACK')
          deallocate(IPACK,STAT=ISTAT)
          deallocate(FAPACK,STAT=ISTAT)
          deallocate(FBPACK,STAT=ISTAT)
          IF(IPRCF.GT.0) THEN
            deallocate(FA_CF,STAT=ISTAT)
            deallocate(FB_CF,STAT=ISTAT)
            deallocate(IH_CF,STAT=ISTAT)
            deallocate(IK_CF,STAT=ISTAT)
            deallocate(IL_CF,STAT=ISTAT)
            deallocate(IEND_CF,STAT=ISTAT)
          ENDIF
          GO TO 100
        ENDIF

        IMOD = 1
        MJ   = 1
        MK   = 1
        FAS  = 0.0
        FBS  = 0.0
        IF(LIST.EQ.'T') THEN
          WRITE(*,*) '-2-',r1
          WRITE(*,*) '-2-',IPRMEM
          WRITE(*,*) '-2-',IPRCF
          WRITE(*,*) '-2-',NOUT
        ENDIF

        CALL WRITER_TRP(MDOC,MSGG,IMOD,FAW,NOUT,MJ,MK,FAS,FBS
     *                   ,FA_CF,FB_CF,IH_CF,IK_CF,IL_CF,IEND_CF,IPRCF
     *                   ,IPACK,FAPACK,FBPACK,IPRMEM,LERR)
        IMOD = 2
        MJ   = 0
        MK   = 0
        FAS = 0.0
        FBS = 0.0

        IF(LIST.EQ.'T') THEN
          WRITE(*,*) '-3-',r1
          WRITE(*,*) '-3-',IPRMEM
          WRITE(*,*) '-3-',IPRCF
          WRITE(*,*) '-3-',NOUT
        ENDIF

        NOUT = 0

        CALL WRITER_TRP(MDOC,MSGG,IMOD,FAW,NOUT,MJ,MK,FAS,FBS
     *                 ,FA_CF,FB_CF,IH_CF,IK_CF,IL_CF,IEND_CF,IPRCF
     *                 ,IPACK,FAPACK,FBPACK,IPRMEM,LERR)
        IF(LERR.GT.0) THEN
          CALL MSGERR(MDOC,' ERROR: trpack: in subroutine WRITER.')
          LINE = 
     *    '        not memory enough for scratch_CF file'
          CALL MSGERR(MDOC,LINE)
          deallocate(IPACK,STAT=ISTAT)
          deallocate(FAPACK,STAT=ISTAT)
          deallocate(FBPACK,STAT=ISTAT)
          IF(IPRCF.GT.0) THEN
            deallocate(FA_CF,STAT=ISTAT)
            deallocate(FB_CF,STAT=ISTAT)
            deallocate(IH_CF,STAT=ISTAT)
            deallocate(IK_CF,STAT=ISTAT)
            deallocate(IL_CF,STAT=ISTAT)
            deallocate(IEND_CF,STAT=ISTAT)
          ENDIF
          GO TO 900
        ENDIF

c --
c      ELSE
c
c      ENDIF
c --

      deallocate(IPACK,STAT=ISTAT)
      deallocate(FAPACK,STAT=ISTAT)
      deallocate(FBPACK,STAT=ISTAT)

C     CLOSE(MTS)
C -----------------------------------------------
  200 CONTINUE

      CALL TRPFFT(MDOC,MDOC_LIST,LIST,NAMED,MODE,FUNC,ACCUM,IOP1,IOP2
     * ,NX,NY,NZ,IZMIN,IZMAX,NSYM,ISYM,IPRSYM
     * ,PACK_MIN,PACK_MAX
     * ,FA_CF,FB_CF,IH_CF,IK_CF,IL_CF,IEND_CF,IPRCF
     * ,RLATT,RESMIN_TRP,RESMAX_TRP,STR
     * ,RESULT,IPRMAX,IPRROW,IERR)
      IF(IPRCF.GT.0) THEN
        deallocate(FA_CF,STAT=ISTAT)
        deallocate(FB_CF,STAT=ISTAT)
        deallocate(IH_CF,STAT=ISTAT)
        deallocate(IK_CF,STAT=ISTAT)
        deallocate(IL_CF,STAT=ISTAT)
        deallocate(IEND_CF,STAT=ISTAT)
      ENDIF

C -----------------------------------------------
  300 CONTINUE

      deallocate(INDIJ,STAT=ISTAT)
      deallocate(JHS,STAT=ISTAT)
      deallocate(JKS,STAT=ISTAT)
      deallocate(JLS,STAT=ISTAT)
      deallocate(IHT,STAT=ISTAT)
      deallocate(IKT,STAT=ISTAT)
      deallocate(ILT,STAT=ISTAT)
      deallocate(IGSYM,STAT=ISTAT)
      deallocate(SFA,STAT=ISTAT)
      deallocate(SFB,STAT=ISTAT)
      deallocate(SFA2,STAT=ISTAT)
      deallocate(SFB2,STAT=ISTAT)

      RETURN
  100 CONTINUE
      IERR=1
      GO TO 300
 900  CONTINUE

      CALL MSGERR(MDOC,
     *    ' ERROR: in STRPACK: problem with memory allocation')
      IERR = 1
      GO TO 300
      END

      SUBROUTINE TTRPACK(MDOC,MD,MTS,MSGG,NUMB,NTOT,NOUT,FAW,MJ,MK
     *  ,PST,SPST
     *  ,JHS,JKS,JLS,IGSYM,SFA,SFB,SFA2,SFB2,RLATT,FOBS2,FOBSB
     *  ,IPACK,FAPACK,FBPACK,IPRMEM
     *  ,POOL_SCR,MEMORY_SCR
     *  ,FAS,FBS,NSYM,ISYM,INDIJ,IPRSYM,IERR)
C ----------------------------------------------------
      INTEGER   MDOC,NSYM,IPRSYM,IERR
      REAL      POOL_SCR(*)

      INTEGER*2 ISYM(5,3,IPRSYM),INDIJ(IPRSYM,IPRSYM)
      INTEGER*2 JHS(IPRSYM),JKS(IPRSYM),JLS(IPRSYM),IGSYM(IPRSYM)
      REAL      SFA(IPRSYM),SFB(IPRSYM)
      REAL      SFA2(IPRSYM),SFB2(IPRSYM)

      REAL      RLATT(6),FOBS2,FOBSB
C ---
      INTEGER IPACK(IPRMEM)
      REAL    FAPACK(IPRMEM),FBPACK(IPRMEM)
C ------------------------------------------------------
C ---
      COMMON/CMPAR/ TWOPI,RAD1,RAD2,COEF,BTMP,RHMIN,RHMAX,FMIN,SCALE
     *             ,IPRINT,INVERS,ISELF
     *             ,MTN,MTIN1,MTIN2,MTIN3,MTIN4,MTOUT
     *             ,IHMAX,IKMAX,LMAX,NX,NY,NZ,IZMIN,IZMAX
     *             ,VOL,PERC1,PERC2,IOP1,IOP2
     *             ,SCALE1,SCALE2,BETMIN,BETMAX,RESMIN,RESMAX
     *     ,MSG,MSG1,MSGB,MSG2,MSG3,MOD2,FUNC,REMOV,INVER,ACCUM,GAUSS
      REAL*8 TWOPI
      CHARACTER MSG*1,MSG1*1,MSGB*1,MSG2*1,MSG3*1
      CHARACTER MOD2*1,FUNC*1,REMOV*1,INVER*1,ACCUM*1,GAUSS*1
C ---
      COMMON/CNSFAC/ FOBS0,FM01,FM02,SH,SH2
     *       ,NADDM,SH3,SFOBS2,SFMOD2,SFMODP
      REAL FOBS0,FM01,FM02,SH(3),SH2(3),SH3(3,10)
     *       ,SFOBS2,SFMOD2,SFMODP
C ---
      REAL*8 R8,S8,FA000,FB000,FAW,FBW
      REAL*8 DARG,COSDD,SINDD
      REAL*8 STORA,STORB
      REAL   RLATT_WRT(6),SPST(3)
      CHARACTER LINE*80
      CHARACTER MSGG*1,PST*1
C ---
      COMMON/COM_TRP_TEST/ SMOOTH,ITEST_P
C ----------------------------------
      INCLUDE 'molrep_lh_infor.fh'
c      COMMON/COM_LH_INFOR/ BOFF_LH,BADD_LH,BOFF_FOR_SCAL
c     *   ,CHECK_CONTRAST,CONTRAST_LIM
c     *   ,BCORR_LH,FILE_FOBS,SCORE_FLAG,LH_LH,DB_LH
cC ---
c      REAL      CHECK_CONTRAST,CONTRAST_LIM
c      REAL      BOFF_FOR_SCAL,BOFF_LH,BADD_LH,BCORR_LH
c      CHARACTER LH_LH*1,SCORE_FLAG*1,DB_LH*1
c      CHARACTER FILE_FOBS*256
C ----------------------------------
c-alloc--allocatable
      real,    allocatable :: temp_array(:,:,:,:)
      integer, allocatable :: itemp_flag(:,:,:)

c       integer itemp_flag(10,10,10)
c       real temp_array(2,10,10,10)
c-alloc-
C ---
      CHARACTER CODEPDB*4,NAMEPDB*40,DATEPDB*9,SPGR*24,TITLEPDB*80 
C =====================================================================
C     MD =-ABS(MDOC)-10 
      M  = 99
      PI     = 4.0*ATAN(1.0)
      TWOPIS = 2.0*PI

C--- 26.03.2010
      PST_COEF = 0.95
      IF(MSGG.EQ.'P') PST_COEF = 1.0
C--- 26.03.2010

C --
      CALL GET_CELL(RLATT,CODEPDB,NAMEPDB,DATEPDB,TITLEPDB
     *   ,NSPGR,NSETT,SPGR,NSM,IERR)

      WRITE(LINE,*) ' Nspgr,Nsett:',NSPGR,NSETT
      CALL MSGDOC(MD,LINE)

      ITPRNT = 0
      FAS    = 0.0
      FBS    = 0.0
      SCALE  = 1.0
      S2MFM2 = 0.0
      S2MFM1 = 0.0
      SFMODP = 0.0
      SC1    = SCALE1*SQRT(PERC1/NSYM)
      SC2    = SCALE2*SQRT(PERC2/NSYM)
      IF(MSGG.EQ.'P'.OR.MSGG.EQ.'D') THEN
        SC1 = 1.0
        SC2 = 1.0
      ENDIF

      FM01S   = FM01*SC1
      FM02S   = FM02*SC2
      FOBS0S  = FOBS0
      SFOBS2S = SFOBS2
      SFMOD2S = SFMOD2

      IF(PST.EQ.'Y') THEN
        FM01S   = FM01S*(1.0+PST_COEF)
      ENDIF

      SUMF  = 0.0
      SUMF2 = 0.0

      WRITE(line,'('' SC1,SC2 : '',2G12.4)') SC1,SC2
            CALL MSGDOC(MDoc,LINE)
      WRITE(line,'('' FO0,FM01,FM02 : '',3G12.4)') FOBS0S,FM01S,FM02S
            CALL MSGDOC(MDoc,LINE)
      WRITE(line,'('' SFOBS2,SFMOD2 : '',3G12.4)') SFOBS2,SFMOD2
            CALL MSGDOC(MDoc,LINE)
      write(line,*)          SUMF,SUMF2
            CALL MSGDOC(MDoc,LINE)

       NFP  = 0
       ssfa = 0.0
       ssfb = 0.0

      ITEST=0

C     MAX RESOLUTION FOR PACK-FUNCTION = 5 A.
C     RMAXP = 1.0/25.0 
C     MAX RESOLUTION FOR PACK-FUNCTION = 4 A.
      RMAXP = 1.0/16.0
C ------------------------------------------------------
      N000  = 0
      NTOT  = 0
      JTOT  = 0
      FA000 = 0.0
      FB000 = 0.0
c -------------------------------
c RSQ.LT.0.0  end of scratch_array
c FLH = RSQ
c MODE.NE.'D'
c  FOBS2  fobs
c  FOBSB   0
c  FOBS2.LT.0.0 missing (-1.0) out_resmin (-2.0)
c  LH.EQ.'Y'.OR.LH.EQ.'V'.OR.LH.EQ.'2' use FLH
c MODE.EQ.'D'
c  FOBS2  cos
c  FOBSB  sin
c  FOBS2 = FOBSB = 0 missing or out_resmin
c  FLH = 0
c -------------------------------
C      READ(MTS) MODE_WRT,(RLATT_WRT(L),L=1,6),RESMIN_WRT,RESMAX_WRT
C     * ,NSYM_WRT,BETMIN_WRT,BETMAX_WRT,PERC1_WRT,PERC2_WRT

c      WRITE(*,*) '>>>',MODE_WRT,RLATT_WRT(1),RLATT_WRT(2)
c     * ,RLATT_WRT(3),RLATT_WRT(4),RLATT_WRT(5),RLATT_WRT(6)
c     * ,RESMIN_WRT,RESMAX_WRT,NSYM_WRT,BETMIN_WRT,BETMAX_WRT
      IND_SCR   = 0
      MODE_WRT  = POOL_SCR(IND_SCR + 1) 
      IND_SCR   = IND_SCR + 1
      DO L=1,6
        RLATT_WRT(L) = POOL_SCR(IND_SCR + 1)   
        IND_SCR      = IND_SCR + 1
      ENDDO
      RESMIN_WRT = POOL_SCR(IND_SCR + 1) 
      IND_SCR    = IND_SCR + 1
      RESMAX_WRT = POOL_SCR(IND_SCR + 1) 
      IND_SCR    = IND_SCR + 1
      NSYM_WRT   = POOL_SCR(IND_SCR + 1)
      IND_SCR    = IND_SCR + 1
      BETMIN_WRT = POOL_SCR(IND_SCR + 1) 
      IND_SCR    = IND_SCR + 1
      BETMAX_WRT = POOL_SCR(IND_SCR + 1) 
      IND_SCR    = IND_SCR + 1
      PERC1_WRT  = POOL_SCR(IND_SCR + 1) 
      IND_SCR    = IND_SCR + 1
      PERC2_WRT  = POOL_SCR(IND_SCR + 1)
      IND_SCR    = IND_SCR + 1

C ---
      CALL DSTARF(RLATT_WRT,AST,BST,CST,COALST,COBEST,COGAST,VOL)
C ================================================================

c-alloc--Find sizes:
      r1 = 1/(2.0*rhmax)
      call limhkl(r1,m1,m2,m3,nn1,nn2,nn3)
      ihhmin  = -m1
      ihhmax =   m1
      ikkmin =  -m2
      ikkmax =   m2
      illmin =   0
      illmax =   m3
      IT = 0
      allocate(itemp_flag
     * (ihhmin:ihhmax,ikkmin:ikkmax,illmin:illmax),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(temp_array
     * (2,ihhmin:ihhmax,ikkmin:ikkmax,illmin:illmax),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      IF(IT.GT.0) THEN
        IERR = 1
        CALL MSGERR(MDOC,
     *    ' ERROR: in TTRPAC: problem with memory allocation')
        CALL MSGERR(MDOC,
     *    '                  try to change resolution')
        RETURN
      ENDIF
      itemp_flag(ihhmin:ihhmax,ikkmin:ikkmax,illmin:illmax) = 0
      temp_array(1:2,ihhmin:ihhmax,ikkmin:ikkmax,illmin:illmax)=0.0
c-alloc----

      DO     IJKL=1,NUMB

C       write(*,*) IJKL,NUMB,IND_SCR, POOL_SCR(IND_SCR + 1) 
C     *  ,MODE_WRT

C        RSQ = POOL_SCR(IND_SCR + 1) 
C        IF(RSQ.LT.0.0) THEN
        FLH = POOL_SCR(IND_SCR + 1) 
        IF(FLH.LT.0.0) THEN
          CALL MSGERR(MDOC,
     *    ' ERROR: trpack: end of scratch_array')
          IERR =1
          RETURN
        ENDIF
C --------
        IF(MODE_WRT.EQ.1) THEN

C          READ(MTS)
C     *    RSQ,FOBS2,FOBSB,(JHS(L),JKS(L),JLS(L)
C     *   ,IGSYM(L),SFA(L),SFB(L),SFA2(L),SFB2(L),L=1,NSYM)

C          RSQ     = POOL_SCR(IND_SCR + 1) 
          FLH     = POOL_SCR(IND_SCR + 1) 
          IND_SCR = IND_SCR + 1
          FOBS2   = POOL_SCR(IND_SCR + 1)
          IND_SCR = IND_SCR + 1
          FOBSB   = POOL_SCR(IND_SCR + 1)
          IND_SCR = IND_SCR + 1
          DO L=1,NSYM
            JHS(L)   = POOL_SCR(IND_SCR + 1)  
            JHS(L)   = JHS(L) - 1000
            IND_SCR  = IND_SCR + 1
            JKS(L)   = POOL_SCR(IND_SCR + 1) 
            JKS(L)   = JKS(L) - 1000
            IND_SCR  = IND_SCR + 1
            JLS(L)   = POOL_SCR(IND_SCR + 1)  
            JLS(L)   = JLS(L) - 1000
            IND_SCR  = IND_SCR + 1
            IGSYM(L) = POOL_SCR(IND_SCR + 1) 
            IGSYM(L) = IGSYM(L) - 1000
            IND_SCR  = IND_SCR + 1
            SFA(L)   = POOL_SCR(IND_SCR + 1) 
            IND_SCR  = IND_SCR + 1
            SFB(L)   = POOL_SCR(IND_SCR + 1)  
            IND_SCR  = IND_SCR + 1
            SFA2(L)  = POOL_SCR(IND_SCR + 1)
            IND_SCR  = IND_SCR + 1
            SFB2(L)  = POOL_SCR(IND_SCR + 1)
            IND_SCR  = IND_SCR + 1
          ENDDO

        ELSE

C          READ(MTS)
C     *    RSQ,FOBS2,FOBSB,(JHS(L),JKS(L),JLS(L)
C     *   ,IGSYM(L),SFA(L),SFB(L),L=1,NSYM)

C         RSQ     = POOL_SCR(IND_SCR + 1) 
          FLH     = POOL_SCR(IND_SCR + 1) 
          IND_SCR = IND_SCR + 1
          FOBS2   = POOL_SCR(IND_SCR + 1)
          IND_SCR = IND_SCR + 1
          FOBSB   = POOL_SCR(IND_SCR + 1)
          IND_SCR = IND_SCR + 1
          
          DO L=1,NSYM
            JHS(L)   = POOL_SCR(IND_SCR + 1)
            JHS(L)   = JHS(L) - 1000
            IND_SCR  = IND_SCR + 1
            JKS(L)   = POOL_SCR(IND_SCR + 1)
            JKS(L)   = JKS(L) - 1000
            IND_SCR  = IND_SCR + 1
            JLS(L)   = POOL_SCR(IND_SCR + 1)
            JLS(L)   = JLS(L) - 1000
            IND_SCR  = IND_SCR + 1
            IGSYM(L) = POOL_SCR(IND_SCR + 1) 
            IGSYM(L) = IGSYM(L) - 1000
            IND_SCR  = IND_SCR + 1
            SFA(L)   = POOL_SCR(IND_SCR + 1) 
            IND_SCR  = IND_SCR + 1
            SFB(L)   = POOL_SCR(IND_SCR + 1)  
            IND_SCR  = IND_SCR + 1
          ENDDO

        ENDIF

        IHN    = JHS(1)
        IKN    = JKS(1)
        ILN    = JLS(1)
        CALL DSTAR(IHN,IKN,ILN,RSQ)


        IF(PST.EQ.'Y') THEN

          DO L=1,NSYM
            IHNn    = JHS(L)
            IKNn    = JKS(L)
            ILNn    = JLS(L)
            ARG    = TWOPIS*(IHNn*SPST(1)+IKNn*SPST(2)+ILNn*SPST(3))
            COSD   = COS(ARG)
            SIND   = SIN(ARG)
            TA     = SFA(L)*COSD-SFB(L)*SIND
            TB     = SFB(L)*COSD+SFA(L)*SIND
            SFA(L) = SFA(L) + TA*PST_COEF
            SFB(L) = SFB(L) + TB*PST_COEF
            IF(MODE_WRT.EQ.1) THEN
cc-              TA      = SFA2(L)*COSD-SFB2(L)*SIND
cc-              TB      = SFB2(L)*COSD+SFA2(L)*SIND
cc-              SFA2(L) = SFA2(L) + TA
cc-              SFB2(L) = SFB2(L) + TB
            ENDIF

          ENDDO
        ENDIF

C --------
C        TEMP=EXP(-BETMAX*0.25*RSQ)*(1.0- EXP(-BETMIN*0.25*RSQ))
        TEMP = 1.0

        IF(MSGG.EQ.'P') THEN
          TEMP  = 1.0
          FOBS2 = 1.0

          IF(RSQ.GT.RMAXP) GO TO 110

C         TEMP = EXP(-BETMAX*0.25*RSQ)
C         BADD FOR PACK-FUNCTION =  256
C          BBB  = 256.0
C          TEMP = EXP(-BBB*0.25*RSQ)
C          temp = 1.0
C          FOBS2= FOBS2*TEMP

          NFP  = NFP+1
          ssfa = ssfa+fobs2
          ssfb = ssfb+fobsb

        ELSE

c         NFT=NFT+1

          T = 1.0
          IF(BETMIN.GT.0.01) THEN
            T = (1.0- EXP(-BETMIN*0.25*RSQ))
          ENDIF
          TEMP = EXP(-BETMAX*0.25*RSQ)*T
          T    = TEMP
          IF(MSGG.NE.'D') T = TEMP*TEMP
c-lh-
          IF(LH_LH.EQ.'Y'.OR.LH_LH.EQ.'V'.OR.
     *       LH_LH.EQ.'2'.OR.LH_LH.EQ.'T') THEN
            IF(MSGG.NE.'D') THEN 
              FOBS2 = FLH*FLH
              FOBSB = FLH
              T     = 1.0
            ENDIF  
          ENDIF
c-lh-
C
          FOBS2 = FOBS2*T
          FOBSB = FOBSB*T

        ENDIF

        DO     I=1,NSYM
          SFA(I) = SFA(I)*SC1*TEMP
          SFB(I) = SFB(I)*SC1*TEMP
          IF(MSG2.NE.'N') THEN
            SFA2(I) = SFA2(I)*SC2*TEMP
            SFB2(I) = SFB2(I)*SC2*TEMP
          ENDIF
        ENDDO
        IHN = JHS(1)
        IKN = JKS(1)
        ILN = JLS(1)

        IF(MSGG.EQ.'T'.OR.MSGG.EQ.'M') THEN
          IF(FOBS2.LT.0.0) GO TO 110
          SUMF  = 0.0
          SUMF2 = 0.0
          IF(ISELF.GT.0) THEN
            SCL = 1.0
            DO     I=1,NSYM
            DO     J=1,NSYM
              IF(INDIJ(I,J).LT.0) THEN
                SUMF = SUMF+(SFA(I)*SFA(J)+SFB(I)*SFB(J))*SCL*SCL
                IF(MSG2.NE.'N') THEN
                SUMF2 = SUMF2+(SFA2(I)*SFA2(J)+SFB2(I)*SFB2(J))*SCL*SCL
                ENDIF
              ENDIF
            ENDDO
            ENDDO
          ENDIF
        ENDIF

        NNFOBS = 0
        DO     I=1,NSYM
          IF(IGSYM(I).NE.0)  THEN
            NNFOBS = NNFOBS + 1
          ENDIF
        ENDDO

        SFMODP = SFMODP + (SFA(1)*SFA(1)+SFB(1)*SFB(1))*NNFOBS

        ISTART  = 1
        IFINISH = NSYM
        IF(MSGG.NE.'D') IFINISH = 1
 
        DO I=ISTART,IFINISH
 
          IF(MSGG.EQ.'D') THEN
            IF(IGSYM(I).EQ.0) GO TO 100
C
C           Fobs(h[Ai])=Fobs(h)*EXP[-2PIi*h*Di]
C
            LS   = IGSYM(I)
            IARG = IHN*ISYM(4,1,I)+IKN*ISYM(4,2,I)+ILN*ISYM(4,3,I)
            ARG  = IARG*TWOPI/24.
            CS   = COS(ARG)
            SN   = SIN(ARG)
            STORA = FOBS2*CS+FOBSB*SN
            STORB =-FOBS2*SN+FOBSB*CS
            IF(INVERS.GT.0) STORB=-STORB
          ENDIF
  
          JSTART = 1
          JEND   = NSYM

          DO     J=JSTART,JEND
            IJ = ABS(INDIJ(I,J))
C
C           IJ=INDIJ(I,J) : [AIJ] = [AI][AJ]
C                            DIJ  = [AI] DJ + DI
C           Gj(h[Ai])=Gij(h)*EXP[-2PIi*h*Di]
C
            GIJA = SFA(IJ)
            GIJB = SFB(IJ)
            IF(MSG2.NE.'N') THEN
              GIJA2 = SFA2(IJ)
              GIJB2 = SFB2(IJ)
            ENDIF

            KSTART = 1
            KEND   = J
            IF(MSGG.EQ.'D') THEN
              KSTART = 1
              KEND   = 1
            ENDIF
            DO     K=KSTART,KEND
              IK = ABS(INDIJ(I,K))
C
C             Gk(h[Ai])=Gik(h)*EXP[-2PIi*h*Di]
C
              GIKA = SFA(IK)
              GIKB = SFB(IK)

              T = 2.0
              IF(J.EQ.K) T = 1.0
              IF(J.NE.K) THEN
                S2MFM1 = S2MFM1+(GIJA*GIKA+GIJB*GIKB)*T*NNFOBS
              ENDIF

              IF(MSG2.NE.'N') THEN
                GIKA2 = SFA2(IK)
                GIKB2 = SFB2(IK)
                IF(J.NE.K) THEN
                  S2MFM2 = S2MFM2+(GIJA2*GIKA2+GIJB2*GIKB2)*2.0
                ENDIF
              ENDIF

              IF(MSGG.EQ.'D'.OR.J.NE.K) THEN
                IF(MSGG.NE.'D') THEN
                  R8  = (GIJA*GIKA+GIJB*GIKB)
                  S8  = (GIJB*GIKA-GIJA*GIKB)
                  IHH = JHS(IK)-JHS(IJ)
                  IKK = JKS(IK)-JKS(IJ)
                  ILL = JLS(IK)-JLS(IJ)
                  R8  = R8*2.0
                  S8  = S8*2.0
                  FAW = R8*FOBS2*NNFOBS
                  FBW = S8*FOBS2*NNFOBS
                ELSE
                  R8  = GIJA
                  S8  =-GIJB
                  IHH = JHS(IJ)
                  IKK = JKS(IJ)
                  ILL = JLS(IJ)
                  R8  = R8*2.0
                  S8  = S8*2.0
                  FAW = R8*STORA-S8*STORB
                  FBW = S8*STORA+R8*STORB
                ENDIF
                IF(IHH.EQ.0.AND.IKK.EQ.0.AND.ILL.EQ.0) THEN
                  N000  = N000  + NNFOBS
                  FA000 = FA000 + FAW
                  FB000 = FB000 + FBW
                ELSE
                  IF(ILL.LT.0) THEN
                    IHH = -IHH
                    IKK = -IKK
                    ILL = -ILL
                    FBW = -FBW
                  ENDIF
                  itemp_flag(ihh,ikk,ill) = 1
                  temp_array(1,ihh,ikk,ill) = 
     &                 temp_array(1,ihh,ikk,ill) + faw
                  temp_array(2,ihh,ikk,ill) = 
     &                 temp_array(2,ihh,ikk,ill) + fbw
                ENDIF
              ENDIF

              IF(MSG2.NE.'N'.AND.ITEST_P.LE.0.AND.MSGG.NE.'D') THEN
                R8  = (GIJA*GIKA2+GIJB*GIKB2)
                S8  = (GIJB*GIKA2-GIJA*GIKB2)
                IHH = -JHS(IJ)
                IKK = -JKS(IJ)
                ILL = -JLS(IJ)
                FAW = R8*FOBS2*NNFOBS
                FBW = S8*FOBS2*NNFOBS
                IF(IHH.EQ.0.AND.IKK.EQ.0.AND.ILL.EQ.0) THEN
                  N000  = N000  + NNFOBS
                  FA000 = FA000 + FAW
                  FB000 = FB000 + FBW
                ELSE
                  IF(ILL.LT.0) THEN
                    IHH = -IHH
                    IKK = -IKK
                    ILL = -ILL
                    FBW = -FBW
                  ENDIF
                  itemp_flag(ihh,ikk,ill) = 1
                  temp_array(1,ihh,ikk,ill) = 
     &                 temp_array(1,ihh,ikk,ill) + faw
                  temp_array(2,ihh,ikk,ill) = 
     &                 temp_array(2,ihh,ikk,ill) + fbw
                ENDIF

                IF(K.NE.J) THEN
                  R82 = (GIKA*GIJA2+GIKB*GIJB2)
                  S82 = (GIKB*GIJA2-GIKA*GIJB2)
                  IHH2 = -JHS(IK)
                  IKK2 = -JKS(IK)
                  ILL2 = -JLS(IK)
                  FAW2 = R82*FOBS2*NNFOBS
                  FBW2 = S82*FOBS2*NNFOBS
                  IF(IHH2.EQ.0.AND.IKK2.EQ.0.AND.ILL2.EQ.0) THEN
                    N000  = N000  + NNFOBS
                    FA000 = FA000 + FAW2
                    FB000 = FB000 + FBW2
                  ELSE
                    IF(ILL2.LT.0) THEN
                      IHH2 = -IHH2
                      IKK2 = -IKK2
                      ILL2 = -ILL2
                      FBW2 = -FBW2
                    ENDIF
                    itemp_flag(ihh2,ikk2,ill2) = 1
                    temp_array(1,ihh2,ikk2,ill2) = 
     &               temp_array(1,ihh2,ikk2,ill2) + faw2
                    temp_array(2,ihh2,ikk2,ill2) = 
     &                 temp_array(2,ihh2,ikk2,ill2) + fbw2
                  ENDIF
                ENDIF
              ENDIF
            ENDDO
          ENDDO
 100      CONTINUE
        ENDDO
C -------
 110    CONTINUE
      ENDDO
C-----------------------------------------------
c-alloc-
      ntot = 0
      iss = 1
      do  il=illmin,illmax
        do ik=ikkmin,ikkmax
          do  ih=ihhmin,ihhmax
            if(itemp_flag(ih,ik,il).eq.1) then
              call asym(iss,ih,ik,il,jss,jh,jk,jl) 
              ntot = ntot + 1
              IF(NTOT.GT.IPRMEM) THEN
                WRITE(LINE,
     *          '('' ERROR: trpack: number of coef >'',I8)') IPRMEM
                CALL MSGERR(MDOC,LINE)
                IERR=1
                RETURN
              ENDIF
              call pack(ipack(ntot),jh,jk,jl)
              fapack(ntot) =  temp_array(1,ih,ik,il)
              fbpack(ntot) =  temp_array(2,ih,ik,il)*jss
            endif
          enddo
        enddo
      enddo

      deallocate(itemp_flag)
      deallocate(temp_array)
c-alloc-      
c ----
c      WRITE(LINE,910) NOUT
c      CALL MSGDOC(MDOC,LINE)
c  910 FORMAT(' NUMBER OF COEFF BEFORE SORT    =',I8)
      NIN=NTOT
      CALL FSORT(NIN,NOUT,IPACK,FAPACK,FBPACK,IPRMEM)
c      WRITE(LINE,920) NOUT
c      CALL MSGDOC(MDOC,LINE)
c  920 FORMAT(' NUMBER OF COEFF AFTER  SORT    =',I8)

        WRITE(LINE,*) ' ntot,NOUT:',ntot,NOUT
        CALL MSGDOC(MD,LINE)

C -----------------------------------------------
      IF(NOUT.GT.0) THEN

        FM012=FM01S+FM02S

        IF(MSGG.EQ.'T'.OR.MSGG.EQ.'M') THEN

          SUMFM2 = SFMOD2S*2.0+(FM01S*FM01S)
          SCALE  = VOL/(SUMFM2*SFOBS2S/NSYM)
          FAW = 0.0

        ELSE IF(MSGG.EQ.'D') THEN

          SUMFM2 = SFMOD2S*2.0+(FM01S*FM01S)
          SCALE  = VOL/SUMFM2
          FAW    = FOBS0S*FM01S*NSYM
          FAW    = FAW*SCALE

        ELSE IF(MSGG.EQ.'P') THEN

          CALL GET_NSYMP(MDOC,NSYM,NSYMP,ISYM,IPRSYM,IERR)

          WRITE(LINE,*) ' NSYM,NSYMP,ITEST_P:',NSYM,NSYMP,ITEST_P
          CALL MSGDOC(MD,LINE)

          SUMFM2 = SFMODP*2.0 + (FM01S*FM01S)
          SCALE  = VOL/(SUMFM2/2.0)

          WRITE(LINE,*) ' SFMODP,FM01S,FM02S:',SFMODP,FM01S,FM02S
          CALL MSGDOC(MD,LINE)
          WRITE(LINE,*) ' Sumfm2:',SUMFM2
          CALL MSGDOC(MD,LINE)

          IF(NSYM.GT.1) THEN
            T1  = FM01S*FM01S*NSYM*(NSYM-1)        
            T2  = FM01S*FM02S*NSYM*NSYM
          ELSE
            T1  = FM01S*FM01S        
            T2  = FM01S*FM02S
          ENDIF

          FAW_0 = FA000*2.0 + T1 + T2

          WRITE(LINE,*) ' FA000,T1,T2:',FA000,T1,T2
          CALL MSGDOC(MD,LINE)
          WRITE(LINE,*) ' FAW0,SCALE:',FAW_0,SCALE
          CALL MSGDOC(MD,LINE)

          FAW = (-FAW_0 + SUMFM2/2.0 )* SCALE

          WRITE(LINE,*) ' FAW,SCALE:',FAW,SCALE
          CALL MSGDOC(MD,LINE)

          IF(MSG1.EQ.'Y') THEN

C           sphere or gaussian

            IF(MSG2.NE.'N') THEN

              IF(NSPGR.EQ.1) THEN
                COEFS = 1.0/2.0
                COEFF = 1.0
              ELSE IF(NSPGR.EQ.3) THEN
                COEFS = 1.0/2.0
                COEFF = 1.0
                T2    = T2/2.0
              ELSE IF(NSPGR.EQ.4) THEN
                COEFS = 1.0/2.0
                COEFF = 1.0
              ELSE IF(NSPGR.EQ.5) THEN
                COEFS = 1.0
                COEFF = 1.0
              ELSE IF(NSPGR.EQ.144.OR.NSPGR.EQ.145) THEN
                COEFS = 1.0/2.0
                COEFF = 1.0
              ELSE 
                COEFS = NSYM/NSYMP
                COEFS = 1.0
                COEFF = COEFS
              ENDIF 

            ELSE

              IF(NSPGR.EQ.3) THEN
                COEFS = 1.0/2.0
                COEFF = 1.0
              ELSE IF(NSPGR.EQ.4) THEN
                COEFS = 1.0/2.0
                COEFF = 1.0
              ELSE IF(NSPGR.EQ.5) THEN
                COEFS = 1.0
                COEFF = 1.0
              ELSE IF(NSPGR.EQ.144.OR.NSPGR.EQ.145) THEN
                COEFS = 1.0
                COEFF = 1.0
              ELSE 
                COEFS = NSYM/NSYMP
                COEFS = 1.0
                COEFF = COEFS
              ENDIF 

            ENDIF


          ELSE

C           structure factors

            COEFS = 1.0
            COEFF = 1.0

            IF(NSYM.EQ.1) THEN
              COEFS = 1.0/2.0
              COEFF = 2.0/1.0
              IF(FUNC.EQ.'S') THEN
                FAW = (-FAW_0 + SUMFM2/16.0 )* SCALE
                COEFS = 1.0/1.0
                COEFF = 1.0/1.0
              ENDIF

              WRITE(LINE,*) '--FUNC:',FUNC, COEFS , COEFf
              CALL MSGDOC(MD,LINE)

            ELSE
              COEFS = 1.0/1.0
              COEFF = 1.0
              IF(FUNC.EQ.'S') THEN
                FAW = (-FAW_0 + SUMFM2/16.0 )* SCALE
                COEFS = 1.0/1.0
                COEFF = 1.0/1.0
              ENDIF
            ENDIF

          ENDIF    

          WRITE(LINE,*) ' COEFS,COEF:',COEFS,COEFf
          CALL MSGDOC(MD,LINE)

          SCALE = SCALE/ COEFS
          FAW   = FAW  / COEFF

          WRITE(LINE,*) ' FAW,SCALE:',FAW,SCALE
          CALL MSGDOC(MD,LINE)

        ENDIF

      ELSE
        FAW   = 0.0
        SCALE = 1.0
      ENDIF

        WRITE(LINE,*) ' FAW,SCALE:',FAW,SCALE
        CALL MSGDOC(MD,LINE)

C -----------------------------------------------
      RETURN
      END


      SUBROUTINE FILES_TRP(MDOC,MODE,ITP,RLATT,NSYM,ISYM,IPRSYM
     * ,NAMEF1,NAMEPH1,NAMEF2,NAMEPH2,NAMEI
     * ,RESMIN_TRP,RESMAX_TRP,TITLE,STR,IERR)
C ------------------------------------------------
      INTEGER   MDOC,NSYM,IPRSYM,IERR     
      INTEGER*2 ISYM(5,3,IPRSYM)

c      INTEGER*2 IPOOL(*)
      integer*2,   allocatable :: IPOOL(:)

      REAL      RLATT(6)
      CHARACTER NAMEF1*(*),NAMEPH1*(*),NAMEF2*(*),NAMEPH2*(*)
      CHARACTER NAMEI*(*),STR*(*)
      CHARACTER TITLE*(*),ITP*4,JTP*4,MODE*1

C ---
C ---
      COMMON/CMPAR/ TWOPI,RAD1,RAD2,COEF,BTMP,RHMIN,RHMAX,FMIN,SCALE
     *             ,IPRINT,INVERS,ISELF
     *             ,MTN,MTIN1,MTIN2,MTIN3,MTIN4,MTOUT
     *             ,IHMAX,IKMAX,LMAX,NX,NY,NZ,IZMIN,IZMAX
     *             ,VOL,PERC1,PERC2,IOP1,IOP2
     *             ,SCALE1,SCALE2,BETMIN,BETMAX,RESMIN,RESMAX
     *    ,MSG,MSG1,MSGB,MSG2,MSG3,MOD2,FUNC,REMOV,INVER,ACCUM,GAUSS
      REAL*8 TWOPI
      CHARACTER MSG*1,MSG1*1,MSGB*1,MSG2*1,MSG3*1
      CHARACTER MOD2*1,FUNC*1,REMOV*1,INVER*1,ACCUM*1,GAUSS*1
C ---
      COMMON/CNSFAC/ FOBS0,FM01,FM02,SH1,SH2
     *       ,NADDM,SH3,SFOBS2,SFMOD2,SFMODP
      REAL FOBS0,FM01,FM02,SH1(3),SH2(3),SH3(3,10)
     *       ,SFOBS2,SFMOD2,SFMODP
C ---
      COMMON/COMWRF/ A_WR,B_WR,C_WR,AL_WR,BE_WR,GA_WR
     *              ,RN_WR,RX_WR,CF_WR,TF_WR
     *              ,NX_WR,NY_WR,NZ_WR,IN_WR,IM_WR
     *              ,NS_WR,IS_WR,IER_WR,IEN_WR
     *              ,TP_WR,T1_WR,T2_WR,TL_WR,DT_WR
     *              ,CD_WR,SG_WR,PT_WR,PD_WR
      REAL A_WR,B_WR,C_WR,AL_WR,BE_WR,GA_WR
      REAL RN_WR,RX_WR,CF_WR,TF_WR
      INTEGER*4 NX_WR,NY_WR,NZ_WR,IN_WR,IM_WR
      INTEGER*4 NS_WR,IS_WR,IER_WR,IEN_WR
      CHARACTER TP_WR*4,T1_WR*4,T2_WR*4,TL_WR*80,DT_WR*20     
      CHARACTER CD_WR*4,SG_WR*24,PT_WR*40,PD_WR*9
C ---
C -----------------------------------------------
      CHARACTER LINE*80,TTT*80,MSGI*1
      CHARACTER ITYP*4,JTYP*4,ITPF*4,ITPH*4
      DATA ITPF/'F   '/,ITPH/'PH  '/
C ------------------------------------------------
      RESOLN  = 0.0
      RESOLX  = 0.0
      RESMIN1 = 0.0
      RESMAX1 = 0.0
      RESMIN2 = 0.0
      RESMAX2 = 0.0
      INVERS  = 0
      ISELF   = 0
      FMIN    = 0.0
      FOBS0   = 0.0
      FM01    = 0.0
      FM02    = 0.0
      SCALE   = 0.0
      COEF    = 1.0
      BTMP    = 0.0
      MTIN1   = 10
      MTIN2   = 11
      MTIN3   = 12
      MTIN4   = 13
      MTN     = 14
      IPRINT  = 0

      MD =-ABS(MDOC)-10
      M  = 99
C -----------------------------------
      CALL LENSTR_BL(NAMEF1,LEN)
      IF(LEN.LE.0.OR.NAMEF1(1:1).EQ.' '.OR.NAMEF1(1:1).EQ.',') THEN
        MSG1   = 'Y'
        NAMEF1 = ' '
        MTIN1  = 0
        MTIN2  = 0
      ELSE
        MSG1   = 'N'
      ENDIF
C ---
      IF(MSG1.EQ.'Y') THEN
        IF(RAD1.LE.1.E-5) RAD1=2.5
        IF(GAUSS.EQ.'N') THEN
          WRITE(LINE,'('' RADIUS OF SPHERE_1:'',F10.2)') RAD1
        ELSE
          WRITE(LINE,'('' WIDTH OF GAUSSIAN_1:'',F10.2)') RAD1
        ENDIF
        CALL MSGDOC(MD,LINE)
        RAD1 = RAD1*2.0
      ELSE
        IERR = 0
        ITPF = 'F   '
        IT = 4000
        allocate(IPOOL(1:IT),STAT=ISTAT)
        CALL ORFILE(MD,MTIN1,NAMEF1,ITPF,NNSYM,IPOOL,IPRSYM,IERR)
        deallocate(IPOOL,STAT=ISTAT)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MDOC,
     *    ' ERROR: trpack: can not open file F_model_1')
          IERR=1
          RETURN
        ENDIF
        CALL GET_TITLE(MD,A,B,C,ALPHA,BETA,GAMMA
     *  ,F1,F2,RESMIN1,RESMAX1,IDM,IDM,IDM,IDM,IDM,LINE,IERR)
C ---
        CALL LENSTR_BL(NAMEPH1,LEN)
        IF(LEN.LE.0.OR.NAMEPH1(1:1).EQ.' '.OR.NAMEPH1(1:1).EQ.',')THEN
          CALL MSGERR(MDOC,
     *    ' ERROR: trpack: wrong name of file PH_model_1')
          IERR=1
          CLOSE(MTIN1)
          RETURN
        ENDIF
        ITPH='PH  '
        IT = 4000
        allocate(IPOOL(1:IT),STAT=ISTAT)
        CALL ORFILE(M,MTIN2,NAMEPH1,ITPH,NNSYM,IPOOL,IPRSYM,IERR)
        deallocate(IPOOL,STAT=ISTAT)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MDOC,
     *    ' ERROR: trpack: can not open file PH_model_1')
          CLOSE(MTIN1)
          IERR=1
          RETURN
        ENDIF
        CALL GET_TITLE(MD,DM,DM,DM,DM,DM,DM
     *  ,F1,F2,F3,F4,IDM,IDM,IDM,IDM,IDM,LINE,IERR)
      ENDIF
C      WRITE(LINE,'('' VECTOR OF SHIFT_1: X,Y,X :'',3F10.4)')
C     *          SH1(1),SH1(2),SH1(3)
C      CALL MSGDOC(MD,LINE)
      IF(MODE.EQ.'T'.OR.MODE.EQ.'M') THEN
        PERC1=1.0
      ENDIF
C ------------------
C      IF(MOD2.EQ.'y') MOD2='Y'
      MSG2=MOD2
C      IF(MSG2.NE.'Y'.AND.MSG2.NE.'2') MSG2='N'
C ---
      IF(MSG2.NE.'N') THEN
        CALL LENSTR_BL(LINE,LEN)
        IF(LEN.LE.0.OR.NAMEF2(1:1).EQ.' '.OR.NAMEF2(1:1).EQ.',') THEN
          MSG3   = 'Y'
          NAMEF2 = ' '
          MTIN3  = 0
          MTIN4  = 0
        ELSE
          MSG3 = 'N'
        ENDIF
        IF(MSG3.EQ.'Y') THEN
          IF(RAD2.LE.1.E-5) RAD2=2.5
          IF(GAUSS.EQ.'N') THEN
            WRITE(LINE,'('' RADIUS OF SPHERE_2:'',F10.2)') RAD2
          ELSE
            WRITE(LINE,'('' WIDTH OF GAUSSIAN_2:'',F10.2)') RAD2
          ENDIF
          CALL MSGDOC(MD,LINE)
          RAD2=RAD2*2.0
        ELSE
          IERR = 0
          ITPF = 'F   '
          IT = 4000
          allocate(IPOOL(1:IT),STAT=ISTAT)
          CALL ORFILE(MD,MTIN3,NAMEF2,ITPF,NNSYM,IPOOL,IPRSYM,IERR)
          deallocate(IPOOL,STAT=ISTAT)
          IF(IERR.NE.0) THEN
            CALL MSGERR(MDOC,
     *      ' ERROR: trpack: can not open file F_model_2')
            IF(MTIN1.GT.0) CLOSE(MTIN1)
            IF(MTIN2.GT.0) CLOSE(MTIN2)
            IERR=1
            RETURN
          ENDIF
          CALL GET_TITLE(MD,A,B,C,ALPHA,BETA,GAMMA
     *    ,F1,F2,RESMIN2,RESMAX2,IDM,IDM,IDM,IDM,IDM,LINE,IERR)
C ---
          CALL LENSTR_BL(NAMEPH2,LEN)
          IF(LEN.LE.0.OR.NAMEPH2(1:1).EQ.' '.OR.NAMEPH2(1:1).EQ.',') 
     *    THEN
            CALL MSGERR(MDOC,
     *      ' ERROR: trpack: can not open file PH_model_2')
            IF(MTIN1.GT.0) CLOSE(MTIN1)
            IF(MTIN2.GT.0) CLOSE(MTIN2)
            IF(MTIN3.GT.0) CLOSE(MTIN3)
            IERR=1
            RETURN
          ENDIF
          ITPH='PH  '
          IT = 4000
          allocate(IPOOL(1:IT),STAT=ISTAT)
          CALL ORFILE(M,MTIN4,NAMEPH2,ITPH,NNSYM,IPOOL,IPRSYM,IERR)
          deallocate(IPOOL,STAT=ISTAT)
          IF(IERR.NE.0) THEN
            CALL MSGERR(MDOC,
     *      ' ERROR: trpack: can not open file PH_model_2')
            IF(MTIN1.GT.0) CLOSE(MTIN1)
            IF(MTIN2.GT.0) CLOSE(MTIN2)
            IF(MTIN3.GT.0) CLOSE(MTIN3)
            IERR=1
            RETURN
          ENDIF
          CALL GET_TITLE(MD,DM,DM,DM,DM,DM,DM
     *    ,F1,F2,F3,F4,IDM,IDM,IDM,IDM,IDM,LINE,IERR)

        ENDIF
C ---
        WRITE(LINE,'('' VECTOR OF SHIFT_1: X,Y,X :'',3F10.4)')
     *          SH2(1),SH2(2),SH2(3)
        CALL MSGDOC(MD,LINE)
        IF(MSG2.EQ.'2') THEN
          WRITE(LINE,'('' VECTOR OF SHIFT_2: X,Y,X :'',3F10.4)')
     *            SH1(1),SH1(2),SH1(3)
          CALL MSGDOC(MD,LINE)
        ENDIF
        IF(MODE.EQ.'T'.OR.MODE.EQ.'M') THEN
          IF(PERC2.LE.0.0001) PERC2=50.0
          IF(PERC2.GT.1.0001) PERC2=PERC2/100.0
          IF(PERC2.GT.0.99) THEN
            PERC1 = 0.5
            PERC2 = 0.5
          ELSE
            PERC1 = 1.0-PERC2
          ENDIF
          PRC1 = PERC1*100.0
          PRC2 = PERC2*100.0
          WRITE(LINE,
     *    '('' MODEL-1 IS '',F8.2,''% OF UNKOWN STRUCTURE'')') PRC1
          CALL MSGDOC(MD,LINE)
          WRITE(LINE,
     *    '('' MODEL-2 IS '',F8.2,''% OF UNKOWN STRUCTURE'')') PRC2
          CALL MSGDOC(MD,LINE)
        ENDIF
      ELSE
        MTIN3 = 0
        MTIN4 = 0
        MSG3  = 'Y'
      ENDIF

      IF(MSG3.EQ.'Y'.AND.MSG2.NE.'N') THEN
        FM02 = (TWOPI*2.0*RAD2*RAD2*RAD2*COEF)/3.0
        IF(GAUSS.EQ.'Y') FM02 = FM02*0.5
      ENDIF
      IF(MSG1.EQ.'Y') THEN
        FM01 = (TWOPI*2.0*RAD1*RAD1*RAD1*COEF)/3.0
        IF(GAUSS.EQ.'Y') FM01 = FM01*0.5
      ENDIF
C -----------------------------------------
C     IF(MODE.EQ.'T'.OR.MODE.EQ.'M'.OR.MODE.EQ.'D') THEN
        ITP='    '
        JTP='    '
        CALL LENSTR_BL(NAMEI,LEN)
        IF(LEN.LE.0.OR.NAMEI(1:1).EQ.' '.OR.NAMEI(1:1).EQ.',') THEN
          CALL MSGERR(MDOC,
     *    ' ERROR: trpack: wrong name of input_F_obs')
          IF(MTIN1.GT.0) CLOSE(MTIN1)
          IF(MTIN2.GT.0) CLOSE(MTIN2)
          IF(MTIN3.GT.0) CLOSE(MTIN3)
          IF(MTIN4.GT.0) CLOSE(MTIN4)
          IERR=1
          RETURN
        ENDIF
        IERR=0
        CALL ORFILE(MD,MTN,NAMEI,ITP,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MDOC,
     *    ' ERROR: trpack: can not open file F_obs')
          IF(MTIN1.GT.0) CLOSE(MTIN1)
          IF(MTIN2.GT.0) CLOSE(MTIN2)
          IF(MTIN3.GT.0) CLOSE(MTIN3)
          IF(MTIN4.GT.0) CLOSE(MTIN4)
          IERR=1
          RETURN
        ENDIF
        CALL GET_TITLE(MD,A,B,C,ALPHA,BETA,GAMMA
     *  ,F1,F2,F3,F4,IDM,IDM,IDM,IDM,IDM,TTT,IERR)
        RESOLN = F3
        RESOLX = F4
        IF(ITP.NE.'F   '.AND.ITP.NE.'FS  '.AND.ITP.NE.'COEF') THEN
          CALL MSGDOC(MDOC,
     *    ' ERROR: trpack : wrong type of input_F_obs /structure/')
          IERR=1
          CLOSE(MTN)
          IF(MTIN1.GT.0) CLOSE(MTIN1)
          IF(MTIN2.GT.0) CLOSE(MTIN2)
          IF(MTIN3.GT.0) CLOSE(MTIN3)
          IF(MTIN4.GT.0) CLOSE(MTIN4)
          RETURN
        ENDIF
        CALL C_RD_CR
        JTYP=TTT(1:4)
        IF(MODE.EQ.'T'.OR.MODE.EQ.'M'.OR.MODE.EQ.'P'.OR.
     *                                   MODE.EQ.'S') THEN
          IF(ITP.EQ.'COEF'.AND.JTYP.NE.'PATT') THEN
            CALL MSGERR(MDOC,
     *      ' ERROR: trpack: wrong type of input_F_obs /structure/.')
            CLOSE(MTN)
            IF(MTIN1.GT.0) CLOSE(MTIN1)
            IF(MTIN2.GT.0) CLOSE(MTIN2)
            IF(MTIN3.GT.0) CLOSE(MTIN3)
            IF(MTIN4.GT.0) CLOSE(MTIN4)
            IERR=1
            RETURN
          ENDIF
          IF(REMOV.EQ.'y') REMOV='Y'
          IF(REMOV.EQ.'Y') ISELF=1
        ELSE IF(MODE.EQ.'D') THEN
          IF(ITP.NE.'COEF'.OR.JTYP.NE.'FOUR') THEN
            CALL MSGERR(MDOC,
     *      ' ERROR: trpack: wrong type of input_F_obs')
            CLOSE(MTN)
            IF(MTIN1.GT.0) CLOSE(MTIN1)
            IF(MTIN2.GT.0) CLOSE(MTIN2)
            IF(MTIN3.GT.0) CLOSE(MTIN3)
            IF(MTIN4.GT.0) CLOSE(MTIN4)
            IERR=1
            RETURN
          ENDIF
          MSGB='Y'
          IF(INVER.EQ.'y') INVER='Y'
          MSGI=INVER
          IF(INVER.EQ.'Y') INVERS=1
        ENDIF
C      ENDIF
C ---
      IF(NSYM.EQ.1.AND.MSG2.EQ.'N'.AND.MODE.NE.'D'.AND.
     *                                 MODE.NE.'S') THEN
        CALL MSGERR(MDOC,' ERROR: trpack: function for NSYM=1 ?')
          IF(MTN.GT.0) CLOSE(MTN)
          IF(MTIN1.GT.0) CLOSE(MTIN1)
          IF(MTIN2.GT.0) CLOSE(MTIN2)
          IF(MTIN3.GT.0) CLOSE(MTIN3)
          IF(MTIN4.GT.0) CLOSE(MTIN4)
        IERR=13
        RETURN
      ENDIF
C ---------------------
      IF(RESMIN.LE.0.0) RESMIN=RESOLN
      IF(RESMAX.LE.0.0) RESMAX=RESOLX
      IF(RESMIN1.GT.0.0.AND.RESMIN1.LT.RESMIN) RESMIN=RESMIN1
      IF(RESMIN2.GT.0.0.AND.RESMIN2.LT.RESMIN) RESMIN=RESMIN2
      IF(RESMAX1.GT.0.0.AND.RESMAX1.GT.RESMAX) RESMAX=RESMAX1
      IF(RESMAX2.GT.0.0.AND.RESMAX2.GT.RESMAX) RESMAX=RESMAX2
      IF(RESMIN.LE.RESMAX) THEN
        T=RESMIN
        RESMIN=RESMAX
        RESMAX=T
      ENDIF
      WRITE(LINE,'('' RESMIN,RESMAX :'',2F10.2)') RESMIN,RESMAX
      CALL MSGDOC(MD,LINE)
      IF(RESMAX.LE.0.0.OR.RESMIN.LE.0.0) THEN
        WRITE(LINE,'('' RESMIN,RESMAX :'',2F10.2)') RESMIN,RESMAX
        CALL MSGERR(MDOC,LINE)
        CALL MSGERR(MDOC,' ERROR : trpack: wrong resolution')
        IF(MTN.GT.0) CLOSE(MTN)
        IF(MTIN1.GT.0) CLOSE(MTIN1)
        IF(MTIN2.GT.0) CLOSE(MTIN2)
        IF(MTIN3.GT.0) CLOSE(MTIN3)
        IF(MTIN4.GT.0) CLOSE(MTIN4)
        IERR=1
        RETURN
      ENDIF
      RHMIN = 1./RESMIN
      RHMAX = 1./RESMAX
      WRITE(LINE,'('' BOFF,BADD :'',2F10.2)') BETMIN,BETMAX
      CALL MSGDOC(MD,LINE)
C ----------------------------------------------------
      MTOUT=15
C ----
      CALL LENSTR_BL(TITLE,LEN)

      IF(LEN.LE.0.OR.TITLE(1:1).EQ.',') THEN
        CALL LENSTR_BL(TTT,LN)
        IF(LN.LE.0) THEN
          TITLE=' ----       '
        ELSE
          TITLE=TTT(1:LN)
        ENDIF        
      ENDIF

      CALL LENSTR_BL(TITLE,LEN)
      LN=8+LEN
      IF(LEN.GT.70) LEN=70
      LNN=LEN+9
      STR(9:LNN)=TITLE(1:LEN)

C ----
      STR(1:4)='FOUR'
      STR(5:8)='TRNS'
      IF(MODE.EQ.'P') STR(5:8)='PACK'
      IF(MODE.EQ.'M') STR(5:8)='MULT'
      IF(MODE.EQ.'T'.AND.(FUNC.EQ.'Y'.OR.FUNC.EQ.'S')) STR(5:8)='MULT'
      STR(9:12)='TRP2'
      IF(MSG2.EQ.'N') STR(9:12)='TRPC'
      IF(MSG2.EQ.'N'.AND.MSG1.EQ.'Y') STR(9:12)='SPHR'
      STR(13:13)='Y'
      STR(14:14)=' '
      IF(GAUSS.EQ.'Y') STR(14:14)='G'
      IF(MSG2.EQ.'N') THEN
        CALL CHECK_REF(NSYM,ISYM,IFX,IFY,IFZ)
        IF(IFZ.EQ.0) STR(13:13)='N'             
      ENDIF
      F1 = COEF
      F2 = BTMP
      C_RES = 2.0
      IF(MODE.EQ.'D') THEN
        F3 = 1./RHMIN
        F4 = 1./RHMAX
        STR(5:8) = 'REAL'
      ELSE
        F3 = C_RES/RHMIN
        F4 = 1.0/(RHMAX*C_RES)
      ENDIF
      RLATT(1) = A
      RLATT(2) = B
      RLATT(3) = C
      RLATT(4) = ALPHA
      RLATT(5) = BETA
      RLATT(6) = GAMMA
      IF(MODE.NE.'D'.AND.IZMAX.NE.-2) THEN
        RX=RESMAX/C_RES
      ELSE
        RX=RESMAX
      ENDIF
      CALL LIMHKL(RX,IHMAX,IKMAX,LMAX,NXMIN,NYMIN,NZMIN)

      S   = (ALPHA+BETA+GAMMA)*0.5
      VOL = 2.0*A*B*C*
     *    SQRT(ABS(SIN(S)*SIN(S-ALPHA)*SIN(S-BETA)*SIN(S-GAMMA)))
      IF(NX.LE.0) NX = NXMIN
      IF(NY.LE.0) NY = NYMIN
      IF(NZ.LE.0) NZ = NZMIN
      NX   = (NX/2)*2
      NY   = (NY/2)*2
      NZ   = (NZ/2)*2
      RESMIN_TRP = F3
      RESMAX_TRP = F4

      ITYP = 'COEF'
C ---
      CALL C_CR_WR
C 
C      NS_WR = 1
C      SG_WR = 'P 1'
C
      CALL SET_TITLE(M,A,B,C,ALPHA,BETA,GAMMA
     *  ,F1,F2,F3,F4,IDM,IDM,IDM,IDM,IDM,STR,IERR)
      IERR=0

C      CALL LENSTR_BL(NAMEC,LEN)
C      IF(LEN.LE.0.OR.NAMEC(1:1).EQ.' '.OR.NAMEC(1:1).EQ.',') THEN
C        NAMEC='trpack_cf'
C      ENDIF

      NS1 = 1
      NS1 = NSYM

C      CALL OWFILE(M,MTOUT,NAMEC,ITYP,NS1,ISYM,IPRSYM,IERR)
C      IF(IERR.NE.0) THEN
C        CALL MSGERR(MDOC,
C     *  ' ERROR: trpack: can not open file: output_coef')
C        IERR=1
C        IF(MTN.GT.0) CLOSE(MTN)
C        IF(MTIN1.GT.0) CLOSE(MTIN1)
C        IF(MTIN2.GT.0) CLOSE(MTIN2)
C        IF(MTIN3.GT.0) CLOSE(MTIN3)
C        IF(MTIN4.GT.0) CLOSE(MTIN4)
C        RETURN
C      ENDIF
C      CALL MSGDOC(MD,
C     *'name of output_coef_file :')
C      CALL MSGDOC(MD,NAMEC)
Cc      CALL MSGDOC(MD,
c     * '   /type of file is COEF, for space group P1/ )')
c      WRITE(LINE,'(''     ( WITH RESOLUTION:'',2F8.2,''    )'')')
c     *        F3,F4
c      CALL MSGDOC(MD,LINE)
C --------------------------------------------------
      IPRINT=0
      IF(MODE.EQ.'P') THEN
C       MAX RESOLUTION FOR PACK-FUNCTION = 5 A.
C       IF(RESMAX.LT.5.0) RESMAX=5.0
C       MAX RESOLUTION FOR PACK-FUNCTION = 4 A.
        IF(RESMAX.LT.4.0) RESMAX=4.0
      ENDIF
C ------------------------------------------------------
      RETURN
      END

      SUBROUTINE READER_TRP(MDOC,MODE,ITP,MTS,NUMB,RLATT,NSYM,ISYM,INDIJ
     * ,JHS,JKS,JLS,IGSYM,IHT,IKT,ILT,SFA,SFB,SFA2,SFB2,FOBS2,FOBSB
     * ,POOL_SCR,MEMORY_SCR,IND_SCR,IND_MAX
     * ,IPRSYM,JERR,KERR,IERR)
C --------------------------------------------
      REAL      POOL_SCR(*)
      INTEGER   MDOC,MTS,NUMB,IPRSYM,IERR
      INTEGER*2 ISYM(5,3,IPRSYM),INDIJ(IPRSYM,IPRSYM)
      REAL RLATT(6)
      CHARACTER ITP*4,MODE*1
      INTEGER*2 JHS(IPRSYM),JKS(IPRSYM),JLS(IPRSYM),IGSYM(IPRSYM)
      INTEGER*2 IHT(IPRSYM),IKT(IPRSYM),ILT(IPRSYM)
      REAL SFA (IPRSYM),SFB(IPRSYM)
      REAL SFA2(IPRSYM),SFB2(IPRSYM)
      REAL FOBS2,FOBSB
C -------------
c     REAL  POOLA(IPRNCR),POOLB(IPRNCR),POOLA1(IPRNCR),POOLB1(IPRNCR)
      real,    allocatable :: POOLA(:)
      real,    allocatable :: POOLB(:)
      real,    allocatable :: POOLA1(:)
      real,    allocatable :: POOLB1(:)
C -------------
C ---
      COMMON/CMPAR/ TWOPI,RAD1,RAD2,COEF,BTMP,RHMIN,RHMAX,FMIN,SCALE
     *             ,IPRINT,INVERS,ISELF
     *             ,MTN,MTIN1,MTIN2,MTIN3,MTIN4,MTOUT
     *             ,IHMAX,IKMAX,LMAX,NX,NY,NZ,IZMIN,IZMAX
     *             ,VOL,PERC1,PERC2,IOP1,IOP2
     *             ,SCALE1,SCALE2,BETMIN,BETMAX,RESMIN,RESMAX
     *     ,MSG,MSG1,MSGB,MSG2,MSG3,MOD2,FUNC,REMOV,INVER,ACCUM,GAUSS
      REAL*8 TWOPI
      CHARACTER MSG*1,MSG1*1,MSGB*1,MSG2*1,MSG3*1
      CHARACTER MOD2*1,FUNC*1,REMOV*1,INVER*1,ACCUM*1,GAUSS*1
C ----------------
      COMMON/CNSFAC/ FOBS0,FM01,FM02,SH,SH2
     *       ,NADDM,SH3,SFOBS2,SFMOD2,SFMODP
      REAL FOBS0,FM01,FM02,SH(3),SH2(3),SH3(3,10)
     *       ,SFOBS2,SFMOD2,SFMODP
C ------------------------------------------------------------
      COMMON/TRFUN_COM_TMP/ FOBS_000,FMOD1_000,FMOD2_000,NEL2,IERR_PK
     *                     ,SCALEP_STORE,BOVER_STORE,SIGMA_STORE
C -----------------------------------------
C ----------------------------------
      INCLUDE 'molrep_lh_infor.fh'
c      COMMON/COM_LH_INFOR/ BOFF_LH,BADD_LH,BOFF_FOR_SCAL
c     *   ,CHECK_CONTRAST,CONTRAST_LIM
c     *   ,BCORR_LH,FILE_FOBS,SCORE_FLAG,LH_LH,DB_LH
cC ---
c      REAL      CHECK_CONTRAST,CONTRAST_LIM
c      REAL      BOFF_FOR_SCAL,BOFF_LH,BADD_LH,BCORR_LH
c      CHARACTER LH_LH*1,SCORE_FLAG*1,DB_LH*1
c      CHARACTER FILE_FOBS*256
C ----------------------------------
      REAL*8 DARG,COSD,SIND,FA,FB,FAW,FBW
      PARAMETER (LMAX_PAR = 1000)
      INTEGER INDEX1(LMAX_PAR),INDEXH1(LMAX_PAR),INDEXK1(LMAX_PAR)
      INTEGER INDEX2(LMAX_PAR),INDEXH2(LMAX_PAR),INDEXK2(LMAX_PAR)
      CHARACTER LINE*80
C ------------------------------------------------
      MD = -ABS(MDOC)-10
      M  = 99
C ---
      JERR     = 0
      KERR     = 0
      JERR1    = 0
      DO I=1,LMAX_PAR
        INDEX1 (I) = 0
        INDEXH1(I) = 0
        INDEXK1(I) = 0
        INDEX2 (I) = 0
        INDEXH2(I) = 0
        INDEXK2(I) = 0
      ENDDO

      CALL LIMHKL(RESMAX,JHMAX,JKMAX,JLMAX,KXMIN,KYMIN,KZMIN)
    
      KX  = 2*JHMAX+1
      KY  = 2*JKMAX+1
      KXY = KX*KY

      JLMAX1 = JLMAX+1

      KX1  = KX+1
      KX2  = KX+2
      KXB2 = KX/2
      KYB2 = KY/2

      MEMTOT = KXY*JLMAX1
 
C ---
      IEND1    =-1
      IEND2    =-1
      IEND3    =-1
      IEND4    =-1
      IENDN    =-1
      NUMB     = 0
      NUMBO    = 0
      NUMBP    = 0
      NUMBM    = 0
      SFOBS2   = 0.0
      SUMFM1   = 0.0
      SUMFM2   = 0.0
      SFMOD2   = 0.0
      SFMODP   = 0.0
      FOBS0    = 0.0
      IND_MAX1 = 0
      IND_MAX2 = 0
      IND_MAX  = 0
C------------------------------------
C
C     initialization
C
      CALL ANOMF(M,NSYM,ISYM)
      CALL DSTARF(RLATT,AST,BST,CST,COALST,COBEST,COGAST,VOL)
C ----------------------------------
c -------------------------------
c RSQ.LT.0.0  end of scratch_array
c FLH = RSQ
c MODE.NE.'D'
c  FOBS2  fobs
c  FOBSB   0
c  FOBS2.LT.0.0 missing (-1.0) out_resmin (-2.0)
c  LH.EQ.'Y'.OR.LH.EQ.'V'.OR.LH.EQ.'2' use FLH
c MODE.EQ.'D'
c  FOBS2  cos
c  FOBSB  sin
c  FOBS2 = FOBSB = 0 missing or out_resmin
c  FLH = 0
c -------------------------------
C      write(*,*) '>>>>>>>>>>>'
C      T = 1.0/RHMAX
C      write(*,*) T,nsym
C      write(*,*) (rlatt(i),i=1,6)
C      write(*,*) '>>',jhmax,jkmax,jlmax
C      write(*,*) '>>msg2:',MSG2,lmax_par

      MODE_WRT = 0
      IF(MSG2.NE.'N') MODE_WRT = 1

C      WRITE(MTS) MODE_WRT,(RLATT(L),L=1,6),RESMIN,RESMAX,NSYM
C     * ,BETMIN,BETMAX,PERC1,PERC2      

      IND_SCR = 0
      POOL_SCR(IND_SCR + 1) = MODE_WRT + 0.1
      IND_SCR = IND_SCR + 1
      DO I=1,6
        POOL_SCR(IND_SCR + 1) = RLATT(I)  
        IND_SCR = IND_SCR + 1
      ENDDO
      POOL_SCR(IND_SCR + 1) = RESMIN
      IND_SCR = IND_SCR + 1
      POOL_SCR(IND_SCR + 1) = RESMAX
      IND_SCR = IND_SCR + 1
      POOL_SCR(IND_SCR + 1) = NSYM + 0.1
      IND_SCR = IND_SCR + 1
      POOL_SCR(IND_SCR + 1) = BETMIN
      IND_SCR = IND_SCR + 1
      POOL_SCR(IND_SCR + 1) = BETMAX
      IND_SCR = IND_SCR + 1
      POOL_SCR(IND_SCR + 1) = PERC1
      IND_SCR = IND_SCR + 1
      POOL_SCR(IND_SCR + 1) = PERC2
      IND_SCR = IND_SCR + 1
C------------------------------------
      IALLOC  = 0
      IALLOC1 = 0
      IF(MSG1.NE.'Y') THEN
        CALL RDF_MODEL_CHECK_MEM(MDOC
     * ,LMAX_PAR,FM01,KX,KY,JLMAX,RHMAX,INDEX1,INDEXH1,INDEXK1
     * ,IND_MAX1,JERR1,IERR)
        IF(IERR.NE.0) THEN
          IERR=1
          IF(MTN.GT.0)   CLOSE(MTN)
          IF(MTIN1.GT.0) CLOSE(MTIN1)
          IF(MTIN2.GT.0) CLOSE(MTIN2)
          IF(MTIN3.GT.0) CLOSE(MTIN3)
          IF(MTIN4.GT.0) CLOSE(MTIN4)
          RETURN
        ENDIF
      ENDIF
      IF(MSG3.NE.'Y') THEN
        CALL RDF_MODEL_CHECK_MEM(MDOC
     * ,LMAX_PAR,FM02,KX,KY,JLMAX,RHMAX,INDEX2,INDEXH2,INDEXK2
     * ,IND_MAX,JERR,IERR)
        IF(IERR.NE.0) THEN
          IERR=1
          IF(MTN.GT.0)   CLOSE(MTN)
          IF(MTIN1.GT.0) CLOSE(MTIN1)
          IF(MTIN2.GT.0) CLOSE(MTIN2)
          IF(MTIN3.GT.0) CLOSE(MTIN3)
          IF(MTIN4.GT.0) CLOSE(MTIN4)
          RETURN
        ENDIF
      ENDIF

c      WRITE(*,*) '--IND_MAX,IND_MAX1--:',IND_MAX,IND_MAX1

      IF(IND_MAX1.GT.IND_MAX) IND_MAX = IND_MAX1

      IF(MSG1.NE.'Y') THEN
        IALLOC  = 1
        IPRNCR = IND_MAX + 1000
        IT = 0
        allocate(POOLA(1:IPRNCR),STAT=ISTAT)
        IT = IT + ABS(ISTAT)
        allocate(POOLB(1:IPRNCR),STAT=ISTAT)
        IT = IT + ABS(ISTAT)
        IF(IT.GT.0) THEN
          IERR = 1
          CALL MSGERR(MDOC,
     *    ' ERROR: in  READER_TRP: problem with memory allocation')
          CALL MSGERR(MDOC,
     *    '                  try to change resolution')
          RETURN
        ENDIF
        CALL RDF_MODEL(MDOC,MTIN1,MTIN2,POOLA,POOLB,IPRNCR
     *  ,LMAX_PAR,FM01,KX,KY,JLMAX,RHMAX,INDEX1,INDEXH1,INDEXK1
     *  ,IND_MAX1,JERR1,IERR)
        IF(IERR.NE.0) THEN
          deallocate(POOLA,STAT=ISTAT)
          deallocate(POOLB,STAT=ISTAT)
          IERR=1
          IF(MTN.GT.0)   CLOSE(MTN)
          IF(MTIN1.GT.0) CLOSE(MTIN1)
          IF(MTIN2.GT.0) CLOSE(MTIN2)
          IF(MTIN3.GT.0) CLOSE(MTIN3)
          IF(MTIN4.GT.0) CLOSE(MTIN4)
          RETURN
        ENDIF
      ENDIF
      IF(MSG3.NE.'Y') THEN
        IPRNCR = IND_MAX + 1000
        IALLOC1  = 1
        IT = 0
        allocate(POOLA1(1:IPRNCR),STAT=ISTAT)
        IT = IT + ABS(ISTAT)
        allocate(POOLB1(1:IPRNCR),STAT=ISTAT)
        IT = IT + ABS(ISTAT)
        IF(IT.GT.0) THEN
          deallocate(POOLA,STAT=ISTAT)
          deallocate(POOLB,STAT=ISTAT)
          IERR = 1
          CALL MSGERR(MDOC,
     *    ' ERROR: in  READER_TRP: problem with memory allocation')
          CALL MSGERR(MDOC,
     *    '                  try to change resolution')
          RETURN
        ENDIF
        CALL RDF_MODEL(MDOC,MTIN3,MTIN4,POOLA1,POOLB1,IPRNCR
     *  ,LMAX_PAR,FM02,KX,KY,JLMAX,RHMAX,INDEX2,INDEXH2,INDEXK2
     *  ,IND_MAX,JERR,IERR)
        IF(IERR.NE.0) THEN
          deallocate(POOLA,STAT=ISTAT)
          deallocate(POOLB,STAT=ISTAT)
          deallocate(POOLA1,STAT=ISTAT)
          deallocate(POOLB1,STAT=ISTAT)
          IERR=1
          IF(MTN.GT.0)   CLOSE(MTN)
          IF(MTIN1.GT.0) CLOSE(MTIN1)
          IF(MTIN2.GT.0) CLOSE(MTIN2)
          IF(MTIN3.GT.0) CLOSE(MTIN3)
          IF(MTIN4.GT.0) CLOSE(MTIN4)
          RETURN
        ENDIF
      ENDIF

      IF(JERR .NE.0) JERR = 2
      IF(JERR1.NE.0) JERR = JERR + 1
      IF(IND_MAX1.GT.IND_MAX) IND_MAX = IND_MAX1

C ------

      IHN    =  0
      IKN    =  0
      ILN    = -1
      NR     =  0
      IFRST  =  1
      ILNOLD = -1
C================================================================
C      nnn = 0
C      nn  = 0
C      n1 = 0
C      n2 = 0

      DO     ILP =0,JLMAX
      DO     IKP =-JKMAX,JKMAX
      DO     IHP =-JHMAX,JHMAX
        IF(IHP.EQ.0.AND.IKP.EQ.0.AND.ILP.EQ.0) GO TO 300
        IIHP=IHP
        IIKP=IKP
        IILP=ILP
        CALL ANOMSC(IIHP,IIKP,IILP,IANOM,JJSYM,NSYM,ISYM)

c         WRITE(*,'('' -- IHP,IIHP,IA,JS:'',8I6)')
c     *   IHP,IKP,ILP,IIHP,IIKP,IILP,IANOM,JJSYM

        IF(IANOM.NE.1.OR.JJSYM.NE.1) GO TO 300
        CALL DSTAR(IHP,IKP,ILP,RSQ)
        RH = SQRT(RSQ)


        IF(IABS(IHP).GE.KXB2.OR.IABS(IKP).GE.KYB2) GO TO 300
        IF(RH.GT.RHMAX) GO TO 300

C        nnn = nnn + 1
C-----------------------------------------------------------------
C     indices h=(IHN,IKN,ILN) from asymmetrical part reciprocal space
C-----------------------------------------------------------------
C        ILNOLD = ILN
C        ILNOLD = ILP

        IF(RH.LT.RHMIN.OR.MODE.EQ.'P') THEN
          FAN   = 0.0
          FBN   = 0.0
          FDN   = 0.0
          FDN2  =-2.0
          FLH   = 0.0
          NUMBP = NUMBP+1
        ELSE
   60     IF(MTN.EQ.0)   GO TO 100
          IF(IENDN.GT.0) GO TO 100

c          IF(ILN-ILP) 50,10,40
c   10     IF(IKN-IKP) 50,20,40
c   20     IF(IHN-IHP) 50,30,40

          IF((ILN-ILP).LT.0) GO TO 50
          IF((ILN-ILP).EQ.0) GO TO 10
          IF((ILN-ILP).GT.0) GO TO 40

   10     IF((IKN-IKP).LT.0) GO TO 50
          IF((IKN-IKP).EQ.0) GO TO 20
          IF((IKN-IKP).GT.0) GO TO 40

   20     IF((IHN-IHP).LT.0) GO TO 50
          IF((IHN-IHP).EQ.0) GO TO 30
          IF((IHN-IHP).GT.0) GO TO 40

   50     CONTINUE
          FLH = 0.0
          IF(ITP.EQ.'F   ') THEN
            CALL RD(MTN,IHN,IKN,ILN,FAN,FBN,NUMBN,IENDN)
            IF(LH_LH.EQ.'Y'.OR.LH_LH.EQ.'V'.OR.
     *         LH_LH.EQ.'2'.OR.LH_LH.EQ.'T') THEN
              FDNAT = FAN
              FLH   = FBN
            ELSE
              IF(FAN.LT.1.E-30) FAN=FBN
              IF(FBN.LT.1.E-30) FBN=FAN
              FDNAT = (FAN+FBN)/2.
            ENDIF
          ELSE IF(ITP.EQ.'COEF') THEN
            CALL RD(MTN,IHN,IKN,ILN,FAN,FBN,NUMBN,IENDN)
            IF(MSGB.EQ.'N') THEN
              FDNAT = SQRT(FAN)
            ELSE
              FDNAT = FAN*FAN+FBN*FBN
              FDNAT = SQRT(FDNAT)
            ENDIF
          ELSE
            CALL RRD(MTN,IHN,IKN,ILN,FAN,FBN,SAD,SBD,NUMBN,IENDN)
            IF(FAN.LT.1.E-30) FAN=FBN
            IF(FBN.LT.1.E-30) FBN=FAN
            FDNAT = (FAN+FBN)/2.
          ENDIF
          IF(IENDN.GT.0) GO TO 100
          IF(IHN.EQ.0.AND.IKN.EQ.0.AND.ILN.EQ.0) THEN
            FOBS0 = FDNAT
            GO TO 60
          ENDIF
          FANAT  = FAN
          FBNAT  = FBN
          FDNAT2 = FDNAT*FDNAT
c
C          WRITE(*,'('' IHP,IIHP:'',6I6)')
C     *    IHP,IKP,ILP,IHN,IKN,ILN
c
          GO TO 60
   40     CONTINUE
          FAN   = 0.0
          FBN   = 0.0
          FDN   = 0.0
          FDN2  =-1.0
          NUMBM = NUMBM+1
          GO TO 35
   30     CONTINUE
          FAN   = FANAT
          FBN   = FBNAT
          FDN   = FDNAT
          FDN2  = FDNAT2
          NUMBO = NUMBO+1
   35     CONTINUE
        ENDIF

C        nn = nn + 1
C ----------------------------------------------------
        TEMP=1.0
        IF(MSG1.EQ.'Y') THEN
          IF(GAUSS.EQ.'Y') THEN
            RR1 = RAD1*2.0
            CALL GAUSS_TRP(RH,RR1,GGG)
            GGG = GGG*TEMP
          ELSE
            CALL GEE(RH,RAD1,GGG)
            GGG = GGG*TEMP
          ENDIF
        ENDIF
        IF(MSG3.EQ.'Y'.AND.MSG2.NE.'N') THEN
          IF(GAUSS.EQ.'Y') THEN
            RR2 = RAD2*2.0
            CALL GAUSS_TRP(RH,RR2,GGG2)
            GGG2 = GGG2*TEMP
          ELSE
            CALL GEE(RH,RAD2,GGG2)
            GGG2 = GGG2*TEMP
          ENDIF
        ENDIF


  200   CONTINUE
        IF(MODE.NE.'D') THEN
          FOBS2 = FDN2
          FOBSB = 0.0
        ELSE
          FOBS2 = FAN
          FOBSB = FBN
        ENDIF
        NGEN  = 0
        SMFM1 = 0.0
        SMFM1P= 0.0
        SMFM2 = 0.0
c
C       WRITE(*,'('' -- IHP,IIHP:'',4I6)')
C     * IHP,IKP,ILP,nsym
c
        DO     I=1,NSYM

          IHS=ISYM(1,1,I)*IHP+ISYM(1,2,I)*IKP+ISYM(1,3,I)*ILP
          IKS=ISYM(2,1,I)*IHP+ISYM(2,2,I)*IKP+ISYM(2,3,I)*ILP
          ILS=ISYM(3,1,I)*IHP+ISYM(3,2,I)*IKP+ISYM(3,3,I)*ILP
C
C         h = (IHN,IKN,ILN), Fobs(h)=FOBS2,FOBSB
C         JHS,JKS,JLS = h[Aj]
C
          JHS(I)  = IHS
          JKS(I)  = IKS
          JLS(I)  = ILS
          IGSYM(I)= I
          ISS     = 1
          CALL ASYM(ISS,IHS,IKS,ILS,JSS,JHH,JKK,JLL)
          IF(NGEN.GT.0) THEN
            DO     J=1,NGEN
              IF(JHH.EQ.IHT(J).AND.JKK.EQ.IKT(J).AND.
     *          JLL.EQ.ILT(J)) THEN
                IGSYM(I)=0
                GO TO 2000
              ENDIF
            ENDDO
          ENDIF
          NGEN      = NGEN+1
          IHT(NGEN) = JHH
          IKT(NGEN) = JKK
          ILT(NGEN) = JLL
          IF(JSS.LT.0) IGSYM(I)=-I
 2000     CONTINUE

C------------------------------------------------------------------
C  calculate   Fmod(h[Aj])*EXP(2*PI*h*Dj)
C-------------------------------------------------------------------

          IF(IABS(JKK).GE.KYB2) GO TO 300
          IF(IABS(JHH).GE.KXB2) GO TO 300

C          IHHS=JHH
C          IKKS=JKK
C          IF(IKKS.LT.0) IKKS=IKKS+KY
C          IKKS=IKKS*KX
C          IF(IHHS.LT.0) IHHS=IHHS+KX
C          IND =IKKS+IHHS+1
C          INDD=JLL*KXY+IND

          IF(MSG1.EQ.'Y') THEN
            FAWW = GGG
            FBWW = 0.0
          ELSE
            ITK = INDEXK1(JLL+1)/2
            ITH = INDEXH1(JLL+1)/2

            IF(IABS(JKK).GE.ITK) GO TO 300
            IF(IABS(JHH).GE.ITH) GO TO 300

            IKKS = JKK
            IF(IKKS.LT.0) IKKS = IKKS+INDEXK1(JLL+1)
            IKKS = IKKS*INDEXH1(JLL+1)
            IHHS = JHH
            IF(IHHS.LT.0) IHHS=IHHS+INDEXH1(JLL+1)
            IND  = IKKS+IHHS+1
            INDD = INDEX1(JLL+1)+IND
            IF(JERR.EQ.0) THEN
              FAWW = POOLA(INDD)
              FBWW = POOLB(INDD)
            ELSE
              FAWW = 1.0
              FBWW = 0.0
            ENDIF

            IF(FAWW.EQ.0.0.AND.FBWW.EQ.0.0) GO TO 300

          ENDIF


          IF(JSS.LT.0) FBWW=-FBWW
          FAW  = FAWW
          FBW  = FBWW

          IARG = IHP*ISYM(4,1,I)+IKP*ISYM(4,2,I)+ILP*ISYM(4,3,I)
          DARG = IARG*TWOPI/24.
          COSD = DCOS(DARG)
          SIND = DSIN(DARG)
          FA   = FAW*COSD-FBW*SIND
          FB   = FAW*SIND+FBW*COSD
C
C         SFA,SFB : G1j(h) = Fm1(h[Aj])*EXP[2PIi*h*Dj]
C
          SFA(I) = FA
          SFB(I) = FB
          SMFM1  = SMFM1 + FA*FA+FB*FB
          IF(IGSYM(I).NE.0) THEN
            SMFM1P = SMFM1P + FA*FA+FB*FB
          ENDIF

          IF(MSG2.NE.'N') THEN

            IF(MSG3.EQ.'Y') THEN
              FAWW = GGG2
              FBWW = 0.0
            ELSE
              ITK = INDEXK2(JLL+1)/2
              ITH = INDEXH2(JLL+1)/2
              IF(IABS(JKK).GE.ITK) GO TO 300
              IF(IABS(JHH).GE.ITH) GO TO 300
              IKKS = JKK
              IF(IKKS.LT.0) IKKS = IKKS+INDEXK2(JLL+1)
              IKKS = IKKS*INDEXH2(JLL+1)
              IHHS = JHH
              IF(IHHS.LT.0) IHHS=IHHS+INDEXH2(JLL+1)
              IND  = IKKS+IHHS+1
              INDD = INDEX2(JLL+1)+IND
              IF(JERR.EQ.0) THEN
                FAWW = POOLA1(INDD)
                FBWW = POOLB1(INDD)
              ELSE
                FAWW = 1.0
                FBWW = 0.0
              ENDIF
              IF(FAWW.EQ.0.0.AND.FBWW.EQ.0.0) GO TO 300
            ENDIF
            IF(JSS.LT.0) FBWW=-FBWW
C           ARG   = JHH*SH2(1)+JKK*SH2(2)+JLL*SH2(3)
            ARG   = IHS*SH2(1)+IKS*SH2(2)+ILS*SH2(3)
            DARG  = ARG*TWOPI
            COSDD = DCOS(DARG)
            SINDD = DSIN(DARG)
            FAW   = FAWW*COSDD-FBWW*SINDD
            FBW   = FAWW*SINDD+FBWW*COSDD
            IF(MSG2.EQ.'2') THEN
              ARG   = IHS*SH(1)+IKS*SH(2)+ILS*SH(3)
              DARG  = ARG*TWOPI
              COSDD = DCOS(DARG)
              SINDD = DSIN(DARG)
              FAW2  = FAWW*COSDD-FBWW*SINDD
              FBW2  = FAWW*SINDD+FBWW*COSDD
              FAW   = FAW + FAW2
              FBW   = FBW + FBW2
            ENDIF
            IF(NADDM.GT.0) THEN
              FA_ADD = 0.0
              FB_ADD = 0.0
              DO IA=1,NADDM
                ARG    = IHS*SH3(1,IA)+IKS*SH3(2,IA)+ILS*SH3(3,IA)
                DARG   = ARG*TWOPI
                COSDD  = DCOS(DARG)
                SINDD  = DSIN(DARG)
                FA_ADD = FA_ADD+FAWW*COSDD-FBWW*SINDD
                FB_ADD = FB_ADD+FAWW*SINDD+FBWW*COSDD
              ENDDO
              FAW  = FAW + FA_ADD
              FBW  = FBW + FB_ADD
            ENDIF      
            IARG  = IHP*ISYM(4,1,I)+IKP*ISYM(4,2,I)+ILP*ISYM(4,3,I)
            DARG  = IARG*TWOPI/24.
            COSD  = DCOS(DARG)
            SIND  = DSIN(DARG)
            FA    = FAW*COSD-FBW*SIND
            FB    = FAW*SIND+FBW*COSD
            SMFM2 = SMFM2+FA*FA+FB*FB
C
C           SFA2,SFB2 : G2j(h) = Fm2(h[Aj])*EXP[2PIi*h*Dj]
C
            SFA2(I) = FA
            SFB2(I) = FB

          ENDIF
c
c         WRITE(*,'('' '',7I4,2F10.2,2g16.4)')
c     *   I,IHS,IKS,ILS,JSS,IGSYM(I),NGEN,FA,FB,COSD,SIND
c
  800     CONTINUE
        ENDDO
C --
C       h = (IHN,IKN,ILN), Fobs(h)=FOBS2,FOBSB
C       JHS,JKS,JLS = h[Aj]
C       SFA,SFB   : G1j(h) = Fm1(h[Aj])*EXP[2PIi*h*Dj]
C       SFA2,SFB2 : G2j(h) = Fm2(h[Aj])*EXP[2PIi*h*Dj]
C
C ------------------
        NUMB = NUMB+1

C       nn1 = nn1 + 3 + NSYM*6
C       nn2 = nn2 + 3 + NSYM*8

        IF(MSG2.NE.'N') THEN
          MTEST = IND_SCR + 3 + NSYM*8 + 1
        ELSE
          MTEST = IND_SCR + 3 + NSYM*6 + 1
        ENDIF
        IF(KERR.EQ.0) THEN 
          IF(MTEST.GT.MEMORY_SCR) THEN
            IF(IALLOC.GT.0) THEN
              deallocate(POOLA,STAT=ISTAT)
              deallocate(POOLB,STAT=ISTAT)
            ENDIF
            IF(IALLOC1.GT.0) THEN
              deallocate(POOLA1,STAT=ISTAT)
              deallocate(POOLB1,STAT=ISTAT)
            ENDIF

            KERR = 1
          ENDIF
        ENDIF

        IF(KERR.EQ.0) THEN 

          IF(MSG2.NE.'N') THEN

C          WRITE(MTS)
C     *    RSQ,FOBS2,FOBSB,(JHS(L),JKS(L),JLS(L)
C     *    ,IGSYM(L),SFA(L),SFB(L),SFA2(L),SFB2(L),L=1,NSYM)

C           POOL_SCR(IND_SCR + 1) = RSQ
            POOL_SCR(IND_SCR + 1) = FLH
            IND_SCR = IND_SCR + 1
            POOL_SCR(IND_SCR + 1) = FOBS2
            IND_SCR = IND_SCR + 1
            POOL_SCR(IND_SCR + 1) = FOBSB
            IND_SCR = IND_SCR + 1
            DO L=1,NSYM
              POOL_SCR(IND_SCR + 1) = JHS(L)   + 1000.1 
              IND_SCR = IND_SCR + 1
              POOL_SCR(IND_SCR + 1) = JKS(L)   + 1000.1  
              IND_SCR = IND_SCR + 1
              POOL_SCR(IND_SCR + 1) = JLS(L)   + 1000.1 
              IND_SCR = IND_SCR + 1
              POOL_SCR(IND_SCR + 1) = IGSYM(L) + 1000.1 
              IND_SCR = IND_SCR + 1
              POOL_SCR(IND_SCR + 1) = SFA(L)
              IND_SCR = IND_SCR + 1
              POOL_SCR(IND_SCR + 1) = SFB(L) 
              IND_SCR = IND_SCR + 1
              POOL_SCR(IND_SCR + 1) = SFA2(L)
              IND_SCR = IND_SCR + 1
              POOL_SCR(IND_SCR + 1) = SFB2(L)
              IND_SCR = IND_SCR + 1
            ENDDO
          ELSE

C          WRITE(MTS)
C     *    RSQ,FOBS2,FOBSB,(JHS(L),JKS(L),JLS(L)
C     *    ,IGSYM(L),SFA(L),SFB(L),L=1,NSYM)

C           POOL_SCR(IND_SCR + 1) = RSQ
            POOL_SCR(IND_SCR + 1) = FLH
            IND_SCR = IND_SCR + 1
            POOL_SCR(IND_SCR + 1) = FOBS2
            IND_SCR = IND_SCR + 1
            POOL_SCR(IND_SCR + 1) = FOBSB
            IND_SCR = IND_SCR + 1
            DO L=1,NSYM
              POOL_SCR(IND_SCR + 1) = JHS(L)   + 1000.1 
              IND_SCR = IND_SCR + 1
              POOL_SCR(IND_SCR + 1) = JKS(L)   + 1000.1 
              IND_SCR = IND_SCR + 1
              POOL_SCR(IND_SCR + 1) = JLS(L)   + 1000.1 
              IND_SCR = IND_SCR + 1
              POOL_SCR(IND_SCR + 1) = IGSYM(L) + 1000.1 
              IND_SCR = IND_SCR + 1
              POOL_SCR(IND_SCR + 1) = SFA(L)
              IND_SCR = IND_SCR + 1
              POOL_SCR(IND_SCR + 1) = SFB(L) 
              IND_SCR = IND_SCR + 1
            ENDDO

          ENDIF
        ELSE
          IF(MSG2.NE.'N') THEN
            IND_SCR = IND_SCR + NSYM*8 + 3
          ELSE
            IND_SCR = IND_SCR + NSYM*6 + 3
          ENDIF
        ENDIF
C -------------------
        IF(FOBS2.GE.0.0) THEN
          SFOBS2 = SFOBS2+FDN*FDN
          IF(NGEN.GT.0) THEN
            SUMFM1 = SUMFM1+SMFM1/NGEN
            SUMFM2 = SUMFM2+SMFM2/NGEN
          ENDIF
          SFMOD2 = SFMOD2+SMFM1
        ENDIF
        SFMODP = SFMODP+SMFM1P
 300    CONTINUE
      ENDDO
      ENDDO
      ENDDO

C-----------------------------------------------------------------
 100  CONTINUE

C      write(*,*) 'ind_scr:',ind_scr,MEMORY_SCR
C      write(*,*) '--nnn,nn:',nnn,nn
C      write(*,*) '--nn1,nn2:',nn1,nn2
C      write(*,*) '>>>>>>>>>>>'

      IF(MSG1.NE.'Y') THEN
        CLOSE(MTIN1)
        CLOSE(MTIN2)
      ENDIF
      IF(MSG2.NE.'N') THEN
        IF(MSG3.NE.'Y') THEN
          CLOSE(MTIN3)
          CLOSE(MTIN4)
        ENDIF
      ENDIF
      IF(MTN.GT.0) CLOSE(MTN)
C ---
      IF(KERR.EQ.0) POOL_SCR(IND_SCR + 1) = -1.0
      IND_SCR               = IND_SCR + 1
C ---     
      SCALE2 = 0.0
      IF(MSG2.EQ.'Y') SCALE2 = 1.0
      IF(MSG2.EQ.'2') SCALE2 = 0.5
      SCALE1 = 1.0
      IF(NUMBO.GT.0) THEN
        SFOBS2 = SFOBS2/NUMBO
        SUMFM1 = SUMFM1/NUMBO
        SUMFM2 = SUMFM2/NUMBO
        IF(SUMFM1.GT.0.00000001) SCALE1 = SQRT(ABS(SFOBS2/SUMFM1))
        IF(MSG2.NE.'N'.AND.SUMFM2.GT.0.00000001) 
     *  SCALE2 = SQRT(ABS(SFOBS2/SUMFM2))
      ENDIF

      WRITE(LINE,'('' SCALE1,SCALE2:'',2G12.4)') SCALE1,SCALE2
      CALL MSGDOC(MD,LINE)
      WRITE(LINE,'('' SFO,SFM1,SFM2:'',3G12.4)') SFOBS2,SUMFM1,SUMFM2
      CALL MSGDOC(MD,LINE)
      WRITE(LINE,'('' NOBS,NPACK,NMISS:'',3I8)') NUMBO,NUMBP,NUMBM
      CALL MSGDOC(MD,LINE)
      WRITE(LINE,'('' SFMOD2,SFMODP:'',2G12.4)') SFMOD2,SFMODP
      CALL MSGDOC(MD,LINE)

C ------------------------------------------------------------
      FOBS_000  = FOBS0
      FMOD1_000 = FM01
      FMOD2_000 = FM02

      WRITE(LINE,'('' F(000),FM01,FM02 : '',3G12.4)') FOBS0,FM01,FM02
      CALL MSGDOC(MD,LINE)
      IF(IALLOC.GT.0) THEN
        deallocate(POOLA,STAT=ISTAT)
        deallocate(POOLB,STAT=ISTAT)
      ENDIF
      IF(IALLOC1.GT.0) THEN
        deallocate(POOLA1,STAT=ISTAT)
        deallocate(POOLB1,STAT=ISTAT)
      ENDIF
      IF(NUMB.GT.0) THEN
        WRITE(LINE,210) NUMB
  210   FORMAT('  NUMBER OF REFLS :',I8)
        CALL MSGDOC(MD,LINE)
      ELSE
        IERR=1
        CALL MSGDOC(MDOC,' ERROR: trpack: number of reflections = 0')
      ENDIF
      RETURN
      END

      SUBROUTINE CALC_NREF_FOR_RESMAX_SCR(RESMAX,RLATT,NSYM,ISYM,NTOT)
C -------------
      REAL   RESMAX,RLATT(6)
      INTEGER*2 ISYM(5,3,NSYM)
C ------------- 
      CALL LIMHKL(RESMAX,JHMAX,JKMAX,JLMAX,KXMIN,KYMIN,KZMIN)
      RHMAX = 1./RESMAX
      M = 99
      CALL ANOMF(M,NSYM,ISYM)
      CALL DSTARF(RLATT,AST,BST,CST,COALST,COBEST,COGAST,VOL)

C      write(*,*) '==========='
C      write(*,*) resmax,nsym
C      write(*,*) (rlatt(i),i=1,6)
C      write(*,*) '>>',jhmax,jkmax,jlmax

      NTOT  = 0
c      n     = 0
c      n1    = 0
c      n2    = 0

      DO     ILP =0,JLMAX
      DO     IKP =-JKMAX,JKMAX
      DO     IHP =-JHMAX,JHMAX
        IF(IHP.EQ.0.AND.IKP.EQ.0.AND.ILP.EQ.0) GO TO 100
        IIHP=IHP
        IIKP=IKP
        IILP=ILP
        CALL ANOMSC(IIHP,IIKP,IILP,IANOM,JJSYM,NSYM,ISYM)
        IF(IANOM.NE.1.OR.JJSYM.NE.1) GO TO 100
        CALL DSTAR(IHP,IKP,ILP,RSQ)
        RH = SQRT(RSQ)
        IF(RH.LE.RHMAX) THEN
C          n = n + 1
c          n1 = n1 + 3 + NSYM*6
c          n2 = n2 + 3 + NSYM*8
          NTOT = NTOT + NSYM
        ENDIF
  100   CONTINUE
      ENDDO
      ENDDO
      ENDDO

c      write(*,*) '--ntot,n:',ntot,n
c      write(*,*) '--n1,n2:',n1,n2
c      write(*,*) '==========='

      RETURN
      END

      SUBROUTINE RDF_MODEL(MDOC,MTIN1,MTIN2,POOLA,POOLB,IPRNCR
     * ,LMAX_PAR,FM01,NX,NY,LMAX,RHMAX,INDEX1,INDEXH1,INDEXK1
     * ,IND_MAX,IMEM,IERR)
C ----------------------------------------------------
      REAL    POOLA(*),POOLB(*)
      INTEGER MDOC,MTIN1,MTIN2,NX,NY,LMAX,IERR
      REAL    FM01,RHMAX
      CHARACTER LINE*80
      INTEGER INDEX1(*),INDEXH1(*),INDEXK1(*)
C ----------------------------------------------------
      IERR = 0
      IMEM = 0
      NXY  = NX*NY
      LMAX1= LMAX+1
      NX1  = NX+1
      NX2  = NX+2
      NXB2 = NX/2
      NYB2 = NY/2
C --
      JH    = 0
      JK    = 0
      JL    = -1
      NUMB1 = 0
      NUMB2 = 0
      FM01  = 0.0
      IEND2 = -1
      IEND1 = -1
      ILOLD = -1

      IHMAX = 0
      IKMAX = 0

      INDEX1 (1) = 0
      INDEXH1(1) = NX
      INDEXK1(1) = NY

      INDEX1 (2) = 0
      INDEXH1(2) = NX
      INDEXK1(2) = NY
        
      IF(IPRNCR.GT.0) THEN
        DO I=1,IPRNCR
          POOLA(I) = 0.0
          POOLB(I) = 0.0
        ENDDO
      ENDIF
      IND_MAX    = 0
C --------------------------------------
 100  CONTINUE

      IF(IEND1.GT.0.OR.IEND2.GT.0)  GO TO 220

      CALL RD1(MTIN1,IH,IK,IL,FA1,FB1,NUMB1,IEND1)
      IF(MTIN1.LE.0) THEN
        CALL MSGERR(MDOC,' ERROR: trpack: read input file F_model')
        IERR=1
        RETURN
      ENDIF

      IF(IEND1.GT.0.OR.IEND2.GT.0)  GO TO 220
      IF(IH.EQ.0.AND.IK.EQ.0.AND.IL.EQ.0) THEN
        FM01 = FA1
        GO TO 100
      ENDIF
C ---
      CALL DSTAR(IH,IK,IL,RSQ)
      RH = SQRT(RSQ)
      IF(IABS(IH).GE.NXB2.OR.IABS(IK).GE.NYB2.OR.IABS(IL).GT.LMAX) 
     *  GO TO 100
      IF(RH.GT.RHMAX) GO TO 100
      IF(IL.GT.LMAX_PAR) THEN
        WRITE(LINE,'('' ERROR: trpack: L index > '',I8)')
     *  LMAX_PAR
        CALL MSGERR(MDOC,LINE)
        IERR=1
        RETURN
      ENDIF
      IF(IL.NE.ILOLD) THEN
        IF(IL.GT.0) THEN
          INDEX1 (IL+1) = INDEX1(IL)+(IHMAX*2+1)*(IKMAX*2+1)
          INDEXH1(IL+1) = IHMAX*2+1
          INDEXK1(IL+1) = IKMAX*2+1

          INDEX1 (IL+2) = INDEX1 (IL+1) 
          INDEXH1(IL+2) = INDEXH1(IL+1) 
          INDEXK1(IL+2) = INDEXK1(IL+1) 

        ENDIF
        IHMAX = 0
        IKMAX = 0
        ILOLD = IL
      ENDIF
C ---      
C --------------
c  550 IF(JL-IL)  560, 510,100
c  510 IF(JK-IK)  560, 520,100
c  520 IF(JH-IH)  560, 540,100

  550 IF((JL-IL).LT.0) GO TO  560
      IF((JL-IL).EQ.0) GO TO  510
      IF((JL-IL).GT.0) GO TO  100
  510 IF((JK-IK).LT.0) GO TO  560
      IF((JK-IK).EQ.0) GO TO  520
      IF((JK-IK).GT.0) GO TO  100
  520 IF((JH-IH).LT.0) GO TO  560
      IF((JH-IH).EQ.0) GO TO  540
      IF((JH-IH).GT.0) GO TO  100

  560 CALL RD2(MTIN2,JH,JK,JL,FA2,FB2,NUMB2,IEND2)
      IF(MTIN2.LE.0) THEN
        CALL MSGERR(MDOC,' ERROR: trpack: read input file PH_model')
        IERR=1
        RETURN
      ENDIF
      IF(IEND1.GT.0.OR.IEND2.GT.0) GO TO 220
      GO TO  550
  540 CONTINUE
C -----
      IF(ABS(IH).GT.IHMAX) IHMAX=ABS(IH)
      IF(ABS(IK).GT.IKMAX) IKMAX=ABS(IK)

      IKK  = IK
      IF(IKK.LT.0) IKK = IKK+INDEXK1(IL+1)
      IKK  = IKK*INDEXH1(IL+1)
      IHH  = IH
      IF(IHH.LT.0) IHH=IHH+INDEXH1(IL+1)
      IND  = IKK+IHH+1
      INDD = INDEX1(IL+1)+IND

      IF(INDD.GT.IPRNCR) THEN
        IMEM = 1
      ENDIF

      IF(INDD.GT.IND_MAX) IND_MAX=INDD

      IF(IMEM.EQ.0) THEN
        POOLA(INDD) = FA1*FA2
        POOLB(INDD) = FA1*FB2
      ENDIF

      GO TO 100
C -----
 220  CONTINUE

      RETURN
      END

      SUBROUTINE RDF_MODEL_CHECK_MEM(MDOC
     * ,LMAX_PAR,FM01,NX,NY,LMAX,RHMAX,INDEX1,INDEXH1,INDEXK1
     * ,IND_MAX,IMEM,IERR)
C ----------------------------------------------------
      INTEGER MDOC,NX,NY,LMAX,IERR
      REAL    FM01,RHMAX
      CHARACTER LINE*80
      INTEGER INDEX1(*),INDEXH1(*),INDEXK1(*)
C ----------------------------------------------------
      IERR = 0
      IMEM = 0
      NXY  = NX*NY
      LMAX1= LMAX+1
      NX1  = NX+1
      NX2  = NX+2
      NXB2 = NX/2
      NYB2 = NY/2
C --
      JH    = 0
      JK    = 0
      JL    = -1
      NUMB1 = 0
      NUMB2 = 0
      FM01  = 0.0
      IEND2 = -1
      IEND1 = -1
      ILOLD = -1

      IHMAX = 0
      IKMAX = 0

      INDEX1 (1) = 0
      INDEXH1(1) = NX
      INDEXK1(1) = NY

      INDEX1 (2) = 0
      INDEXH1(2) = NX
      INDEXK1(2) = NY
        
      IND_MAX    = 0
C --------------------------------------
      RESMAX = 1./RHMAX
      CALL LIMHKL(RESMAX,JHMAX,JKMAX,JLMAX,KXMIN,KYMIN,KZMIN)

      DO     IL =0,JLMAX
      DO     IK =-JKMAX,JKMAX
      DO     IH =-JHMAX,JHMAX
        CALL DSTAR(IH,IK,IL,RSQ)
        RH = SQRT(RSQ)
        IF(IABS(IH).GE.NXB2.OR.IABS(IK).GE.NYB2.OR.IABS(IL).GT.LMAX) 
     *    GO TO 100
        IF(RH.GT.RHMAX) GO TO 100

        IF(IL.GT.LMAX_PAR) THEN
          WRITE(LINE,'('' ERROR: trpack: L index > '',I8)')
     *    LMAX_PAR
          CALL MSGERR(MDOC,LINE)
          IERR=1
          RETURN
        ENDIF
        IF(IL.NE.ILOLD) THEN
          IF(IL.GT.0) THEN
            INDEX1 (IL+1) = INDEX1(IL)+(IHMAX*2+1)*(IKMAX*2+1)
            INDEXH1(IL+1) = IHMAX*2+1
            INDEXK1(IL+1) = IKMAX*2+1
            INDEX1 (IL+2) = INDEX1 (IL+1) 
            INDEXH1(IL+2) = INDEXH1(IL+1) 
            INDEXK1(IL+2) = INDEXK1(IL+1) 
          ENDIF
          IHMAX = 0
          IKMAX = 0
          ILOLD = IL
        ENDIF

        IF(ABS(IH).GT.IHMAX) IHMAX=ABS(IH)
        IF(ABS(IK).GT.IKMAX) IKMAX=ABS(IK)

        IKK  = IK
        IF(IKK.LT.0) IKK = IKK+INDEXK1(IL+1)
        IKK  = IKK*INDEXH1(IL+1)
        IHH  = IH
        IF(IHH.LT.0) IHH=IHH+INDEXH1(IL+1)
        IND  = IKK+IHH+1
        INDD = INDEX1(IL+1)+IND


        IF(INDD.GT.IND_MAX) IND_MAX=INDD

 100    CONTINUE

      ENDDO
      ENDDO
      ENDDO

      RETURN
      END

      SUBROUTINE SPGRP(MDOC,NSYM,ISYM,INDIJ,IPRSYM,IERR)
C --------------------------------
C
C      IJ=INDIJ(I,J) : [AIJ] = [AI][AJ]
C                       DIJ  = [AI] DJ + DI
C --------------------------------
CMS     : INDIJ
      INTEGER   MDOC,IERR
      INTEGER   NSYM,IPRSYM
      INTEGER*2 ISYM(5,3,IPRSYM),INDIJ(IPRSYM,IPRSYM)
C ---
      CHARACTER LINE*80
C --------------------------------------------
      INTEGER*2 IAM(3,3),IVECT(3)
C ---------------------------------------------
      IERR=0
      DO     I=1,NSYM
        DO     J=1,3
          IS         =(24*ISYM(4,J,I))/ISYM(5,J,I)
  100     CONTINUE
          IF(IS.LT.0) THEN
            IS=IS+24
            GO TO 100
          ENDIF
          ISYM(4,J,I)=MOD(IS,24)
        ENDDO
c
C       WRITE(*,'('' ---'',I3,'' ---'')') I
C       WRITE(*,'(1X,3I4,2X,I4)') ISYM(1,1,I),ISYM(2,1,I),ISYM(3,1,I)
C    *                           ,ISYM(4,1,I)
C       WRITE(*,'(1X,3I4,2X,I4)') ISYM(1,2,I),ISYM(2,2,I),ISYM(3,2,I)
C    *                           ,ISYM(4,2,I)
C       WRITE(*,'(1X,3I4,2X,I4)') ISYM(1,3,I),ISYM(2,3,I),ISYM(3,3,I)
C    *                           ,ISYM(4,3,I)
c
      ENDDO
      DO     I=1,NSYM
        DO     J=1,NSYM
C ----
          DO     II=1,3
            DO     JJ=1,3
              IS=0
              DO     K=1,3
                IS=IS+ISYM(K,II,I)*ISYM(JJ,K,J)
              ENDDO
              IAM(JJ,II)=IS
            ENDDO
          ENDDO
          DO     II=1,3
            IS=0
            DO     K=1,3
              IS=IS+ISYM(K,II,I)*ISYM(4,K,J)
            ENDDO
            IS=IS+ISYM(4,II,I)
 3030       CONTINUE
            IF(IS.LT.0) THEN
              IS=IS+24
              GO TO 3030
            ENDIF
            IVECT(II)=MOD(IS,24)
          ENDDO
c
C       WRITE(*,'('' ----- '',2I3,'' ------'')') I,J
C       WRITE(*,'(1X,3I4,2X,I4)') IAM(1,1),IAM(2,1),IAM(3,1)
C    *                           ,IVECT(1)
C       WRITE(*,'(1X,3I4,2X,I4)') IAM(1,2),IAM(2,2),IAM(3,2)
C    *                           ,IVECT(2)
C       WRITE(*,'(1X,3I4,2X,I4)') IAM(1,3),IAM(2,3),IAM(3,3)
C    *                           ,IVECT(3)
C
          DO     II=1,NSYM
            JJJ=II
            DO     JJ=1,3
              DO     K=1,3
                IF(IAM(JJ,K).NE.ISYM(JJ,K,II)) GO TO 3000
              ENDDO
            ENDDO
            DO     K=1,3
              IF(IVECT(K).NE.ISYM(4,K,JJJ)) GO TO 3000
            ENDDO
            INDIJ(I,J)=JJJ
            GO TO 3010
 3000       CONTINUE
          ENDDO
          IERR=1
          CALL MSGERR(MDOC,' ERR: IN SP.GR.SYMMETRY-OPERATORS')
          WRITE(LINE,'(''     No :'',2I5)') I,J
          CALL MSGERR(MDOC,LINE)

          DO K=1,NSYM 

      WRITE(LINE,'('' ---'',I3,'' ---'')') K
      CALL MSGERR(MDOC,LINE)
      WRITE(LINE,'(1X,3I4,3X,I4)') ISYM(1,1,K),ISYM(2,1,K),ISYM(3,1,K)
     *                          ,ISYM(4,1,K)
      CALL MSGERR(MDOC,LINE)
      WRITE(LINE,'(1X,3I4,3X,I4)') ISYM(1,2,K),ISYM(2,2,K),ISYM(3,2,K)
     *                          ,ISYM(4,2,K)
      CALL MSGERR(MDOC,LINE)
      WRITE(LINE,'(1X,3I4,3X,I4)') ISYM(1,3,K),ISYM(2,3,K),ISYM(3,3,K)
     *                          ,ISYM(4,3,K)
      CALL MSGERR(MDOC,LINE)
          ENDDO


      WRITE(LINE,'('' ----- '',I3,'' X '',I3,'' ------'')') I,J
      CALL MSGERR(MDOC,LINE)
      WRITE(LINE,'(1X,3I4,3X,I4)') IAM(1,1),IAM(2,1),IAM(3,1)
     *                          ,IVECT(1)
      CALL MSGERR(MDOC,LINE)
      WRITE(LINE,'(1X,3I4,3X,I4)') IAM(1,2),IAM(2,2),IAM(3,2)
     *                          ,IVECT(2)
      CALL MSGERR(MDOC,LINE)
      WRITE(LINE,'(1X,3I4,3X,I4)') IAM(1,3),IAM(2,3),IAM(3,3)
     *                          ,IVECT(3)
      CALL MSGERR(MDOC,LINE)

          RETURN
 3010     CONTINUE
C ----
        ENDDO
      ENDDO
      DO     I=1,NSYM
      DO     J=1,NSYM
        DO     L=1,3
          DO     K=1,3
            IF(ISYM(L,K,I).NE.ISYM(L,K,J)) GO TO 3020
          ENDDO
        ENDDO
        INDIJ(I,J) =-INDIJ(I,J)
 3020   CONTINUE
      ENDDO
      ENDDO

      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERROR: trpack: small array INDIJ(nsym,nsym)')
        IERR=1
      ENDIF

      RETURN
      END
 

      SUBROUTINE WRITER_TRP(MDOC,MSGG,IMOD,FAW,NUMB,MJ,MK,FAS,FBS
     *                 ,FA_CF,FB_CF,IH_CF,IK_CF,IL_CF,IEND_CF,IPRCF
     *                 ,IPACK,FAPACK,FBPACK,IPRMEM,IERR)
C ------------------------------------
      INTEGER   MDOC,IMOD,NUMB,MJ,MK,IERR
      REAL      FAS,FBS
      REAL*8    FAW
      CHARACTER MSGG*1
C ---
      REAL      FA_CF(IPRCF),FB_CF(IPRCF)
      INTEGER*2 IH_CF(IPRCF),IK_CF(IPRCF),IL_CF(IPRCF),IEND_CF(IPRCF)
C
      INTEGER IPACK(IPRMEM)
      REAL    FAPACK(IPRMEM),FBPACK(IPRMEM)
      COMMON/COM_TRP_WRT/ IEND,NUMB1,IFIRST
C ----------------------------------
C ---
      COMMON/CMPAR/ TWOPI,RAD1,RAD2,COEF,BTMP,RHMIN,RHMAX,FMIN,SCALE
     *             ,IPRINT,INVERS,ISELF
     *             ,MTN,MTIN1,MTIN2,MTIN3,MTIN4,MTOUT
     *             ,IHMAX,IKMAX,LMAX,NX,NY,NZ,IZMIN,IZMAX
     *             ,VOL,PERC1,PERC2,IOP1,IOP2
     *             ,SCALE1,SCALE2,BETMIN,BETMAX,RESMIN,RESMAX
     *     ,MSG,MSG1,MSGB,MSG2,MSG3,MOD2,FUNC,REMOV,INVER,ACCUM,GAUSS
      REAL*8 TWOPI
      CHARACTER LINE*80,MSG*1,MSG1*1,MSGB*1,MSG2*1,MSG3*1
      CHARACTER MOD2*1,FUNC*1,REMOV*1,INVER*1,ACCUM*1,GAUSS*1
      EXTERNAL  PACK,UNPACK
C --------------------------------------------------
      IERR = 0
      IF(IFIRST.EQ.0) THEN
        IFIRST = 1
        IEND   =-1
        NUMB1  = 0 
      ENDIF
      IF(NUMB.GT.0.AND.IMOD.EQ.1) THEN
        NUMB1    = NUMB1 + 1
        IF(NUMB1.GT.IPRCF) THEN
C          WRITE(LINE,'(A)')
C     *    ' ERROR: trpack: not memory enough for scratch_CF file: '
C          CALL MSGERR(MDOC,LINE)
          IERR=1
C          RETURN
        ENDIF
        IF(IERR.EQ.0) THEN
        IH_CF(NUMB1)    = 511
        IK_CF(NUMB1)    = MJ
        IL_CF(NUMB1)    = MK
        FA_CF(NUMB1)    = FAS
        FB_CF(NUMB1)    = FBS
        IEND_CF(NUMB1)  = 0
        ENDIF
      ENDIF
      IF(NUMB.GT.0) THEN
        NUMB1    = NUMB1 + 1
        IF(NUMB1.GT.IPRCF) THEN
C          WRITE(LINE,'(A)')
C     *    ' ERROR: trpack: not memory enough for scratch_CF file: '
C          CALL MSGERR(MDOC,LINE)
          IERR=1
C          RETURN
        ENDIF
        IF(IERR.EQ.0) THEN
        IH_CF(NUMB1)    = 0
        IK_CF(NUMB1)    = 0
        IL_CF(NUMB1)    = 0
        FA_CF(NUMB1)    = FAW
        FB_CF(NUMB1)    = 0.0
        IEND_CF(NUMB1)  = 0
        ENDIF
        DO     I=1,NUMB
          CALL UNPACK(IPACK(I),IH,IK,IL)
          IF(ABS(IH).LE.511.AND.ABS(IK).LE.511.AND.ABS(IL).LE.511) THEN
            NUMB1    = NUMB1 + 1
            IF(NUMB1.GT.IPRCF) THEN
C              WRITE(LINE,'(A)')
C     *    ' ERROR: trpack: not memory enough for scratch_CF file: '
C              CALL MSGERR(MDOC,LINE)
              IERR=1
C              RETURN
            ENDIF
            IF(IERR.EQ.0) THEN
            IH_CF(NUMB1)    = IH
            IK_CF(NUMB1)    = IK
            IL_CF(NUMB1)    = IL
            FA_CF(NUMB1) = FAPACK(I)*SCALE
            FB_CF(NUMB1) = FBPACK(I)*SCALE
            IF(MSGG.EQ.'P') THEN
              FA_CF(NUMB1) =-FA_CF(NUMB1)
              FB_CF(NUMB1) =-FB_CF(NUMB1)
            ENDIF
            IEND_CF(NUMB1)  = 0
            ENDIF
          ENDIF
        ENDDO
      ENDIF
C --------------------------------------
      IF(IMOD.EQ.2) THEN
        IEND  = 2
        NUMB1 = NUMB1 + 1
        IF(NUMB1.GT.IPRCF) THEN
C          WRITE(LINE,'(A)')
C     *    ' ERROR: trpack: not memory enough for scratch_CF file: '
C          CALL MSGERR(MDOC,LINE)
         IERR=1
C          RETURN
        ENDIF
        IF(IERR.EQ.0) THEN
        IH_CF(NUMB1)    = 0
        IK_CF(NUMB1)    = 0
        IL_CF(NUMB1)    = 0
        FA_CF(NUMB1)    = 0.0
        FB_CF(NUMB1)    = 0.0
        IEND_CF(NUMB1)  = 1
        ENDIF
      ENDIF
      RETURN
      END

      SUBROUTINE FSORT(NIN,NOUT,IPACK,FAPACK,FBPACK,IPRMEM)
C -------------------------------------
      INTEGER IPACK(IPRMEM)
      REAL    FAPACK(IPRMEM),FBPACK(IPRMEM)
C ------------------------------------
      INTEGER*4 NIN
      REAL*8 R8,S8,FAW,FBW
C ---------------------------------------------
      IF(NIN.LE.0) THEN
C        WRITE(*,'('' WARNING: NUMB FOR SORT = 0'')')
C        CALL EXIT
        NOUT=0
        RETURN
      ENDIF
C ----------------------------------------------
      CALL ISORT2(IPACK,NIN,FAPACK,FBPACK)
C ----------------------------------------------
      NOUT   = 0
      INDOLD =-1
      IOUT   = 0
      R8     = 0.0
      S8     = 0.0
      DO     I=1,NIN
        IND = IPACK(I)
        FAW = FAPACK(I)
        FBW = FBPACK(I)
        IF(IND.EQ.INDOLD) THEN
          R8 = R8+FAW
          S8 = S8+FBW
        ELSE
          IF(IOUT.GE.1) THEN
            IPACK (IOUT) = INDOLD
            FAPACK(IOUT) = R8
            FBPACK(IOUT) = S8
            NOUT         = NOUT+1
          ENDIF
          IOUT   = IOUT+1
          INDOLD = IND
          R8     = FAW
          S8     = FBW
        ENDIF
      ENDDO
      IPACK (IOUT) = INDOLD
      FAPACK(IOUT) = R8
      FBPACK(IOUT) = S8
      NOUT         = NOUT+1
C --------------------------------------
c      WRITE(*,1010) NIN,NOUT
c1010  FORMAT(' SORT :',I10,' --> ',I10)
      RETURN
      END

      SUBROUTINE ADD(MDOC,JTOT,NTOT,NOUT,IPRINT
     *  ,IHH,IKK,ILL,ISS,FAW,FBW,IPACK,FAPACK,FBPACK,IPRMEM,IERR)
C ----------------------------------------------------------
      INTEGER IPACK(IPRMEM)
      REAL    FAPACK(IPRMEM),FBPACK(IPRMEM)
C ---------------------------------------------------------
      REAL*8 FAW,FBW
      CHARACTER LINE*80
      EXTERNAL  PACK
C ----------------------------------------------------------
      IF(ABS(IHH).GT.511.OR.ABS(IKK).GT.511.OR.ABS(ILL).GT.511)
     * RETURN
      CALL ASYM(ISS,IHH,IKK,ILL,JSS,JHH,JKK,JLL)
      IF(JSS.LT.0) FBW=-FBW
      JTOT = JTOT+1
      NTOT = NTOT+1
      IF(NTOT.GT.IPRMEM) THEN
        WRITE(LINE,'('' ERROR: trpack: number of coef >'',I8)') IPRMEM
        CALL MSGERR(MDOC,LINE)
        IERR=1
        RETURN
      ENDIF
      CALL PACK(IPACK(NTOT),JHH,JKK,JLL)
      FAPACK(NTOT) = FAW
      FBPACK(NTOT) = FBW
      IF(IPRINT.GT.0) THEN
        IF(MOD(NTOT,IPRINT).EQ.0) THEN
          WRITE(LINE,'('' '',4I6,2G12.4)') NTOT,JHH,JKK,JLL,FAW,FBW
          CALL MSGDOC(MDOC,LINE)
          IERR=0
        ENDIF
      ENDIF
      IF(NTOT.GE.IPRMEM) THEN
        CALL FSORT(NTOT,NOUT,IPACK,FAPACK,FBPACK,IPRMEM)
        NTOT=NOUT
        IF(NTOT.GE.IPRMEM) THEN
          WRITE(LINE,'('' ERROR: trpack: number of coef >'',I8)') IPRMEM
          CALL MSGERR(MDOC,LINE)
          IERR=1
          RETURN
        ENDIF
C      ELSE IF(NTOT.LE.0) THEN
C        IERR=1
C        RETURN
      ENDIF
      RETURN
      END

      SUBROUTINE TRPFFT_new(MDOC,MDOC_LIST,LIST
     * ,NAMED,MODE,FUNCR,ACCUMR,IOP1R,IOP2R
     * ,NXI,NYI,NZI,IZMINI,IZMAXI,NSYM,ISYM,IPRSYM
     * ,RRMIN,RRMAX
     * ,FA_CF,FB_CF,IH_CF,IK_CF,IL_CF,IEND_CF,IPRCF
     * ,RLATT,RESMIN,RESMAX,TITLE
     * ,RESULT,IPRMAX,IPRROW,IERR)
C --------------------------------------------
C
      REAL      RESULT (IPRMAX,IPRROW)

cc      COMPLEX   POOL (IPRNCR)
cc      REAL      POOLA(IPRNCR)
c      COMPLEX   POOL (*)
c      REAL      POOLA(*)
c      REAL      RPOOL(*)
c      REAL      POOLS(IPRNCR,3)

      complex,    allocatable :: POOL(:)
      complex,    allocatable :: POOL_PACK(:)
C      real,    allocatable :: RPOOLA(:)
      real,    allocatable :: POOLA(:)
      real,    allocatable :: POOLS(:,:)


      INTEGER*2 ISYM(5,3,IPRSYM)
      REAL      RLATT(6)
C ---
      REAL      FA_CF(IPRCF),FB_CF(IPRCF)
      INTEGER*2 IH_CF(IPRCF),IK_CF(IPRCF),IL_CF(IPRCF),IEND_CF(IPRCF)
C ---
      INTEGER   MDOC,IERR
      INTEGER   IOP1R,IOP2R,NXI,NYI,NZI,IZMINI,IZMAXI
      CHARACTER FUNCR*1,ACCUMR*1,MODE*1
      CHARACTER NAMED*(*),TITLE*(*)
C ---
      COMMON/COM_TRP_WRT/ IEND_WRT,NUMB1_WRT,IFIRST_WRT
C ---
      COMPLEX   CDM,SM
      INTEGER   IH(2),IK(2),IL(2),IOP1,IOP2
      INTEGER   IDIM(10)
      REAL      CZL(512),SZL(512)
      REAL      FA(2),FB(2)
      CHARACTER LINE*80,ITP*4,MSG_T*1,TYPE1*4,PACK*1
      CHARACTER PACK_SRCH*1
      CHARACTER FUNC*1,ACCUM*1,TYPER*1,TYPE2*4,SPEC*1,LIST*1
C --
      COMMON/COM_TRP_SRPK/ FRTOCR,CRTOFR,NX,NY,NZ,IZMIN,IZMAX,
     *                 DELA,DELG,DELB,TYPE
      REAL      FRTOCR(3,3),CRTOFR(3,3)
      CHARACTER TYPE*1
C ---
      INTEGER   ISECT(3)
C ----------------------
      PARAMETER ( IPRORG=24)
      REAL      SOR(3,IPRORG)
C ----------------------
      CHARACTER TIME_CURRENT*15,TIME_ELAPSED*15,TIME_EXPECTED*15
C ==============================================================
      IERR = 0
      M    = 99
      MD   =-ABS(MDOC)-1
C ----
      IF(LIST.EQ.'T') THEN
        MD = MDOC
        CALL MSGDOC(MD,' --- TRPFFT ---')
        LINE = 'MODE,FUNCR,ACCUMR:'//MODE//FUNCR//ACCUMR
        CALL MSGDOC(MD,LINE)
      ENDIF
c --
      NRUN_TIME   = 0
      ITIME_START = 0
      CALL EXPECTED_TIME(ITIME_START,NRUN_TIME
     *    ,ITIME_CURR,TIME_CURRENT,TIME_ELAPSED,TIME_EXPECTED)
      WRITE(LINE,*) 'Time:',TIME_CURRENT,' Elapsed:',TIME_ELAPSED
      CALL MSGDOC(MDOC,LINE)
      WRITE(*,*) 'Time3:',TIME_CURRENT,' Elapsed:',TIME_ELAPSED
c ---
C ---
      ACCUM = ACCUMR
      FUNC  = FUNCR
C ----
      PI   =4.0*ATAN(1.0)
      TWOPI=2.0*PI
C --------------------
      MTOUT = 0
C ---
      RX = RESMAX
C ----
      A     = RLATT(1)
      B     = RLATT(2)
      C     = RLATT(3)
      ALPHA = RLATT(4)
      BETA  = RLATT(5)
      GAMMA = RLATT(6)

      NX    = NXI
      NY    = NYI
      NXZ   = NZI
      IZMIN = IZMINI
      IZMAX = IZMAXI

C ----
C     VOLUME OF CELL
C
      S   = (ALPHA+BETA+GAMMA)*0.5
      VOL = 2.0*A*B*C*
     *      SQRT(ABS(SIN(S)*SIN(S-ALPHA)*SIN(S-BETA)*SIN(S-GAMMA)))

      TYPE1 = TITLE(5:8)
      TYPE2 = TITLE(9:12)
      TYPER = TITLE(13:13)

      CALL LIMHKL(RESMAX,IHMAX,IKMAX,ILMAX,NXMIN,NYMIN,NZMIN)
      WRITE(LINE,1020) IHMAX,IKMAX,ILMAX
 1020 FORMAT(' Hmax,Kmax,Lmax :',3I4)
      CALL MSGDOC(MD,LINE)
      CALL MSGDOC(MD,
     * 'Defaults are minimal grid spacing for calculation SF')
C ----
      WRITE(LINE,1030) NXMIN,NYMIN,NZMIN
 1030 FORMAT('GRID: NX,NY,NZ <',I3,',',I3,',',I3,'>') 
      CALL MSGDOC(MD,LINE)
      IF(NX.LE.0) NX = NXMIN
      IF(NY.LE.0) NY = NYMIN
      IF(NZ.LE.0) NZ = NZMIN
      NX   = (NX/2)*2
      NY   = (NY/2)*2
      NZ   = (NZ/2)*2

      NXYZ = NX*NY*NZ
      NXYZ = NXYZ/2
      NXY  = NX*NY
      NXY  = NXY/2
      NX2  = NX/2

      KXY  = NX*NY
      KXYZ = KXY*NZ
      
      IHMAX = NX2-1
      IKMAX = NY/2-1
      ILMAX = NZ/2-1
      IF(IHMAX.GT.510) IHMAX = 510
      IF(IKMAX.GT.510) IKMAX = 510
      IF(ILMAX.GT.510) ILMAX = 510

      ISMALL = 0
      IF(IZMAX.LT.IZMIN) THEN
        IZMAXR = IZMAX
        IF(TYPE1.EQ.'REAL'.OR.IZMAX.EQ.-2) THEN
          IZMIN = 0
          IZMAX = NZ-1
        ELSE
          IZMIN = 0
          IZMAX = NZ/2
          IF(TYPE2.EQ.'TRP2') THEN
            IZMAX = NZ-1
          ELSE
            ISMALL = 1
          ENDIF
        ENDIF
        IF(TYPER.EQ.'N'.AND.IZMAXR.NE.-2) THEN
          IZMAX  = 0 
          ISMALL = 2            
        ENDIF
      ENDIF

      IPRNCR = KXY
      IT = 0
C     allocate(POOL(1:NXY),STAT=ISTAT)
      allocate(POOL(1:NXYZ),STAT=ISTAT)
      allocate(POOL_PACK(1:NXYZ),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(POOLA(1:IPRNCR),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(POOLS(1:IPRNCR,1:3),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      IF(IT.GT.0) THEN
        IERR = 1
        CALL MSGERR(MDOC,
     *    ' ERROR: in TRPFFT: problem with memory allocation')
        IPRNCR = 0
        RETURN
      ENDIF

C ---------------------
c      ICPU=0
c      CALL CPU(ICPU)
C ---------------------
      ZERO    = 0.0
      CDM     = CMPLX(ZERO,ZERO)
C ------------------
      NUMB1_WRT  = 0
      JEND       = 0
      IPACK      = 0
      IPOLD      = 0
      IPACK_FFT  = 0
      ITRANS_FFT = 0
      PACK_SRCH  = 'N'

      DO I=1,NXYZ
        POOL(I)      = CDM
        POOL_PACK(I) = CDM
      ENDDO

      IF(ISMALL.EQ.1) THEN
        NZ   = NZ/2
        KXYZ = KXY/2
        NXYZ = NXYZ/2
      ENDIF
C------------------------------
C     first or next step
c     cycle by refls
  500 CONTINUE
      F000  = 0.0
      NMB   = 0
C ---
  300 CONTINUE

      NUMB1_WRT = NUMB1_WRT + 1 
      FA(1) = FA_CF(NUMB1_WRT)
      FB(1) = FB_CF(NUMB1_WRT)
      IH(1) = IH_CF(NUMB1_WRT)
      IK(1) = IK_CF(NUMB1_WRT)
      IL(1) = IL_CF(NUMB1_WRT)
      IEND  = IEND_CF(NUMB1_WRT)

C      write(*,*) '>',NUMB1_WRT,IH(1),IK(1),IL(1),IEND

      IF(IEND.GT.0) THEN
c       end of list         
        JEND  = 1
        IPOLD = IPACK
C       go to fft
        GO TO 200
      ENDIF

      IF(IH(1).EQ.511) THEN
c       start first or next step
        IPOLD = IPACK
        J = IK(1)
        K = IL(1)
        IF(J.EQ.0.AND.K.EQ.0) THEN
C         pack. function
          IPACK = 1
        ELSE 
C         TR function
          IPACK = 0
        ENDIF

        IF(NMB.GT.0) THEN
c         it is not first step
C         go to fft        
          GO TO 200
        ENDIF
c       next refl
        GO TO 300
      ENDIF
C ----------------------------------
C     USE F000
C
      IF(IH(1).EQ.0.AND.IK(1).EQ.0.AND.IL(1).EQ.0) THEN
        F000    = FA(1)/VOL
        TEMP    = F000
        SM      = CMPLX(TEMP,ZERO)
        IF(IPACK.EQ.1) THEN
          POOL_PACK(1) = SM
        ELSE
          POOL(1) = SM
        ENDIF
c       WRITE(*,*) ' F000:',F000
c       next refl
        GO TO 300
      ENDIF
C ------------------------
      NMB   = NMB + 1
      VVOL = VOL
      IF(ISMALL.EQ.1) VVOL = VOL
      FA(1) = FA(1)/VVOL
      FB(1) = FB(1)/VVOL
C ----------------------
      IF(ISMALL.EQ.1) THEN
        IL(1) = IL(1)/2
      ELSE IF(ISMALL.EQ.2) THEN
        IF(ABS(IL(1)).NE.0) GO TO 300
      ENDIF

      CALL TRP_GNR_P1(N,IH,IK,IL,FA,FB)
C ------------------------
      DO     I=1,N
        JH  = IH(I)
        JK  = IK(I)
        JL  = IL(I)
        FAA = FA(I)
        FBB = FB(I)

c       WRITE(*,'('' H,K,L,A,B:'',3I5,2F12.4)') JH,JK,JL,FAA,FBB

        IF(IABS(JL).LE.ILMAX.AND.
     *     IABS(JK).LE.IKMAX.AND.
     *     IABS(JH).LT.IHMAX     ) THEN
          IHD = JH +1
          IF(JK.LT.0) JK = NY + JK
          IKD = JK + 1
          IF(JL.LT.0) JL = NZ + JL
          ILD  = JL + 1
          IND  = (ILD-1)*NXY + (IKD-1)*NX2 + IHD
          SM   = CMPLX(FAA,FBB)
          IF(IPACK.EQ.1) THEN
            POOL_PACK(IND) = POOL_PACK(IND) + SM
          ELSE
            POOL(IND) = POOL(IND) + SM
          ENDIF
        ENDIF
      ENDDO
c     next refl
      GO TO 300
C--------------------------------------------
  200 CONTINUE
c     fft (PACK- IPOLD=0 , TF- IPOLD#0 )     
      IF(NMB.GT.0) THEN
        IDIM(1) = NX2
        IDIM(2) = NY
        IF(ISMALL.EQ.2) THEN
          IDIM(3) = 0
        ELSE
          IDIM(3) = NZ
        ENDIF
        IDIM(4) = 0
        IF(IPOLD.EQ.1) THEN
          IPACK_FFT  = 1
          CALL MDHFT(POOL_PACK,IDIM,IERR)
        ELSE
          ITRANS_FFT = 1
          CALL MDHFT(POOL,IDIM,IERR)
        ENDIF
        IF(IERR.NE.0) THEN
          CALL MSGERR(MDOC,' ERROR: trpack: in kernel-FFT')
          GO TO 900
        ENDIF
      ENDIF
      IF(JEND.EQ.0) THEN
C       go to second step
        GO TO 500
      ENDIF
C--------------------------------------------------------------
      RRMAX = 0.0
      RRMIN = 0.0
      RMAX = 0.0
      RMIN = 0.0
      IF(IPACK_FFT.GT.0.AND.ITRANS_FFT.GT.0) THEN
        PACK = 'Y'
        CALL TRP_MULTD_3D(KXYZ,POOL,POOL_PACK,PACK
     *                            ,RMAX,RMIN,RRMAX,RRMIN)
      ELSE IF(IPACK_FFT.GT.0.AND.ITRANS_FFT.LE.0) THEN
        DO I=1,NXYZ
          POOL(I) = POOL_PACK(I)
        ENDDO
        PACK = 'N'
        CALL TRP_MULTD_3D(KXYZ,POOL,POOL_PACK,PACK
     *                            ,RMAX,RMIN,RRMAX,RRMIN)
      ENDIF
      IF(PACK.EQ.'Y') THEN
        WRITE(LINE,'(''Packing Function: max,min :'',2G16.4)')
     *  RRMAX,RRMIN
        CALL MSGDOC(MDOC,LINE)
        IF(RRMAX.LE.0.0.AND.RRMAX.GE.RRMIN) THEN
          CALL MSGDOC(MDOC,
     *     ' WARNING: trpack: all values of Packing Function =< 0.')
          IERR=10
          GO TO 900
        ENDIF          
      ENDIF
C ---------------------------------------------------------------
      IF(ISMALL.EQ.1) THEN
        NZ   = NZ*2
        KXYZ = KXYZ*2
        NXYZ = NXYZ*2
      ENDIF
c --
      NRUN_TIME   = 0
      ITIME_START = 0
      CALL EXPECTED_TIME(ITIME_START,NRUN_TIME
     *    ,ITIME_CURR,TIME_CURRENT,TIME_ELAPSED,TIME_EXPECTED)
      WRITE(LINE,*) 'Time:',TIME_CURRENT,' Elapsed:',TIME_ELAPSED
      CALL MSGDOC(MDOC,LINE)
      WRITE(*,*) 'Time33:',TIME_CURRENT,' Elapsed:',TIME_ELAPSED
c ---
C ----------------------------------------------------------------
      MTOUT = 13
      ITP   = 'RI  '
      IERR  = 0
      CALL LENSTR_BL(NAMED,LEN)
      IF(LEN.GT.0.AND.NAMED(1:1).NE.' '.AND.NAMED(1:1).NE.',') THEN
        MTOUT = 13
      ELSE
        MTOUT = 0
      ENDIF
C ---
      F1 = 1.0
      F2 = 0.0
      F3 = RESMIN
      F4 = RESMAX
      CALL C_CR_WR
      CALL SET_TITLE(MD,RLATT(1),RLATT(2),RLATT(3),RLATT(4),RLATT(5)
     * ,RLATT(6),F1,F2,F3,F4,NX,NY,NZ,IZMIN,IZMAX,TITLE,IERR)

      IF(MTOUT.GT.0) THEN
        CALL OWFILE(MD,MTOUT,NAMED,ITP,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MDOC,' ERROR: trpack: can not open file_DENS')
          CLOSE(MTOUT)
          MTOUT = 0
          GO TO 900
        ENDIF
      ENDIF
C ---
      NPEAK  = 0
      NPEAK_MAX = 50
      IF(NPEAK_MAX.GT.IPRMAX) NPEAK_MAX = IPRMAX
c      RRMAX   =-1.0 E30
c      RRMIN   = 1.0 E30
c      DRMAX   =-1.0 E30
c      DRMIN   = 1.0 E30
      DIST_LIM = 0.0
      SPEC     = 'Y'
      CALL TRP_PSRCH_INI(MDOC,DIST_LIM,SPEC,RX
     * ,A,B,C,ALPHA,BETA,GAMMA
     * ,DLIM,TITLE,NORIG,SOR,IPRORG,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN   
        CALL MSGERR(MDOC,' ERROR: trpack: TRP_PSRCH_INI')
        IERR=1
        GO TO 900
      ENDIF
      ICNTZ   =-999
      IX0     = 0
      IY0     = 0
      IZ0     = IZMIN
      ITR     = 0

      DO IZ=IZMIN,IZMAX

        CALL TRP_COPY_3D(IZ,IZMIN,KXYZ,KXY,POOL,POOLA)

        CALL TRP_PKSRCH(MDOC,DIST_LIM,DLIM,SPEC,SOR,NORIG
     *    ,NPEAK,NPEAK_MAX,IZ,ISECT,DRMS,DRMS2
     *    ,POOLA,POOLA,POOLS,POOLS,IPRNCR,PACK_SRCH
     *    ,NSYM,ISYM,IPRSYM,RESULT,IPRMAX,IPRROW,IERR)
        IF(IERR.NE.0) THEN   
          CALL MSGERR(MDOC,' ERROR: trpack: TRP_PKSRCH')
          GO TO 900
        ENDIF
C --
        IF(MTOUT.GT.0) THEN
          CALL WDENS(MTOUT,MDOC,ICNTZ,NX,NY,NZ,IZMIN,IZMAX,RMAX,RMIN
     *             ,POOLA,RX,IX0,IY0,IZ0,ITR)
          IF(MTOUT.EQ.0) THEN
            CALL MSGERR(MDOC,' ERROR: trpack: write to file-DENS')
C           CLOSE(MTIN)
            IF(MTOUT.GT.0) CLOSE(MTOUT)
            MTOUT = 0
            IERR=1
            GO TO 900
          ENDIF
        ENDIF
      ENDDO
C --
      IZ = IZMAX + 1
      CALL TRP_PKSRCH(MDOC,DIST_LIM,DLIM,SPEC,SOR,NORIG
     *  ,NPEAK,NPEAK_MAX,IZ,ISECT,DRMS,DRMS2
     *  ,POOLA,POOLA,POOLS,POOLS,IPRNCR,PACK_SRCH
     *  ,NSYM,ISYM,IPRSYM,RESULT,IPRMAX,IPRROW,IERR)
      IF(IERR.NE.0) THEN   
        CALL MSGERR(MDOC,' ERROR: trpack: TRP_PKSRCH')
        GO TO 900
      ENDIF
C ---------
      NR    = NX*NY
      NR    = NR*(IZMAX-IZMIN+1)
      DRMS  = DRMS /NR
      DRMS2 = DRMS2/NR
      DRMS  = DRMS2-DRMS*DRMS
      IF(DRMS.LT.0.0) DRMS = 0.0
      IF(DRMS.GT.0.0) DRMS = SQRT(ABS(DRMS))
C --
      CALL TRP_PSRCH_FIN(MDOC_LIST,NPEAK,NPEAK_MAX,SPEC,FRTOCR,DRMS
     *            ,ISYM,IPRSYM,RESULT,IPRMAX,IPRROW,IERR)
      IF(IERR.NE.0) THEN   
        CALL MSGERR(MDOC,' ERROR: trpack: TRP_PSRCH_FIN')
        GO TO 900
      ENDIF
C------------------------------------------------------------------
c      ICPU=1
C      CALL CPU(ICPU)
C ------------------------------------

900   CONTINUE

      deallocate(POOL,STAT=ISTAT)
      deallocate(POOL_PACK,STAT=ISTAT)
      deallocate(POOLA,STAT=ISTAT)
      deallocate(POOLS,STAT=ISTAT)

      IF(MTOUT.GT.0) CLOSE(MTOUT)
c --
      NRUN_TIME   = 0
      ITIME_START = 0
      CALL EXPECTED_TIME(ITIME_START,NRUN_TIME
     *    ,ITIME_CURR,TIME_CURRENT,TIME_ELAPSED,TIME_EXPECTED)
      WRITE(LINE,*) 'Time:',TIME_CURRENT,' Elapsed:',TIME_ELAPSED
      CALL MSGDOC(MDOC,LINE)
      WRITE(*,*) 'Time4:',TIME_CURRENT,' Elapsed:',TIME_ELAPSED
c ---

      RETURN
      END

      SUBROUTINE TRP_COPY_3D(IZ,IZMIN,NXYZ,NXY,POOL3,POOL2)
C ---------------------------------------------------------------
      REAL POOL3(3),POOL2(*)
C ----------------------------------------------------------------
      DO  I=1,NXY
        IND = (IZ-IZMIN)*NXY + I
        R   = POOL3(IND)
        POOL2(I) =  R 
      ENDDO
      RETURN
      END

      SUBROUTINE TRP_MULTD_3D(NXYZ,POOL_TR,POOL_PACK,PACK
     *                       ,DMAX,DMIN,PMAX,PMIN)
C ---------------------------------------------------------------
      REAL POOL_PACK(*),POOL_TR(*)
      CHARACTER PACK*1
C ----------------------------------------------------------------
      PMAX   =-1.0 E30
      PMIN   = 1.0 E30
      DMAX   =-1.0 E30
      DMIN   = 1.0 E30
      DO  I=1,NXYZ
        R    = POOL_PACK(I)
        IF(PACK.EQ.'Y') THEN
          R  = POOL_PACK(I)
          IF(R.GE.PMAX) PMAX=R
          IF(R.LE.PMIN) PMIN=R
          IF(R.GT.0.0) THEN
            RR = R
            IF(RR.GT.0.75) RR = 0.75                 
            RR = RR*1.3333
          ELSE
            RR = 0.0
          ENDIF
          POOL_TR(I) = POOL_TR(I) * RR
        ENDIF
        IF(POOL_TR(I).GE.DMAX) DMAX=POOL_TR(I)
        IF(POOL_TR(I).LE.DMIN) DMIN=POOL_TR(I)
      ENDDO
      RETURN
      END

      SUBROUTINE TRPFFT(MDOC,MDOC_LIST,LIST
     * ,NAMED,MODE,FUNCR,ACCUMR,IOP1R,IOP2R
     * ,NXI,NYI,NZI,IZMINI,IZMAXI,NSYM,ISYM,IPRSYM
     * ,RRMIN,RRMAX
     * ,FA_CF,FB_CF,IH_CF,IK_CF,IL_CF,IEND_CF,IPRCF
     * ,RLATT,RESMIN,RESMAX,TITLE
     * ,RESULT,IPRMAX,IPRROW,IERR)
C --------------------------------------------
C
      REAL      RESULT (IPRMAX,IPRROW)

cc      COMPLEX   POOL (IPRNCR)
cc      REAL      POOLA(IPRNCR)
c      COMPLEX   POOL (*)
c      REAL      POOLA(*)
c      REAL      RPOOL(*)
c      REAL      POOLS(IPRNCR,3)

      complex,    allocatable :: POOL(:)
C      real,    allocatable :: RPOOLA(:)
      real,    allocatable :: POOLA(:)
      real,    allocatable :: POOLB(:)
      real,    allocatable :: POOLS(:,:)
      real,    allocatable :: POOLP(:,:)


      INTEGER*2 ISYM(5,3,IPRSYM)
      REAL      RLATT(6)
C ---
      REAL      FA_CF(IPRCF),FB_CF(IPRCF)
      INTEGER*2 IH_CF(IPRCF),IK_CF(IPRCF),IL_CF(IPRCF),IEND_CF(IPRCF)
C ---
      INTEGER   MDOC,IERR
      INTEGER   IOP1R,IOP2R,NXI,NYI,NZI,IZMINI,IZMAXI
      CHARACTER FUNCR*1,ACCUMR*1,MODE*1
      CHARACTER NAMED*(*),TITLE*(*)
C ---
      COMMON/COM_TRP_WRT/ IEND_WRT,NUMB1_WRT,IFIRST_WRT
C ---
      COMPLEX   CDM,SM
      INTEGER   IH(2),IK(2),IL(2),IOP1,IOP2
      INTEGER   IDIM(10)
      REAL      CZL(512),SZL(512)
      REAL      FA(2),FB(2)
      CHARACTER LINE*80,ITP*4,MSG_T*1,TYPE1*4,PACK*1
      CHARACTER PACK_SRCH*1
      CHARACTER FUNC*1,ACCUM*1,TYPER*1,TYPE2*4,SPEC*1,LIST*1
C --
      COMMON/COM_TRP_SRPK/ FRTOCR,CRTOFR,NX,NY,NZ,IZMIN,IZMAX,
     *                 DELA,DELG,DELB,TYPE
      REAL      FRTOCR(3,3),CRTOFR(3,3)
      CHARACTER TYPE*1
C ---
      INTEGER   ISECT(3)
C ----------------------
      PARAMETER ( IPRORG=24)
      REAL      SOR(3,IPRORG)
C ----------------------
      CHARACTER TIME_CURRENT*15,TIME_ELAPSED*15,TIME_EXPECTED*15
C ==============================================================
      IERR = 0
      M    = 99
      MD   =-ABS(MDOC)-1
      IF(LIST.EQ.'T') THEN
        MD = MDOC
        CALL MSGDOC(MD,' --- TRPFFT ---')
        LINE = 'MODE,FUNCR,ACCUMR:'//MODE//FUNCR//ACCUMR
        CALL MSGDOC(MD,LINE)

        WRITE(*,*) '=T:',TITLE
        WRITE(*,*) 'IOP1R,IOP2R',IOP1R,IOP2R
        WRITE(*,*) 'RES',RESMIN,RESMAX

      ENDIF
c --
c      NRUN_TIME   = 0
c      ITIME_START = 0
c      CALL EXPECTED_TIME(ITIME_START,NRUN_TIME
c     *    ,ITIME_CURR,TIME_CURRENT,TIME_ELAPSED,TIME_EXPECTED)
c      WRITE(LINE,*) 'Time:',TIME_CURRENT,' Elapsed:',TIME_ELAPSED
c      CALL MSGDOC(MDOC,LINE)
c      WRITE(*,*) 'Time3:',TIME_CURRENT,' Elapsed:',TIME_ELAPSED
c ---
C ---
      ACCUM = ACCUMR
      FUNC  = FUNCR
      IOP1  = IOP1R
      IOP2  = IOP2R
C ----
      PI   =4.0*ATAN(1.0)
      TWOPI=2.0*PI
C --------------------
      MTIN   = 10
      ITP    = 'COEF'
      IPRINT = 0
      NPEAK  = 0
      NPEAK_MAX = 100
      IF(NPEAK_MAX.GT.IPRMAX) NPEAK_MAX = IPRMAX
C ---
      RX = RESMAX
C ----
      A     = RLATT(1)
      B     = RLATT(2)
      C     = RLATT(3)
      ALPHA = RLATT(4)
      BETA  = RLATT(5)
      GAMMA = RLATT(6)

      NX    = NXI
      NY    = NYI
      NXZ   = NZI
      IZMIN = IZMINI
      IZMAX = IZMAXI

C ----
C     VOLUME OF CELL
C
      S   = (ALPHA+BETA+GAMMA)*0.5
      VOL = 2.0*A*B*C*
     *      SQRT(ABS(SIN(S)*SIN(S-ALPHA)*SIN(S-BETA)*SIN(S-GAMMA)))

      TYPE1 = TITLE(5:8)
      TYPE2 = TITLE(9:12)
      TYPER = TITLE(13:13)

      CALL LIMHKL(RESMAX,IHMAX,IKMAX,ILMAX,NXMIN,NYMIN,NZMIN)
      WRITE(LINE,1020) IHMAX,IKMAX,ILMAX
 1020 FORMAT(' Hmax,Kmax,Lmax :',3I4)
      CALL MSGDOC(MD,LINE)
      CALL MSGDOC(MD,
     * 'Defaults are minimal grid spacing for calculation SF')
C ----
      WRITE(LINE,1030) NXMIN,NYMIN,NZMIN
 1030 FORMAT('GRID: NX,NY,NZ <',I3,',',I3,',',I3,'>') 
      CALL MSGDOC(MD,LINE)
      IF(NX.LE.0) NX = NXMIN
      IF(NY.LE.0) NY = NYMIN
      IF(NZ.LE.0) NZ = NZMIN
      NX   = (NX/2)*2
      NY   = (NY/2)*2
      NZ   = (NZ/2)*2

      NXY  = NX*NY
      NXY  = NXY/2
      KXY  = NX*NY
      NX2  = NX/2

      IHMAX = NX2-1
      IKMAX = NY/2-1
      ILMAX = NZ/2-1
      IF(IHMAX.GT.510) IHMAX = 510
      IF(IKMAX.GT.510) IKMAX = 510
      IF(ILMAX.GT.510) ILMAX = 510

      IPRNCR = KXY
      IT = 0
      allocate(POOL(1:NXY),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(POOLA(1:IPRNCR),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(POOLB(1:IPRNCR),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(POOLS(1:IPRNCR,1:3),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(POOLP(1:IPRNCR,1:3),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      IF(IT.GT.0) THEN
        IERR = 1
        CALL MSGERR(MDOC,
     *    ' ERROR: in TRPFFTT: problem with memory allocation')
        IPRNCR = 0
        RETURN
      ENDIF

      IF(IZMAX.LT.IZMIN) THEN
        IZMAXR = IZMAX
        IF(TYPE1.EQ.'REAL'.OR.IZMAX.EQ.-2) THEN
          IZMIN = 0
          IZMAX = NZ-1
        ELSE
          IZMIN = 0
          IZMAX = NZ/2
          IF(TYPE2.EQ.'TRP2') THEN
            IZMAX = NZ-1
          ENDIF
        ENDIF
        IF(TYPER.EQ.'N'.AND.IZMAXR.NE.-2) THEN
          IZMAX = 0             
        ENDIF
      ENDIF
C ---

      MTOUT = 13
      ITP   = 'RI  '
      IERR  = 0
      CALL LENSTR_BL(NAMED,LEN)

      IF(LEN.GT.0.AND.NAMED(1:1).NE.' '.AND.NAMED(1:1).NE.',') THEN
        MTOUT = 13
      ELSE
        MTOUT = 0
      ENDIF

      F1 = 1.0
      F2 = 0.0
      F3 = RESMIN
      F4 = RESMAX
      CALL C_CR_WR
      CALL SET_TITLE(MD,RLATT(1),RLATT(2),RLATT(3),RLATT(4),RLATT(5)
     * ,RLATT(6),F1,F2,F3,F4,NX,NY,NZ,IZMIN,IZMAX,TITLE,IERR)

      IF(MTOUT.GT.0) THEN
        CALL OWFILE(MD,MTOUT,NAMED,ITP,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MDOC,' ERROR: trpack: can not open file_DENS')
C         CLOSE(MTIN)
          CLOSE(MTOUT)
          MTOUT = 0
          GO TO 900
        ENDIF
      ENDIF

C -----
c      ICPU=0
c      CALL CPU(ICPU)
C ----
      ZERO    = 0.0
      CDM     = CMPLX(ZERO,ZERO)
      ITP     = '    '
      IPRINT  = 0
      IX0     = 0
      IY0     = 0
      IZ0     = IZMIN
      ITR     = 0
      ICNTZ   =-999
      IDIM(1) = NX2
      IDIM(2) = NY
      IDIM(3) = 0

      RRMAX   =-1.0 E30
      RRMIN   = 1.0 E30
      DRMAX   =-1.0 E30
      DRMIN   = 1.0 E30
      PACK    = 'N'
      PACK_SRCH = 'N'
C ---
C --
      DIST_LIM = 0.0
      SPEC     = 'Y'
      CALL TRP_PSRCH_INI(MDOC,DIST_LIM,SPEC,RX
     * ,A,B,C,ALPHA,BETA,GAMMA
     * ,DLIM,TITLE,NORIG,SOR,IPRORG,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN   
        CALL MSGERR(MDOC,' ERROR: trpack: TRP_PSRCH_INI')
        IERR=1
        GO TO 900
      ENDIF
C --
      IF(LIST.EQ.'T') THEN
c        CALL MSGDOC(MD,' --- TRPFFT 1')
      ENDIF
C =================================================
      DO IZ=IZMIN,IZMAX
        Z      = FLOAT(IZ)/FLOAT(NZ)
        ANG    = TWOPI*Z
        CSZ    = COS(ANG)
        SNZ    = SIN(ANG)
        CZL(1) = 1.0
        SZL(1) = 0.0
        DO  I=2,512
          CZL(I) = CZL(I-1)*CSZ-SZL(I-1)*SNZ
          SZL(I) = SZL(I-1)*CSZ+CZL(I-1)*SNZ
        ENDDO
        DO I=1,KXY
          POOLA(I) = 0.0
c         for PF : -1 means not calculated
          POOLB(I) =-1.0
        ENDDO
        NUMBF  = 0
C---------------
        NUMB1_WRT = 0
        JEND      = 0
        IEND      =-1
        IFIRST    = 0
        IPACK     = 0
        IPOLD     = 0
        IF(MODE.EQ.'P') THEN
          IPOLD = 1
          IPACK = 1
        ENDIF
C----------------------------------------------------------------
  500   CONTINUE
        F000  = 0.0
        NMB   = 0
        IPOLD = IPACK
        IPACK = 0
        IF(MODE.EQ.'P') IPACK = 1
        DO I=1,NXY
          POOL(I) = CDM
        ENDDO
C ---
  300   CONTINUE

C        CALL RD1(MTIN,IH(1),IK(1),IL(1),FA(1),FB(1),NUMB,IEND)
C        IF(MTIN.LE.0) THEN
C          CALL MSGERR(MDOC,' ERROR: trpack: read coef_file')
C          WRITE(LINE,'(''    indexes,numb,iend:'',5I6)')
C     *                     IH(1),IK(1),IL(1),NUMB,IEND
C          CALL MSGERR(MDOC,LINE)
C          CLOSE(MTOUT)
C          IERR=1
C          RETURN
C        ENDIF


        NUMB1_WRT = NUMB1_WRT + 1 
        FA(1) = FA_CF(NUMB1_WRT)
        FB(1) = FB_CF(NUMB1_WRT)
        IH(1) = IH_CF(NUMB1_WRT)
        IK(1) = IK_CF(NUMB1_WRT)
        IL(1) = IL_CF(NUMB1_WRT)
        IEND  = IEND_CF(NUMB1_WRT)

        IF(IEND.GT.0) THEN
          JEND  = 1
          IPOLD = IPACK
          GO TO 200
        ENDIF

        IF(IH(1).EQ.511) THEN

          J = IK(1)
          K = IL(1)
             
          IF(MODE.EQ.'P') THEN
            IPACK = 1
          ENDIF
          ACCUM = 'A'
          IF(J.EQ.0.AND.K.EQ.0) THEN
C           pack. function
            IPACK = 1
            IF(MODE.EQ.'D') TYPE1 = 'MULT'
            IF(IFIRST.EQ.0) THEN
              IPOLD  = 1
            ENDIF
          ELSE 
            IPACK = 0
          ENDIF
          IFIRST = 1

          IF(TYPE1.NE.'MULT') GO TO 300

          J = IK(1)
          K = IL(1)

c          WRITE(*,'('' -->'',3I5,2G15.4)')
c     *    IH(1),IK(1),IL(1),FA(1),FB(1)

          ACCUM = 'M'
          IPACK = 0
          IF(NMB.GT.0) GO TO 200
          GO TO 300
        ENDIF
C ----------------------------------
C       USE F000
C
        IF(IH(1).EQ.0.AND.IK(1).EQ.0.AND.IL(1).EQ.0) THEN
          F000    = FA(1)/VOL
          TEMP    = F000
          SM      = CMPLX(TEMP,ZERO)
          POOL(1) = SM
c         WRITE(*,*) ' F000:',F000
          GO TO 300
        ENDIF
C ------------------------
        NMB   = NMB+1
        FA(1) = FA(1)/VOL
        FB(1) = FB(1)/VOL
C ----------------------
        CALL TRP_GNR_P1(N,IH,IK,IL,FA,FB)
C ------------------------
        DO     I=1,N
          JH  = IH(I)
          JK  = IK(I)
          JL  = IL(I)
          FAA = FA(I)
          FBB = FB(I)
C         WRITE(*,'('' H,K,L,A,B:'',3I5,2F12.4)') JH,JK,JL,FAA,FBB
          IF(IABS(JL).LE.ILMAX.AND.
     *       IABS(JK).LE.IKMAX.AND.
     *       IABS(JH).LT.IHMAX     ) THEN
            IHD = JH+1
            IF(JK.LT.0) JK=NY+JK
            IKD = JK+1
            ILD = IABS(JL)+1
            IF(ILD.LE.512) THEN
              PCOS = CZL(ILD)
              PSIN = SZL(ILD)
              IF(JL.LT.0 ) PSIN=-PSIN
              AP  = FAA * PCOS + FBB * PSIN
              BP  = FBB * PCOS - FAA * PSIN
              SM  = CMPLX(AP,BP)
              IND = (IKD-1)*NX2+IHD
              POOL(IND) = POOL(IND)+SM
            ENDIF
          ENDIF
        ENDDO
        GO TO 300
C--------------------------------------------
  200   CONTINUE
        IF(NMB.GT.0) THEN

          IF(LIST.EQ.'T') THEN
c           CALL MSGDOC(MD,' --- TRPFFT 2')
c           write(*,*)'-->',IPRNCR,IDIM(1),IDIM(2),IDIM(3)
          ENDIF

C         CALL MDHFT(RPOOL,IDIM,IERR)
          CALL MDHFT(POOL,IDIM,IERR)

          IF(LIST.EQ.'T') THEN
c           CALL MSGDOC(MD,' --- TRPFFT 3')
          ENDIF

          IF(IERR.NE.0) THEN
            CALL MSGERR(MDOC,' ERROR: trpack: in kernel-FFT')
C           CLOSE(MTIN)
            CLOSE(MTOUT)
            MTOUT = 0
            GO TO 900
          ENDIF
          IF(IPOLD.EQ.0) THEN
            NUMBF = NUMBF+1
            MSG_T = 'N'
          ELSE
            MSG_T = 'Y'
            PACK  = 'Y'
          ENDIF
          IF(LIST.EQ.'T') THEN
            WRITE(*,*) ' MULTD-MSG_T',MSG_T,ACCUM,NUMBF
          ENDIF           
          DRMAX   =-1.0 E30
          DRMIN   = 1.0 E30

c         MSG_T = Y, ACCUM = M - packing function POOLA
C         PACK_SRCH = 'Y'

          CALL TRP_MULTD(NX,NY,POOL,POOLA,POOLB
     *       ,MSG_T,ACCUM,PACK_SRCH
     *       ,RRMAX,RRMIN,DRMAX,DRMIN)
          IF(LIST.EQ.'T') THEN
            WRITE(*,*) ' RRMAX,,,DRMIN',jend,RRMAX,RRMIN,DRMAX,DRMIN
          ENDIF           
        ENDIF
        IF(JEND.EQ.0) GO TO 500
C--------------------------------------------------------------
C        IF(LIST.EQ.'T') THEN
C          WRITE(*,*) ' NORMD-ACCUM:',ACCUM,NUMBF,NPEAK
C        ENDIF        
C 3.12.2002  CALL TRP_NORMD(NX,NY,POOLA,NUMBF,ACCUM)
c
c 600    CONTINUE
C --
        CALL TRP_PKSRCH(MDOC,DIST_LIM,DLIM,SPEC,SOR,NORIG
     *    ,NPEAK,NPEAK_MAX,IZ,ISECT,DRMS,DRMS2
     *    ,POOLA,POOLB,POOLS,POOLP,IPRNCR,PACK_SRCH
     *    ,NSYM,ISYM,IPRSYM,RESULT,IPRMAX,IPRROW,IERR)
        IF(IERR.NE.0) THEN   
          CALL MSGERR(MDOC,' ERROR: trpack: TRP_PKSRCH')
          GO TO 900
        ENDIF
C --
        IF(MTOUT.GT.0) THEN
          CALL WDENS(MTOUT,MDOC,ICNTZ,NX,NY,NZ,IZMIN,IZMAX,RMAX,RMIN
     *             ,POOLA,RX,IX0,IY0,IZ0,ITR)
          IF(MTOUT.EQ.0) THEN
            CALL MSGERR(MDOC,' ERROR: trpack: write to file-DENS')
C           CLOSE(MTIN)
            IF(MTOUT.GT.0) CLOSE(MTOUT)
            MTOUT = 0
            IERR=1
            GO TO 900
          ENDIF
        ENDIF
      ENDDO
C --
      IZ = IZMAX + 1
      CALL TRP_PKSRCH(MDOC,DIST_LIM,DLIM,SPEC,SOR,NORIG
     *  ,NPEAK,NPEAK_MAX,IZ,ISECT,DRMS,DRMS2
     *  ,POOLA,POOLB,POOLS,POOLP,IPRNCR,PACK_SRCH
     *  ,NSYM,ISYM,IPRSYM,RESULT,IPRMAX,IPRROW,IERR)
      IF(IERR.NE.0) THEN   
        CALL MSGERR(MDOC,' ERROR: trpack: TRP_PKSRCH')
        GO TO 900
      ENDIF

C --
      NR    = NX*NY
      NR    = NR*(IZMAX-IZMIN+1)
      DRMS  = DRMS /NR
      DRMS2 = DRMS2/NR
      DRMS  = DRMS2-DRMS*DRMS
      IF(DRMS.LT.0.0) DRMS = 0.0
      IF(DRMS.GT.0.0) DRMS = SQRT(ABS(DRMS))
C --
      CALL TRP_PSRCH_FIN(MDOC_LIST,NPEAK,NPEAK_MAX,SPEC,FRTOCR,DRMS
     *            ,ISYM,IPRSYM,RESULT,IPRMAX,IPRROW,IERR)
      IF(IERR.NE.0) THEN   
        CALL MSGERR(MDOC,' ERROR: trpack: TRP_PSRCH_FIN')
        GO TO 900
      ENDIF
C --
      IF(PACK.EQ.'Y') THEN
        WRITE(LINE,'(''Packing Function: max,min :'',2G16.4)')
     *  RRMAX,RRMIN
        CALL MSGDOC(MDOC,LINE)
        IF(RRMAX.LE.0.0.AND.RRMAX.GE.RRMIN) THEN
          CALL MSGDOC(MDOC,
     *     ' WARNING: trpack: all values of Packing Function =< 0.')
          IERR=10
          IF(MTOUT.GT.0) CLOSE(MTOUT)
          MTOUT = 0
          GO TO 900
        ENDIF          
      ELSE
        RRMAX = 0.0
        RRMIN = 0.0
      ENDIF
C------------------------------------------------------------------
c      ICPU=1
C      CALL CPU(ICPU)
C ------------------------------------
C     CLOSE(MTIN)

900   CONTINUE

      deallocate(POOL,STAT=ISTAT)
      deallocate(POOLA,STAT=ISTAT)
      deallocate(POOLB,STAT=ISTAT)
      deallocate(POOLS,STAT=ISTAT)
      deallocate(POOLP,STAT=ISTAT)

      IF(MTOUT.GT.0) CLOSE(MTOUT)
c --
c      NRUN_TIME   = 0
c      ITIME_START = 0
c      CALL EXPECTED_TIME(ITIME_START,NRUN_TIME
c     *    ,ITIME_CURR,TIME_CURRENT,TIME_ELAPSED,TIME_EXPECTED)
c      WRITE(LINE,*) 'Time:',TIME_CURRENT,' Elapsed:',TIME_ELAPSED
c      CALL MSGDOC(MDOC,LINE)
c      WRITE(*,*) 'Time4:',TIME_CURRENT,' Elapsed:',TIME_ELAPSED
c ---

      RETURN
      END

      SUBROUTINE TRP_MULTD(NX,NY,POOL,POOLA,POOLB
     *    ,MSG_P,MSG_A,PACK_SRCH
     *    ,RMAX,RMIN,DMAX,DMIN)
C ---------------------------------------------------------------
      REAL POOL(*),POOLA(*),POOLB(*)
      CHARACTER MSG_A*1,MSG_P*1,PACK_SRCH*1
C ----------------------------------------------------------------
      NXY = NX*NY
      DO     J=1,NY
        IY  = J-1
        IND = IY*NX
        DO     I=1,NX
          IX   = I-1
          INDX = IND+I

          R    = POOL(INDX)

          IF(MSG_P.EQ.'Y') THEN

            IF(R.GE.RMAX) RMAX=R
            IF(R.LE.RMIN) RMIN=R
  
          ENDIF

          IF(MSG_A.EQ.'M') THEN

C 3.12.2002
C            IF(R.GT.1.0 E-10)THEN
C              RR = ALOG(R)
C            ELSE
C              RR =-1.0 E30
C            ENDIF
C
C           POOLA(INDX) = POOLA(INDX) + RR
C 3.12.2002

            IF(MSG_P.EQ.'Y') THEN
              IF(R.GT.0.0) THEN
                RR = R
                IF(RR.GT.0.75) RR = 0.75                 
                POOLA(INDX) = RR*1.3333
                POOLB(INDX) = POOLA(INDX)
              ELSE
                POOLA(INDX) = 0.0
              ENDIF
            ELSE
              POOLA(INDX) = POOLA(INDX)*R
              PACK_SRCH   = 'Y'
            ENDIF

          ELSE

            POOLA(INDX) = POOLA(INDX) + R

          ENDIF

          IF(POOLA(INDX).GE.DMAX) DMAX=POOLA(INDX)
          IF(POOLA(INDX).LE.DMIN) DMIN=POOLA(INDX)
 
        ENDDO
      ENDDO
      RETURN
      END

      SUBROUTINE TRP_NORMD(NX,NY,POOLA,NUMBF,MSG_N)
C ----------------------------------------------------------------
      REAL POOLA(*)
      CHARACTER MSG_N*1
C ----------------------------------------------------------------
      IF(NUMBF.EQ.  0) RETURN
      IF(MSG_N.EQ.'A') RETURN
      NXY = NX*NY

      DO     J=1,NY
        IY  = J-1
        IND = IY*NX
        DO     I=1,NX
          IX   = I-1
          INDX = IND+I
          R    = POOLA(INDX)
          IF(R.GT.-1.0E20)THEN
            RR = R/NUMBF
            R  = EXP(RR)
          ELSE
            R = 0.0
          ENDIF
          POOLA(INDX) = R
        ENDDO
      ENDDO

      RETURN
      END

      SUBROUTINE TRP_GNR_P1(NGEN,IH,IK,IL,FA,FB)
C -------------------------------------------
C     generate indexes  for P1
C -------------------------------------------
      INTEGER   IH(*),IK(*),IL(*)
      REAL      FA(*),FB(*)
C -------------------------------------------
      NGEN = 0
      IH1  = IH(1)
      IK1  = IK(1)
      IL1  = IL(1)
      FB1  = FB(1)
      FAA  = FA(1)
      JH   = IH1
      JK   = IK1
      JL   = IL1
      FBB  = FB1
      IT   = 0.0
      IF(JH.LT.0) THEN
        JH  =-JH
        JK  =-JK
        JL  =-JL
        IT  =-IT
        FBB =-FBB
      ENDIF
      NGEN     = NGEN+1
      IH(NGEN) = JH
      IK(NGEN) = JK
      IL(NGEN) = JL
      FA(NGEN) = FAA
      FB(NGEN) = FBB
      IF(JH.EQ.0) THEN
        NGEN     = NGEN+1
        IH(NGEN) = JH
        IK(NGEN) =-JK
        IL(NGEN) =-JL
        FA(NGEN) = FA(NGEN-1)
        FB(NGEN) =-FB(NGEN-1)
      ENDIF
      RETURN
      END

      SUBROUTINE TRP_PSRCH_INI(MDOC,DIST_LIM,SPEC,RESOL
     * ,A,B,C,ALPHA,BETA,GAMMA
     * ,DLIM,TTT,NORIG,SOR,IPRORG,NSYM,ISYM,IPRSYM,IERR)
C ---------------------------------------
      INTEGER*2 ISYM(5,3,IPRSYM)
      REAL      DIST_LIM,RESOL,DLIM
      CHARACTER TTT*80,SPEC*1
C --
      COMMON/COM_TRP_SRPK/ FRTOCR,CRTOFR,NX,NY,NZ,IZMIN,IZMAX,
     *                 DELA,DELG,DELB,TYPE
      REAL      FRTOCR(3,3),CRTOFR(3,3)
      REAL      SOR(3,*)
      CHARACTER TYPE*1
C ---
      CHARACTER LINE*80,TYPE2*1
C --------------------------------------
      IERR = 0
      MD   =-ABS(MDOC)-10
      M    = 99
C --
      IF(SPEC.EQ.'n') SPEC='N'
      IF(SPEC.EQ.'p') SPEC='P'
      IF(SPEC.EQ.'a') SPEC='A'
      IF(SPEC.EQ.'s') SPEC='S'
      IF(SPEC.NE.'N'.AND.SPEC.NE.'P'.AND.SPEC.NE.'A'.AND.
     *                                        SPEC.NE.'S') SPEC='Y'
C ---
      TYPE = 'D'
      IF(TTT(1:4).EQ.'PATT')  TYPE='P'
      TYPE2 = TYPE
      IF(TTT(5:8).NE.'REAL'.AND.
     *  (TTT(9:12).EQ.'SPHR'.OR.TTT(9:12).EQ.'GAUS')) THEN
        TYPE  = 'H'
        TYPE2 = 'H'
      ENDIF
      IF(TTT(5:8).NE.'REAL'.AND.TTT(9:12).EQ.'TRPC') THEN
        TYPE  = 'T'
        TYPE2 = 'H'
      ENDIF
      IF(TTT(5:8).NE.'REAL'.AND.TTT(9:12).EQ.'TRP2') THEN
        TYPE  = 'T'
        TYPE2 = 'T'
      ENDIF
C ---
      CALL CALC_ORIG_AV(MDOC,NORIG,SOR,IPRORG
     *   ,NSYM,ISYM,IPRSYM,IERR)
C ---
      CALL FRORTH(A,B,C,ALPHA,BETA,GAMMA,FRTOCR,CRTOFR,IERR)

      IF(DIST_LIM.LE.0.0) THEN
        DIST_LIM = RESOL/2.0
        IF(TTT(5:8).EQ.'REAL') DIST_LIM = RESOL/3.0
      ENDIF

      IF(TYPE .EQ.'D') NORIG=1
      IF(TYPE .EQ.'P') NORIG=1
      IF(TYPE2.EQ.'T') NORIG=1
      IF(TTT(5:8).EQ.'PACK') NORIG=1

C ----------------------
C      IF(ALEVEL.LE.0.0) ALEVEL=1.0
C      DLIM = RMS*ALEVEL
C      WRITE(LINE,'('' limit Dens-MIN,D-RMS :'',2G14.4)') DLIM,RMS     
C      CALL MSGDOC(MD,LINE)
      DLIM = 0.0
      WRITE(LINE,'('' SPEC : '',A1)') SPEC     
      CALL MSGDOC(MD,LINE)
      WRITE(LINE,'('' distance limit :'',G14.4,'' / angstrom/'')') 
     *  DIST_LIM     
      CALL MSGDOC(MD,LINE)

C ----------------------
      RETURN
      END

      SUBROUTINE TRP_PKSRCH(MDOC,DIST_LIM,DLIM,SPEC,SOR,NORIG
     *  ,NPEAK,NPEAK_MAX,IZ,ISECT,DRMS,DRMS2
     *  ,POOLA,POOLB,POOL,POOLP,NCRES,PACK_SRCH
     *  ,NSYM,ISYM,IPRSYM,RESULT,IPRMAX,IPRROW,IERR)
C -------------------------------------------------------
      REAL      RESULT(IPRMAX,IPRROW)
      REAL      POOL(NCRES,3)
      REAL      POOLP(NCRES,3)
      REAL      POOLA(NCRES)
      REAL      POOLB(NCRES)
      INTEGER*2 ISYM(5,3,IPRSYM)
      CHARACTER SPEC*1,PACK_SRCH*1
      REAL      DIST_LIM
C -------------------------------------------------------------
C ---
      COMMON/COM_TRP_SRPK/ FRTOCR,CRTOFR,NX,NY,NZ,IZMIN,IZMAX,
     *                 DELA,DELG,DELB,TYPE
      REAL      FRTOCR(3,3),CRTOFR(3,3)
      CHARACTER TYPE*1
C ---
C --------------------------------------------------------------
      CHARACTER TYPE_S*1
C --------------------------------------------------------------
      REAL      SOR(3,*)
C ----------------------
      REAL        XF(3),XC(3)
      INTEGER     ISECT(3)
      CHARACTER   LINE*80
C --------------------------------------------------------------
      PI   = 4.0*ATAN(1.0)
      IERR = 0
      MD   =-ABS(MDOC)-10
      M    = 99
C --------------------------------
      ITR   = 0
      NNX   = NX
      NNY   = NY
      IDEL  = 1
      NXY = NX*NY
      IF(NXY.GT.NCRES) THEN
        CALL MSGERR(MDOC,
     *  ' ERROR: trpack: not memory for 3 sections of X-Y')
        IERR = 1
        RETURN
      ENDIF
C ------------
      IF(IZ.EQ.IZMIN) THEN
        DRMS  = 0.0
        DRMS2 = 0.0
        NPEAK = 0

        DO I=1,3
        DO J=1,NXY
          POOL(J,I) =-1.E30
          POOLP(J,I)=-1.E30
        ENDDO
        ENDDO

        ISECT(1) = 1
        ISECT(2) = 2
        ISECT(3) = 3
        DO I=1,NXY
          D     = POOLA(I)
          DRMS  = DRMS  + D
          DRMS2 = DRMS2 + D*D
          POOL(I,2) = D
          POOLP(I,2) = POOLB(I)
        ENDDO
        RETURN
      ENDIF
C -------------------------------------------------------------
C///  DO     IZ=IZMIN+1,IZMAX+1
        IPP = ISECT(1)        
        IP  = ISECT(2)        
        IPN = ISECT(3)

        IZ1 = IZ-1
        Z   = IZ1/FLOAT(NZ)
        IF(IZ.LE.IZMAX) THEN        
          DO I=1,NXY
            D     = POOLA(I)
            DRMS  = DRMS  + D
            DRMS2 = DRMS2 + D*D
            POOL(I,IPN) = D
            POOLP(I,IPN)= POOLB(I)
          ENDDO
        ELSE
          DO J=1,NXY
            POOL(J,IPN) =-1.0E30
            POOLP(J,IPN)=-1.0E30
          ENDDO
        ENDIF

        IXCONST=0
        DO     IY=1,NNY
          IND0 = (IY-1)*NX
          DO     IX=1,NNX
            IND = IND0+IX
            D = POOL(IND,IP )
            P = POOLP(IND,IP )
            IF(IX.EQ.1) THEN
              DOLD=D
              POLD=P
            ELSE
              IF(D.NE.DOLD) THEN
                IXCONST=0
                GO TO 400
              ENDIF
            ENDIF
          ENDDO
          IXCONST=1
        ENDDO
  400   CONTINUE


        IYCONST=0
        DO     IX=1,NNX
          DO     IY=1,NNY
            IND0 = (IY-1)*NX
            IND  = IND0+IX
            D    = POOL(IND,IP )
            P    = POOLP(IND,IP )
            IF(IY.EQ.1) THEN
              DOLD=D
              POLD=P
            ELSE
              IF(D.NE.DOLD) THEN
                IYCONST=0
                GO TO 410
              ENDIF
            ENDIF
          ENDDO
          IYCONST=1
        ENDDO
  410   CONTINUE

        NNNY=NNY
        IF(IYCONST.EQ.1) NNNY=1
        DO     IY=1,NNNY
          Y    = (IY-1)/FLOAT(NY)
          IND0 = (IY-1)*NX

          NNNX=NNX
          IF(IXCONST.EQ.1) NNNX=1
          DO     IX=1,NNNX
            X   = (IX-1)/FLOAT(NX)
            IND = IND0+IX

            D  = POOL(IND,IP )
            DP = POOL(IND,IPP)
            DN = POOL(IND,IPN)
            P  = POOLP(IND,IP )
            PP = POOLP(IND,IPP)
            PN = POOLP(IND,IPN)

            IF(D.GT.DLIM) THEN
              IF(D.GT.DP) THEN
                IF(D.GE.DN) THEN
                  DO JY=-IDEL,IDEL
                    JYY=IY+JY
                    IF(JYY.LT.1) THEN
                      IF(ITR.EQ.0) THEN
                        JYY=JYY+NY
                      ELSE
                        GO TO 300
                      ENDIF
                    ENDIF
                    IF(JYY.GT.NY) THEN
                      IF(ITR.EQ.0) THEN
                        JYY=JYY-NY
                      ELSE
                        GO TO 300
                      ENDIF
                    ENDIF
                    JND0=(JYY-1)*NX
                    DO JX=-IDEL,IDEL
                      JXX=IX+JX
                      IF(JXX.LT.1) THEN
                        IF(ITR.EQ.0) THEN
                          JXX=JXX+NX
                        ELSE
                          GO TO 200
                        ENDIF
                      ENDIF
                      IF(JXX.GT.NX) THEN
                        IF(ITR.EQ.0) THEN
                          JXX=JXX-NX
                        ELSE
                          GO TO 200
                        ENDIF
                      ENDIF
                      IF(JXX.NE.IX.OR.JYY.NE.IY) THEN
                        IF(TYPE.NE.'R'.OR.IZ1.NE.0.OR.JX.NE.-JY)THEN 
                        JND = JND0+JXX
                        DD  = POOL(JND,IP)
                        PDD = POOLP(JND,IP)
                        IF(DD.GT.D) GO TO 100
                        ENDIF
                      ENDIF
 200                  CONTINUE
                    ENDDO
 300                CONTINUE
                  ENDDO
C                 DRMS = D/RMS
                  RMS  = 0.0
                  IX1  = IX-1
                  IY1  = IY-1

                  TYPE_S = TYPE
                  IF(TYPE_S.EQ.'H') TYPE_S = 'P'
                  IF(SPEC  .EQ.'P') TYPE_S = 'P'

                  IF(SPEC.EQ.'N'.OR.SPEC.EQ.'P') THEN
                    CALL TRP_DEF_SPEC_POS(IX1,IY1,IZ1,DIST_LIM
     *              ,TYPE_S,ISPEC,SOR,NORIG,NSYM,ISYM,IPRSYM,IERR)
                    IF(ISPEC.NE.0) GO TO 100
                  ENDIF
                  
                  IF(IX.GT.1.AND.IX.LT.NX) THEN
                    KIND0 = IY1*NX
                    KIND  = KIND0+IX1
                    D1    = POOL(KIND,IP)
                    D2    = D
                    KIND0 = IY1*NX
                    KIND  = KIND0+(IX+1)
                    D3    = POOL(KIND,IP)
                    CALL TRP_PARAB(D1,D2,D3,X_PR,C_PR,D_PR)
                  ELSE
                    X_PR = 0.0
                    C_PR = 0.0
                    D_PR = D
                  ENDIF
                  FX = FLOAT(IX1)+X_PR

                  IF(IY.GT.1.AND.IY.LT.NY) THEN
                    KIND = (IY1-1)*NX+IX
                    D1   = POOL(KIND,IP)
                    D2   = D
                    KIND = (IY1+1)*NX+IX
                    D3   = POOL(KIND,IP)
                    CALL TRP_PARAB(D1,D2,D3,X_PR,C_PR,D_PR)
                  ELSE
                    X_PR = 0.0
                    C_PR = 0.0
                    D_PR = D
                  ENDIF
                  FY = FLOAT(IY1)+X_PR

                  IF(IZ1.GT.IZMIN.AND.IZ1.LT.IZMAX) THEN
                    D1 = DP
                    D2 = D
                    D3 = DN
                    CALL TRP_PARAB(D1,D2,D3,X_PR,C_PR,D_PR)
                  ELSE
                    X_PR = 0.0
                    C_PR = 0.0
                    D_PR = D
                  ENDIF
                  FZ = FLOAT(IZ1)+X_PR

                  T_DIST_LIM = DIST_LIM
                  IF(SPEC.EQ.'A') THEN
                    FX = FLOAT(IX1)
                    FY = FLOAT(IY1)                  
                    FZ = FLOAT(IZ1)
                    T_DIST_LIM =-1.0
                  ENDIF

                  PF =-1.0 
                  IF(PACK_SRCH.EQ.'Y') PF = P

                  CALL TRP_PSTORE(MDOC,NPEAK,NPEAK_MAX,D,RMS,PF
     *            ,IX1,IY1,IZ1,T_DIST_LIM,FX,FY,FZ
     *            ,RESULT(1,1),RESULT(1,2),RESULT(1,3),RESULT(1,4)       
     *            ,RESULT(1,5),RESULT(1,6),RESULT(1,7),RESULT(1,8)       
     *            ,RESULT(1,9),RESULT(1,22),IPRMAX,IPRROW
     *            ,SOR,NORIG,NSYM,ISYM,IPRSYM,TYPE,IERR)

 100              CONTINUE
                ENDIF
              ENDIF
            ENDIF
          ENDDO
        ENDDO

        ITEMP    = ISECT(1)
        ISECT(1) = ISECT(2)
        ISECT(2) = ISECT(3)
        ISECT(3) = ITEMP
C///  ENDDO
C ----------------------
      RETURN
      END

      SUBROUTINE TRP_PSRCH_FIN(MDOC,NPEAK,NPEAK_MAX,SPEC,FRTOCR,DRMS
     *            ,ISYM,IPRSYM,RESULT,IPRMAX,IPRROW,IERR)
C -------------------------------------------------------
      REAL      RESULT(IPRMAX,IPRROW)
      INTEGER*2 ISYM(5,3,IPRSYM)
      CHARACTER SPEC*1
C -------------------------------------------------------------
      REAL      FRTOCR(3,3)
C ----------------------
      REAL        XF(3),XC(3),RINDEX
      INTEGER     INDEX
      CHARACTER   LINE*256
      EQUIVALENCE (RINDEX,INDEX)
C --------------------------------------------------------------
      PI   = 4.0*ATAN(1.0)
      IERR = 0
      MD   =-ABS(MDOC)-10
      M    = 99
C --------------------------------
      NPMAXP = NPEAK_MAX
      IF(NPMAXP.LE.0) NPMAX = 20
      CALL TRP_RES_PRINT(MDOC,NPEAK,NPMAXP,DRMS
     *            ,RESULT(1,1),RESULT(1,2),RESULT(1,3),RESULT(1,4)       
     *            ,RESULT(1,5),RESULT(1,6),RESULT(1,7),RESULT(1,8)       
     *            ,RESULT(1,9),RESULT(1,10),RESULT(1,11),RESULT(1,12)    
     *            ,RESULT(1,22),SPEC,IPRMAX,IPRROW
     *            ,NSYM,ISYM,IPRSYM,IERR)
C ----------------------
c                                        1      2     3      4
c      SUBROUTINE RES_PRINT(MDOC,NPEAK,IXPEAK,IYPEAK,IZPEAK,PEAK
c           5    6   7   8   9
c     *  ,SIGPK,DXA,DYB,DZG,INDPK
      IF(NPEAK.GT.0) THEN

        DO I=1,NPEAK
          RINDEX       = RESULT(I,9)
          RESULT(I,10) = RESULT(INDEX,1)
          RESULT(I,11) = RESULT(INDEX,2)
          RESULT(I,12) = RESULT(INDEX,3)
          RESULT(I,22) = RESULT(INDEX,22)
        ENDDO
        DO I=1,NPEAK
          RINDEX      = RESULT(I,10)
          RESULT(I,1) = INDEX
          RINDEX      = RESULT(I,11)
          RESULT(I,2) = INDEX
          RINDEX      = RESULT(I,12)
          RESULT(I,3) = INDEX
        ENDDO

        DO I=1,NPEAK
          RINDEX       = RESULT(I,9)
          RESULT(I,10) = RESULT(INDEX,4)
          RESULT(I,11) = RESULT(INDEX,5)
        ENDDO
        DO I=1,NPEAK
          RESULT(I,4) = RESULT(I,10)
          RESULT(I,5) = RESULT(I,11)
        ENDDO

        DO I=1,NPEAK
          RINDEX       = RESULT(I,9)
          RESULT(I,10) = RESULT(INDEX,6)
          RESULT(I,11) = RESULT(INDEX,7)
          RESULT(I,12) = RESULT(INDEX,8)
        ENDDO
        DO I=1,NPEAK
          RESULT(I,6)  = RESULT(I,10)
          RESULT(I,7)  = RESULT(I,11)
          RESULT(I,8)  = RESULT(I,12)
        ENDDO

        RESULT(1,12) = NPEAK

        DO I=1,NPEAK
          XF(1)        = RESULT(I,6)
          XF(2)        = RESULT(I,7)
          XF(3)        = RESULT(I,8)
          RESULT(I,9)  = RESULT(I,6)
          RESULT(I,10) = RESULT(I,7)
          RESULT(I,11) = RESULT(I,8)
          CALL MVMULT(FRTOCR,XF,XC)
          RESULT(I,6) = XC(1)
          RESULT(I,7) = XC(2)
          RESULT(I,8) = XC(3)

        ENDDO
      ELSE
        RESULT(1,12) = 0
        IERR = 0
      ENDIF
      RETURN
      END


      SUBROUTINE TRP_PSTORE(MDOC,NPEAK,NPEAK_MAX,D,RMS,PF
     *   ,IX,IY,IZ,DIST_LIM,FX,FY,FZ
     *   ,IXPEAK,IYPEAK,IZPEAK,PEAK
     *   ,SIGPK,DM1,DM2,DM3,INDPK,PACK
     *   ,IPRMAX,IPRROW
     *   ,SOR,NORIG,NSYM,ISYM,IPRSYM,TYPE,IERR)
C ---------------------------------------------------------------
      INTEGER*2 ISYM(5,3,IPRSYM)
      REAL      SOR(3,*)
      INTEGER   IXPEAK(*),IYPEAK(*),IZPEAK(*),INDPK(*)
      REAL      PEAK(*),SIGPK(*),DM1(*),DM2(*),DM3(*),PACK(*)
      CHARACTER TYPE*1       
C ---------------------------------------------------------------

      NPMAX = NPEAK_MAX 
      IF(NPMAX.LE.0.OR.NPMAX.GT.IPRMAX) NPMAX = IPRMAX

      IF(NPEAK.GT.0) THEN      

        IF(NPEAK.GE.NPMAX) THEN
          INDM=INDPK(NPMAX)
          IF(PEAK(INDM).GE.D) THEN
            RETURN
          ENDIF
        ENDIF

        DO I=1,NPEAK
          IND  = INDPK(I)
C         DIST = 1000.0
          JX   = IXPEAK(IND)
          JY   = IYPEAK(IND)
          JZ   = IZPEAK(IND)
          FJX  = DM1(IND)
          FJY  = DM2(IND)
          FJZ  = DM3(IND)
          SIGI = SIGPK(IND)         
          
          IF(DIST_LIM.GE.0.0) THEN

c          WRITE(*,*) '>->',FX,FY,FZ,NSYM
c          WRITE(*,*) '>->',FJX,FJY,FJZ

            CALL TRP_CALC_DST(IX,IY,IZ,JX,JY,JZ
     *      ,FX,FY,FZ,FJX,FJY,FJZ,DIST
     *      ,SOR,NORIG,NSYM,ISYM,IPRSYM,IERR)

          ELSE
            DIST = 0.0
          ENDIF

c          WRITE(*,*) '>>>',d,NPEAK,DIST,DIST_LIM

          IF(DIST.LE.DIST_LIM) THEN
            IF(PEAK(IND).GE.D) THEN
              RETURN
            ENDIF
            PEAK(IND)   = D
            PACK(IND)   = PF
            IXPEAK(IND) = IX
            IYPEAK(IND) = IY
            IZPEAK(IND) = IZ
            DM1   (IND) = FX
            DM2   (IND) = FY
            DM3   (IND) = FZ
            SIGPK (IND) = RMS
            IF(I.EQ.1) THEN
              RETURN
            ENDIF
C           SORT FROM I TO 1           
            DO J=I,2,-1
              IND1 = INDPK(J )
              IND2 = INDPK(J-1)
              IF(PEAK(IND1).GT.PEAK(IND2)) THEN
                IT         = INDPK(J)
                INDPK(J)   = INDPK(J-1)
                INDPK(J-1) = IT
              ELSE
                GO TO 200
              ENDIF
            ENDDO
 200        CONTINUE
            RETURN
          ELSE
C            IF(TYPE.EQ.'H') THEN
C              DEL = ABS(SIGI-RMS)
C              IF(DEL.LT.0.001) RETURN
C            ENDIF
          ENDIF 
        ENDDO
      ENDIF   
 400  CONTINUE
      IF(NPEAK.LT.NPMAX) THEN
        NPEAK        = NPEAK+1
        INDPK(NPEAK) = NPEAK
        IND          = NPEAK
        PEAK(IND)    = D
        PACK(IND)    = PF
        IXPEAK(IND)  = IX
        IYPEAK(IND)  = IY
        IZPEAK(IND)  = IZ
        DM1   (IND)  = FX
        DM2   (IND)  = FY
        DM3   (IND)  = FZ
        SIGPK (IND)  = RMS
      ELSE
        IND = INDPK(NPMAX)
        IF(PEAK(IND).GE.D) THEN
          RETURN
        ENDIF
        PEAK  (IND) = D
        PACK(IND)   = PF
        IXPEAK(IND) = IX
        IYPEAK(IND) = IY
        IZPEAK(IND) = IZ
        DM1   (IND) = FX
        DM2   (IND) = FY
        DM3   (IND) = FZ
        SIGPK (IND) = RMS
      ENDIF
      IF(NPEAK.GT.1) THEN
        DO I=NPEAK,2,-1
          IND1 = INDPK(I )
          IND2 = INDPK(I-1)
          IF(PEAK(IND1).GT.PEAK(IND2)) THEN
            IT         = INDPK(I)
            INDPK(I)   = INDPK(I-1)
            INDPK(I-1) = IT
          ELSE
            GO TO 100
          ENDIF
        ENDDO
 100    CONTINUE
      ENDIF
      RETURN
      END

      SUBROUTINE TRP_RES_PRINT(MDOC,NPEAK,NPMAX,DRMS
     *  ,IXPEAK,IYPEAK,IZPEAK,PEAK
     *  ,SIGPK,DXA,DYB,DZG,INDPK,DM1,DM2,DM3
     *  ,PF,SPEC,IPRMAX,IPRROW,NSYM,ISYM,IPRSYM,IERR)
C ---------------------------------------------------------------
      INTEGER   IXPEAK(*),IYPEAK(*),IZPEAK(*),INDPK(*)
      REAL      PEAK(*),SIGPK(*),DXA(*),DYB(*),DZG(*)
      REAL      DM1(*),DM2(*),DM3(*),PF(*)
      INTEGER*2 ISYM(5,3,IPRSYM)       
C ---------------------------------------------------------------
C --
      COMMON/COM_TRP_SRPK/ FRTOCR,CRTOFR,NX,NY,NZ,IZMIN,IZMAX,
     *                 DELA,DELG,DELB,TYPE
      REAL      FRTOCR(3,3),CRTOFR(3,3)
      CHARACTER TYPE*1
C ---
      CHARACTER SPEC*1
C ---
      REAL    XF(3),XC(3)
C -------------------------------------------------------------
      CHARACTER LINE*256
C ---------------------------------------------------------------
      MD =-ABS(MDOC)-10
      PI = 4.0*ATAN(1.0)
C ---
      WRITE(LINE,'('' Number of peaks :'',I8)') NPEAK 
      CALL MSGDOC(MD,LINE)

      NPEAK_PRT = NPEAK
      IF(NPEAK_PRT.GT.NPMAX.AND.NPMAX.GT.0) NPEAK_PRT = NPMAX


      IF(NPEAK_PRT.GT.0) THEN      

        CALL MSGDOC(MDOC,
     * '      IX  IY  IZ  Xfrac  Yfrac  Zfrac  Xort   Yort    Zort   Den
     *s Dens/sigma')

        DO I=1,NPEAK_PRT
          IND = INDPK (I)
          IX  = IXPEAK(IND)
          IY  = IYPEAK(IND)
          IZ  = IZPEAK(IND)
          FX  = DXA   (IND)
          FY  = DYB   (IND)
          FZ  = DZG   (IND)
          PK  = PEAK  (IND)
          SIG = SIGPK (IND)
          IF(DRMS.GT.0.000001) THEN
            SIG = PK/DRMS
            SIGPK (IND) = SIG
          ENDIF

          XF(1) = FX/FLOAT(NX)
          XF(2) = FY/FLOAT(NY)
          XF(3) = FZ/FLOAT(NZ)
C            XF(1)=IX/FLOAT(NX)
C            XF(2)=IY/FLOAT(NY)
C            XF(3)=IZ/FLOAT(NZ)
          DXA(IND) = XF(1)
          DYB(IND) = XF(2)
          DZG(IND) = XF(3)
          CALL MVMULT(FRTOCR,XF,XC)

          WRITE(LINE,100) I,IX,IY,IZ,XF(1),XF(2),XF(3)
     *    ,XC(1),XC(2),XC(3)
     *    ,PK,SIG,PF(IND)
 100      FORMAT(4I4,3F7.3,3F7.2,G12.4,F6.2,F6.2)
          CALL MSGDOC(MDOC,LINE)
        ENDDO
      ENDIF
      RETURN
      END

      SUBROUTINE TRP_CALC_DST(IX,IY,IZ,JX,JY,JZ
     *   ,FIX,FIY,FIZ,FJX,FJY,FJZ,DIST
     *   ,SOR,NORIG,NSYM,ISYM,IPRSYM,IERR)
C -------------------------------------------------------------
      INTEGER*2 ISYM(5,3,IPRSYM)
      REAL      SOR(3,*)
C --
      COMMON/COM_TRP_SRPK/ FRTOCR,CRTOFR,NX,NY,NZ,IZMIN,IZMAX,
     *                 DELA,DELG,DELB,TYPE
      REAL      FRTOCR(3,3),CRTOFR(3,3)
      CHARACTER TYPE*1
C ---
      REAL X(3),Y(3),Z(3),XX(3)
      REAL YY(3),W(3),WW(3)
C -------------------------------------------------------------

c        WRITE(*,*) FRTOCR(1,1),FRTOCR(1,2),FRTOCR(1,3)
c        WRITE(*,*) FRTOCR(2,1),FRTOCR(2,2),FRTOCR(2,3)
c        WRITE(*,*) FRTOCR(3,1),FRTOCR(3,2),FRTOCR(3,3)


      DIST = 1.E20

C        YY(1)=FLOAT(IX)/NX
C        YY(2)=FLOAT(IY)/NY
C        YY(3)=FLOAT(IZ)/NZ
C        WW(1)=FLOAT(JX)/NX
C        WW(2)=FLOAT(JY)/NY
C        WW(3)=FLOAT(JZ)/NZ

        YY(1) = FIX/NX
        YY(2) = FIY/NY
        YY(3) = FIZ/NZ
        WW(1) = FJX/NX
        WW(2) = FJY/NY
        WW(3) = FJZ/NZ

        N  = 1
        NN = NSYM

        INVERSI=1
C       IF(TYPE.EQ.'P') INVERSI=2
c        IF(TYPE.EQ.'P') INVERSI=1
c        IF(TYPE.EQ.'H') INVERSI=1

c            WRITE(*,*) NSYM,TYPE

        INVERSJ=1
        IF(TYPE.EQ.'P') INVERSJ=2
        IF(TYPE.EQ.'H') INVERSJ=2

        ITRS=2
        ITRF=2
        IF(TYPE.EQ.'P') THEN
          ITRS=1
          ITRF=1
        ENDIF

        JTRS=2
        JTRF=2
        IF(TYPE.EQ.'P') THEN
          JTRS=1
          JTRF=1
        ENDIF
  
        DO IS=1,N


c            WRITE(*,*) '>>>',INVERSI,WW(1),WW(2),WW(3)
c            I = 1
c            WRITE(*,*) '>>>--//////',IS,I

          DO I=1,INVERSI

c            WRITE(*,*) '>>>--//',I

            IF(I.EQ.2) THEN
              W(1) =-WW(1)
              W(2) =-WW(2)
              W(3) =-WW(3)
            ELSE
              W(1) = WW(1)
              W(2) = WW(2)
              W(3) = WW(3)
            ENDIF

c            WRITE(*,*) '->>>',W(1),W(2),W(3)
c         WRITE(*,*) '->>>',ISYM(1,1,IS),ISYM(2,1,IS),ISYM(3,1,IS)

            Z(1)=W(1)*ISYM(1,1,IS)+W(2)*ISYM(2,1,IS)+W(3)*ISYM(3,1,IS)
            TTX= REAL(ISYM(4,1,IS))/REAL(ISYM(5,1,IS))
            Z(2)=W(1)*ISYM(1,2,IS)+W(2)*ISYM(2,2,IS)+W(3)*ISYM(3,2,IS)
            TTY= REAL(ISYM(4,2,IS))/REAL(ISYM(5,2,IS))
            Z(3)=W(1)*ISYM(1,3,IS)+W(2)*ISYM(2,3,IS)+W(3)*ISYM(3,3,IS)
            TTZ= REAL(ISYM(4,3,IS))/REAL(ISYM(5,3,IS))

c            WRITE(*,*) ITRS,ITRF,TYPE

            DO ITR=ITRS,ITRF

              IF(ITR.EQ.2) THEN
                Z(1)=Z(1)+TTX
                Z(2)=Z(2)+TTY
                Z(3)=Z(3)+TTZ
              ENDIF

              DO     JS=1,NN

                DO J=1,INVERSJ
                  DO IOR=1,NORIG
                  
                    IF(J.EQ.2) THEN
                      Y(1)=-YY(1)+SOR(1,IOR)
                      Y(2)=-YY(2)+SOR(2,IOR)
                      Y(3)=-YY(3)+SOR(3,IOR)
                    ELSE
                      Y(1)=YY(1)+SOR(1,IOR)
                      Y(2)=YY(2)+SOR(2,IOR)
                      Y(3)=YY(3)+SOR(3,IOR)
                    ENDIF

          X1= Y(1)*ISYM(1,1,JS)+Y(2)*ISYM(2,1,JS)+Y(3)*ISYM(3,1,JS)
          TX=REAL(ISYM(4,1,JS))/REAL(ISYM(5,1,JS))
          X2= Y(1)*ISYM(1,2,JS)+Y(2)*ISYM(2,2,JS)+Y(3)*ISYM(3,2,JS)
          TY=REAL(ISYM(4,2,JS))/REAL(ISYM(5,2,JS))
          X3= Y(1)*ISYM(1,3,JS)+Y(2)*ISYM(2,3,JS)+Y(3)*ISYM(3,3,JS)
          TZ=REAL(ISYM(4,3,JS))/REAL(ISYM(5,3,JS))



                    DO JTR=JTRS,JTRF

                      IF(JTR.EQ.2) THEN
                        X1=X1+TX
                        X2=X2+TY
                        X3=X3+TZ
                      ENDIF

                      XX(1)=X1-Z(1)
                      XX(2)=X2-Z(2)
                      XX(3)=X3-Z(3)

 10       CONTINUE
          IF(XX(1).GE.0.5)THEN
            XX(1)=XX(1)-1.0
            GO TO 10
          ENDIF
 20       CONTINUE
          IF(XX(1).LT.-0.5)THEN
            XX(1)=XX(1)+1.0
            GO TO 20
          ENDIF
 30       CONTINUE
          IF(XX(2).GE.0.5)THEN
            XX(2)=XX(2)-1.0
            GO TO 30
          ENDIF
 40       CONTINUE
          IF(XX(2).LT.-0.5)THEN
            XX(2)=XX(2)+1.0
            GO TO 40
          ENDIF
 50       CONTINUE
          IF(XX(3).GE.0.5)THEN
            XX(3)=XX(3)-1.0
            GO TO 50
          ENDIF
 60       CONTINUE
          IF(XX(3).LT.-0.5)THEN
            XX(3)=XX(3)+1.0
            GO TO 60
          ENDIF

                      CALL MVMULT(FRTOCR,XX,X)
                      D2=X(1)*X(1)+X(2)*X(2)+X(3)*X(3)
                      IF(D2.LT.DIST) DIST=D2

                    ENDDO
C JTR
                  ENDDO
C ORIGINE
                ENDDO
C J
              ENDDO
C JS

            ENDDO
C ITR
          ENDDO
C I
        ENDDO
C IS
        DIST=SQRT(DIST)

      RETURN
      END

      SUBROUTINE TRP_DEF_SPEC_POS(IX,IY,IZ,DIST_LIM,MODE,ISPEC
     *   ,SOR,NORIG,NSYM,ISYM,IPRSYM,IERR)
C -------------------------------------------------------------
      INTEGER*2 ISYM(5,3,IPRSYM)
      REAL      SOR(3,*)
C --
      COMMON/COM_TRP_SRPK/ FRTOCR,CRTOFR,NX,NY,NZ,IZMIN,IZMAX,
     *                 DELA,DELG,DELB,TYPE
      REAL      FRTOCR(3,3),CRTOFR(3,3)
      CHARACTER TYPE*1
C ---
      CHARACTER MODE*1
C ---
      REAL X(3),Y(3),Z(3),XX(3),AM1(3,3),AM2(3,3),AM3(3,3),SM(3,3)
      REAL AM4(3,3),YY(3),W(3),WW(3)
C -------------------------------------------------------------
      CALL CHECK_REF(NSYM,ISYM,IFX,IFY,IFZ)             

      DIST_LIM2 = DIST_LIM*DIST_LIM

      DIST  = 1.E20
      ISPEC = 0


        YY(1) = FLOAT(IX)/NX
        YY(2) = FLOAT(IY)/NY
        YY(3) = FLOAT(IZ)/NZ


        WW(1) = YY(1)
        WW(2) = YY(2)
        WW(3) = YY(3)

        N  = 1
        NN = NSYM

        INVERSI = 1

        INVERSJ = 1

c molrep 
        IF(MODE.EQ.'P') INVERSJ = 2
C
        IF(MODE.EQ.'H') INVERSJ = 2

        ITRS = 2
        ITRF = 2
        IF(MODE.EQ.'P') THEN
          ITRS = 1
          ITRF = 1
        ENDIF

        JTRS = 2
        JTRF = 2
        IF(MODE.EQ.'P') THEN
          JTRS = 1
          JTRF = 1
        ENDIF
  
        DO IS=1,N

          DO I=1,INVERSI
            IF(I.EQ.2) THEN
              W(1) =-WW(1)
              W(2) =-WW(2)
              W(3) =-WW(3)
            ELSE
              W(1) = WW(1)
              W(2) = WW(2)
              W(3) = WW(3)
            ENDIF

            Z(1)=W(1)*ISYM(1,1,IS)+W(2)*ISYM(2,1,IS)+W(3)*ISYM(3,1,IS)
            TTX= REAL(ISYM(4,1,IS))/REAL(ISYM(5,1,IS))
            Z(2)=W(1)*ISYM(1,2,IS)+W(2)*ISYM(2,2,IS)+W(3)*ISYM(3,2,IS)
            TTY= REAL(ISYM(4,2,IS))/REAL(ISYM(5,2,IS))
            Z(3)=W(1)*ISYM(1,3,IS)+W(2)*ISYM(2,3,IS)+W(3)*ISYM(3,3,IS)
            TTZ= REAL(ISYM(4,3,IS))/REAL(ISYM(5,3,IS))

            DO ITR=ITRS,ITRF

              IF(ITR.EQ.2) THEN
                Z(1) = Z(1)+TTX
                Z(2) = Z(2)+TTY
                Z(3) = Z(3)+TTZ
              ENDIF

C molrep      
              DO     JS=1,NN
C
C pealsrch    DO     JS=2,NN

                DO J=1,INVERSJ

                  DO IOR=1,NORIG
                  
                    IF(J.EQ.2) THEN
                      Y(1) =-YY(1)+SOR(1,IOR)
                      Y(2) =-YY(2)+SOR(2,IOR)
                      Y(3) =-YY(3)+SOR(3,IOR)
                    ELSE
                      Y(1) = YY(1)+SOR(1,IOR)
                      Y(2) = YY(2)+SOR(2,IOR)
                      Y(3) = YY(3)+SOR(3,IOR)
                    ENDIF

          X1= Y(1)*ISYM(1,1,JS)+Y(2)*ISYM(2,1,JS)+Y(3)*ISYM(3,1,JS)
          TX=REAL(ISYM(4,1,JS))/REAL(ISYM(5,1,JS))
          X2= Y(1)*ISYM(1,2,JS)+Y(2)*ISYM(2,2,JS)+Y(3)*ISYM(3,2,JS)
          TY=REAL(ISYM(4,2,JS))/REAL(ISYM(5,2,JS))
          X3= Y(1)*ISYM(1,3,JS)+Y(2)*ISYM(2,3,JS)+Y(3)*ISYM(3,3,JS)
          TZ=REAL(ISYM(4,3,JS))/REAL(ISYM(5,3,JS))



                    DO JTR=JTRS,JTRF

                      IF(JTR.EQ.2) THEN
                        X1 = X1+TX
                        X2 = X2+TY
                        X3 = X3+TZ
                      ENDIF

                      XX(1) = X1-Z(1)
                      XX(2) = X2-Z(2)
                      XX(3) = X3-Z(3)

 10                   CONTINUE
                      IF(XX(1).GE.0.5)THEN
                        XX(1) = XX(1)-1.0
                        GO TO 10
                      ENDIF
 20                   CONTINUE
                      IF(XX(1).LT.-0.5)THEN
                        XX(1) = XX(1)+1.0
                        GO TO 20
                      ENDIF
 30                   CONTINUE
                      IF(XX(2).GE.0.5)THEN
                        XX(2) = XX(2)-1.0
                        GO TO 30
                      ENDIF
 40                   CONTINUE
                      IF(XX(2).LT.-0.5)THEN
                        XX(2) = XX(2)+1.0
                        GO TO 40
                      ENDIF
 50                   CONTINUE
                      IF(XX(3).GE.0.5)THEN
                        XX(3) = XX(3)-1.0
                        GO TO 50
                      ENDIF
 60                   CONTINUE
                      IF(XX(3).LT.-0.5)THEN
                        XX(3) = XX(3)+1.0
                        GO TO 60
                      ENDIF

                      CALL MVMULT(FRTOCR,XX,X)

                      IF(IFX.EQ.0) THEN
                        D2 = X(2)*X(2)+X(3)*X(3)
                      ELSE IF(IFY.EQ.0) THEN
                        D2 = X(1)*X(1)+X(3)*X(3)
                      ELSE IF(IFZ.EQ.0) THEN
                        D2 = X(1)*X(1)+X(2)*X(2)
                      ELSE
                        D2 = X(1)*X(1)+X(2)*X(2)+X(3)*X(3)
                      ENDIF

                      IF(JS.NE.1.OR.J.NE.1.OR.IOR.NE.1) THEN
                        IF(D2.LT.DIST_LIM2) THEN
                          ISPEC = 1
                          RETURN
                        ENDIF
                      ENDIF

                    ENDDO
C JTR
                  ENDDO
C ORIGINE
                ENDDO
C J
              ENDDO
C JS

            ENDDO
C ITR
          ENDDO
C I
        ENDDO
C IS
C       DIST = SQRT(DIST)

      RETURN
      END

      SUBROUTINE TRP_PARAB(F_1,F0,F1,X_PR,C_PR,D_PR)
      IF(F1.GT.F0.OR.F_1.GT.F0) GO TO 100
      C_PR = F0 - (F_1 + F1 )/2.0
      IF(C_PR.LE.0.00001)       GO TO 100
      X_PR = (F1 - F_1)/(4.0*C_PR)
      IF(ABS(X_PR).GE.1.0)      GO TO 100
      D_PR = F0 + C_PR*X_PR*X_PR
      RETURN
 100  CONTINUE
      X_PR = 0.0
      C_PR = 0.0
      D_PR = F0
      RETURN
      END

      SUBROUTINE MODDN1(MDOC,NAME1,NAME2,NAMEW
     *    ,DSCALE
     *    ,MSGF,AMLT,IFLS,CMIN,CMAX,ADD,RAD,SH
     *    ,IZMINW,IZMAXW,ALEVEL,DLEVEL
     *    ,RESULT,IPRROW,ISYM,IPRSYM,IERR)
c -----------------------------------------
C      INTEGER*2 IPOOLA(NCRES),IPOOLB(NCRES)
C      REAL      POOLC(NCRES)

      integer*2,   allocatable :: IPOOLA(:)
      integer*2,   allocatable :: IPOOLB(:)
      real,        allocatable :: POOLC(:)

      REAL      RESULT(IPRROW)
      INTEGER*2 ISYM(5,3,IPRSYM)
      CHARACTER NAME1*(*),NAME2*(*),NAMEW*(*),MSGF*1
      CHARACTER TTT1*80
      CHARACTER TTT2*80
      CHARACTER TTTW*80,TYPE*4
      CHARACTER LINE*80
      REAL XF(3),XC(3),SH(3)
C ----------------------------------------------------------------------
C ---
      COMMON/COMWRF/ A_WR,B_WR,C_WR,AL_WR,BE_WR,GA_WR
     *              ,RN_WR,RX_WR,CF_WR,TF_WR
     *              ,NX_WR,NY_WR,NZ_WR,IN_WR,IM_WR
     *              ,NS_WR,IS_WR,IER_WR,IEN_WR
     *              ,TP_WR,T1_WR,T2_WR,TL_WR,DT_WR
     *              ,CD_WR,SG_WR,PT_WR,PD_WR
      REAL A_WR,B_WR,C_WR,AL_WR,BE_WR,GA_WR
      REAL RN_WR,RX_WR,CF_WR,TF_WR
      INTEGER*4 NX_WR,NY_WR,NZ_WR,IN_WR,IM_WR
      INTEGER*4 NS_WR,IS_WR,IER_WR,IEN_WR
      CHARACTER TP_WR*4,T1_WR*4,T2_WR*4,TL_WR*80,DT_WR*20     
      CHARACTER CD_WR*4,SG_WR*24,PT_WR*40,PD_WR*9
C ---
C --------------------------------------------------------------------
      IERR=0
      MD=-ABS(MDOC)-1
      M = 99
C--------------------------------------
C     READ OF TITLE OF FILE-1
C
      MTIN1 = 40
      MTIN2 =  0
      MTS   =  0
      TYPE  = 'RI  '
      CALL ORFILE(M,MTIN1,NAME1,TYPE,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.GT.0) THEN
        IERR=1
        RETURN
      ENDIF
      CALL GET_TITLE(M,A,B,C,AL,BE,GA
     *        ,F1,F2,F3,F4,NX1,NY1,NZ1,IZMIN1,IZMAX1,TTT1,IERR)
      CLOSE(MTIN1)
      IF(IERR.GT.0) THEN
        IERR=2
        RETURN
      ENDIF
      NXY1=NX1*NY1
      NXY2=NX1*NY1
      IF(IFLS.EQ.2) THEN
        MTIN2 = 41
        TYPE  = 'RI  '
        CALL ORFILE(M,MTIN2,NAME2,TYPE,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.GT.0) THEN
          IERR=1
          RETURN
        ENDIF
        CALL GET_TITLE(M,A,B,C,AL,BE,GA
     *        ,F1,F2,F3,F4,NX2,NY2,NZ2,IZMIN2,IZMAX2,TTT2,IERR)
        CLOSE(MTIN2)
        IF(IERR.GT.0) THEN
          IERR=2
          RETURN
        ENDIF
        NXY2=NX2*NY2
      ENDIF
      IT = 0
      allocate(IPOOLA(1:NXY1),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      IF(IFLS.EQ.2) THEN
        allocate(IPOOLB(1:NXY2),STAT=ISTAT)
        IT = IT + ABS(ISTAT)
      ENDIF
      IF(IT.GT.0) THEN
        IERR = 1
        CALL MSGERR(MDOC,
     *    ' ERROR: in MODDEN: problem with memory allocation')
        CALL MSGERR(MDOC,
     *    '                   try to change resolution')
        RETURN
      ENDIF

      ITYPE  = 0
      MTIN1  =40
      MD=-ABS(MDOC)-1
c      WRITE(*,*) '      INPUT FILE /DENS/ - 1'
      CALL IRDENS(MTIN1,NAME1,MDOC,ITYPE,ICNTZ1,NX1,NY1,NZ1,IZMAX1,
     * IZMIN1,RMAX1,RMIN1,IPOOLA,SCALE1,A1,B1,C1,AL1,BE1,GA1,DRMS1,
     * RAVER,RESOL1,IX01,IY01,IZ01,ITR1,TTT1,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERR: FILE-DENS-1')
        IERR=1
        GO TO 900  
      ENDIF
      CALL C_RD_CR
      NXY1=NX1*NY1
      IXMIN1=0
      IXMAX1=NX1-1
      IYMIN1=0
      IYMAX1=NY1-1
      IX0W=IX01
      IY0W=IY01
      IZ0W=IZ01
      TTTW=TTT1
      IF(IZMAXW.GT.IZMAX1) IZMAXW=IZMAX1
      IF(IZMINW.LT.IZMIN1) IZMINW=IZMIN1
C ---
C -----------------------------------------------------------
      IF(IFLS.EQ.2) THEN
        ITYPE = 0
        MTIN2 =41
c        WRITE(*,*) '      INPUT FILE /DENS/ - 2'
        CALL IRDNS2(MTIN2,NAME2,MDOC,ITYPE,ICNTZ2,NX2,NY2,NZ2,IZMAX2,
     *  IZMIN2,RMAX2,RMIN2,IPOOLB,SCALE2,A2,B2,C2,AL2,BE2,GA2,DRMS2,
     *  RAVER,RESOL2,IX02,IY02,IZ02,ITR2,TTT2,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MDOC,' ERR: FILE-DENS-2')
          IERR=1
          GO TO 900
        ENDIF
        NXY2=NX2*NY2
      ELSE
        MTIN2=0
      ENDIF
C--------------------------------------------------------
      ALW=AL1
      BEW=BE1
      GAW=GA1
      IF(MSGF.EQ.'P') THEN
        AW =A1
        BW =B1
        CW =C1
        NXW=NX1
        NYW=NY1
        NZW=1
        IXMINW=0
        IXMAXW=NXW-1
        IYMINW=0
        IYMAXW=NYW-1
        IZMINP=IZMINW
        IZMAXP=IZMAXW
        IZMINW=0
        IZMAXW=0
      ELSE
        AW =A1
        BW =B1
        CW =C1
        NXW=NX1
        NYW=NY1
        NZW=NZ1
        IXMINW=0
        IXMAXW=NXW-1
        IYMINW=0
        IYMAXW=NYW-1
        IZMINW=IZMIN1
        IZMAXW=IZMAX1
      ENDIF
      IF(MSGF.EQ.'H') THEN
        IX0W   = 0
        IY0W   = 0
        IZ0W   = 0
        IZMINW = 0
        IZMAXW = IZMAX1 - IZMIN1
      ENDIF
C--------------------------------------------------------
      MTS      =43
      TTTW(1:4)='MODI'
      TTTW(5:8)='M '//MSGF//' '
      TYPE     ='RI  '
      IPRINT   =1
      CALL C_CR_WR
      NS1=NSYM
      IF(MSGF.EQ.'R'.OR.MSGF.EQ.'B') THEN
C 
        NS_WR=1
        SG_WR='P 1'
C
        NS1=1

      ENDIF
      NXYW = NXW * NYW
      allocate(POOLC(1:NXYW),STAT=ISTAT)
      IF(ISTAT.GT.0) THEN
        IERR = 1
        CALL MSGERR(MDOC,
     *    ' ERROR: in TRFUN: problem with memory allocation')
        CALL MSGERR(MDOC,
     *    '                  try to change resolution')
        GO TO 900
      ENDIF
  
c      WRITE(*,*) '      OUTPUT-FILE'
      CALL SET_TITLE(MDOC,AW,BW,CW,ALW,BEW,GAW
     *  ,DDM,DDM,DDM,DDM,NXW,NYW,NZW,IZMINW,IZMAXW,TTTW,IERR)

      CALL LENSTR_BL(NAMEW,LEN)
      IF(LEN.LE.0.OR.NAMEW(1:1).EQ.','.OR.NAMEW.EQ.' ') THEN
        CALL MSGERR(MD,' ERR: OPEN OUTPUT-FILE-DENS')
        deallocate(POOLC,STAT=ISTAT)
        IERR=1
        GO TO 900
      ENDIF 
      CALL OWFILE(MDOC,MTS,NAMEW,TYPE,NS1,ISYM,IPRSYM,IERR)
      IF(IERR.EQ.2) GO TO 100
      IF(IERR.GT.0) THEN
        deallocate(POOLC,STAT=ISTAT)
        GO TO 900
      ENDIF
C      CALL WTITLE(MTS,NAMEW,MDOC,TYPE,IPRINT,AW,BW,CW,ALW,BEW,GAW,DDM,
C     * DDM,DDM,DDM,NXW,NYW,NZW,IZMINW,IZMAXW,TTTW)
      IF(MSGF.EQ.'P') THEN
        DO     I=1,NXYW
          POOLC(I)=0.0
        ENDDO
      ENDIF
C---------------------------------------------------------------
      ICNTZ3=-999
      ITYPE1=1
      ITYPE2=1
      IF(MSGF.EQ.'F') THEN
        WRITE(LINE,201)
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,200)
 200    FORMAT(3X,'X',3X,'Y',3X,'Z',6X,'R-MAX',7X,'X',3X,'Y',
     *         3X,'Z',6X,'R-MIN',8X,'TIME',8X,'N+/N')
 201    FORMAT(' ')
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,201)
        CALL MSGDOC(MDOC,LINE)
      ENDIF
C---------------------------------------------------------------
      PERCNT= 0.0
      AVER  = 0.0
      RMS   = 0.0
      DSUM1 = 0.0
      DSUM2 = 0.0
      DSUMO = 0.0
      DSUMP = 0.0
      DSUMN = 0.0
      DSUMO2= 0.0
      D2    = 0.0
      NUMB  = 0
      NNN1  = 0
      NNN2  = 0
      NNNP  = 0
      NNNN  = 0
      NNNZ  = 0
      N     = 0
      NZN   = 0
      RAD2  = RAD*RAD     
      DO     IZ=IZMIN1,IZMAX1

        IF(MSGF.EQ.'P'.AND.IZ.GT.IZMAXP) GO TO 100

        Z=IZ/FLOAT(NZ1)
        NN1=0
        NN2=0
C-----------------------
        CALL IRDENS(MTIN1,NAME1,MDOC,ITYPE1,ICNTZ1,NX1,NY1,NZ1,IZMAX1,
     *  IZMIN1,RMAX1,RMIN1,IPOOLA,SCALE1,A1,B1,C1,AL1,BE1,GA1,DRMS1,
     *  RAVER,RESOL1,IX01,IY01,IZ01,ITR1,TTT1,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MDOC,' ERR: FILE-DENS-1.')
          IERR=1
          deallocate(POOLC,STAT=ISTAT)
          GO TO 900
        ENDIF
        IF(MTIN2.GT.0) THEN
        CALL IRDNS2(MTIN2,NAME2,MDOC,ITYPE2,ICNTZ2,NX2,NY2,NZ2,IZMAX2,
     *  IZMIN2,RMAX2,RMIN2,IPOOLB,SCALE2,A2,B2,C2,AL2,BE2,GA2,DRMS2,
     *  RAVER,RESOL2,IX02,IY02,IZ02,ITR2,TTT2,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MDOC,' ERR: FILE-DENS-2.')
          IERR=1
          deallocate(POOLC,STAT=ISTAT)
          GO TO 900
        ENDIF
        ENDIF
C-----------------------
        IF(MSGF.EQ.'P'.AND.IZ.LT.IZMINP) GO TO 300

        N=0

        DO     IY=IYMINW,IYMAXW
          IYY=IY
          Y=IY/FLOAT(NY1)
          IND0 =IY*NX1
          INDD0=IND0

          DO     IX=IXMINW,IXMAXW
            X=IX/FLOAT(NX1)
            IXX=IX
            IND =IND0+IX+1
            INDD=IND
            D1=IPOOLA(IND)/SCALE1
            IF(MTIN2.GT.0) D2=IPOOLB(IND)/SCALE2
C       -------  F ----------
            IF(MSGF.EQ.'F') THEN
              IF(D2.GT.ALEVEL) THEN
                NN1=NN1+1
                NNN1=NNN1+1
                DOUT=D1
              ELSE
                DOUT=DLEVEL
                NN2=NN2+1
                NNN2=NNN2+1
              ENDIF
C       -------  2 ----------
            ELSE IF(MSGF.EQ.'2') THEN
              DOUT=D1*D2
C       -------  N ----------
            ELSE IF(MSGF.EQ.'N') THEN
              DOUT=D1*D2
              IF(D2.LE.0.0) DOUT=0.0
C       -------  I ----------
            ELSE IF(MSGF.EQ.'I') THEN
              IF(D2.GE.0.5) THEN
                DOUT = 0.0
              ELSE
                DOUT = D1
              ENDIF
C       -------  E ----------
            ELSE IF(MSGF.EQ.'E') THEN
              T=D2-D1*D1
              IF(T.LT.0.0) T=0.0   
              DOUT=SQRT(T)
C       -------  X ----------
            ELSE IF(MSGF.EQ.'X') THEN
C            (<r>^3+3*sigma^2*<r>), file_1-D file_2-sigma
              T=D1*D1*D1+3.0*D1*D2*D2
              DOUT=T
C       -------  M ----------
            ELSE IF(MSGF.EQ.'M') THEN
              DOUT=D1*AMLT
C       -------  * ----------
            ELSE IF(MSGF.EQ.'*') THEN
              DOUT=D1*D1
C       -------  3 ----------
            ELSE IF(MSGF.EQ.'3') THEN
              DOUT=D1*D1*D1
C       -------  Q ----------
            ELSE IF(MSGF.EQ.'Q') THEN
              IF(D1.LE.0.0) THEN
                DOUT=0.0
              ELSE
                DOUT=SQRT(ABS(D1))
              ENDIF
C       -------  L ----------
            ELSE IF(MSGF.EQ.'L') THEN
              IF(D1.LE.1.0E-20) THEN
                DOUT=0.0
              ELSE
                DOUT=LOG(ABS(D1))
              ENDIF
C       -------  P ----------
            ELSE IF(MSGF.EQ.'P') THEN
              DOUT=D1
C       -------  S ----------
            ELSE IF(MSGF.EQ.'S') THEN
              DOUT=D1-D2*DSCALE
C       -------  D ----------
            ELSE IF(MSGF.EQ.'D') THEN
              IF(ABS(D2).GT.1.E-8) THEN
                DOUT=D1/D2
              ELSE
                DOUT=0.0
              ENDIF
C       -------  C ----------
            ELSE IF(MSGF.EQ.'C') THEN
              DOUT=D1
              IF(D1.LT.CMIN) DOUT=CMIN
              IF(D1.GT.CMAX) DOUT=CMAX
C       -------  K ----------
            ELSE IF(MSGF.EQ.'K') THEN
              IF(D2.GT.ALEVEL) THEN
                NN1 =NN1+1
                NNN1=NNN1+1
                DOUT=D1
                DSUMO =DSUMO+DOUT
                DSUMO2=DSUMO2+DOUT*DOUT
                NUMB=NUMB+1
                IF(DOUT.GT.0) THEN
                  DSUMP=DSUMP+DOUT
                  NNNP=NNNP+1
                ELSE IF(DOUT.LT.0) THEN
                  DSUMN=DSUMN+DOUT
                  NNNN=NNNN+1
                ELSE
                  NNNZ=NNNZ+1
                ENDIF
              ELSE
                DOUT=DLEVEL
                NN2=NN2+1
                NNN2=NNN2+1
              ENDIF
C       -------  U ----------
            ELSE IF(MSGF.EQ.'U') THEN
              DOUT=D1
              IF(D1.LT.CMIN) DOUT=CMIN
              IF(D1.GT.CMAX) DOUT=CMAX
              DOUT=DOUT+(-CMIN)
C       -------  R ----------
            ELSE IF(MSGF.EQ.'R') THEN
              XX=X
              YY=Y
              ZZ=Z
              IF(XX.GT.0.5) XX=1.0-XX
              IF(YY.GT.0.5) YY=1.0-YY
              IF(ZZ.GT.0.5) ZZ=1.0-ZZ
              XF(1)=XX
              XF(2)=YY
              XF(3)=ZZ
              CALL FTOO(XF,XC,IERR)
              DIST=SQRT(XC(1)*XC(1)+XC(2)*XC(2)+XC(3)*XC(3))   
              DOUT=D1
              IF(DIST.LT.CMIN) DOUT=0.0
              IF(DIST.GT.CMAX) DOUT=0.0
C       -------  B ----------
            ELSE IF(MSGF.EQ.'B') THEN
              XX=X
              YY=Y
              ZZ=Z
              IF(XX.GT.0.5) XX=1.0-XX
              IF(YY.GT.0.5) YY=1.0-YY
              IF(ZZ.GT.0.5) ZZ=1.0-ZZ
              XF(1)=XX
              XF(2)=YY
              XF(3)=ZZ
              CALL FTOO(XF,XC,IERR)
              DIST2=XC(1)*XC(1)+XC(2)*XC(2)+XC(3)*XC(3)   
              IF(CMIN.GT.0.0) THEN
                CINN=1.0-EXP(-DIST2/(2.0*CMIN*CMIN))
              ELSE
                CINN=1.0
              ENDIF
              IF(CMAX.GT.0.0) THEN
                COUT=EXP(-DIST2/(0.5*CMAX*CMAX))
              ELSE
                COUT=1.0
              ENDIF
              DOUT=D1*CINN*COUT
C       -------  H ----------
            ELSE IF(MSGF.EQ.'H') THEN
              XX=X-SH(1)
              YY=Y-SH(2)
              ZZ=Z-SH(3)

              IF(ABS(XX).GT.0.5) THEN
                IF(XX.LT.0.0) XX=1.0+XX
                IF(XX.GE.0.0) XX=XX-1.0
              ENDIF
              IF(ABS(YY).GT.0.5) THEN
                IF(YY.LT.0.0) YY=1.0+YY
                IF(YY.GE.0.0) YY=YY-1.0
              ENDIF
              IF(ABS(ZZ).GT.0.5) THEN
                IF(ZZ.LT.0.0) ZZ=1.0+ZZ
                IF(ZZ.GE.0.0) ZZ=ZZ-1.0
              ENDIF

              XF(1)=XX
              XF(2)=YY
              XF(3)=ZZ
              CALL FTOO(XF,XC,IERR)

              DIST2=XC(1)*XC(1)+XC(2)*XC(2)+XC(3)*XC(3)   
              IF(DIST2.GT.RAD2) THEN
                DOUT = 0.0
              ELSE
                DOUT = D1
              ENDIF
C       -------  T ----------
            ELSE IF(MSGF.EQ.'T') THEN
              IF(D1.LT.ADD) THEN
                DOUT=0.0
              ELSE
                DOUT=1.0
              ENDIF
C       -------  A ----------
            ELSE IF(MSGF.EQ.'A') THEN
              DOUT=D1+ADD
            ENDIF
C ---
            IF(MSGF.EQ.'P') THEN
              POOLC(INDD)=POOLC(INDD)+DOUT
            ELSE
              POOLC(INDD)=DOUT
            ENDIF

            IF(MSGF.NE.'K') THEN
              DSUM1=DSUM1+D1
              DSUM2=DSUM2+D2
              DSUMO=DSUMO+DOUT
              DSUMO2=DSUMO2+DOUT*DOUT
              NUMB=NUMB+1
            ENDIF

            IF(MSGF.NE.'F'.AND.MSGF.NE.'K') THEN
              IF(DOUT.GT.0) THEN
                DSUMP=DSUMP+DOUT
                NNNP=NNNP+1
              ELSE IF(DOUT.LT.0) THEN
                DSUMN=DSUMN+DOUT
                NNNN=NNNN+1
              ELSE
                NNNZ=NNNZ+1
              ENDIF
            ENDIF

C----XXXX---YYYY-------
  500       CONTINUE
          ENDDO

  400     CONTINUE
        ENDDO
        IF(N.GT.0) NZN=IZ
C---------------------

        IF(MSGF.EQ.'F'.OR.MSGF.EQ.'K') THEN
          PERCNT=(NN1*100.)/FLOAT(NN1+NN2)
          CALL WDENSC(MTS,MDOC,ICNTZ3,NXW,NYW,NZW,IZMINW,IZMAXW,
     *         RMAXD,RMIND,POOLC,RESOL1,IX01,IY01,IZ01,ITR1,PERCNT)
        ELSE IF(MSGF.EQ.'P'.AND.IZ.EQ.IZMAXP) THEN
          CALL WDENS(MTS,MDOC,ICNTZ3,NXW,NYW,NZW,IZMINW,IZMAXW,
     *               RMAXD,RMIND,POOLC,RESOL1,IX01,IY01,IZ01,ITR1)
        ELSE IF(MSGF.NE.'P') THEN
          CALL WDENS(MTS,MDOC,ICNTZ3,NXW,NYW,NZW,IZMINW,IZMAXW,
     *               RMAXD,RMIND,POOLC,RESOL1,IX01,IY01,IZ01,ITR1)
        ENDIF
        IF(MTS.LE.0) THEN
          CALL MSGERR(MDOC,' ERR: OUTPUT-FILE-DENS')
          IERR=1
          deallocate(POOLC,STAT=ISTAT)
          GO TO 900
        ENDIF
  300   CONTINUE
C---ZZZZZZZZZ----------
      ENDDO
C----------------------
  100 CONTINUE

      deallocate(POOLC,STAT=ISTAT)

      IF(MSGF.EQ.'F'.OR.MSGF.EQ.'K') THEN
        PERCNT=(NNN1*100.)/FLOAT(NNN1+NNN2)
        WRITE(LINE,'('' N+,N0,% :'',2I8,F8.2)') NNN1,NNN2,PERCNT
        CALL MSGDOC(MDOC,LINE)
      ENDIF
      IF(MSGF.NE.'F') THEN
        AVER=0.0
        RMS =0.0
        IF(NUMB.GT.0) THEN
          AVER=DSUMO/NUMB
          RMS=SQRT(ABS((DSUMO2+NUMB*AVER*AVER-2.0*AVER*DSUMO)/NUMB))
        ENDIF

        WRITE(LINE,'('' <D>,RMS(R),N ='',2G16.4,I10)') AVER,RMS,NUMB
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,40) DSUMO,DSUMO2
   40   FORMAT(' SUM-R, SUM-R**2 :',2G18.5)
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,80) NNNP,DSUMP
   80   FORMAT(' NUMB D>0 , SUM:',I10,G18.5)
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,82) NNNN,DSUMN
   82   FORMAT(' NUMB D<0 , SUM:',I10,G18.5)
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,84) NNNZ
   84   FORMAT(' NUMB D=0 :',I10)
        CALL MSGDOC(MDOC,LINE)
      ENDIF
C---------------------
      RESULT( 1)=NUMB
      RESULT( 2)=AVER
      RESULT( 3)=RMS
      RESULT( 4)=NNNP
      RESULT( 5)=DSUMP
      RESULT( 6)=0.0
      RESULT( 7)=NNNN
      RESULT( 8)=DSUMN
      RESULT( 9)=0.0
      RESULT(10)=NNNZ
      RESULT(11)=PERCNT
      IF(IPRROW.GT.11) THEN
        RESULT(12)=RMAX1
        RESULT(13)=RMIN1
        RESULT(14)=RMAX2
        RESULT(15)=RMIN2
        RESULT(16)=RMAXD
        RESULT(17)=RMIND
      ENDIF
C---------------------
  900 CONTINUE
      deallocate(IPOOLA,STAT=ISTAT)
      deallocate(IPOOLB,STAT=ISTAT)
      IF(MTIN1.GT.0) CLOSE(MTIN1)
      IF(MTIN2.GT.0) CLOSE(MTIN2)
      IF(MTIN2.GT.0) CLOSE(MTS)
      RETURN
      END

      SUBROUTINE WDENSC(MTOUT,MDOC,ICNTZ,NX,NY,NZ,IZMIN,IZMAX,RMAX,RMIN
     .                ,POOL,RESOL,IX0,IY0,IZ0,ITR,PERCNT)
C ------------------------------------------
CMS     : POOL
      REAL POOL(*)
      COMMON/COM_WDC/ AVER,AVER2
C ------------------------------------------
      CALL WSECTC(MTOUT,MDOC,ICNTZ,IZMIN,IZMAX,NX,NY,RMAX,RMIN,POOL
     *          ,POOL,AVER,AVER2,PERCNT)
      IF(MTOUT.EQ.0) RETURN
      IF(ICNTZ.GE.IZMAX) THEN
        CALL WTTL2C(MTOUT,MDOC,NX,NY,NZ,IZMIN,IZMAX,RMAX,RMIN
     .                ,IX0,IY0,IZ0,ITR,AVER,AVER2,RESOL)
        IF(MTOUT.EQ.0) RETURN
        END FILE MTOUT
        CLOSE(MTOUT)
      ENDIF
      END

      SUBROUTINE WTTL2C(MTOUT,MDOC,NX,NY,NZ,IZMIN,IZMAX,RMAX,RMIN
     .                ,IX0,IY0,IZ0,ITR,AVER,AVER2,RESOL)
C ------------------------------
      INTEGER*4 NR
      INTEGER ILINE(20)
      CHARACTER LINE*80
      EQUIVALENCE (LINE,ILINE(1))
      DATA NWW/20/
C------------------------------------
      MT=ABS(MTOUT)
      NR=NX*NY
      NR=NR*(IZMAX-IZMIN+1)
C     ----------------
      AVER=AVER/NR
      AVER2=AVER2/NR
      RMS=AVER2-AVER*AVER
      IF(RMS.LT.0.00000001) RMS=0.0
      IF(RMS.GT.0.0) RMS=SQRT(RMS)  
      DELX=RMS
      DELY=RESOL
      DELZ=AVER
      WRITE(LINE,32) NR,RMAX,RMIN,IX0,IY0,IZ0,DELX,DELY,DELZ,ITR
32    FORMAT(I10,2G12.4,3I4,G12.4,F7.4,G12.4,I1)
      CALL WBLOCK(MT,ILINE,NWW,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERR: WRITE FILE-OUT')
        CLOSE(MT)
        MTOUT=0
        RETURN
      ENDIF
c      IF(MDOC.GT.0.AND.MDOC.LT.99) THEN
        CALL MSGDOC(MDOC,' ------------------------------------ ')
        WRITE(LINE,'('' RMAX :'',G12.4,''  RMIN :'',G12.4)') RMAX,RMIN
        CALL MSGDOC(MDOC,LINE)
c      ENDIF
c      IF(MTOUT.GT.0) THEN
c        MMDOC=0
c        CALL MSGDOC(MMDOC,' ------------------------------------')
c        WRITE(LINE
c     .   ,'('' RMAX :'',G12.4,''  RMIN :'',G12.4)') RMAX,RMIN
c        CALL MSGDOC(MMDOC,LINE)
c      ENDIF
      RETURN
      END

      SUBROUTINE WSECTC(MTOUT,MDOC,IZ,IZMIN,IZMAX,NX,NY,RMAX,RMIN
     *                  ,POOL,IPOOL,AVER,AVER2,PERCNT)
C -----------------------------------------
CMS     : POOL,IPOOL
      REAL POOL(*)
      INTEGER IDATE(7)
      INTEGER*2 IPOOL(*),IDAT(8)
      CHARACTER LINE*80
      EQUIVALENCE (IDAT(1),SCAL1),(IDAT(3),SCAL),(IDAT(5),RM)
      EQUIVALENCE (IDAT(7),RN)
      DATA NW8/4/
C ----------------------------------------
      MT=ABS(MTOUT)
      IF(IZ.EQ.-999) THEN
        RMAX=-1.E 30
        RMIN= 1.E 30
        AVER=0.0
        AVER2=0.0
        IZ=IZMIN
      ELSE
        IZ=IZ+1
      ENDIF
      SCAL1=1.
      RN= 1.E 30
      RM=-1.E 30
      NXY=NX*NY
      DO     J=1,NY
        IY=J-1
        IND=IY*NX
        DO     I=1,NX
          IX=I-1
          INDX=IND+I
          R=POOL(INDX)
          AVER=AVER+ABS(R)
          AVER2=AVER2+R*R
          IF(R.GE.RMAX) RMAX=R
          IF(R.LE.RMIN) RMIN=R
          IF(R.GE.RM) THEN
            RM=R
            IXM=IX
            IYM=IY
          ENDIF
          IF(R.LE.RN) THEN
            RN=R
            IXN=IX
            IYN=IY
          ENDIF
        ENDDO
      ENDDO
      RRMAX=MAX(ABS(RM),ABS(RN))
      IF(ABS(RRMAX).GT.1.E-6) THEN
        SCAL=(32 766.)/RRMAX
      ELSE
        SCAL=1.
      ENDIF
      DO     J=1,NY
        IND=(J-1)*NX
        DO     I=1,NX
          INDX=IND+I
          PL=POOL(INDX)*SCAL
          IF(ABS(PL).GT.32766.) PL=SIGN(32766.,PL)
          IPOOL(INDX)=PL
        ENDDO
      ENDDO

      CALL WBLOCK_I2(MT,IDAT,NW8,IERR)

      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERR: WRITE DATA TO FILE-OUT')
        CLOSE(MT)
        MTOUT=0
        RETURN
      ENDIF
      NXY2=NXY/2

      CALL WBLOCK_I2(MT,IPOOL,NXY2,IERR)

      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERR: WRITE DATA TO FILE-OUT')
        CLOSE(MT)
        MTOUT=0
        RETURN
      ENDIF
      CALL CLOCK(IDATE)
c      IF(MDOC.GT.0) THEN
        WRITE(LINE,1) IXM,IYM,IZ,RM,IXN,IYN,IZ,RN,IDATE(4),IDATE(3)
     *               ,IDATE(2),PERCNT
        CALL MSGDOC(MDOC,LINE)
c      ENDIF
C --------
c      IF(MTOUT.GT.0) THEN
c        MMDOC=0
c        WRITE(LINE,1) IXM,IYM,IZ,RM,IXN,IYN,IZ,RN,IDATE(4),IDATE(3)
c     *               ,IDATE(2),PERCNT
c        CALL MSGDOC(MMDOC,LINE)
c      ENDIF
    1 FORMAT(' ',3I4,1X,G12.4,' , ',3I4,1X,G12.4,' ; ',I2,2('.',I2)
     *    ,' %=',F5.1)
      RETURN
      END

C -I-
      SUBROUTINE ANISOSCL(MDOC,NAMEF,NAMED,NAMEO,RSMIN,RSMAX,SCALE,BOVER
     * ,NCYCLR,BOFF,BADD,SOLV,PATT_IN
     * ,ISYM,IPRSYM,RESULT,IPRROW,IERR)
C -------------------------------------------------------------------
C -P- ANISOSCL -
C -S-
C      Fnew = Scale*Fold*exp(-(B11a*a*hh +2B12a*b*hk+..)*(1-Ks*exp(-Bsr^2)) 
C
C      Dialog:
C
C  FILE_F:  - input file F_obs.
C  FILE_D:  - input file F_der.
C  RESOL:   - MIN,MAX <from file> - resolution 
C  BOFF:     <256>    - 256 corresponds to RESmin=8A, Boff= 4RES*min^2
C  BADD:      <0>       BOFF and BADD mean :
C                       !F!new = !F!input *EXP(-BADD*RSQ)*(1-EXP(*-BOFF*RSQ)
C  NC:        <5>     - number of cycles 
C  SCALE:     <1>     - initial scale 
C  BOVER:     <0>     - initial B_overall 
C  SOLV:       <N>/Y  - Y means with solvent correction
C  PATT:     <Y>/N/I  - Y means pre-isoscaling by Patterson 
C                     - I means only isoscaling by Patterson 
C  FILE_O: <anisoscl_fsc> - outpit file of scaled !F! 
C
C  Parameters of subroutine ANISOSCL: 
C
C      SUBROUTINE ANISOSCL(MDOC,NAMEF,NAMED,NAMEO,RSMIN,RSMAX,SCALE,BOVER
C     * ,NCYCLR,BOFF,BADD,SOLV,PATT_IN
C     * ,ISYM,IPRSYM,RESULT,IPRROW,IERR)
C
C    MDOC    - mode of writting messages to DOC-file
C              0 - only terminal , < - 0 only file, 0 < < 99 - both
C              >= 99 - don't write  
C  NAMEF:  - input file F_obs.
C  NAMED:  - input file F_der.
C  RSMIN:  - MIN,MAX <from file> - resolution 
C  RSMAX:
C  BOFF:     <256>    - 256 corresponds to RESmin=8A, Boff= 4RES*min^2
C  BADD:      <0>       BOFF and BADD mean :
C                       !F!new = !F!input *EXP(-BADD*RSQ)*(1-EXP(*-BOFF*RSQ)
C  NCYCL:     <5>     - number of cycles 
C  SCALE:     <1>     - initial scale 
C  BOVER:     <0>     - initial B_overall 
C  SOLV:       <N>/Y  - Y means with solvent correction
C  PATT:     <Y>/N/I  - Y means pre-isoscaling by Patterson 
C                     - I means only isoscaling by Patterson 
C  NAMEO: <anisoscl_fsc> - outpit file of scaled !F!
C  ISYM    - integer*2 array for cryst.symmetry operators.
C  IPRSYM  - dimension of integer*2 array ISYM(5,3,IPRSYM),
C            max number of cryst. symm. operators.
C  IERR    - output signal of error / = 1 -error , = 0 - OK / 
C
C        output information :
C
C     REAL RESULT(IPRROW,3)
C
C        RESULT( 1,1)=NC    
C        RESULT( 2,1)=Scale    Fnew = Scale*Fold*exp(-(B11a*a*hh +2B12a*b*hk+..)
C        RESULT( 3,1)=Ks              *(1-Ks*exp(-Bsr^2)) 
C        RESULT( 4,1)=Bs
C        RESULT( 5,1)=B11
C        RESULT( 6,1)=B22
C        RESULT( 7,1)=B33
C        RESULT( 8,1)=B12
C        RESULT( 9,1)=B13
C        RESULT(10,1)=B23
C        RESULT(11,1)=RVAL(1) Ratio of Eigen values 
C        RESULT(12,1)=RVAL(2)
C        RESULT(13,1)=RVAL(3)
C        RESULT(14,1)=RFACTOR
C        RESULT(15,1)=CC
C        RESULT(16,1)=NREF
C        RESULT(17,1)=RSMIN
C        RESULT(18,1)=RSMAX
C 
C        RESULT( 1,2)=EVAL(1)
C        RESULT( 2,2)=EVAL(2)   Eigen values
C        RESULT( 3,2)=EVAL(3)
C        RESULT( 4,2)=EVEC(1,1) Eigen vectors
C        RESULT( 5,2)=EVEC(2,1)
C        RESULT( 6,2)=EVEC(3,1)
C        RESULT( 7,2)=EVEC(1,2)
C        RESULT( 8,2)=EVEC(2,2)
C        RESULT( 9,2)=EVEC(3,2)
C        RESULT(10,2)=EVEC(1,3)
C        RESULT(11,2)=EVEC(2,3)
C        RESULT(12,2)=EVEC(3,3)
C
C           iso-scaling by Patterson
C
C        RESULT(1,3) = Bscale    F2_new = F2_old * scale * exp (-Bscal*s^2) 
C        RESULT(2,3) = SCALE
C                                   Bscale = Boverall_1-Boverall_2
C                                   SCALE  = Sqr_p000_1/Sqr_p000_2
C
C        RESULT( 3,3)  = SQR_P000 - sqrt(P000_patt) for file_1 (test)
C        RESULT( 4,3)  = B_OVER     B_overall
C        RESULT( 5,3)  = RESEFF     Res_optical
C        RESULT( 6,3)  = RESMXI     Res_max
C
C        RESULT( 7,3)  = SQR_P000 - sqrt(P000_patt) for file_2 (scaling)
C        RESULT( 8,3)  = B_OVER     B_overall
C        RESULT( 9,3)  = RESEFF     Res_optical
C        RESULT(10,3)  = RESMXI     Res_max
C -I-
C ----------------------------------------------------------
      PARAMETER (NPAR=9)
C --------------------------------------------
      INTEGER*2 ISYM(5,3,IPRSYM)
      CHARACTER NAMEF*(*),NAMED*(*),NAMEO*(*)
      REAL      RESULT(IPRROW,3)
      INTEGER   IHH(192),IKK(192),ILL(192)
      REAL      FAA(192)
C ---------------------------------------------------------
      INTEGER*4 NUMB,NUMB1,NTOT,NREF
      REAL      RLATT(6),FRTOCR(3,3),CRTOFR(3,3)
      REAL      SK(NPAR),SKN(NPAR),DV(NPAR),V(NPAR),AM(NPAR,NPAR)
      REAL      SHIFTS(NPAR),SK_OLD(NPAR),IFIX(NPAR),SK_TMP(NPAR)
      REAL      CM(3,3),BM(3,3),S11(6),BETA(6),EVAL(3),RVAL(3)
      REAL      EVEC(3,3)
      CHARACTER TTT*80,ITYP*4,NAME*256,ITYPE*4,FNAME*256,PATT_IN
      CHARACTER ITF1*4,ITF2*4,TITLE*80,MSG3*1,LINE*80,P1*1,SOLV*1,PATT*1
C -----------------------------------------------------------
      IERR  = 0
      JERR  = 0
      PATT  = PATT_IN
      MD    =-ABS(MDOC)-1
      M     = 99
      PI    = 4.0*ATAN(1.0)
      TWOPI = 2.0*PI
C -------
      P1     = 'Y'
      THRESH = 0.0
      TOP    = 0.0
      NCYCL  = NCYCLR
C -------
      IF(P1.EQ.'n') P1='N'
      IF(P1.NE.'N') P1='Y'
      IF(SOLV.EQ.'y') SOLV='Y'
      IF(SOLV.NE.'Y') SOLV='N'

      IF(PATT.EQ.'n') PATT='N'
      IF(PATT.EQ.'i') PATT='I'
      IF(PATT.NE.'N'.AND.PATT.NE.'I') PATT='Y'
C -------
      IF(BOFF.LE.0.0) BOFF=256.0
      IF(SCALE.LT.0.0000001) SCALE=1.0
      SCALE_I = SCALE
      BOVER_I = BOVER
C ---
      DO I=1,IPRROW
        RESULT(I,1)=0.0
        RESULT(I,2)=0.0
        RESULT(I,3)=0.0
      ENDDO
C --------------------------------------------
      CALL LENSTR_BL(NAMED,L)
      IF(L.LE.0.OR.NAMED(1:1).EQ.' '.OR.NAMED(1:1).EQ.',') THEN
        MTIN=0
C       SOLV='N'
      ELSE
        MTIN=10
        ITYP='FF  '

        CALL ORFILE(MD,MTIN,NAMED,ITYP,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.GT.0) THEN
          CALL MSGERR(MDOC,' ERROR: open input F_scale file')
          RETURN
        ENDIF
        ITF1=ITYP
        NSYMS=NSYM
        CALL GET_TITLE(MD,A,B,C,AL,BE,GA
     *  ,COEF1,BET1,RESMIN1,RESMAX1,NX,NY,NZ,IZN,IZM,TTT,IERR)
        CALL C_RD_CR

      ENDIF
C ---     
      TITLE    = TTT
C ----------------------------------------
      CALL LENSTR_BL(NAMEF,L)
      IF(L.LE.0.OR.NAMEF(1:1).EQ.' '.OR.NAMEF(1:1).EQ.',') THEN
        CALL MSGERR(MDOC,' ERROR: wrong name of input F_test file')
        IERR=1
        RETURN
      ENDIF

      MTNAT=11
      ITYPE='FF  '

      CALL ORFILE(MD,MTNAT,NAMEF,ITYPE,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.GT.0) THEN
          CALL MSGERR(MDOC,' ERROR: open F_test file')
        RETURN
      ENDIF
      NSYMT=NSYM

      IF(MTIN.LE.0) CALL C_RD_CR

      CALL GET_TITLE(MD,A,B,C,AL,BE,GA
     *  ,F1,F2,RESMIN2,RESMAX2,NX,NY,NZ,IZN,IZM,TTT,IERR)
      ITF2=ITYPE
      IF(MTIN.LE.0) TITLE=TTT

      IF(RSMIN.LT.RSMAX) THEN
        T     = RSMAX
        RSMAX = RSMIN
        RSMIN = T
      ENDIF
      IF(RSMIN.LT.1.E-5)   RSMIN=RESMIN2
      IF(RSMAX.LT.1.E-5)   RSMAX=RESMAX2
      IF(RSMIN.GT.RESMIN2) RSMIN=RESMIN2
      IF(RSMAX.LT.RESMAX2) RSMAX=RESMAX2
      IF(MTIN.GT.0) THEN
        IF(RSMIN.GT.RESMIN1) RSMIN=RESMIN1
        IF(RSMAX.LT.RESMAX1) RSMAX=RESMAX1
      ENDIF

      WRITE(LINE,*) ' RESMIN,RESMAX:',RSMIN,RSMAX
      CALL MSGDOC(MDOC,LINE) 
      WRITE(LINE,*) ' BOFF,BADD:',BOFF,BADD
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,*) ' PATT:',PATT
      CALL MSGDOC(MDOC,LINE)
C ---
      IF(TOP.LE.0.0) TOP=1.0E30
c      WRITE(LINE,*) ' THRESH,TOP:',THRESH,TOP
c      CALL MSGDOC(MDOC,LINE)
C ---
      IF(PATT.NE.'N') THEN

        CLOSE(MTNAT)

        CALL CHECK_PATT_ASC(M,NAMEF
     *  ,BOFF,BADD,RESULT_S,RESULT_B
     *  ,RSMIN,RSMAX,RESULT(1,3),IPRROW,ISYM,IPRSYM,IERR)
        IF(IERR.GT.0) THEN
          CALL MSGERR(MDOC,' ERROR: ANISOSCL: F_test file')
          RETURN
        ENDIF
C
C      RESULT_B  = BSUM
C      RESULT_S  = SCALE
C
C      RESULT(1) = BSUM
C      RESULT(2) = SCALE
C
C      RESULT(7)  = SQR_P000
C      RESULT(8)  = B_OVER
C      RESULT(9)  = RESEFF
C      RESULT(10) = RESMXI
C
C ---
        CALL MSGDOC(MDOC,' File_1:')
        WRITE(LINE,*) ' sqrt(P000),Boverall:',RESULT(7,3),RESULT(8,3)
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,*) ' Res_optical        :',RESULT(9,3)
        CALL MSGDOC(MDOC,LINE)
C ---
        RESULT( 3,3) = RESULT( 7,3)
        RESULT( 4,3) = RESULT( 8,3)
        RESULT( 5,3) = RESULT( 9,3)
        RESULT( 6,3) = RESULT(10,3)
        RESULT( 7,3) = 0.0 
        RESULT( 8,3) = 0.0 
        RESULT( 9,3) = 0.0 
        RESULT(10,3) = 0.0 
        RESULT( 1,3) = 0.0 
        RESULT( 2,3) = 0.0 

        PSCALE2 = SQRT(ABS(RESULT_S)) 
        PBTEMP2 = RESULT_B/2.0 

        BOVER = PBTEMP2
        SCALE = PSCALE2
        SCALE_I = SCALE
        BOVER_I = BOVER

        ITYPE='FF  '
        CALL ORFILE(M,MTNAT,NAMEF,ITYPE,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.GT.0) THEN
          CALL MSGERR(MDOC,' ERROR: open F_test file')
          RETURN
        ENDIF

        IF(MTIN.GT.0) THEN

          CLOSE(MTIN)
          CALL CHECK_PATT_ASC(M,NAMED
     *   ,BOFF,BADD,RESULT_S,RESULT_B
     *   ,RSMIN,RSMAX,RESULT(1,3),IPRROW,ISYM,IPRSYM,IERR)
          IF(IERR.GT.0) THEN
            CALL MSGERR(MDOC,' ERROR: ANISOSCL: F_scale file')
            RETURN
          ENDIF

          PSCALE1 = SQRT(ABS(RESULT_S)) 
          PBTEMP1 = RESULT_B/2.0 

          BOVER = PBTEMP2-PBTEMP1
          SCALE = (PSCALE2/PSCALE1)
          SCALE_I = SCALE
          BOVER_I = BOVER

          RESULT( 1,3) = BOVER
          RESULT( 2,3) = SCALE

          CALL MSGDOC(MDOC,' File_2:')
          WRITE(LINE,*) ' sqrt(P000),Boverall:',RESULT(7,3),RESULT(8,3)
          CALL MSGDOC(MDOC,LINE)
          WRITE(LINE,*) ' Res_optical        :',RESULT(9,3)
          CALL MSGDOC(MDOC,LINE)

          CALL MSGDOC(MDOC,' ')
          CALL MSGDOC(MDOC,
     *' Scaling / F2_new = F2_old * scale * exp (-Bscal*s^2)/ :')
          WRITE(LINE,*) ' scale,Bscal:',RESULT(2,3),RESULT(1,3)
          CALL MSGDOC(MDOC,LINE)

          ITYP='FF  '
          CALL ORFILE(M,MTIN,NAMED,ITYP,NSYM,ISYM,IPRSYM,IERR)
          IF(IERR.GT.0) THEN
            CALL MSGERR(MDOC,' ERROR: open input F_scale file')
            RETURN
          ENDIF

        ENDIF

      ENDIF

C ---
      CALL FRORTH(A,B,C,AL,BE,GA,FRTOCR,CRTOFR,IERR)
      RLATT(1) = A
      RLATT(2) = B
      RLATT(3) = C
      RLATT(4) = AL
      RLATT(5) = BE
      RLATT(6) = GA
      CALL DSTARF(RLATT,AST,BST,CST,COALST,COBEST,COGAST,VOL)
c
C----INITIALIZE SCALE FACTORS
      DO    I=1,NPAR
        SK(I)    =0.0
        SK_OLD(I)=0.0
        IFIX(I)  =0
      ENDDO
      SK(7)      =1.0
      RFACTOR_OLD=0.0
      FUN_OLD    =1.0E30
      SK(8)      =0.75
      SK(9)      =250.0
C ---
      IF(SOLV.EQ.'N') THEN
        SK(8)    =1.00
        SK(9)    =100000.0
        IFIX(8)  =1
        IFIX(9)  =1
      ENDIF

      IF(PATT.EQ.'I') THEN
        IFIX(1)  =1
        IFIX(2)  =1
        IFIX(3)  =1
        IFIX(4)  =1
        IFIX(5)  =1
        IFIX(6)  =1
        IFIX(7)  =1
        IF(SOLV.EQ.'N') NCYCL=1
C            DO   I=2,6
C              V(I) = 0.0
C              DO   J=1,I
C                 AM(I,J) = 0.0 
C              ENDDO
C              AM(7,I)  = AM=0.0 
C              AM(8,I)  = AM=0.0 
C              AM(9,I)  = AM=0.0 
C            ENDDO
      ENDIF
C ---
      CALL BISO_TO_B_ASC(SK,BOVER
     *      ,A,B,C,AL,BE,GA     
     *      ,AST,BST,CST,COALST,COBEST,COGAST)

      SK(1)=SK(1)/(AST*AST)          
      SK(2)=SK(2)/(BST*BST)
      SK(3)=SK(3)/(CST*CST)
      SK(4)=SK(4)/(AST*BST)
      SK(5)=SK(5)/(AST*CST)
      SK(6)=SK(6)/(BST*CST)

      SK(7)=SCALE
C ---
      DO I=1,NPAR
        SK_OLD(I)=SK(I)
      ENDDO
C ---

      RHMIN=1.0/RSMIN
      RHMAX=1.0/RSMAX

      IF(PATT.EQ.'I'.AND.MTIN.LE.0) THEN
        GO TO 1000
      ENDIF
C ---
      IF(NCYCL.LE.0) NCYCL=10
      NC=0
      NREF_OLD=0

c      write(*,*) '=1'

C
C ---- START OF THE MAIN LOOP
C
      DO    III=1,NCYCL
C ---

        IF(MTIN.GT.0) THEN
          ITYP='FF  '
          CALL OPFILE(M,MTIN,NAMED,ITYP,NSYM,ISYM,IPRSYM,IERR)
          IF(IERR.GT.0) THEN
            CALL MSGERR(MDOC,' ERROR: RE-OPEN F_FOR_SCALE FILE')
            RETURN
          ENDIF
        ENDIF
        ITYPE='FF  '
        CALL OPFILE(M,MTNAT,NAMEF,ITYPE,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.GT.0) THEN
          CALL MSGERR(MDOC,' ERROR: RE-OPEN F_TEST FILE')
          RETURN
        ENDIF
C ---
        Q=0.

        RZDEN=0
        RZNUM=0
        SUMYC=0
        SUMOC=0
        SUMO2=0
        SUMC2=0


        SUMFD2  = 0.0
        SUMFN2  = 0.0 
C
C---CLEAR MATRIX AND VECTOR ELEMENTS
C
        DO    I=1,NPAR
          V(I)=0.0
          DO    J=1,NPAR
            AM(I,J)=0.0
          ENDDO
        ENDDO
C ------
        NTOT = 0
        NREF = 0
        IEND1=-1
        IEND =-1
        NUMB = 0
        NUMB1= 0
        JH   = 0
        JK   = 0
        JL   =-1
C --------------------------------------
  200   IF(ITF2.EQ.'FS  ') THEN
          CALL RRD1(MTNAT,IH,IK,IL,FN,FNA,SN,SNA,NUMB,IEND)
          IF(SN .LT.0.000001) SN =0.04*FN
          IF(SNA.LT.0.000001) SNA=0.04*FNA
        ELSE
          CALL RD1(MTNAT,IH,IK,IL,FN,FNA,NUMB,IEND)
          SN =0.04*FN
          SNA=0.04*FNA
        ENDIF

        IF(IEND.GT.0) GO TO 220

        IF(FN.GT.1.E-6.AND.FNA.GT.1.E-6) THEN
          WT1=1./(SN*SN)
          WT2=1./(SNA*SNA)
          WT =WT1+WT2
          FN =FN*WT1+FNA*WT2
          FN =FN/WT
          SN =1./SQRT(WT)
        ELSE IF(FNA.GT.1.E-6) THEN
          FN =FNA
          SN =SNA
        ENDIF

        IF(IH.EQ.0.AND.IK.EQ.0.AND.IL.EQ.0) GO TO 210
        CALL DSTAR(IH,IK,IL,RSQ)
        RHKL=SQRT(RSQ)
        IF(RHKL.LT.RHMIN.OR.RHKL.GT.RHMAX) GO TO 210
        IF(FN.LE.THRESH)  GO TO 210
        IF(TOP.GT.1.0E-8) THEN
          IF(FN.GT.TOP)     GO TO 210
        ENDIF

        IF(MTIN.LE.0) THEN
          FD   = 1.0
          SF   = 0.04*FD
          GO TO 275
        ENDIF

        IF(IEND1.GT.0) GO TO 220

C  255   IF(JL-IL) 230,250,210
C  250   IF(JK-IK) 230,260,210
C  260   IF(JH-IH) 230,270,210

  255   IF((JL-IL).LT.0) GO TO 230
        IF((JL-IL).EQ.0) GO TO 250
        IF((JL-IL).GT.0) GO TO 210
  250   IF((JK-IK).LT.0) GO TO 230
        IF((JK-IK).EQ.0) GO TO 260
        IF((JK-IK).GT.0) GO TO 210
  260   IF((JH-IH).LT.0) GO TO 230
        IF((JH-IH).EQ.0) GO TO 270
        IF((JH-IH).GT.0) GO TO 210

  230   CONTINUE

        IF(ITF1.EQ.'FS  ') THEN
          CALL RRD2(MTIN,JH,JK,JL,FD,FDA,SF,SFA,NUMB1,IEND1)
          IF(SF .LT.0.000001) SF =0.04*FD
          IF(SFA.LT.0.000001) SFA=0.04*FDA
        ELSE
          CALL RD2(MTIN,JH,JK,JL,FD,FDA,NUMB1,IEND1)
          SF =0.04*FD
          SFA=0.04*FDA
        ENDIF
        IF(IEND1.GT.0) GO TO 220
        GO TO 255

  270   CONTINUE

        IF(FD.GT.1.E-6.AND.FDA.GT.1.E-6) THEN
          WT1=1./(SF*SF)
          WT2=1./(SFA*SFA)
          WT =WT1+WT2
          FD =FD*WT1+FDA*WT2
          FD =FD/WT
          SF =1./SQRT(WT)
        ELSE IF(FDA.GT.1.E-6) THEN
          FD =FDA
          SF =SFA
        ENDIF

C ---
 275    CONTINUE

        IHH(1)=IH
        IKK(1)=IK
        ILL(1)=IL
        N=1
        IF(P1.EQ.'Y') THEN
          CALL GNR_IND_ANISO(N,IHH,IKK,ILL,NSYM,ISYM)
        ENDIF

        NREF = NREF + 1
        DO I_N=1,N
C ---
          LH=IHH(I_N)
          LK=IKK(I_N)
          LL=ILL(I_N)

          IF(BOFF.GT.0.0) THEN
            BT=BOFF/4.0
            CBOFF=1.0-EXP(-BT*RSQ)
          ELSE
            CBOFF=1.0
          ENDIF
          IF(ABS(BADD).GT.0.00001) THEN
            BT=BADD/4.0
            CBADD=EXP(-BT*RSQ)
          ELSE
            CBADD=1.0
          ENDIF

          FD=FD*CBOFF*CBADD

          FN=FN*CBOFF*CBADD


          S1     = AST*LH 
          S2     = BST*LK 
          S3     = CST*LL 

          S11(1) = S1*S1
          S11(2) = S2*S2
          S11(3) = S3*S3
          S11(4) = S1*S2*2.0
          S11(5) = S1*S3*2.0
          S11(6) = S2*S3*2.0

          TEMP = 0.0
          DO I=1,6
            TEMP=TEMP+SK(I)*S11(I)
          ENDDO
          IF(TEMP.LT.0.0) TEMP = 0.0
          EXPB   = EXP(-TEMP)

          BT    = SK(9)/4.0
          IF(BT.LT.0.0) BT = 0.0
          BCORR = EXP(-BT*RSQ)
          TCORR = 1.0-SK(8)*BCORR

          IF(PATT.EQ.'I') THEN

            IF(I_N.EQ.1) THEN
              TEMP   = BOVER/4.0
              X      = SCALE*EXP(-TEMP*RSQ)
              T1 = FD * TCORR* X 
              T2 = FN  
              SUMFD2  = SUMFD2+T1*T1*N
              SUMFN2  = SUMFN2+T2*T2*N
            ENDIF

          ENDIF

          YC = FD
          YO = FN
          YCEXPB = YC*EXPB
          YC_NEW = SK(7)*YCEXPB*TCORR

      
          DY     = (YO - SK(7)*YCEXPB*TCORR)

          V(7) = V(7) + DY*YCEXPB*TCORR
          V(8) = V(8) - DY*YCEXPB*SK(7)*BCORR
          V(9) = V(9) + DY*YCEXPB*SK(7)*SK(8)*BCORR*(RSQ/4.0)
 
          
          DO   I=1,6
            V(I) = V(I) - S11(I)*SK(7)*YCEXPB*TCORR*DY
            DO   J=1,I
               AM(I,J) = AM(I,J) 
     *         + S11(I)*S11(J)*YCEXPB*YCEXPB*TCORR*TCORR*SK(7)*SK(7)
            ENDDO
            AM(7,I)  = AM(7,I) 
     *         - S11(I)*SK(7)*YCEXPB*TCORR*YCEXPB*TCORR
            AM(8,I)  = AM(8,I) 
     *         + S11(I)*SK(7)*YCEXPB*TCORR*YCEXPB*SK(7)*BCORR
            AM(9,I)  = AM(9,I) 
     *         - S11(I)*SK(7)*YCEXPB*TCORR*YCEXPB*SK(7)*SK(8)*BCORR
     *         *(RSQ/4.0)
          ENDDO

C          IF(PATT.EQ.'I') THEN
C            DO   I=2,6
C              V(I) = 0.0
C              DO   J=1,I
C                 AM(I,J) = 0.0 
C              ENDDO
C              AM(7,I)  = AM=0.0 
C              AM(8,I)  = AM=0.0 
C              AM(9,I)  = AM=0.0 
C            ENDDO
C          ENDIF

          AM(7,7) = AM(7,7) + YCEXPB*YCEXPB*TCORR*TCORR 
          AM(8,8) = AM(8,8) + YCEXPB*YCEXPB*BCORR*BCORR*SK(7)*SK(7) 
          AM(9,9) = AM(9,9) + YCEXPB*YCEXPB*BCORR*BCORR*SK(7)*SK(7)
     *              *SK(8)*SK(8)*(RSQ/4.0)*(RSQ/4.0) 

          AM(8,7) = AM(8,7) - YCEXPB*TCORR*YCEXPB*BCORR*SK(7) 
          AM(9,7) = AM(9,7) + YCEXPB*TCORR*YCEXPB*BCORR*SK(7)*SK(8)
     *              *(RSQ/4.0) 
          AM(9,8) = AM(9,8) - YCEXPB*BCORR*SK(7)*SK(8)*(RSQ/4.0)
     *              *YCEXPB*SK(7)*BCORR 

          Q  = Q+DY*DY

          IF(I_N.EQ.1) THEN

            NTOT=NTOT+N

            RZNUM=RZNUM+ABS(DY)      *N
            RZDEN=RZDEN+ABS(YO)      *N
            SUMC2=SUMC2+YC_NEW*YC_NEW*N
            SUMO2=SUMO2+YO*YO        *N
            SUMOC=SUMOC+YO*YC_NEW    *N
            SUMYC=SUMYC+YC_NEW       *N

          ENDIF
C ----
        ENDDO
C ----
  210   CONTINUE
        GO TO 200
C --------------------------
  220   CONTINUE
        
        IF(NTOT.LE.0) THEN
          CALL MSGERR(MDOC,
     *    ' ERROR: ANISOSCL: number of reflections = 0')
          IF(MTIN.GT.0) CLOSE(MTIN)
          CLOSE(MTNAT)
          IERR=1
          RETURN
        ENDIF

        IF(PATT.EQ.'I') THEN

          IF(MTIN.GT.0) THEN
            T =  SQRT(ABS(SUMFN2/SUMFD2))
            SCALE = SCALE * T
            RESULT( 2,3) = SCALE
            SK_OLD(7)    = SCALE
            WRITE(LINE,*) ' new_scale:',RESULT(2,3)
            CALL MSGDOC(MDOC,LINE)

          ENDIF

          IF(SOLV.EQ.'N') GO TO 3000

        ENDIF


        DO I=1,NPAR-1
          DO J=I+1,NPAR
            AM(I,J) = AM(J,I)
          ENDDO
        ENDDO

        DMAX=-1.0E30          
        DO I=1,NPAR
          IF(ABS(AM(I,I)).GT.DMAX) DMAX=AM(I,I)
        ENDDO

        TOL=1.0E-7
        DO   I=1,NPAR         
          IF(ABS(AM(I,I))/DMAX.LE.TOL) THEN
            V(I) = 0.0
            DO    J=1,NPAR
              AM(I,J) = 0.0
              AM(J,I) = 0.0
            ENDDO
          ENDIF  
        ENDDO

C     call ifix()

        DO   I=1,NPAR         
          IF(IFIX(I).GT.0) THEN
            V(I) = 0.0
            DO    J=1,NPAR
              AM(I,J) = 0.0
              AM(J,I) = 0.0
            ENDDO
          ENDIF  
        ENDDO

        CALL SVSOLV_ASC(AM,NPAR,NPAR,NPAR,NPAR,V,SHIFTS,IERR)
        IF(IERR.NE.0) THEN
C          IF(III.EQ.1) THEN
C            CALL MSGERR(MDOC,
C     *      ' WARNING: program: "anisoscl" is terminated')
c            IF(MTIN.GT.0) CLOSE(MTIN)
c            CLOSE(MTNAT)
c            RETURN
C            IERR=0   
C            JERR=1
C            GO TO 1000 
C          ELSE
          IF(IERR.EQ.2) THEN
            CALL MSGERR(MDOC,
     *     ' WARNING in SVDCMP: No convergence in 30 iterations')
          ELSE
            CALL MSGERR(MDOC,
     *     ' WARNING error in SVDCMP')
          ENDIF
            CALL MSGERR(MDOC,
     *     '         isoscaling will be used')
          IERR=0
          JERR=1   
          IF(MTIN.LE.0) THEN
            SCALE = 1.0
            BOVER = 0.0
          ELSE
            SCALE = SCALE_I
            BOVER = BOVER_I
          ENDIF
          CALL BISO_TO_B_ASC(SK,BOVER
     *       ,A,B,C,AL,BE,GA     
     *       ,AST,BST,CST,COALST,COBEST,COGAST)

          SK(1)=SK(1)/(AST*AST)          
          SK(2)=SK(2)/(BST*BST)
          SK(3)=SK(3)/(CST*CST)
          SK(4)=SK(4)/(AST*BST)
          SK(5)=SK(5)/(AST*CST)
          SK(6)=SK(6)/(BST*CST)

          SK(7)=SCALE
C ---
          DO I=1,NPAR
            SK_OLD(I)=SK(I)
          ENDDO
          GO TO 1000 
C         ENDIF
        ENDIF
C -------------------------
       
        IF(MTIN.GT.0) THEN

          SF1A   = RZDEN/NTOT
          SF2A   = SUMYC/NTOT
          SF12A  = SUMO2/NTOT
          SF22A  = SUMC2/NTOT
          SF1F2A = SUMOC/NTOT
          T1 = (SF12A-SF1A*SF1A)
          T2 = (SF22A-SF2A*SF2A)
          T1 = T1*T2

c          write(*,*) '-1',NTOT
c          write(*,*) '-1',SF1A
c          write(*,*) '-1',SF2A
c          write(*,*) '-1',SF12A
c          write(*,*) '-1',SF22A
c          write(*,*) '-1',SF1F2A
c          write(*,*) '-1',RZDEN
c          write(*,*) '-1',RZNUM
      



          IF(T1.GE.0.0) THEN
            CC = (SF1F2A-SF1A*SF2A)/SQRT(ABS(T1))
          ELSE
            CC =-1.0
          ENDIF


C          CC=(NTOT*SUMOC-RZDEN*SUMYC)/
C     *    SQRT(ABS((NTOT*SUMO2-RZDEN*RZDEN)*(NTOT*SUMC2 - SUMYC*SUMYC)))

          WRITE(LINE,'('' CORRELATION COEF:'',F8.5)') CC
          CALL MSGDOC(MD,LINE)
          RFACTOR=RZNUM/RZDEN
          WRITE(LINE,'('' R-factor        :'',F8.5)') RFACTOR
          CALL MSGDOC(MD,LINE)

          IF(III.GT.1)THEN
            DEL=ABS(Q-FUN_OLD)
            T=ABS(DEL/Q)
            IF(T.LT.1.E-6) GO TO 1000
          ENDIF

          IF(III.EQ.1.OR.(RFACTOR_OLD.GE.RFACTOR)) THEN
            DO I=1,NPAR
              SK_OLD(I)=SK(I)
            ENDDO 
            RFACTOR_OLD=RFACTOR            
            NC=III-1
            NREF_OLD=NREF
          ENDIF

        ELSE

          DO I=1,NPAR
            SK_OLD(I)=SK(I)
          ENDDO 
          NC=III-1
          NREF_OLD=NREF 
        ENDIF

        WRITE(LINE,'(''Sc:'',F10.5)') SK(7)
        CALL MSGDOC(MD,LINE)
        WRITE(LINE,'(''Bold:'',6E12.4)') (SK(J),J=1,6)
        CALL MSGDOC(MD,LINE)
        WRITE(LINE,'(''Ks,Bs:'',F12.5,F14.3)') SK(8),SK(9)
        CALL MSGDOC(MD,LINE)

        IF(MTIN.LE.0) THEN
          DO    I=1,NPAR
            SK_TMP(I) = SK(I)
          ENDDO
          SK_TMP(1)=SK(1)*AST*AST          
          SK_TMP(2)=SK(2)*BST*BST
          SK_TMP(3)=SK(3)*CST*CST
          SK_TMP(4)=SK(4)*AST*BST
          SK_TMP(5)=SK(5)*AST*CST
          SK_TMP(6)=SK(6)*BST*CST
          CALL CALC_B_EQUIV_ASC(SK_TMP,BISO
     *        ,A,B,C,AL,BE,GA     
     *        ,AST,BST,CST,COALST,COBEST,COGAST)

          WRITE(LINE,'('' B-equiv :'',G16.5)') BISO
          CALL MSGDOC(MD,LINE)

          IF(BISO.LT.0.0) THEN
            CALL MSGDOC(MD,
     *     'INFO:  isoscaling will be used')
            SCALE = 1.0
            BOVER = 0.0
            CALL BISO_TO_B_ASC(SK,BOVER
     *       ,A,B,C,AL,BE,GA     
     *       ,AST,BST,CST,COALST,COBEST,COGAST)
            SK(1)=SK(1)/(AST*AST)          
            SK(2)=SK(2)/(BST*BST)
            SK(3)=SK(3)/(CST*CST)
            SK(4)=SK(4)/(AST*BST)
            SK(5)=SK(5)/(AST*CST)
            SK(6)=SK(6)/(BST*CST)
            SK(7)=SCALE
            DO I=1,NPAR
              SK_OLD(I)=SK(I)
            ENDDO
            GO TO 1000 
          ENDIF
        ENDIF

        DO     I=1,NPAR
         SK(I)=SK(I)+(SHIFTS(I))
        ENDDO

C       set fix.
C Ks SK(8)     0.1 - 0.9      
C BS SK(9)     70 - 500

        IF(IFIX(8).LE.0) THEN
          IF(SK(8).LT.0.0999) THEN
            SK(8)  =0.1
            IFIX(8)=  1
          ELSE IF(SK(8).GT.0.899) THEN
            SK(8)  =0.9
            IFIX(8)=  1
          ENDIF
        ENDIF
        IF(IFIX(9).LE.0) THEN
          IF(SK(9).LT.70.01) THEN
            SK(9)  = 70.0
            IFIX(9)=  1
          ELSE IF(SK(9).GT.499.9) THEN
            SK(9)  = 500.0
            IFIX(9)=  1
          ENDIF
        ENDIF
        
        WRITE(LINE,'(''Sc:'',F10.5)') SK(7)
        CALL MSGDOC(MD,LINE)
        WRITE(LINE,'(''Bnew:'',6E12.4)') (SK(J),J=1,6)
        CALL MSGDOC(MD,LINE)
        WRITE(LINE,'(''Ks,Bs:'',F12.5,F14.3)') SK(8),SK(9)
        CALL MSGDOC(MD,LINE)
        WRITE(LINE,'(''shift  :'',F10.5)') SHIFTS(7)
        CALL MSGDOC(MD,LINE)
        WRITE(LINE,'(''shift  :'',6E12.4)') (SHIFTS(J),J=1,6)
        CALL MSGDOC(MD,LINE)
        WRITE(LINE,'(''        '',2F10.5)') SHIFTS(8),SHIFTS(9)
        CALL MSGDOC(MD,LINE)
        WRITE(LINE,'(''FUNCTION VALUE  : '',E14.5)') Q
        CALL MSGDOC(MD,LINE)
        WRITE(LINE,'(I6,'' reflections'')') NREF
        CALL MSGDOC(MD,LINE)
        CALL MSGDOC(MD,' ')
        FUN_OLD=Q

      ENDDO
 290  CONTINUE          
 300  CONTINUE                 

C -------------------------------------------------------
 1000 CONTINUE

      DO I=1,NPAR
        SK(I)=SK_OLD(I)
      ENDDO

      CALL MSGDOC(MDOC,' --------------------------')
      WRITE(LINE,'('' Scale      :'',2G16.5)') SK(7)
      CALL MSGDOC(MDOC,LINE)

      WRITE(LINE,'('' Ks,Bs      :'',2G16.5)') SK(8),SK(9)
      CALL MSGDOC(MDOC,LINE)

      WRITE(LINE,'('' Beta       :'',6F10.5)') (SK(J),J=1,6)
      CALL MSGDOC(MDOC,LINE)

      SK(1)=SK(1)*AST*AST          
      SK(2)=SK(2)*BST*BST
      SK(3)=SK(3)*CST*CST
      SK(4)=SK(4)*AST*BST
      SK(5)=SK(5)*AST*CST
      SK(6)=SK(6)*BST*CST

      CALL CALC_B_EQUIV_ASC(SK,BISO
     *        ,A,B,C,AL,BE,GA     
     *        ,AST,BST,CST,COALST,COBEST,COGAST)

      WRITE(LINE,'('' B-equiv        :'',G16.5)') BISO
      CALL MSGDOC(MDOC,LINE)


      CALL SOLV_ASC(SK,EVAL,EVEC,FRTOCR,CRTOFR
     *      ,A,B,C,AL,BE,GA     
     *      ,AST,BST,CST,COALST,COBEST,COGAST)

      WRITE(LINE,'('' Eigen values :'',3G16.5)') 
     *EVAL(1),EVAL(2),EVAL(3)
      CALL MSGDOC(MDOC,LINE)

      EMAX=1.0E-30
      DO I=1,3  
        IF(ABS(EVAL(I)).GT.EMAX) EMAX=ABS(EVAL(I))
      ENDDO
      IF(EMAX.GT.1.0E-5) THEN
        DO I=1,3
          RVAL(I)=EVAL(I)/EMAX
        ENDDO  
      ELSE
        DO I=1,3
          RVAL(I)=1.0
          EVAL(I)=1.0
        ENDDO  
      ENDIF

      WRITE(LINE,'('' Ratio        :'',3G16.5)') 
     *  RVAL(1),RVAL(2),RVAL(3)
      CALL MSGDOC(MDOC,LINE)
C ---
        RESULT( 1,1)=NC
        RESULT( 2,1)=SK_OLD(7)
        RESULT( 3,1)=SK_OLD(8)
        RESULT( 4,1)=SK_OLD(9)
        RESULT( 5,1)=SK_OLD(1)
        RESULT( 6,1)=SK_OLD(2)
        RESULT( 7,1)=SK_OLD(3)
        RESULT( 8,1)=SK_OLD(4)
        RESULT( 9,1)=SK_OLD(5)
        RESULT(10,1)=SK_OLD(6)
        RESULT(11,1)=RVAL(1)
        RESULT(12,1)=RVAL(2)
        RESULT(13,1)=RVAL(3)
        RESULT(14,1)=0.0
        RESULT(15,1)=0.0
        RESULT(16,1)=NREF_OLD
        RESULT(17,1)=RSMIN
        RESULT(18,1)=RSMAX
        RESULT(19,1)=BISO

        RESULT( 1,2)=EVAL(1)
        RESULT( 2,2)=EVAL(2)
        RESULT( 3,2)=EVAL(3)
        RESULT( 4,2)=EVEC(1,1)
        RESULT( 5,2)=EVEC(2,1)
        RESULT( 6,2)=EVEC(3,1)
        RESULT( 7,2)=EVEC(1,2)
        RESULT( 8,2)=EVEC(2,2)
        RESULT( 9,2)=EVEC(3,2)
        RESULT(10,2)=EVEC(1,3)
        RESULT(11,2)=EVEC(2,3)
        RESULT(12,2)=EVEC(3,3)

      IF(MTIN.LE.0) GO TO 2000

C -------------------------------------------------------
 3000 CONTINUE


c      write(*,*) '=2',bover,scale,SK_OLD(9),SK_OLD(8)

      NREF =0
      SUMFA=0.0
      SUMF =0.0
      FAV  =0.0
      FAVA =0.0
C -----
      CALL OPFILE(M,MTNAT,NAMEF,ITYPE,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.GT.0) THEN
        CALL MSGERR(MDOC,' ERROR: RE-OPEN F_TEST FILE')
        RETURN
      ENDIF
C ---
      CALL OPFILE(M,MTIN,NAMED,ITYP,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.GT.0) THEN
        CALL MSGERR(MDOC,' ERROR: RE-OPEN F_FOR_SCALE FILE')
        CLOSE(MTNAT)
        RETURN
      ENDIF
C ---
      MTOUT=13
      CALL LENSTR_BL(NAMEO,LEN)
      IF(LEN.LE.0.OR.NAMEO(1:1).EQ.','.OR.NAMEO(1:1).EQ.' ') THEN

C       NAMEO='anisoscl_fsc'
        MTOUT=0

      ENDIF

      CALL C_CR_WR

      IF(MTOUT.GT.0) THEN
        CALL SET_TITLE(MD,A,B,C,AL,BE,GA
     *    ,COEF1,BET1,RESMIN1,RESMAX1,NX,NY,NZ,IZN,IZM,TTT,IERR)
        CALL OWFILE(MD,MTOUT,NAMEO,ITYP,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.GT.0) THEN
          CALL MSGERR(MDOC,' ERROR: OPEN OUTPUT FILE')
          CLOSE(MTNAT)
          CLOSE(MTIN)
          RETURN
        ENDIF
      ENDIF
C ---
      IEND =-1
      IEND1=-1
      IEND2=-1
      NUMB = 0
      NUMB1= 0
      NUMB2= 0
      SD1  =0.0
      SD2  =0.0
      NTOT =0

      RZDEN=0
      RZNUM=0
      SUMYC=0
      SUMOC=0
      SUMO2=0
      SUMC2=0

      RZDEN_I=0
      RZNUM_I=0
      SUMYC_I=0
      SUMOC_I=0
      SUMO2_I=0
      SUMC2_I=0

      JH   =0
      JK   =0
      JL   =-1
  400 CONTINUE
C ---
      IF(ITYP.EQ.'F   ') THEN
        CALL RD2(MTIN,IH,IK,IL,FD,FDA,NUMB,IEND)
        SD1 =0.04*FD
        SD2 =0.04*FDA
      ELSE
        CALL RRD2(MTIN,IH,IK,IL,FD,FDA,SD1,SD2,NUMB,IEND)
        IF(SD1.LT.0.000001) SD1=0.04*FD
        IF(SD2.LT.0.000001) SD2=0.04*FDA
      ENDIF

      IF(IEND.EQ.1) GO TO 420

      IF(FD.GT.1.E-6.AND.FDA.GT.1.E-6) THEN
        WT1=1./(SD1*SD1)
        WT2=1./(SD2*SD2)
        WT  =WT1+WT2
        FMD =FD*WT1+FDA*WT2
        FMD =FMD/WT
        SFMD=1./SQRT(WT)
      ELSE IF(FDA.GT.1.E-6) THEN
        FMD =FDA
        SFMD=SD2
      ELSE
        FMD =FD
        SFMD=SD1
      ENDIF

      IF(IH.EQ.0.AND.IK.EQ.0.AND.IL.EQ.0) THEN
        FMOD=FD *SK_OLD(7)
        FAN =FDA*SK_OLD(7)
        GO TO 415
      ENDIF

      CALL DSTAR(IH,IK,IL,RSQ)
      RHKL=SQRT(RSQ)

      IF(BOFF.GT.0.0) THEN
        BT=BOFF/4.0
        CBOFF=1.0-EXP(-BT*RSQ)
      ELSE
        CBOFF=1.0
      ENDIF
      IF(ABS(BADD).GT.0.00001) THEN
        BT=BADD/4.0
        CBADD=EXP(-BT*RSQ)
      ELSE
        CBADD=1.0
      ENDIF
      
      IF(IEND2.GT.0) THEN
        FNN=-1.0
        GO TO 1271
      ENDIF

C 1255 IF(JL-IL) 1230,1250,1271
C 1250 IF(JK-IK) 1230,1260,1271
C 1260 IF(JH-IH) 1230,1270,1271

 1255 IF((JL-IL).LT.0) GO TO 1230
      IF((JL-IL).EQ.0) GO TO 1250
      IF((JL-IL).GT.0) GO TO 1271
 1250 IF((JK-IK).LT.0) GO TO 1230
      IF((JK-IK).EQ.0) GO TO 1260
      IF((JK-IK).GT.0) GO TO 1271
 1260 IF((JH-IH).LT.0) GO TO 1230
      IF((JH-IH).EQ.0) GO TO 1270
      IF((JH-IH).GT.0) GO TO 1271



 1230 CONTINUE

      IF(ITYPE.EQ.'FS  ') THEN
        CALL RRD1(MTNAT,JH,JK,JL,FN,FNA,SN,SNA,NUMB2,IEND2)
        IF(SN .LT.0.000001) SN =0.04*FN
        IF(SNA.LT.0.000001) SNA=0.04*FNA
      ELSE
        CALL RD1(MTNAT,JH,JK,JL,FN,FNA,NUMB2,IEND2)
        SN =0.04*FN
        SNA=0.04*FNA
      ENDIF
      
      IF(IEND2.GT.0) THEN
        FNN=-1.0
        GO TO 1271
      ENDIF
      GO TO 1255

 1271 CONTINUE
      FNN=-1.0
      GO TO 1272
 1270 CONTINUE
      FNN=FN
 1272 CONTINUE
C ---
      IF(PATT.EQ.'I') THEN

        TEMP   = BOVER/4.0
        EXPB   = EXP(-TEMP*RSQ)
        X      = SCALE*EXPB
        BT     = SK_OLD(9)/4.0
        BCORR  = EXP(-BT*RSQ)
        TCORR  = 1.0-SK_OLD(8)*BCORR
        X      = X*TCORR

      ELSE

        S1     = AST*IH 
        S2     = BST*IK
        S3     = CST*IL

        S11(1) = S1*S1
        S11(2) = S2*S2
        S11(3) = S3*S3
        S11(4) = S1*S2*2.0
        S11(5) = S1*S3*2.0
        S11(6) = S2*S3*2.0

        TEMP = 0.0
        DO I=1,6
          T=SK_OLD(I)*S11(I)
          TEMP=TEMP+T
        ENDDO

        EXPB   = EXP(-TEMP)
        X      = SK_OLD(7)*EXPB
        BT     = SK_OLD(9)/4.0
        BCORR  = EXP(-BT*RSQ)
        TCORR  = 1.0-SK_OLD(8)*BCORR
        X      = X*TCORR

      ENDIF

      FMOD=FD   *X
      FAN =FDA  *X
      SD1 =SD1  *X
      SD2 =SD2  *X


      IF((RHKL.GE.RHMIN.AND.RHKL.LE.RHMAX).AND.FNN.GE.0.0) THEN

        IF(FNN.LE.THRESH)  GO TO 1210
        IF(TOP.GT.1.0E-8) THEN
          IF(FNN.GT.TOP)     GO TO 1210
        ENDIF


        CALL CALC_EPS(N,IH,IK,IL,NSYM,ISYM)

        NTOT=NTOT+N

        FMD=FMD*CBOFF*CBADD
        FNN=FNN*CBOFF*CBADD

        YC = FMD*X
        YO = FNN

        DY = YO-YC  

        RZNUM=RZNUM+ABS(DY) *N
        RZDEN=RZDEN+ABS(YO) *N
        SUMC2=SUMC2+YC*YC   *N
        SUMO2=SUMO2+YO*YO   *N
        SUMOC=SUMOC+YO*YC   *N
        SUMYC=SUMYC+YC      *N

c        RZNUM_I=RZNUM_I+ABS(DY*DY) *N
c        RZDEN_I=RZDEN_I+ABS(YO*YO) *N
c        SUMC2_I=SUMC2_I+YC*YC*YC*YC*N
c        SUMO2_I=SUMO2_I+YO*YO*YO*YO*N
c        SUMOC_I=SUMOC_I+YO*YC*YO*YC*N
c        SUMYC_I=SUMYC_I+YC*YC      *N

      ENDIF

 1210 CONTINUE

C
      IF(FMOD.LE.THRESH.AND.FAN.LE.THRESH) GO TO 410

      IF(FMOD.LE.1.0E-20.AND.FAN.LE.1.0E-20) GO TO 410

      SUMF =SUMF +FMOD
      SUMFA=SUMFA+FAN

 415  CONTINUE

      NREF=NREF+1

      IF(MTOUT.GT.0) THEN
        IF(ITYP.EQ.'F   ') THEN
          CALL WRT(MTOUT,IH,IK,IL,FMOD,FAN,NUMB1,IEND1)
        ELSE
          CALL WWRT(MTOUT,IH,IK,IL,FMOD,FAN,SD1,SD2,NUMB1,IEND1)
        ENDIF
      ENDIF

  410 CONTINUE
      GO TO 400
C -------------------------
  420 IEND1=2
      IF(MTOUT.GT.0) THEN
        CALL WRT(MTOUT,IH,IK,IL,FMOD,FAN,NUMB1,IEND1)
      ENDIF
      IF(NREF.GT.0) THEN
        FAV =SUMF/NREF
        FAVA=SUMFA/NREF
      ENDIF
      CALL MSGDOC(MDOC,' --------------------------')
      WRITE(LINE,60) NREF
   60 FORMAT(' Write ',I6,' reflections.')
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,1060) NREF,FAV,FAVA
      CALL MSGDOC(MDOC,LINE)
      CLOSE(MTIN)
      CLOSE(MTNAT)
C ---
c          write(*,*) '-2',NTOT

      SF1A   = RZDEN/NTOT
      SF2A   = SUMYC/NTOT
      SF12A  = SUMO2/NTOT
      SF22A  = SUMC2/NTOT
      SF1F2A = SUMOC/NTOT

c          write(*,*) '-2',NTOT
c          write(*,*) '-2',SF1A
c          write(*,*) '-2',SF2A
c          write(*,*) '-2',SF12A
c          write(*,*) '-2',SF22A
c          write(*,*) '-2',SF1F2A
c          write(*,*) '-2',RZDEN
c          write(*,*) '-2',RZNUM




      T1 = (SF12A-SF1A*SF1A)
      T2 = (SF22A-SF2A*SF2A)
      T1 = T1*T2
      IF(T1.GE.0.0) THEN
        CC = (SF1F2A-SF1A*SF2A)/SQRT(ABS(T1))
      ELSE
        CC =-1.0
      ENDIF

c          write(*,*) '-2-'

C      CC=(NTOT*SUMOC-RZDEN*SUMYC)/
C     *  SQRT(ABS((NTOT*SUMO2-RZDEN*RZDEN)*(NTOT*SUMC2 - SUMYC*SUMYC)))

      WRITE(LINE,'('' CORRELATION COEF:'',F8.5)') CC
      CALL MSGDOC(MDOC,LINE)
      RFACTOR=RZNUM/RZDEN
      WRITE(LINE,'('' R-factor        :'',F8.5)') RFACTOR
      CALL MSGDOC(MDOC,LINE)


c      SF1A   = RZDEN_I/NTOT
c      SF2A   = SUMYC_I/NTOT
c      SF12A  = SUMO2_I/NTOT
c      SF22A  = SUMC2_I/NTOT
c      SF1F2A = SUMOC_I/NTOT

c          write(*,*) '-3',NTOT
c          write(*,*) '-3',SF1A
c          write(*,*) '-3',SF2A
c          write(*,*) '-3',SF12A
c          write(*,*) '-3',SF22A
c          write(*,*) '-3',SF1F2A
c          write(*,*) '-3',RZDEN_I
c          write(*,*) '-3',RZNUM_I


c      T1 = (SF12A-SF1A*SF1A)
c      T2 = (SF22A-SF2A*SF2A)
c      T1 = T1*T2
c      IF(T1.GE.0.0) THEN
c        CC_I = (SF1F2A-SF1A*SF2A)/SQRT(ABS(T1))
c      ELSE
c        CC_I =-1.0
c      ENDIF

c          write(*,*) '-3-'

C      CC_I=(NTOT*SUMOC_I-RZDEN_I*SUMYC_I)/
C     *  SQRT(ABS((NTOT*SUMO2_I-RZDEN_I*RZDEN_I)*
C     *  (NTOT*SUMC2_I - SUMYC_I*SUMYC_I)))

      CC_I      = 0.0
      RFACTOR_I = 0.0

c      WRITE(LINE,'('' CORRELATION COEF_I:'',G16.5)') CC_I
c      CALL MSGDOC(MDOC,LINE)
c      RFACTOR_I=RZNUM_I/RZDEN_I
c      WRITE(LINE,'('' R-factor_I        :'',G16.5)') RFACTOR_I
c      CALL MSGDOC(MDOC,LINE)

        RESULT(14,1)=RFACTOR
        RESULT(15,1)=CC
        RESULT(16,1)=NREF

        RESULT(20,1)=RFACTOR_I
        RESULT(21,1)=CC_I

C ----
      RETURN
C -------------------------------------------------
 2000 CONTINUE

      NREF =0
      SUMFA=0.0
      SUMF =0.0
      FAV  =0.0
      FAVA =0.0
      MTOUT=13
C -----
      CALL OPFILE(M,MTNAT,NAMEF,ITYPE,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.GT.0) THEN
        CALL MSGERR(MDOC,' ERROR: RE-OPEN F_TEST FILE')
        RETURN
      ENDIF
C ---
      CALL LENSTR_BL(NAMEO,LEN)

      IF(LEN.LE.0.OR.NAMEO(1:1).EQ.','.OR.NAMEO(1:1).EQ.' ') THEN

C        NAMEO='anisoscl_fsc'
        MTOUT= 0

      ENDIF
      IF(MTOUT.GT.0) THEN
        CALL C_CR_WR
        ITYP=ITF2
        CALL SET_TITLE(MD,A,B,C,AL,BE,GA
     *    ,F1,F2,RESMIN2,RESMAX2,NX,NY,NZ,IZN,IZM,TITLE,IERR)
        CALL OWFILE(MD,MTOUT,NAMEO,ITYP,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.GT.0) THEN
          CALL MSGERR(MDOC,' ERROR: OPEN OUTPUT FILE')
          CLOSE(MTNAT)
          CLOSE(MTIN)
          RETURN
        ENDIF
      ENDIF
C ---
      IEND =-1
      IEND1=-1
      NUMB = 0
      NUMB1= 0
      SD1  =0.0
      SD2  =0.0
 2400 CONTINUE
C ---
      IF(ITYP.EQ.'F   ') THEN
        CALL RD2(MTNAT,IH,IK,IL,FD,FDA,NUMB,IEND)
        SD1 =0.04*FD
        SD2 =0.04*FDA
      ELSE
        CALL RRD2(MTNAT,IH,IK,IL,FD,FDA,SD1,SD2,NUMB,IEND)
        IF(SD1.LT.0.000001) SD1=0.04*FD
        IF(SD2.LT.0.000001) SD2=0.04*FDA
      ENDIF

      IF(IEND.EQ.1) GO TO 2420

      IF(FD.GT.1.E-6.AND.FDA.GT.1.E-6) THEN
        WT1=1./(SD1*SD1)
        WT2=1./(SD2*SD2)
        WT  =WT1+WT2
        FMD =FD*WT1+FDA*WT2
        FMD =FMD/WT
        SFMD=1./SQRT(WT)
      ELSE IF(FDA.GT.1.E-6) THEN
        FMD =FDA
        SFMD=SD2
      ELSE
        FMD =FD
        SFMD=SD1
      ENDIF

      IF(IH.EQ.0.AND.IK.EQ.0.AND.IL.EQ.0) THEN
        FMOD = FD
        FAN  = FDA
        GO TO 2415
      ENDIF

      CALL DSTAR(IH,IK,IL,RSQ)

C ---
      S1     = AST*IH 
      S2     = BST*IK
      S3     = CST*IL

      S11(1) = S1*S1
      S11(2) = S2*S2
      S11(3) = S3*S3
      S11(4) = S1*S2*2.0
      S11(5) = S1*S3*2.0
      S11(6) = S2*S3*2.0

      TEMP = 0.0
      DO I=1,6
        T=SK_OLD(I)*S11(I)
        TEMP=TEMP+T
      ENDDO

      T=BOVER/4.0
      TEMP=TEMP-(T*RSQ)

      X   = EXP(TEMP)

      FMOD=FD   *X
      FAN =FDA  *X
      SD1 =SD1  *X
      SD2 =SD2  *X



c     IF(FMOD.LE.1.0E-20.AND.FAN.LE.1.0E-20) GO TO 2410

      SUMF =SUMF +FMOD
      SUMFA=SUMFA+FAN

2415  CONTINUE

      NREF=NREF+1

      IF(MTOUT.GT.0) THEN
        IF(ITYP.EQ.'F   ') THEN
          CALL WRT(MTOUT,IH,IK,IL,FMOD,FAN,NUMB1,IEND1)
        ELSE
          CALL WWRT(MTOUT,IH,IK,IL,FMOD,FAN,SD1,SD2,NUMB1,IEND1)
        ENDIF
      ENDIF

 2410 CONTINUE
      GO TO 2400
C -------------------------
 2420 IEND1=2

      IF(MTOUT.GT.0) THEN
        CALL WRT(MTOUT,IH,IK,IL,FMOD,FAN,NUMB1,IEND1)
      ENDIF

      IF(NREF.GT.0) THEN
        FAV =SUMF/NREF 
        FAVA=SUMFA/NREF
      ENDIF
      CALL MSGDOC(MDOC,' --------------------------')
      WRITE(LINE,2060) NREF
 2060 FORMAT(' Write ',I6,' reflections')
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,1060) NREF,FAV,FAVA
 1060 FORMAT('NUMB REFLS=',I6,
     *       ' F(h,k,l)-AVER=',E12.4,' F(-h,-k,-l)-AVER=',E12.4)
      CALL MSGDOC(MDOC,LINE)
      IF(MTNAT.GT.0) CLOSE(MTNAT)
C ---
      RESULT(16,1)=NREF
      RETURN
      END 

      SUBROUTINE GNR_IND_ANISO(N,IHH,IKK,ILL,NSYM,ISYM)
C
C     GENERATE H,K,L,F FOR SEMI-SPHERE / L >= 0 /
C
      INTEGER*2 ISYM(5,3,NSYM)
      INTEGER   IHH(192),IKK(192),ILL(192)
C --------------------------------------------
      N=1
      IH1=IHH(1)
      IK1=IKK(1)
      IL1=ILL(1)
      IF(NSYM.LE.1) RETURN

      DO     I=2,NSYM
        JH=ISYM(1,1,I)*IH1 +ISYM(1,2,I)*IK1 +ISYM(1,3,I)*IL1
        JK=ISYM(2,1,I)*IH1 +ISYM(2,2,I)*IK1 +ISYM(2,3,I)*IL1
        JL=ISYM(3,1,I)*IH1 +ISYM(3,2,I)*IK1 +ISYM(3,3,I)*IL1
        IF(JL.LT.0) THEN
          JH=-JH
          JK=-JK
          JL=-JL
        ELSE IF(JL.EQ.0) THEN
          IF(JK.LT.0) THEN
            JH=-JH
            JK=-JK
          ELSE IF(JK.EQ.0) THEN
            IF(JH.LT.0) THEN
              JH=-JH
            ENDIF
          ENDIF
        ENDIF
        IF(N.GT.0) THEN
          DO  L=1,N
            IF(IHH(L).EQ.JH.AND.IKK(L).EQ.JK.AND.ILL(L).EQ.JL)GOTO 10
          ENDDO
        ENDIF
        N = N+1
        IHH(N)=JH
        IKK(N)=JK
        ILL(N)=JL
   10   CONTINUE
      ENDDO
      RETURN
      END

      SUBROUTINE CALC_B_EQUIV_ASC(BETA,B_EQUIV
     *        ,A,B,C,AANGL,BANGL,GANGL     
     *        ,AST,BST,CST,COALST,COBEST,COGAST)
C ------------------------
      REAL BETA(*)
      REAL G(3,3),GS(3,3),BT(3,3)
C ------------------------
      PI   =4.0*ATAN(1.0)
      TWOPI=2.0*PI
C ------------------------
      G(1,1)=A*A
      G(2,2)=B*B
      G(3,3)=C*C
      G(1,2)=A*B*COS(GANGL)
      G(2,1)=G(1,2)
      G(1,3)=A*C*COS(BANGL)
      G(3,1)=G(1,3)
      G(2,3)=B*C*COS(AANGL)
      G(3,2)=G(2,3)
C ---
      GS(1,1)=AST*AST
      GS(2,2)=BST*BST
      GS(3,3)=CST*CST
      GS(1,2)=AST*BST*COGAST
      GS(2,1)=GS(1,2)
      GS(1,3)=AST*CST*COBEST
      GS(3,1)=GS(1,3)
      GS(2,3)=BST*CST*COALST
      GS(3,2)=GS(2,3)
C ---
      BT(1,1)=BETA(1)
      BT(2,2)=BETA(2)
      BT(3,3)=BETA(3)
      BT(1,2)=BETA(4)
      BT(1,3)=BETA(5)
      BT(2,3)=BETA(6)
      BT(2,1)=BT(1,2)
      BT(3,1)=BT(1,3)
      BT(3,2)=BT(2,3)
C ---
C      write(*,*)
C      write(*,*) ' g:',g(1,1),g(1,2),g(1,3)
C      write(*,*) ' g:',g(2,1),g(2,2),g(2,3)
C      write(*,*) ' g:',g(3,1),g(3,2),g(3,3)
C -----------------
      SUM=0.0
      DO I=1,3
      DO J=1,3
        SUM=SUM+BT(I,J)*G(I,J)
      ENDDO
      ENDDO     
      B_EQUIV=(SUM*4.0)/3.0
C -----------------
      RETURN
      END

      SUBROUTINE BISO_TO_B_ASC(BETA,BISO
     *        ,A,B,C,AANGL,BANGL,GANGL     
     *        ,AST,BST,CST,COALST,COBEST,COGAST)
C ------------------------
      REAL BETA(*)
      REAL G(3,3),GS(3,3)
C ------------------------
      PI   =4.0*ATAN(1.0)
      TWOPI=2.0*PI
C ------------------------
      G(1,1)=A*A
      G(2,2)=B*B
      G(3,3)=C*C
      G(1,2)=A*B*COS(GANGL)
      G(2,1)=G(1,2)
      G(1,3)=A*C*COS(BANGL)
      G(3,1)=G(1,3)
      G(2,3)=B*C*COS(AANGL)
      G(3,2)=G(2,3)
C ---
      GS(1,1)=AST*AST
      GS(2,2)=BST*BST
      GS(3,3)=CST*CST
      GS(1,2)=AST*BST*COGAST
      GS(2,1)=GS(1,2)
      GS(1,3)=AST*CST*COBEST
      GS(3,1)=GS(1,3)
      GS(2,3)=BST*CST*COALST
      GS(3,2)=GS(2,3)
C ---
C -----------------
      BETA(1)=(GS(1,1)*BISO)/4.0
      BETA(2)=(GS(2,2)*BISO)/4.0
      BETA(3)=(GS(3,3)*BISO)/4.0
      BETA(4)=(GS(1,2)*BISO)/4.0
      BETA(5)=(GS(1,3)*BISO)/4.0
      BETA(6)=(GS(2,3)*BISO)/4.0
C -----------------
C      write(*,*)  
C      WRITE(*,*) ' B:',BETA(1),BETA(2),BETA(3),BETA(4)
C     * ,BETA(5),BETA(6)
      RETURN
      END


      SUBROUTINE SOLV_ASC(B_ANIS,EVAL,EVEC,FRTOCR,CRTOFR
     *      ,ACELL,BCELL,CCELL,AANGL,BANGL,GANGL     
     *      ,AST,BST,CST,COALST,COBEST,COGAST)
C      SUBROUTINE SOLV(U_ANIS,FRTOCR,CRTOFR
C     *      ,ACELL,BCELL,CCELL,AANGL,BANGL,GANGL     
C     *      ,AST,BST,CST,COALST,COBEST,COGAST)
C ------------------------------------------------------------
      REAL   B_ANIS(*),R(3,3),G(3,3),GS(3,3),BT(3,3)
      REAL   V(3,3),VT(3,3),Y(3)
      REAL   VO(3,3),VOT(3,3),AO(3,3),CRTOFRT(3,3),FRTOCRT(3,3)
      REAL   U_ANIS(6),A(3,3),FRTOCR(3,3),CRTOFR(3,3)
      REAL   S(3,3),X(3),BETA(6)
      REAL   EVAL(3),EVEC(3,3),DISP(3)
      DATA   ZIP/1.0E-5/
      DATA   MM/10/
C ------------------------------------
      PI   =4.0*ATAN(1.0)
      TWOPI=2.0*PI
      CONST=TWOPI*PI
C -------------------------------
C      CALL  INVERT(GV,GVI,IERR)
C
C     SUBROUTINE MCOPY(X,Y)      
C -P- MCOPY - [Y] <= [X]
C
C      SUBROUTINE MATMLT(X,Y,Z)
C      REAL X(3,3),Y(3,3),Z(3,3)
C -P- MATMLT - [Z] =[X] [Y]
C
C      SUBROUTINE MTRANS(AM,BM)
C      REAL AM(3,3),BM(3,3)
C
C -P- MTRANS - matrix transposition
C           ! 11 21 31 !            ! 11 12 13 !  
C     AM  = ! 12 22 32 !  --> BM =  ! 21 22 33 !
C           ! 13 23 33 !            ! 31 32 33 !    
C     It is posible to use CALL MTRANS(AM,AM)
C----SET UP THE A MATRIX
C      SUBROUTINE FTOO(X,Y,IERR)
C      SUBROUTINE FTOO(X,Y,IERR)
C      SUBROUTINE OTOF(X,Y,IERR)
C -----------------------------------
C
C metric matrix G in direct space
C
      G(1,1)=ACELL*ACELL
      G(2,2)=BCELL*BCELL
      G(3,3)=CCELL*CCELL
      G(1,2)=ACELL*BCELL*COS(GANGL)
      G(2,1)=G(1,2)
      G(1,3)=ACELL*CCELL*COS(BANGL)
      G(3,1)=G(1,3)
      G(2,3)=BCELL*CCELL*COS(AANGL)
      G(3,2)=G(2,3)
C -----------------------------------
C
C metric matrix G* in reciprocal space
C
      GS(1,1)=AST*AST
      GS(2,2)=BST*BST
      GS(3,3)=CST*CST
      GS(1,2)=AST*BST*COGAST
      GS(2,1)=GS(1,2)
      GS(1,3)=AST*CST*COBEST
      GS(3,1)=GS(1,3)
      GS(2,3)=BST*CST*COALST
      GS(3,2)=GS(2,3)
C -------------------------------------
C  tensor U
C 
C      A(1,1)=U_ANIS(1)
C      A(2,2)=U_ANIS(2)
C      A(3,3)=U_ANIS(3)
C      A(1,2)=U_ANIS(4)
C      A(1,3)=U_ANIS(5)
C      A(2,3)=U_ANIS(6)
C      A(2,1)=A(1,2)
C      A(3,1)=A(1,3)
C      A(3,2)=A(2,3)      
C -------------------------------------
C      write(*,*)
C      write(*,*) ' u:',a(1,1),a(1,2),a(1,3)
C      write(*,*) ' u:',a(2,1),a(2,2),a(2,3)
C      write(*,*) ' u:',a(3,1),a(3,2),a(3,3)
C -------------------------------------
C      CALL U_TO_B(U_ANIS,B_ANIS
C     *      ,ACELL,BCELL,CCELL,AANGL,BANGL,GANGL     
C     *      ,AST,BST,CST,COALST,COBEST,COGAST)

C      write(*,*)  
C      WRITE(*,*) ' B:',B_ANIS(1),B_ANIS(2),B_ANIS(3),B_ANIS(4)
C     * ,B_ANIS(5),B_ANIS(6)
C ---------------------------
C
C   tensor B
C 
      BT(1,1)=B_ANIS(1)
      BT(2,2)=B_ANIS(2)
      BT(3,3)=B_ANIS(3)
      BT(1,2)=B_ANIS(4)
      BT(1,3)=B_ANIS(5)
      BT(2,3)=B_ANIS(6)
      BT(2,1)=BT(1,2)
      BT(3,1)=BT(1,3)
      BT(3,2)=BT(2,3)
C      write(*,*)
C      write(*,*) ' b:',bt(1,1),bt(1,2),bt(1,3)
C      write(*,*) ' b:',bt(2,1),bt(2,2),bt(2,3)
C      write(*,*) ' b:',bt(3,1),bt(3,2),bt(3,3)
C -----------------------------
C   tensor   U* = B/2PI^2    
C
      BT(1,1)=BT(1,1)/CONST
      BT(2,1)=BT(2,1)/CONST
      BT(3,1)=BT(3,1)/CONST
      BT(1,2)=BT(1,2)/CONST
      BT(2,2)=BT(2,2)/CONST
      BT(3,2)=BT(3,2)/CONST
      BT(1,3)=BT(1,3)/CONST
      BT(2,3)=BT(2,3)/CONST
      BT(3,3)=BT(3,3)/CONST
C      write(*,*)
C      write(*,*) ' u*:',bt(1,1),bt(1,2),bt(1,3)
C      write(*,*) ' u*:',bt(2,1),bt(2,2),bt(2,3)
C      write(*,*) ' u*:',bt(3,1),bt(3,2),bt(3,3)
C ------------------------------

C VVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVV
C      V(1,1)=-.0393
C      V(1,2)=-.028
C      V(1,3)=-.1515
C
C      V(2,1)=-.0139
C      V(2,2)=-.0866
C      V(2,3)= .0587
C
C      V(3,1)=-.1097
C      V(3,2)= .0210
C      V(3,3)= .0492
C      CALL  MTRANS(V,VT)
C
C      X(1)=-.0393
C      X(2)=-.028
C      X(3)=-.1515
C      CALL FTOO(X,Y,IERR)
C      VO(1,1)=Y(1)
C      VO(1,2)=Y(2)
C      VO(1,3)=Y(3)
C
C      X(1)=-.0139
C      X(2)=-.0866
C      X(3)= .0587
C      CALL FTOO(X,Y,IERR)
C      VO(2,1)=Y(1)
C      VO(2,2)=Y(2)
C      VO(2,3)=Y(3)
C
C      X(1)=-.1097
C      X(2)= .0210
C      X(3)= .0492
C      CALL FTOO(X,Y,IERR)
C      VO(3,1)=Y(1)
C      VO(3,2)=Y(2)
C      VO(3,3)=Y(3)
C      CALL  MTRANS(VO,VOT)
C
C      write(*,*)
C      write(*,*) ' vo:',VO(1,1),VO(1,2),VO(1,3)
C      write(*,*) ' vo:',VO(2,1),VO(2,2),VO(2,3)
C      write(*,*) ' vo:',VO(3,1),VO(3,2),VO(3,3)
C ---
C ok
c      CALL  MATMLT(G,V,GV)
c      CALL  MATMLT(BT,GV,R)
c      CALL  MATMLT(G,R,S)
c      CALL  MATMLT(VT,S,R)
C^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

C ---------------------------------
C
C     tensor U = G U* G
C
      CALL  MATMLT(BT,G,S)
      CALL  MATMLT(G,S,R)

C      write(*,*)
C      write(*,*) ' u:',r(1,1),r(1,2),r(1,3)
C      write(*,*) ' u:',r(2,1),r(2,2),r(2,3)
C      write(*,*) ' u:',r(3,1),r(3,2),r(3,3)
C -----------------------------
C
C     tensor in cartesian. system Uo = [CtoF]' U [CtoF]
C  
      CALL  MTRANS(CRTOFR,CRTOFRT)

      CALL  MATMLT(R,CRTOFR,S)
      CALL  MATMLT(CRTOFRT,S,A)
C -----------------------------------------

c VVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVV
C      CALL  MATMLT(A,VO,S)
C      CALL  MATMLT(VOT,S,AO)
C 
C      write(*,*)
C      write(*,*) ' g:',G(1,1),G(1,2),G(1,3)
C      write(*,*) ' g:',G(2,1),G(2,2),G(2,3)
C      write(*,*) ' g:',G(3,1),G(3,2),G(3,3)
C      write(*,*)
C      write(*,*) ' v:',V(1,1),V(1,2),V(1,3)
C      write(*,*) ' v:',V(2,1),V(2,2),V(2,3)
C      write(*,*) ' v:',V(3,1),V(3,2),V(3,3)
C      write(*,*)
C      write(*,*) ' r:',R(1,1),R(1,2),R(1,3)
C      write(*,*) ' r:',R(2,1),R(2,2),R(2,3)
C      write(*,*) ' r:',R(3,1),R(3,2),R(3,3)
C      write(*,*)
C      write(*,*) ' ao:',AO(1,1),AO(1,2),AO(1,3)
C      write(*,*) ' ao:',AO(2,1),AO(2,2),AO(2,3)
C      write(*,*) ' ao:',AO(3,1),AO(3,2),AO(3,3)
C
C      CALL  MATMLT(R,CRTOFR,S)
C      CALL  MATMLT(CRTOFR,S,R)
C      CALL  MTRANS(R,A)
C      
C      write(*,*)
C      write(*,*) ' r:',R(1,1),R(1,2),R(1,3)
C      write(*,*) ' r:',R(2,1),R(2,2),R(2,3)
C      write(*,*) ' r:',R(3,1),R(3,2),R(3,3)
C
C      CALL  MATMLT(A,FRTOCR,S)
C      CALL  MATMLT(FRTOCR,S,A)
C      CALL  MTRANS(A,A)
C      CALL  MTRANS(A,A)
C
c       CALL  MCOPY(AO,A)
c       CALL  MCOPY(AO,A)
C
c      a(2,1)=0
c      a(3,1)=0
c      a(3,2)=0
c      a(1,2)=0
c      a(1,3)=0
c      a(2,3)=0
C
C^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^


C ----------------------
C      write(*,*) 
C      write(*,*) ' Uo:',a(1,1),a(1,2),a(1,3)
C      write(*,*) ' Uo:',a(2,1),a(2,2),a(2,3)
C      write(*,*) ' Uo:',a(3,1),a(3,2),a(3,3)
C -----------------------------------------------------
C     eigen value : EVAL(i)
C     eigen vector: EVEC(1,i)
C                   EVEC(2,i)
C                   EVEC(3,i)
C                   
      N=3
      CALL  CALCRS_ASC(N,A,EVAL,EVEC)

      RETURN

C      write(*,*) 
C      write(*,*) ' E:',eval(1),eval(2),eval(3)
C      write(*,*) 
C      write(*,*) ' e:',evec(1,1),evec(1,2),evec(1,3)
C      write(*,*) ' e:',evec(2,1),evec(2,2),evec(2,3)
C      write(*,*) ' e:',evec(3,1),evec(3,2),evec(3,3)
C
C      t=(eval(1)+eval(2)+eval(3))/(3.0*twopi*pi)
C      write(*,*) ' t:',t      
C      scale=t
C --------------------------
C
C   <u^2>i mean-square displacement along the ith principal axis.
C
C   <u^2>i = Eval(i)/2pi^2 ( in A^2 )
C
C
C      DISP(1)=EVAL(1)
C      DISP(2)=EVAL(2)
C      DISP(3)=EVAL(3)
C
C      write(*,*) 
C      write(*,*) ' D^2:',disp(1),disp(2),disp(3)
C      DISP(1)=SQRT(DISP(1))
C      DISP(2)=SQRT(DISP(2))
C      DISP(3)=SQRT(DISP(3))
C      write(*,*) 
C      write(*,*) ' D:',disp(1),disp(2),disp(3)
C --------------------------
C
C  eigen vectors in ort. system
C
C                                      !  V1(1) V2(1)  V3(1) !
C matrix transformation      VO[3,3] = !  V1(2) V2(2)  V3(2) !
C                                      !  V1(3) V2(3)  V3(3) !
C
C     from standard Ort.system to principial axis
C
C     Up = VO' Uo VO
C
C
C      Y(1)=EVEC(1,1)
C      Y(2)=EVEC(2,1)
C      Y(3)=EVEC(3,1)
C      CALL OTOF(Y,X)
C      WRITE(*,*) 'fr1:',X(1),X(2),X(3)        
C      Y(1)=EVEC(1,2)
C      Y(2)=EVEC(2,2)
C      Y(3)=EVEC(3,2)
C      CALL OTOF(Y,X)
C      WRITE(*,*) 'fr2:',X(1),X(2),X(3)        
C      Y(1)=EVEC(1,3)
C      Y(2)=EVEC(2,3)
C      Y(3)=EVEC(3,3)
C      CALL OTOF(Y,X)
C      WRITE(*,*) 'fr3:',X(1),X(2),X(3)        
C
C
C      VO(1,1)=EVEC(1,1)
C      VO(2,1)=EVEC(2,1)
C      VO(3,1)=EVEC(3,1)
C      VO(1,2)=EVEC(1,2)
C      VO(2,2)=EVEC(2,2)
C      VO(3,2)=EVEC(3,2)
C      VO(1,3)=EVEC(1,3)
C      VO(2,3)=EVEC(2,3)
C      VO(3,3)=EVEC(3,3)
C for blanc
C      CALL  MTRANS(VO,VO)
C      CALL  MTRANS(VO,VOT)
C      write(*,*)
C      write(*,*) ' vo:',VO(1,1),VO(1,2),VO(1,3)
C      write(*,*) ' vo:',VO(2,1),VO(2,2),VO(2,3)
C      write(*,*) ' vo:',VO(3,1),VO(3,2),VO(3,3)
C
C      CALL  MATMLT(A,VO,S)
C      CALL  MATMLT(VOT,S,AO)
C
C      write(*,*)
C      write(*,*) ' Uc:',AO(1,1),AO(1,2),AO(1,3)
C      write(*,*) ' Uc:',AO(2,1),AO(2,2),AO(2,3)
C      write(*,*) ' Uc:',AO(3,1),AO(3,2),AO(3,3)
C     
C
C VVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVV
C
C      WRITE(*,*) ' ======================='
C      CALL  INVERT(VO,S,IERR)
C      CALL  MCOPY(S,VO)
C      CALL  MTRANS(VO,VOT)
C
C      CALL  MATMLT(AO,VO,S)
C      CALL  MATMLT(VOT,S,A)
C
C      write(*,*) 
C      write(*,*) ' Uo:',a(1,1),a(1,2),a(1,3)
C      write(*,*) ' Uo:',a(2,1),a(2,2),a(2,3)
C      write(*,*) ' Uo:',a(3,1),a(3,2),a(3,3)
C
C      CALL  MTRANS(FRTOCR,FRTOCRT)
C
C      CALL  MATMLT(A,FRTOCR,S)
C      CALL  MATMLT(FRTOCRT,S,R)
C
C      write(*,*)
C      write(*,*) ' u:',r(1,1),r(1,2),r(1,3)
C      write(*,*) ' u:',r(2,1),r(2,2),r(2,3)
C      write(*,*) ' u:',r(3,1),r(3,2),r(3,3)
C
C      U_ANIS(1)=R(1,1)
C      U_ANIS(2)=R(2,2)
C      U_ANIS(3)=R(3,3)
C      U_ANIS(4)=R(1,2)
C      U_ANIS(5)=R(1,3)
C      U_ANIS(6)=R(2,3)
C
C      U_ANIS(1)=R(1,1)/CONST
C      U_ANIS(2)=R(2,2)/CONST
C      U_ANIS(3)=R(3,3)/CONST
C      U_ANIS(4)=R(1,2)/CONST
C      U_ANIS(5)=R(1,3)/CONST
C      U_ANIS(6)=R(2,3)/CONST
C
C      CALL U_TO_B(U_ANIS,BETA
C     *      ,ACELL,BCELL,CCELL,AANGL,BANGL,GANGL     
C     *      ,AST,BST,CST,COALST,COBEST,COGAST)
C
C      write(*,*)  
C      WRITE(*,*) ' B:',BETA(1),BETA(2),BETA(3),BETA(4)
C     * ,BETA(5),BETA(6)
C
C ===
C^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
C      RETURN

      END

C
C
C
C     ******************************************************************
      SUBROUTINE CALCRS_ASC(N,R,EVAL,EVEC)
C     ******************************************************************
C
C     THIS SUBROUTINE CALCULATE EIGENVALUES (EVAL) AND VECTORS (EVEC) OF
C     MATRIX R OF ORDER N 
C 
C     PARAMETERS:
C
C     N     = ON ENTRY, ORDER OF MATRIX R FOR WHICH COMPUTATIONS ARE
C             DONE. UNCHANGED ON EXIT.
C     R     = REAL SYMMETRIC MATRIX OF DIMENSIONS N BY N.
C             UNCHANGED ON EXIT.
C     EVAL  = REAL ARRAY OF PHYSICAL DIMENSION N WHICH, ON EXIT,
C             CONTAINS EIGENVALUES OF R.
C     EVEC  = REAL MATRIX OF DIMENSIONS N BY N, WHOSE COLUMNS CONTAIN,
C             ON EXIT, THE EIGENVECTORS OF R.
C
      IMPLICIT    NONE
      INTEGER     NMAX
      PARAMETER  (NMAX=6)
C
      INTEGER     II,IL,I1,I2,J,K,NROT,IFAIL,N
      REAL        R(N,N),EVAL(N),EVEC(N,N),R2(NMAX)
C
C      IF (N*(N+1)/2.GT.NMAX)
C     &CALL MSGERR('MAXIMUM NUMBER OF ELEMENTS EXCEEDED IN ') //
C     &' CALCRS; CHANGE NMAX')
C
      IL=0
      DO  I1=1,N
        DO  I2=1,I1
          IL=IL+1
          R2(IL)=R(I1,I2)
        ENDDO
      ENDDO
C  
      CALL EIGEN_ASC(R2,EVEC,N,0)
C
      K=0
      DO  J=1,N
        K=K+J
        EVAL(J)=R2(K)
      ENDDO
      END
C
C
C
C     ******************************************************************
      SUBROUTINE EIGEN_ASC(A, R, N, MV)
C     ******************************************************************
C
C---- SUBROUTINE TO COMPUTE EIGENVALUES & EIGENVECTORS OF A REAL
C---- SYMMETRIC MATRIX, FROM IBM SSP MANUAL (SEE P165).
C---- DESCRIPTION OF PARAMETERS -
C---- A - ORIGINAL MATRIX STORED COLUMNWISE AS UPPER TRIANGLE ONLY,
C---- I.E. "STORAGE MODE" = 1.  EIGENVALUES ARE WRITTEN INTO DIAGONAL
C---- ELEMENTS OF A  I.E.  A(1)  A(3)  A(6)  FOR A 3*3 MATRIX.
C---- R - RESULTANT MATRIX OF EIGENVECTORS STORED COLUMNWISE IN SAME
C---- ORDER AS EIGENVALUES.
C---- N - ORDER OF MATRICES A & R.
C---- MV = 0 TO COMPUTE EIGENVALUES & EIGENVECTORS.
C
C
      IMPLICIT    NONE
      REAL        A(*), R(*)
      INTEGER     N, MV
C
      INTEGER     IQ, J, I, IJ, IA, IND, L, M, MQ, LQ, LM, LL, MM
      INTEGER     ILQ, IMQ, IM, IL, ILR, IMR
      REAL        ANORM, ANRMX, RANGE, THR, X, Y, SINX, SINX2,
     &            COSX, COSX2, SINCS
C
C-- FOR DOUBLE PRECISION
C      DATA RANGE/1D-12/
      DATA RANGE/1E-6/
C
      IF (MV.EQ.0) THEN
        IQ=-N
        DO  J=1,N
          IQ=IQ+N
          DO  I=1,N
            IJ=IQ+I
            IF (I.EQ.J) THEN
              R(IJ)=1.
            ELSE
              R(IJ)=0.
            ENDIF
          ENDDO
        ENDDO
      ENDIF
C
C---- INITIAL AND FINAL NORMS (ANORM & ANRMX)
      IA=0
      ANORM=0.
      DO  I=1,N
        DO  J=1,I
          IA=IA+1
          IF (J.NE.I) ANORM=ANORM+A(IA)**2
        ENDDO
      ENDDO
C
      IF (ANORM.LE.0.) GOTO 165
      ANORM=SQRT(2.*ANORM)
      ANRMX=ANORM*RANGE/N
C
C---- INITIALIZE INDICATORS AND COMPUTE THRESHOLD
      IND=0
      THR=ANORM
45    THR=THR/N
50    L=1
55    LQ=L*(L-1)/2
      LL=L+LQ
      M=L+1
      ILQ=N*(L-1)
C
C---- COMPUTE SIN & COS
60    MQ=M*(M-1)/2
      LM=L+MQ
      IF (ABS(A(LM))-THR.LT.0.) GOTO 130
      IND=1
      MM=M+MQ
      X=.5*(A(LL)-A(MM))
      Y=-A(LM)/SQRT(A(LM)**2+X*X)
      IF (ABS(Y).GT.1.0) Y=SIGN(1.0,Y)
      IF (X.LT.0.) Y=-Y
      SINX=Y/SQRT(2.*(1.+(SQRT(1.-Y*Y))))
      SINX2=SINX**2
      COSX=SQRT(1.-SINX2)
      COSX2=COSX**2
      SINCS=SINX*COSX
C
C---- ROTATE L & M COLUMNS
      IMQ=N*(M-1)
      DO  I=1,N
        IQ=I*(I-1)/2
        IF (I.NE.L .AND. I.NE.M) THEN
          IF (I.LT.M) THEN
            IM=I+MQ
          ELSE
            IM=M+IQ
          ENDIF
          IF (I.LT.L) THEN
            IL=I+LQ
          ELSE
            IL=L+IQ
          ENDIF
          X=A(IL)*COSX-A(IM)*SINX
          A(IM)=A(IL)*SINX+A(IM)*COSX
          A(IL)=X
        ENDIF
        IF (MV.EQ.0) THEN
          ILR=ILQ+I
          IMR=IMQ+I
          X=R(ILR)*COSX-R(IMR)*SINX
          R(IMR)=R(ILR)*SINX+R(IMR)*COSX
          R(ILR)=X
        ENDIF
      ENDDO
C
      X=2.*A(LM)*SINCS
      Y=A(LL)*COSX2+A(MM)*SINX2-X
      X=A(LL)*SINX2+A(MM)*COSX2+X
      A(LM)=(A(LL)-A(MM))*SINCS+A(LM)*(COSX2-SINX2)
      A(LL)=Y
      A(MM)=X
C
C---- TESTS FOR COMPLETION
C---- TEST FOR M = LAST COLUMN
130   IF (M.NE.N) THEN
        M=M+1
        GOTO 60
      ENDIF
C
C---- TEST FOR L =PENULTIMATE COLUMN
      IF (L.NE.N-1) THEN
        L=L+1
        GOTO55
      ENDIF
      IF (IND.EQ.1) THEN
        IND=0
        GOTO50
      ENDIF
C
C---- COMPARE THRESHOLD WITH FINAL NORM
      IF (THR.GT.ANRMX) GOTO 45
165   RETURN
      END

C ===================================
C----linalgebra_block
C Subroutines and functions to deal with problems of linear algebra
C
C  Strange eanough it begins with singular value decomposition.
C  But I need it now.
C
      SUBROUTINE SVDCMP_ASC(A,M,N,MP,NP,W,V,IERR)

C----This subroutine makes singular value decomposition
C----as   A = U.W.VT
C----See Press, Flannery, Teukolsky, Vettering  Numerical recipes
C----M and N are physical sizes of matrix MP and NP are logical
C---sizes. M >= N. Otherwise routine will fail
C---Note: Output is VT but not V
C---A will be destroyed and replaced by U
C
      PARAMETER (NMAX = 1000)
      REAL A(MP,NP),W(NP),V(NP,NP),RV1(NMAX)
      CHARACTER LINE*80,CHAR4*4
      REAL*8  dtemp1,dtemp2,dtemp3,dtemp4,dtemp5,dtemp6,dtemp7  
C
      IERR =0
C      IF(M.LT.N) CALL ERRWRT(1,'SVDMP: M Should be > N')
      IF(M.LT.N) THEN
        MDOC = 0
        CALL MSGERR(MDOC,' ERROR in SVDMP: M Should be > N')
        IERR=1
        RETURN
      ENDIF
      G     = 0.0
      SCALE = 0.0
      ANORM = 0.0
      NCONV = 50
      DO   I=1,N
        L      = I+1
        RV1(I) = SCALE*G
        G      = 0.0
        S      = 0.0
        SCALE  = 0.0
        IF(I.LE.M) THEN
          DO   K=I,M
            SCALE = SCALE+ABS(A(K,I))
          ENDDO
          IF(SCALE.NE.0.0) THEN
            DO    K=I,M
              A(K,I) = A(K,I)/SCALE
              S      = S + A(K,I)*A(K,I)
            ENDDO
            F = A(I,I)
            G = -SIGN(SQRT(S),F)
            H = F*G-S
            A(I,I) = F-G
            DO   J=L,N
              S = 0.0
              DO   K=I,M
                S = S+A(K,I)*A(K,J)
              ENDDO
              F = S/H
              DO    K=I,M
                A(K,J) =A(K,J)+F*A(K,I)
              ENDDO
            ENDDO
            DO   K=I,M
              A(K,I) = SCALE*A(K,I)
            ENDDO
          ENDIF
        ENDIF
        W(I)  = SCALE*G
        G     = 0.0
        S     = 0.0
        SCALE = 0.0
        IF((I.LE.M).AND.(I.NE.N)) THEN
          DO   K=L,N
            SCALE = SCALE+ABS(A(I,K))
          ENDDO
          IF(SCALE.NE.0.0) THEN
            DO   K=L,N
              A(I,K) = A(I,K)/SCALE
              S      = S + A(I,K)*A(I,K)
            ENDDO
            F = A(I,L)
            G = -SIGN(SQRT(S),F)
            H = F*G-S
            A(I,L) = F-G
            DO   K=L,N
              RV1(K) = A(I,K)/H
            ENDDO
            DO   J=L,M
              S = 0.0
              DO   K=L,N
                S = S+A(J,K)*A(I,K)
              ENDDO
              DO   K=L,N
                A(J,K) = A(J,K)+S*RV1(K)
              ENDDO
            ENDDO
            DO    K=L,N
              A(I,K) = SCALE*A(I,K)
            ENDDO
          ENDIF
        ENDIF
        ANORM = MAX(ANORM,(ABS(W(I))+ABS(RV1(I))))
      ENDDO
C
C Accumulation of right hand transformation
C
      DO   I=N,1,-1
        IF(I.LT.N) THEN
          IF(G.NE.0.0) THEN
            DO   J=L,N
C
C   Doulde division to avoid underflow (????
C
                dtemp1 = A(I,J)
                dtemp2 = A(I,L)
                dtemp3 = G
                dtemp4 = (dtemp1/dtemp2)/dtemp3
                if(dabs(dtemp4).gt.1.0D30) then
                  ierr = 7
                  return
                endif

             V(J,I) = dtemp4
c            V(J,I) = (A(I,J)/A(I,L))/G

            ENDDO
            DO   J=L,N
              S = 0.0
              DO   K=L,N
                S = S+A(I,K)*V(K,J)
              ENDDO
              DO   K=L,N
                V(K,J) = V(K,J)+S*V(K,I)
              ENDDO
            ENDDO
          ENDIF
          DO   J=L,N
            V(I,J) = 0.0
            V(J,I) = 0.0
          ENDDO
        ENDIF
        V(I,I) = 1.0
        G      = RV1(I)
        L      = I
      ENDDO
C
C Accumulation of left hand transformation
C
      DO    I=min(m,N),1,-1 
        L = I+1
        G = W(I)
        DO  J=L,N
          A(I,J) = 0.0
        ENDDO 
        IF(G.NE.0.0) THEN
          G = 1.0/G
          DO   J=L,N
            S = 0.0
            DO   K=L,M
              S=S+A(K,I)*A(K,J)
            ENDDO
            F = (S/A(I,I))*G
            DO    K=I,M
              A(K,J) = A(K,J)+F*A(K,I)
            ENDDO
          ENDDO 
          DO    J=I,M
            A(J,I) = A(J,I)*G
          ENDDO
        ELSE
          DO    J=I,M
            A(J,I) = 0.0
          ENDDO
        ENDIF
        A(I,I) = A(I,I)+1.0
      ENDDO
C
C  Diagonalisation fo bidiagonal form
C
      DO   K=N,1,-1
C
C  Loop over singular values
C
        DO   ITS=1,30
C
C Loop over iteration. 
C
          DO    L=K,1,-1
C
C  Test for splitting
C
            NM = L-1
            IF((ABS(RV1(L))+ANORM).EQ.ANORM) GOTO 2
            IF((ABS(W(NM))+ANORM).EQ.ANORM) GOTO 1
          ENDDO
 1        C = 0.0
          S = 1.0
          DO   I=L,K
            F = S*RV1(I)
            rv1(i)=c*rv1(i)
            IF((ABS(F)+ANORM).eq.ANORM) goto 2
            G = W(I)
            h = pythag(f,g)
            W(I) = H
            H = 1.0/H
            C = G*H
            S = -F*H
            DO    J=1,M
              Y = A(J,NM)
              Z = A(J,I)
              A(J,NM) = (Y*C)+(Z*S)
              A(J,I)  = -(Y*S)+(Z*C)
            ENDDO
          ENDDO
 2        Z = W(K)
          IF(L.EQ.K) THEN
            IF(Z.LT.0.0) THEN
              W(K) = -Z
              DO   J=1,N
                V(J,K) = -V(J,K)
              ENDDO
            ENDIF
            GOTO 3
          ENDIF
C          IF(ITS.EQ.30) 
C     .        CALL ERRWRT(-1,
C     .         'SVDCMP: No convergence in 30 iterations')
          IF(ITS.EQ.NCONV) THEN
            MDOC = 0
C            WRITE(CHAR4,'(I4)') NCONV
C            LINE = ' ERROR in SVDCMP(rbfft): No convergence in'
C     *             //CHAR4//' iterations'
C            CALL MSGERR(0,
C     *         ' ERROR in SVDCMP: No convergence in 30 iterations')
c            CALL MSGERR(MDOC,
c     *     ' ERROR in SVDCMP: No convergence in 30 iterations')
            IERR=2
            RETURN
          ENDIF
          X = W(L)
          NM= K-1
          Y = W(NM)
          G = RV1(NM)
          H = RV1(K)

            dtemp1 = Y-Z
            dtemp2 = Y+Z
            dtemp3 = (2.0*H*Y)
            dtemp4 = G-H
            dtemp5 = G+H

            dtemp6 = (dtemp1*dtemp2+dtemp4*dtemp5)/dtemp3

            if(dabs(dtemp6).gt.1.0D30) then
              ierr = 8
              return
            endif

          F = dtemp6
c         F = ((Y-Z)*(Y+Z)+(G-H)*(G+H))/(2.0*H*Y)

          g = pythag(f,1.0)
c         G = SQRT(F*F+1.0)

            dtemp1 = X-Z
            dtemp2 = X+Z
            dtemp3 = (F+SIGN(G,F))
            dtemp4 = H
            dtemp5 = Y
            dtemp6 = X

            dtemp7 = (dtemp1*dtemp2+dtemp4*
     *               ((dtemp5/dtemp3)-dtemp4))/dtemp6
            if(dabs(dtemp7).gt.1.0D30) then
              ierr = 9
              return
            endif

           F = dtemp7
c          F = ((X-Z)*(X+Z)+H*((Y/(F+SIGN(G,F)))-H))/X

C
C  Next QR transformation
C
          C = 1.0
          S = 1.0
          DO   J=L,NM
            I = J+1
            G = RV1(I)
            Y = W(I)
            H = S*G
            G = C*G
            z = pythag(f,h)
c           Z = SQRT(F*F+H*H)
            RV1(J) = Z
            C = F/Z
            S = H/Z
            F =  X*C+G*S
            G = -X*S+G*C
            H = Y*S
            Y = Y*C
            DO   JJ=1,N
              X = V(JJ,J)
              Z = V(JJ,I)
              V(JJ,J) =  (X*C)+(Z*S)
              V(JJ,I) = -(X*S)+(Z*C)
            ENDDO
            z = pythag(f,h)
c           Z = SQRT(F*F+H*H)
            W(J) = Z
            IF(Z.NE.0.0) THEN
              Z = 1.0/Z
              C = F*Z
              S = H*Z
            ENDIF
            F =  C*G+S*Y
            X = -S*G+C*Y
            DO   JJ=1,M
              Y = A(JJ,J)
              Z = A(JJ,I)
              A(JJ,J) =   (Y*C)+(Z*S)
              A(JJ,I) =  -(Y*S)+(Z*C)
            ENDDO
          ENDDO
          RV1(L) = 0.0
          RV1(K) = F
          W(K)   = X
        ENDDO
 3      CONTINUE
      ENDDO
      RETURN
      END      
C
       function pythag(a,b)
       real a,b,pythag
       real absa, absb
       absa = abs(a)
       absb = abs(b)
       if(absa.gt.absb) then
         pythag = absa*sqrt(1.+(absb/absa)**2)
       else
         if(absb.eq.0.0) then
           pythag = 0.0
         else
           pythag = absb*sqrt(1.+(absa/absb)**2)
         endif
       endif
       return
       end
C

      SUBROUTINE SVBKSB_ASC(U,W,V,M,N,MP,NP,B,X)
C
C  Solves AX = B. A should be decomposed by SVDCMP subrouitne
C  A = U.W.VT
C
      PARAMETER (NMAX = 1000)
      REAL U(MP,NP),W(NP),V(NP,NP),B(NP),X(NP),TMP(NMAX)
C
C Calculate Ut.B
C
      DO   J=1,N
        S = 0.0
        IF(W(J).NE.0.0) THEN
          DO   I=1,M
            S = S+U(I,J)*B(I)
          ENDDO
          S = S/W(J)
        ENDIF
        TMP(J) = S
      ENDDO
C
C Multiply by V to get answer
C
      DO   J=1,N
        S = 0.0
        DO   JJ=1,N
          S = S+V(J,JJ)*TMP(JJ)
        ENDDO
        X(J) = S
      ENDDO
      RETURN
      END


      SUBROUTINE SVSOLV_ASC(A,M,N,MP,NP,B,X,IERR)
C
C   Solve Ax=B by calling singular value decomposition 
C   subroutines
C
C//////      INCLUDE 'const.fh'
      PARAMETER (NMAX   = 1000)
      PARAMETER (NMAX21 = NMAX+NMAX*NMAX)      
      REAL WV(NMAX21)
      REAL A(MP,NP),B(NP),X(NP)
      DATA TOL/1.0E-7/
      IERR=0
C
C---First call SVDCMP to decompose A = U.W.Vt
C
      CALL SVDCMP_ASC(A,M,N,MP,NP,WV(1),WV(NMAX+1),IERR)
      IF(IERR.NE.0) RETURN
C  
C  Now edit W-s
C
      WMAX = 0.0
      DO    I=1,N
        IF(WMAX.LT.WV(I)) WMAX = WV(I)
      ENDDO
      WMIN = WMAX*TOL
      DO   I=1,N
        IF(WV(I).LT.WMIN) THEN
cd          WRITE(LINE,'(A,I5)')
cd     .      ' Singular values for parameter',I
cd          CALL ERRWRT(0,LINE)
          WV(I) = 0.0
        ENDIF
      ENDDO

C
C--Now call SVBKSB to solve equation
C
      CALL SVBKSB_ASC(A,WV(1),WV(NMAX+1),M,N,MP,NP,B,X)

      RETURN
      END
C
      SUBROUTINE SVDVAR_ASC(V,MA,W,CVM,NCVM)
C
C---Evaluation of covariance matrix after using singular
C---value decomposition. Parameters with singular contribution
C---to matrix will have 0.0 variance.
C
      PARAMETER (NMAX = 1000)
      REAL V(MA,MA),W(MA),CVM(NCVM,NCVM),WTI(NMAX)
C
      DO   I=1,MA
        WTI(I) = 0.0
        IF(W(I).NE.0.0) WTI(I) = 1.0/(W(I)*W(I))
      ENDDO
      DO   I=1,MA
        DO   J=1,I
          SUM = 0.0
          DO    K=1,MA
            SUM = SUM + V(I,K)*V(J,K)*WTI(K)
          ENDDO
          CVM(I,J) = SUM
          CVM(J,I) = SUM
        ENDDO
      ENDDO
      RETURN
      END

      SUBROUTINE CHECK_PATT_ASC(MDOC,F_NAME
     * ,BOFFR,BADDR,RESULT_S,RESULT_B
     * ,RESMNIR,RESMXIR,RESULT,IPRROW,ISYM,IPRSYM,IERR)
C ------------------------------
      INTEGER*2 ISYM(5,3,IPRSYM)
      REAL      RESMNI,RESMXI
      REAL      RESULT(IPRROW)
      INTEGER*4 MDOC,NUMGP,IERR
      CHARACTER F_NAME*(*),MISS*1,MISSR*1
C ==============================
      INTEGER*4 MTIN
      REAL      RLATT(6),DISTR(41),AVERF(40),SUMF20(40),RHRP2(40)
      REAL      AVERF2(40),SUMN(40),SUMFNT(40),SUMH2F(40)
      REAL      SUMA(40),SUMB(40),SUMC(40),SUMD(40),SUME(40)
      REAL      SUMH2F2T(40),AVERF2T(40),SUMAT(40),AVERFT(40)
      REAL      AVERF2T0(40),SUMSIG2(40),SUMSIG0(40),SUMH2F2(40)
      REAL      RHR(41),SUMF2(40),SUMFN(40),SUMF(40),RHRP(41)
      REAL      SUMR(40)
      CHARACTER ITYP*4
      CHARACTER LINE*80,TITLE*80,TITLE1*80
C -----------------------------------------------------------
      PI    = 4.0*ATAN(1.0)
      TWOPI = 2.0*PI
      IERR  = 0
      MD    =-ABS(MDOC)-1
      M     = 99
C -----------------------------------------------------------
      MISS   = 'N'
      NUMGP  = 0
      COEF   = 0
      BOFF   = BOFFR
      BADD   = BADDR
      RESMNI = RESMNIR
      RESMXI = RESMXIR
      MTIN   = 20
      ITYP   = 'FF  '
      CALL LENSTR_BL(F_NAME,LEN)
      IF(LEN.LE.0.OR.F_NAME(1:1).EQ.' '.OR.F_NAME(1:1).EQ.',') THEN
        CALL MSGERR(MDOC,' ERROR: wrong name of FILE-F')
        IERR=1
        RETURN
      ENDIF
      CALL ORFILE(M,MTIN,F_NAME,ITYP,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERROR: open FILE-F')
        RETURN
      ENDIF
      CALL GET_TITLE(M,A,B,C,AL,BE,GA
     *  ,COEF1,BET1,RESMIN,RESMAX,IDM,IDM,IDM,IDM,IDM,TITLE,IERR)
C -------------------------------------------------------------
      IF(RESMNI.LT.1.E-5)  RESMNI=RESMIN
      IF(RESMXI.LT.1.E-5)  RESMXI=RESMAX
      IF(RESMXI.LT.RESMAX) RESMXI=RESMAX
      IF(RESMNI.GT.RESMIN) RESMNI=RESMIN
      WRITE(LINE,
     *'(''Resolution       :'',2F10.2)') RESMNI,RESMXI
      CALL MSGDOC(MDOC,LINE)
C ---
      CALL C_RD_CR
      RLATT(1) = A
      RLATT(2) = B
      RLATT(3) = C
      RLATT(4) = AL
      RLATT(5) = BE
      RLATT(6) = GA
      CALL DSTARF(RLATT,AST,BST,CST,COALST,COBEST,COGAST,VOL)
C ---
      IF(COEF.LE.0.0) COEF=1.5
      WRITE(LINE,
     *'(''Boff,Badd        :'',2F10.2)') BOFF,BADD
      CALL MSGDOC(MDOC,LINE)
C ---
      IF(NUMGP.LE. 0) NUMGP=20
      IF(NUMGP.GT.20) NUMGP=20
      WRITE(LINE,
     *'(''Number of shells :'',I7)') NUMGP
      CALL MSGDOC(MDOC,LINE)
C ---
      CALL ANOMF(M,NSYM,ISYM)
      CALL LIMHKL(RESMXI,IHMAX,IKMAX,ILMAX,NXMIN,NYMIN,NZMIN)
C ----------------------------------------------------------------
C --------------------------------------
      CALL MSGDOC(MDOC,' ')
      WRITE(LINE,
     *'('' ---- Scaling by Patterson with Boff ='',F9.0,'' ----'')')
     * BOFF
      CALL MSGDOC(MDOC,LINE)
      CALL MSGDOC(MDOC,' ')
C ---
      RHMIN=1.0/RESMNI
      RHMAX=1.0/RESMXI

      DMAX =(RESMXI/3.0)*2.0*COEF
      B    = 0.0
c      IF(B.LT.0.0) B=0.0

      DMAX1=SQRT(ABS(B/(8.0*PI*PI)))*2.0*COEF
      IF(DMAX1.GT.DMAX) DMAX=DMAX1
c      WRITE(LINE,1000) DMAX,VOL,DVOL
c 1000 FORMAT('D-max, VOL , 4/3*PI*Rmax^3:'
c     *  ,F7.2,1X,2G14.4)
c      CALL MSGDOC(MDOC,LINE)
C ---
      DELT =DMAX/NUMGP
      DO    K=1,NUMGP
        SUMA    (K) =0.
        SUMB    (K) =0.
        SUMF2   (K) =0.
        SUMF20  (K) =0.
        SUMFN   (K) =0.
        SUMFNT  (K) =0.
        SUMF    (K) =0.
        SUMSIG2 (K) =0.
        SUMSIG0 (K) =0.
        AVERF   (K) =0.
        AVERF2  (K) =0.
        AVERF2T0(K) =0.
        SUMH2F  (K) =0.
        SUMH2F2 (K) =0.
        SUMH2F2T(K) =0.
      ENDDO
      D=0
      DO    K=1,NUMGP+1
        DISTR(K)=D
        D=D+DELT
      ENDDO
      DELTRH=(RHMAX-RHMIN)/NUMGP
      RHR(1) =RHMIN
      RHRP(1)=1./RHMIN
      DO    I=2,NUMGP+1
        RHR(I)=RHR(I-1)+DELTRH
        RHRP(I)=1.0/RHR(I)
      ENDDO
      IH    = 0
      IK    = 0
      IL    =-1
      IFIRST= 0
      IEND  =-1
C
      NREF  = 0
      NTOT  = 0
      NREFA = 0
      NTOTA = 0
      NREAD = 0
      NREF0 = 0
      NSIG0 = 0
      NREF_ABS = 0
      NREF_OUT = 0
      NREF_MISS= 0
      NADD     = 0
      NF000    = 0
      NABS     = 0
C
      F000  =0.0
      SSIG  =0.0
      SF    =0.0
      SF2   =0.0
      SF20  =0.0
      SF4   =0.0
      SH2F  =0.0
      SH2S2 =0.0
      SH2   =0.0
      MISS  ='Y'
c ------------------------
      DO     ILP=0,ILMAX
      DO     IKP=-IKMAX,IKMAX
      DO     IHP=-IHMAX,IHMAX
        IF(IHP.EQ.0.AND.IKP.EQ.0.AND.ILP.EQ.0) GO TO 100
        IIHP=IHP
        IIKP=IKP
        IILP=ILP
        CALL ANOMSC(IIHP,IIKP,IILP,IANOM,JJSYM,NSYM,ISYM)
        IF(IANOM.NE.1.OR.JJSYM.NE.1) GO TO 100

        CALL SYSABS_BL(IHP,IKP,ILP,NSYM,ISYM,ICND)
        IF(NSYM.GT.1) THEN
          CALL SYSABS_BL(IHP,IKP,ILP,NSYM,ISYM,ICND)
        ELSE
          ICND=0
        ENDIF
        IF(ICND.NE.0) THEN
           GO TO 100
        ENDIF

        CALL DSTAR(IHP,IKP,ILP,RSQ)
        RH=SQRT(RSQ)
        IF(RH.LT.RHMIN.OR.RH.GT.RHMAX) THEN
          GO TO 100
        ENDIF

        IHT=IHP
        IKT=0
        ILT=0
        CALL DSTAR(IHT,IKT,ILT,RSQT)
        RHT=SQRT(RSQT)

        K=(RH-RHMIN)/DELTRH+1.0
        IF(K.GT.NUMGP) K=NUMGP
        IF(K.LT.1) K=1     

        CALL INDMLTT(IHP,IKP,ILP,NGEN,NSYM,ISYM)

 4060   IF(MTIN.LE.0)  THEN
          IERR=1
          RETURN
        ENDIF
        IF(IEND.GT.0) GO TO 4040

c        IF(IL-ILP) 4050,4010,4040
c 4010   IF(IK-IKP) 4050,4020,4040
c 4020   IF(IH-IHP) 4050,4030,4040

        IF((IL-ILP).LT.0) GO TO 4050
        IF((IL-ILP).EQ.0) GO TO 4010
        IF((IL-ILP).GT.0) GO TO 4040
 4010   IF((IK-IKP).LT.0) GO TO 4050
        IF((IK-IKP).EQ.0) GO TO 4020
        IF((IK-IKP).GT.0) GO TO 4040
 4020   IF((IH-IHP).LT.0) GO TO 4050
        IF((IH-IHP).EQ.0) GO TO 4030
        IF((IH-IHP).GT.0) GO TO 4040

 4040   CONTINUE

        CALL DSTAR(IH,IK,IL,RSQI)
        RHI=SQRT(RSQI)
        IF(RHI.LT.RHMIN.OR.RHI.GT.RHMAX) THEN
          NREF_OUT = NREF_OUT + 1
          GO TO 100
        ENDIF
        IF(NSYM.GT.1) THEN
          CALL SYSABS_BL(IHP,IKP,ILP,NSYM,ISYM,ICND)
        ELSE
          ICND=0
        ENDIF
        IF(ICND.NE.0) THEN
          NREF_ABS = NREF_ABS + 1
          GO TO 100
        ENDIF
        IF(MISS.EQ.'Y') THEN
          SUMFNT(K)=SUMFNT(K)+NGEN
          NTOT=NTOT+NGEN
        ENDIF
        NTOTA=NTOTA+1
        NREF_MISS = NREF_MISS + 1
        GO TO 100

 4050   CONTINUE
        IF(IFIRST.EQ.1) THEN
C         ADDITIONAL IL,IK,IL,REFLS
          IF(NSYM.GT.1) THEN
            CALL SYSABS_BL(IH,IK,IL,NSYM,ISYM,ICND)
          ELSE
            ICND=0
          ENDIF
          IF(ICND.NE.0) THEN 
            NABS = NABS + 1
            IFIRST=0
            GO TO 4050 
          ENDIF
          NADD = NADD + 1
          IFIRST=0
          CALL DSTAR(IH,IK,IL,RSQI)
          RHI=SQRT(RSQI)
          IF(RHI.LT.RHMIN.OR.RHI.GT.RHMAX) THEN
            NREF_OUT = NREF_OUT + 1
c            T=1/RHI
c            WRITE(*,*) IH,IK,IL,T,FN,SN
            IFIRST=0
            GO TO 4050 
          ENDIF
          GO TO 4050
        ENDIF
        IFIRST=1
        IF(ITYP.EQ.'FS  ') THEN
          CALL RRD1(MTIN,IH,IK,IL,FN,FNA,SN,SNA,KEY,IEND)
          IDUMMY_SIG=0
          IF(SN .LT.0.000001) SN =0.04*FN
          IF(SNA.LT.0.000001) SNA=0.04*FNA
        ELSE
          CALL RD1(MTIN,IH,IK,IL,FN,FNA,KEY,IEND)
C         SIG-DUMMY
          IDUMMY_SIG=1
          SN =0.04*FN
          SNA=0.04*FNA
        ENDIF
        IF(MTIN.LE.0) THEN
          CALL MSGERR(MDOC,' ERROR: read FILE_F')
          IERR=1
          RETURN
        ENDIF
        IF(IEND.GT.0)                    GO TO 4040
        NREAD = NREAD+1
        IF(IH.EQ.0.AND.IK.EQ.0.AND.IL.EQ.0) THEN
          NF000=NF000+1
          F000 =FN
          IFIRST=0
          GO TO 4060
        ENDIF
        IF(FN.GT.1.E-6.AND.FNA.GT.1.E-6) THEN
          WT1=1./(SN*SN)
          WT2=1./(SNA*SNA)
          WT =WT1+WT2
          FN =FN*WT1+FNA*WT2
          FN =FN/WT
          SN =1./SQRT(WT)
        ELSE IF(FNA.GT.1.E-6) THEN
          FN =FNA
          SN =SNA
        ENDIF
        GO TO 4060

 4030   IFIRST=0
        IF(NSYM.GT.1) THEN
          CALL SYSABS_BL(IH,IK,IL,NSYM,ISYM,ICND)
        ELSE
          ICND=0
        ENDIF
        IF(ICND.NE.0) THEN
          NABS = NABS + 1
          IF(IFIRST.EQ.0) GO TO 100
          IFIRST=0
          GO TO 4050 
        ENDIF

        IF(FN.LE.1.E-8) THEN
          NREF0 = NREF0 + 1
          GO TO 100
        ENDIF

        IF(SN.LE.1.E-6) THEN
          NSIG0 = NSIG0 + 1 
          GO TO 100
        ENDIF


        NREF =NREF+NGEN
        NTOT =NTOT+NGEN
        NREFA=NREFA+1
        NTOTA=NTOTA+1
        IF(BOFF.GT.0.0) THEN
          BT=BOFF/4.0
          CBOFF=1.0-EXP(-BT*RSQ)
        ELSE
          CBOFF=1.0
        ENDIF
        IF(ABS(BADD).GT.0.00001) THEN
          BT=BADD/4.0
          CBADD=EXP(-BT*RSQ)
        ELSE
          CBADD=1.0
        ENDIF
        Y = CBOFF*CBADD
        FN2       =FN*FN*CBOFF*CBOFF*CBADD*CBADD
        SN2       =SN*SN*CBOFF*CBOFF*CBADD*CBADD
        SUMF2 (K) =SUMF2(K)   +FN2    *NGEN
        SUMF20(K) =SUMF20(K)  +FN*FN  *NGEN

        SUMH2F(K) =SUMH2F(K)  +RSQT*FN*NGEN*Y
        SUMSIG2(K)=SUMSIG2(K) +RSQT*SN*SN*NGEN*Y*Y

        SUMH2F2(K)=SUMH2F2(K) +RSQ *FN*NGEN
        SUMFN (K) =SUMFN(K)   +        NGEN
        SUMFNT(K) =SUMFNT(K)  +        NGEN
        SUMSIG0(K)=SUMSIG0(K) +SN     *NGEN
        SSIG      =SSIG       +SN     *NGEN
        SF        =SF         +FN     *NGEN
        SF20      =SF20       +FN*FN  *NGEN
        SF2       =SF2        +FN2    *NGEN
        SF4       =SF4        +FN2*FN2*NGEN

        SH2F      =SH2F       +RSQT*FN*NGEN*Y
        SH2S2     =SH2S2      +RSQT*SN*SN*NGEN*Y*Y

        SH2       =SH2        +RSQT   *NGEN
  100   CONTINUE
      ENDDO
      ENDDO
      ENDDO
C ---
      CLOSE (MTIN)
      IF(NREF.LE.0) THEN
        CALL MSGERR(MDOC,
     *  ' ERROR: CHECK_PATT_ASC: number of reflections = 0')
        IERR=1
        RETURN
      ENDIF

C      IF(MISS.EQ.'Y'.AND.NTOT.NE.NREF) THEN
C        CALL MSGDOC(MDOC,
C     *  ' ---  Missing reflections will be included with F=0 ---')
C      ELSE
C        NTOT=NREF
C        DO I=1,NUMGP
C          SUMFNT(I)=SUMFN(I)
C        ENDDO
C      ENDIF

      A_CELL=A
      SF2   =(SQRT(ABS(SF2*2.0))        )/VOL
      SF4   =(SQRT(ABS(SF4*2.0))        )/VOL
      SH2S2 =(SQRT(ABS(SH2S2*2.0))*TWOPI)  /(VOL*A_CELL)
      SH2   =(SQRT(ABS(SH2  *4.0))*TWOPI)  /(VOL*A_CELL)
      SH2F  =((SH2F *2.0)*TWOPI*PI)/(VOL*A_CELL*A_CELL)
      COMPL=1.0
      IF(NTOTA.GT.0) COMPL=FLOAT(NREFA)/FLOAT(NTOTA)
      RSTAND=0.0
      IF(NREF.GT.0) THEN
        SSIG=SSIG/NREF
        SF  =SF  /NREF
        SF20=SF20/NREF
        IF(SF.GT.0.0.AND.IDUMMY_SIG.LE.0) RSTAND=SSIG/SF
      ENDIF
      DO I=1,NUMGP
        AVERF2  (I)=0.0
        AVERF2T (I)=0.0
        AVERF2T0(I)=0.0
        IF(SUMFNT(I).GT.0.000001) AVERF2T (I) =SUMF2 (I)/SUMFNT(I)
        IF(SUMFNT(I).GT.0.000001) AVERF2T0(I) =SUMF20(I)/SUMFNT(I)
        IF(SUMFN(I) .GT.0.000001) AVERF2  (I) =SUMF2 (I)/SUMFN(I)
        AVERF (I) =SQRT(ABS(AVERF2 (I)))
        AVERFT(I) =SQRT(ABS(AVERF2T(I)))
        SUMH2F2T(I)=0.0
        IF(SUMFN (I).GT.0.0000001) THEN
          SUMH2F2T(I)=(SUMH2F2(I)*SUMFNT(I))/SUMFN(I)
        ENDIF
      ENDDO
C -----------------------
      WRITE(LINE,
     *'(''Number of reflections / & total number/  :'',2I8)') 
     *NREFA,NTOTA
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,
     *'(''Numbers: In file,Sys.abs,Miss,RES_out    :'',4I8)') 
     * NREAD,NREF_ABS,NREF_MISS,NREF_OUT
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,
     *'(''Numbers: With_F=<0,With_sig=<0,Nadd,NF000:'',4I8)') 
     * NREF0,NSIG0,NADD,NF000
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,
     *'(''Resolution                               :'',2F8.3)') 
     *RESMNI,RESMXI
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,
     *'(''Completeness                             :'',F9.3)')COMPL
      CALL MSGDOC(MDOC,LINE)
      IF(NF000.GT.0) THEN
        WRITE(LINE,
     *  '(''F000                                     :'',G14.4)')
     *  F000
        CALL MSGDOC(MDOC,LINE)
      ENDIF
      WRITE(LINE,
     *'(''<F>,<F^2>                                :'',2G14.4)')
     *SF,SF20
      CALL MSGDOC(MDOC,LINE)
      IF(IDUMMY_SIG.LE.0) THEN
        WRITE(LINE,
     *  '(''<sig(F)>,R_stand(F) (<sig(F)>/<F>)       :'',G14.4,F9.3)')
     *  SSIG,RSTAND
        CALL MSGDOC(MDOC,LINE)
      ENDIF

      WRITE(LINE,
     *'(''<Curvature>_of atomic peak               :'',G14.4)') 
     *SH2F 
      CALL MSGDOC(MDOC,LINE)
C -----------------------------------------
C
C ---- PATTERSON ----------------------------------------------------
C
      CALL MSGDOC(MDOC,
     *' ----          Patterson                ----')
      CALL MSGDOC(MDOC,' ')
      NUMGPF=NUMGP

      CALL CALC_PATT(MDOC,NUMGP,NUMGPF,DELT,DELTRH,RHR,COMPL
     *     ,AVERF2,AVERF2T,SUMA,SUMC,IERR)

      ALIM=0.1
      CALL  TEMP_FLPP(SUMC,NUMGP,DISTR,SCALE,BTP,ALIM)

      IF(BTP.GT.0.0000000001) THEN
        DT2=1.0/(2.0*BTP)
      ELSE
        DT2=0.0
      ENDIF

      DT=SQRT(ABS(DT2))
      BSUM=8.0*PI*PI*DT2

      BSUMF=BSUM/2.0
      DTFOUR=SQRT(ABS(BSUMF/(8.0*PI*PI)))
      B_OVER=BSUMF

      DTR =RESMXI/3.0
      BRES=4.0*RESMXI*RESMXI

      RESEFF=DTFOUR*2.0*SQRT(2.0)
      BEFF=4.0*RESEFF*RESEFF

      RESEFF_COMP=RESEFF
C     SLAP_COMP =SLAP
      DTFOURT   =DTFOUR
      SCALET    =SCALE
      BSUMT     =BSUM
      BSUMFT    =BSUMF

C --------------------------------------
C 
C Width_of_origin_peak_patt                D     
c Corresponding Thermal factor:            B_patt    = 8p^2*D^2
C
c Expected <width> of atomic peaks         <u>_four  = D/sqr(2)
c Corresponding B_overall                  B_overall = 8pi^2*<u>_four^2  
C
c <width> of atomic peaks for              <u>_resol = RESmax/3                
c resolution only                          B_resol   = 4*RESmax^2
C
c Resolution_effective                     Res_eff   = <u>_four*2.0*sqrt(2)
c Corresponding thermal factor             R_res_eff = 4Res_eff^2
c
C -----------------------
      WRITE(LINE,
     *'(''Patt_origin_peak,Width_of_peak: P000,D :'',2G14.4)') 
     * SCALE,DT
      CALL MSGDOC(MDOC,LINE)
      SQR_P000=SQRT(ABS(SCALE))
      WRITE(LINE,
     *'(''sqrt(P000)                             :'',G14.4)') 
     * SQR_P000
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,
     *'(''Corresponding Thermal factor: B_patt= 8p^2*D^2   :'',G14.4)') 
     * BSUM
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,
     *'(''Expected <width> of atomic peaks: <u>_f=D/sqr(2) :'',G14.4)') 
     * DTFOUR
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,
     *'(''Corresponding B_overall = 8pi^2*<u>_f^2          :'',G14.4)') 
     * B_OVER
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,
     *'(''<u>_resol = RESmax/3                             :'',G14.4)') 
     * DTR
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,
     *'(''B_resol = 4*RESmax^2                             :'',G14.4)') 
     * BRES
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,
     *'(''Resolution_effective =  <u>_f*2.0*sqrt(2)        :'',G14.4)') 
     * RESEFF
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,
     *'(''Corresponding thermal factor/4Res_eff^2/         :'',G14.4)') 
     * BEFF
      CALL MSGDOC(MDOC,LINE)

      RESULT_B   = BSUM
      RESULT_S   = SCALE

      RESULT(1)  = BSUM
      RESULT(2)  = SCALE

      RESULT( 7) = SQR_P000
      RESULT( 8) = B_OVER
      RESULT( 9) = RESEFF
      RESULT(10) = RESMXI
 

C -----------------------
      RETURN
      END

      SUBROUTINE SRTRANS(MDOC
     *  ,NAMER,NAMEO,CHI,NSYMF,IRMM,IPRMEM,FMM,IPRMM2
     *  ,NSYM,ISYM,IPRSYM,IERR)
      INTEGER*2 IRMM(IPRMEM)
      INTEGER*2 ISYM(5,3,IPRSYM)
      REAL      FMM (IPRMM2)
      REAL      RSCALE(150)
      CHARACTER NAMER*(*),TITLE*80,LINE*80,NAMEO*(*)
C ========================================================================
      IERR =  0
      PI   =  4.0*ATAN(1.0)
      MD   = -ABS(MDOC)-1
      M    = 99
C ---
      MT    = 10
      ITYPE =  0
      CALL IRDENS(MT,NAMER,MD,ITYPE,ICNTZ,NX,NY,NZZ,IZMAX,IZMIN,RMAX
     *  ,RMIN,IRMM,SCALE,A,B,C,AL,BE,GA,DRMS,RAVER,RESOL,IX0,IY0,IZ0
     *  ,ITR,TITLE,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERR: OPEN FILE-ROT-RES')
        RETURN
      ENDIF
C ---
      NXY=NX*NY
      NZ    =IZMAX-IZMIN+1
      NXYZ  =NXY*NZ
      IF(NXYZ.GT.IPRMEM) THEN
        WRITE(LINE,'(
     * '' ERR: not memory '',I4,'' x'',I4,'' x'',I4,'' >'',I8)')
     *             NX,NY,NZ,IPRMEM
        CALL MSGERR(MDOC,LINE)
        CLOSE(MT)
        IERR=1
        GO TO 500
      ENDIF

c      CALL C_RD_CR

      RFMAX = RMAX
      ITYPE = 1
C -------------------------------------------
C      IF(ABS(CHI).LT.0.0001) CHI=180.0
C      IF(ABS(CHI).GT.180.0 ) CHI=180.0
C --------------------
C    FROM RFRES
C        A=ARAD*10.
C        B=RN  *10.
C        C=RX  *10.
C        AL=PI/(2.*FLOAT(NSYM1))
C        BE=PI/(2.*FLOAT(NSYM2))
C        GA=PI/2.
C        NX=IPRGAM
C        NY=IPRGAM2
C        NZ=180./BETDEL+1.
C        TITLE(5:8)='ABG '
C        TITLE(1:4)='RF: '
C        DELALP=360.0/NX
C        DELGAM=360.0/NY
C        IZMIN=BETMIN/BETDEL
C        IZMAX=BETMAX/BETDEL
C        DELB=(BETDEL*PI)/180.0
C        RESMAX=DELB
C        DELA=(2.0*PI)/(IPRGAM *NSYM1)      
C        DELG=(2.0*PI)/(IPRGAM2*NSYM2)
C        IF(RESMAX.LT.DELA) RESMAX=DELA      
C        IF(RESMAX.LT.DELG) RESMAX=DELG      
C        RESMAX=(RESMAX*180.0)/PI
C ---
      ARAD   = A/10.
      RESMIN = B/10.
      RESMAX = C/10.
      NSYM1  = PI/(2.*AL)+.1
      NSYM2  = PI/(2.*BE)+.1
C --------------------
      NSYMF = NSYM1
C --------------------
      ALPMAX = AL * 4.0
      GAMMAX = BE * 4.0
      ALPDEL = 2.*PI/(NX*NSYM1)

      BETDEL = PI/(NZZ-1)

      GAMDEL = 2.*PI/(NY*NSYM2)

      BETMIN = BETDEL*IZMIN
      BETMAX = BETDEL*IZMAX
      BTMAX  = (BETMAX*180.0)/PI

      IF(BETMIN.GT.0.0000001) THEN
        CALL MSGERR(MDOC,' ERR:  betmin=0 ')
        IERR=1
        GO TO 500
      ENDIF

      CALL GET_TWOFOLD_PATT(NSYM,ISYM,ITWOX,ITWOY)

      IF(BETMAX.LT.PI.AND.(ITWOX.EQ.0.AND.ITWOY.EQ.0)) THEN
        WRITE(LINE,*) ' ERR: betmax:',BTMAX
        CALL MSGERR(MDOC,LINE)
        CALL MSGERR(MDOC,'   must be betmax=180')
        IERR=1
        GO TO 500
      ENDIF

C ---
      NX2   = 72+2
      NZ2   = 36+2
      NXY2  = NX2*NZ2

      IF(NXY2.GT.IPRMM2) THEN
        WRITE(LINE,*) ' ERROR: NO MEMORY :',IPRMM2
        CALL MSGERR(MDOC,LINE)
        IERR=1
        GO TO 500
      ENDIF
      CALL MSGDOC(MDOC,' ')
      J    = 1
      IND  = 1
      BETA = BETMIN

      DO     I=IZMIN,IZMAX
        CALL IRDENS(MT,NAMER,MDOC
     *  ,ITYPE,ICNTZ,NX,NY,NZZ,IZMAX,IZMIN,RMAX
     *  ,RMIN,IRMM(IND),SCALE,A,B,C,AL,BE,GA
     *  ,DRMS,RAVER,RESOL,IX0,IY0,IZ0
     *  ,ITR,TITLE,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MD,' ERR: READ FILE-ROT-RES')
          GO TO 500
        ENDIF
        RSCALE(J) = SCALE
        WBETA     = BETA/(PI/180.)
        BETA      = BETA+BETDEL
        J         = J+1
        IND       = IND + NXY
      ENDDO
C ----------
      CALL TRFOUT(MDOC,IRMM,FMM,RSCALE,NX,NY,NZ,NX2,NZ2,ALPMAX,GAMMAX
     *  ,BETDEL,BETMIN,BETMAX,ALPDEL,GAMDEL,NSYM1,NSYM2
     *  ,RFMAX,RESOL,NAMEO,CHI,NSYMF,NSYM,ISYM,IPRSYM,IERR)
C ----------
 500  CONTINUE
      RETURN
      END

      SUBROUTINE TRFOUT(MDOC,IRMM,FMM,RSCALE,KX,KY,KZ,KX2,KZ2,ALPMAX
     * ,GAMMAX,BETDEL,BETMIN,BETMAX,ALPDEL,GAMDEL,NSYM1,NSYM2
     * ,RFMAX,RESOL,NAMEO,CHI,NSYMF,NSYM,ISYM,IPRSYM,IERR)
C -------------------------------------------------------------------
      INTEGER*2 IRMM(KX,KY,*)
      INTEGER*2 ISYM(5,3,IPRSYM)
      REAL      RSCALE(*)
      REAL      FMM(KX2,KZ2)
      REAL      AM(3,3)
      CHARACTER NAMEO*(*),LINE*80,TITLE*80,ITP*4,MSG*1
C====================================================================
      PI    = 4.0*ATAN(1.0)
      TWOPI = 2.*PI
      PIBY2 = PI/2.0
      MD    = -ABS(MDOC)-1
      M     = 99
C --------------------
      TITLE = ' '
      NX    = KX2
      NY    = KZ2
      NSYMF = 1
      PRALP = TWOPI/FLOAT(NSYM1)
      PRGAM = TWOPI/FLOAT(NSYM2)

      CALL GET_TWOFOLD_PATT(NSYM,ISYM,ITWOX,ITWOY)

C --------------------
8000  CONTINUE

C      IF(CHI.LE.0.001) CHI=180.0
C      IF(CHI.GT.180.0) CHI=180.0

      WCHI = CHI
      CHI  = CHI*PI/180.
      IF(NSYMF.LE.0) NSYMF=1
C --------------------
      MT     = 17
      A      = 360./NSYMF
      B      = 90.
      C      = WCHI
      AL     = PIBY2/FLOAT(NSYMF)
      BE     = PIBY2/FLOAT(NSYM2)
      GA     = PI/2.
      NZ     = 100
      IZMIN  = 0
      IZMAX  = 0
      IPRINT = 1
      ITP    = 'RI  '
      TITLE(5:8)='TPC '

      CALL C_CR_WR
      CALL SET_TITLE(MD,A,B,C,AL,BE,GA,
     *     F1,F2,F3,F4,NX,NY,NZ,IZMIN,IZMAX,TITLE,IERR)

      CALL OWFILE(MD,MT,NAMEO,ITP,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERR: OPEN output file')
        CLOSE(MT)
        RETURN
      ENDIF
C ---------------------------------------------------------
      DO     I=1,NX
      DO     J=1,NY
        FMM(I,J)=0.0
      ENDDO
      ENDDO
C ---------
      DELTH   =PIBY2/(NY-2)
      DELPHI  =TWOPI/(NX-2)*NSYMF
C ---------
c          ABETMIN=BETMIN*CONV
c          ABETMAX=BETMAX*CONV
c          ADELTH =DELTH *CONV
c          ADELPHI=DELPHI*CONV
c          AALPDEL=ALPDEL*CONV
c          ABETDEL=BETDEL*CONV
c          ABETDEL=BETDEL*CONV
c          AGAMDEL=GAMDEL*CONV
c          APRALP =PRALP *CONV
c          APRGAM =PRGAM *CONV
c          WRITE(line,*) ' B min,max,del:',ABETMIN,ABETMAX,ABETDEL
c          CALL MSGDOC(MDoc,LINE)
c          WRITE(line,*) ' Adel,Apr:',AALPDEL,APRALP
c          CALL MSGDOC(MDoc,LINE)
c          WRITE(line,*) ' Gdel,Gpr:',AGAMDEL,APRGAM
c          CALL MSGDOC(MDoc,LINE)
c          WRITE(line,*) ' CHI,THdel,PHIdel:',WCHI,ADELTH,ADELPHI
c          CALL MSGDOC(MDoc,LINE)
c          WRITE(line,*) ' NX,NY:',NX,NY
c          CALL MSGDOC(MDoc,LINE)
c          WRITE(line,*) ' KX,KY,KZ:',KX,KY,KZ
c          CALL MSGDOC(MDoc,LINE)
C ---
      CALL MSGDOC(MDOC,' ')

      DO     ITH=1,NY-1

        DO     IPHI=1,NX-1

          THETA  = (ITH- 1)*DELTH
          PHI    = (IPHI-1)*DELPHI
          CCHI   = CHI
C
C         PS,PHI,CHI  --> ALP,BET,GAM
C
          CALL ANGCON_TR(AM,ALP,BET,GAM,THETA,PHI,CCHI)
C
c          ATH  = THETA*CONV
c          APHI = PHI  *CONV
c          ACHI = CCHI *CONV
c          AALP  = ALP  *CONV
c          ABET = BET  *CONV
c          AGAM = GAM  *CONV
c          WRITE(line,'(2I4,3F8.2,'' -->'',3F8.2)')
c     *   ITH,IPHI,ATH,APHI,ACHI,AALP,ABET,AGAM
c          CALL MSGDOC(MDoc,LINE)
      
          IF(BET.LT.0.0) THEN
            BET = BET + TWOPI
          ENDIF

          IF(BET.GT.TWOPI) THEN
            BET = BET - TWOPI
          ENDIF

          IF(BET.GT.PI   ) THEN
            BET = TWOPI - BET
            ALP = ALP   + PI
            IF(ALP.GT.TWOPI) ALP = ALP - TWOPI 
            GAM = - GAM
            IF(GAM.LT.0.0) GAM = GAM + TWOPI 
          ENDIF


          IF(BET.GT.PIBY2.AND.BETMAX.LE.(PIBY2+0.000001)) THEN
            BET = PI - BET
            IF(ITWOX.GT.0) THEN
              ALP =  -ALP
              IF(ALP.LT.0.0)   ALP = ALP + TWOPI 
            ELSE IF(ITWOY.GT.0) THEN
              ALP = PI - ALP  
              IF(ALP.LT.0.0)   ALP = ALP + TWOPI 
              GAM = PI + GAM 
              IF(GAM.GT.TWOPI) GAM = GAM - TWOPI 
            ENDIF
          ENDIF

          IF(BET.LT.BETMIN.OR.BET.GT.BETMAX) THEN
            WRITE(LINE,*) ' ERR: RETA > BETMAX OR < BETMIN'
            CALL MSGERR(MDOC,LINE)
            IERR=1
            RETURN
          ENDIF

          IF(ALP.LT.0.0) THEN
            ALP = ALP + TWOPI
          ENDIF

          IF(ALP.GT.TWOPI) THEN
            ALP = ALP - TWOPI
          ENDIF


          IF(ALP.GE.PRALP) THEN
            IALP = ALP/PRALP
            ALP  = ALP - IALP*PRALP 
          ENDIF

          IF(GAM.LT.0.0) THEN
            GAM = GAM + TWOPI
          ENDIF

          IF(GAM.GT.TWOPI) THEN
            GAM = GAM - TWOPI
          ENDIF

          IF(GAM.GE.PRGAM) THEN
            IGAM = GAM/PRALP
            GAM  = GAM - IGAM*PRALP 
          ENDIF

c          BALP = ALP  *CONV
c          BBET = BET  *CONV
c          BGAM = GAM  *CONV


          FBET =BET/BETDEL
          IBET =FBET
          FBET =FBET - IBET
          IF(FBET.LT.0.0) FBET = 0.0
          IF(FBET.GT.1.0) FBET = 1.0

          IBET =IBET + 1
          IF(IBET.GE.KZ) THEN
            IBET  = KZ
            IBET1 = KZ
            FBET  = 0.0
          ELSE
            IBET1 = IBET + 1
          ENDIF
          IF(IBET.LE.0) THEN
            IBET =1
            IBET1=1
            FBET =0.0
          ENDIF

          FALP = ALP/ALPDEL
          FGAM = GAM/GAMDEL

          IALP = FALP
          IGAM = FGAM
          FALP = FALP-IALP
          FGAM = FGAM-IGAM
          IF(IALP.LT.0) THEN
            IALP=0
            FALP=0.0
          ENDIF
          IF(IGAM.LT.0) THEN
            IGAM=0
            FGAM=0.0
          ENDIF
          IF(IALP.GE.KX) THEN
            IALP=0
          ENDIF
          IF(IGAM.GE.KY) THEN
            IGAM=0
          ENDIF
          IALP  = IALP+1
          IGAM  = IGAM+1
          IALP1 = IALP
          IGAM1 = IGAM
          IF(IALP1.GE.KX) THEN
            IALP1=0
          ENDIF
          IF(IGAM1.GE.KY) THEN
            IGAM1=0
          ENDIF
          IF(FALP.LT.0.0) FALP = 0.0
          IF(FALP.GT.1.0) FALP = 1.0
          IF(FGAM.LT.0.0) FGAM = 0.0
          IF(FGAM.GT.1.0) FGAM = 1.0
          IALP1  =IALP1 + 1
          IGAM1  =IGAM1 + 1
          FROT11 =IRMM(IALP ,IGAM ,IBET )/RSCALE(IBET)
          FROT21 =IRMM(IALP1,IGAM ,IBET )/RSCALE(IBET)
          FROT12 =IRMM(IALP ,IGAM1,IBET )/RSCALE(IBET)
          FROT22 =IRMM(IALP1,IGAM1,IBET )/RSCALE(IBET)
          FFF1 = (1.-FALP)*FROT11+FALP*FROT21
          FFF2 = (1.-FALP)*FROT12+FALP*FROT22
          FFF  = (1.-FGAM)*FFF1  +FGAM*FFF2
          FFROT11 = IRMM(IALP ,IGAM ,IBET1)/RSCALE(IBET1)
          FFROT21 = IRMM(IALP1,IGAM ,IBET1)/RSCALE(IBET1)
          FFROT12 = IRMM(IALP ,IGAM1,IBET1)/RSCALE(IBET1)
          FFROT22 = IRMM(IALP1,IGAM1,IBET1)/RSCALE(IBET1)
          FFF1 =(1.-FALP)*FFROT11+FALP*FFROT21
          FFF2 =(1.-FALP)*FFROT12+FALP*FFROT22
          RRR  =(1.-FGAM)*FFF1  +FGAM*FFF2
          TEMP =(1.-FBET)*FFF   +FBET*RRR

          FMM(IPHI,ITH) = FMM(IPHI,ITH)+TEMP

c          WRITE(line,'(2I3,2F6.1,'' -->'',3F6.1,3f6.1,'' '',3i3)')
c     * ITH,IPHI,ATH,APHI,AALP,ABET,AGAM,BALP,BBET,BGAM,ialp,igam,ibet
c          CALL MSGDOC(MDoc,LINE)

        ENDDO
      ENDDO
C -------------------------------------------
      DO     I=1,NX-1
        FMM(I,NY) = FMM(I,NY-1)
      ENDDO
      DO     I=1,NY
        FMM(NX,I) = FMM(NX-1,I)
      ENDDO
      DO     J=1,NY
      DO     I=1,NX
        IF(FMM(I,J).LT.0.0) FMM(I,J)=0.
      ENDDO
      ENDDO
C -------------------------------------
      ITR = 1
      IX0 = 0
      IY0 = 0
      IZ0 = 0
      RX  = RESOL
      ICNTZ=-999
       CALL WDENS(MT,MDOC,ICNTZ,NX,NY,NZ,IZMIN,IZMAX,RRMAX,RRMIN,
     *             FMM,RX,IX0,IY0,IZ0,ITR)
      RETURN
      END

      SUBROUTINE ANGCON_TR(AM,THETA1,THETA2,THETA3,PSI,PHI,CHI)
      REAL AM(3,3)
C ---------------------------------------------------------
      PI   = 4.0*ATAN(1.0)
      CONV = 180.0/PI
C ---
      COSP = COS(PSI)
      SINP = SIN(PSI)
      COSF = COS(PHI)
      SINF = SIN(PHI)
      COSC = COS(CHI)
      SINC = SIN(CHI)

      C1   = COSF*SINP
      S12  = 1-C1*C1
      C2   = SINF*SINP
      S22  = 1-C2*C2
      C3   = COSP
      S32  = SINP*SINP
      D1   = 1-COSC

      AM(1,1) = 1-S12*D1
      AM(1,2) = C1*C2*D1-C3*SINC
      AM(1,3) = C1*C3*D1+C2*SINC
      AM(2,1) = C2*C1*D1+C3*SINC
      AM(2,2) = 1-S22*D1
      AM(2,3) = C2*C3*D1-C1*SINC
      AM(3,1) = C3*C1*D1-C2*SINC
      AM(3,2) = C3*C2*D1+C1*SINC
      AM(3,3) = 1-S32*D1

      CALL ANGFX_TR(AM,THETA1,THETA2,THETA3)

      ALPHA = CONV * THETA1
      BETA  = CONV * THETA2
      GAMMA = CONV * THETA3

      RETURN
      END

      SUBROUTINE ANGFX_TR(TRMAT,THETA1,THETA2,THETA3)
      REAL TRMAT(3,3)
C ----------------------------------------------------
      PI     = 4.0*ATAN(1.0)
C ---
      THETA1=0.
      THETA2=0.
      THETA3=0.

      TRACE = TRMAT(1,1)+TRMAT(2,2)+TRMAT(3,3)

      IF(TRACE.GE.3.0)            GO TO 100

      IF(TRMAT(3,3).GE. 0.999999) GO TO 13
      IF(TRMAT(3,3).LE.-0.999999) GO TO 13

      THETA2=ACOS(TRMAT(3,3))
C
      R13    = TRMAT(1,3)
      R23    = TRMAT(2,3)
      R31    = TRMAT(3,1)
      R32    = TRMAT(3,2)
      THETA3 = ATAN2(R32,-R31)
      THETA1 = ATAN2(R23,R13)
      GO TO 100

C   BETA =0 OR 180  CAN ONLY FIND ALPHA + OR - GAMMA.

13    THETA2 = 0.
      IF(TRMAT(3,3).LT.0.) THETA2 = PI
      IF(TRMAT(2,1).EQ.0.0.AND.TRMAT(2,2).EQ.0.0) THEN
        THETA3 = 0.0
      ELSE
        THETA3 = ATAN2(TRMAT(2,1),TRMAT(2,2))
      ENDIF
      THETA1 = 0.0
100   CONTINUE
      RETURN
      END



      SUBROUTINE PICTURE(MODE,IPICT,NX,NY,IRM,NX4,NY4,IR,NXR,NYR
     * ,THETA,PHI,RMAX_CROSS
     * ,CHI,A,B,ANG,RMAX,RMAX1,SCALE_R,IERR)
C=====================================================================
C     drawing of isolines in array IR(NX,NY)
C---------------------------------------------------------------------
C     IPICT =0 SELF     
C     IPICT =1 CROSS(T,P,C)
C     IPICT =2 CROSS(A,B,G)
C     IPICT =3 TRANS(X,Y,Z)      
C
C
C
C                  <........A........>
C        NYR-1  NY+-------------------+  -
C          +======================+   !  !
C          I      !               I   !  B
C          I    0 !               I   !  !
C     IY0C I......+---------------I---+  -
C          I      . 0             I  NX 
C          I      .               I
C        0 +======================+
C          0     IX0C           NXR-1
C
C                                                         
C     MTOUT - output file (G-P or TEKTRONIX)  
C     IR(NXR,NYR) -  array /INTEGER*2/ data  
C     IRM(NX4,NY4) - array /INTEGER*2/ labels   
C                    NX4=NX/4+2            
C                    NY4=NY/4+2       
C     A     - size along axiz X from 0 to NX  (angstroms)
C     B     - size along axiz Y from 0 to NY  (angstroms)
C     ANG   - angle beetwin X and Y (in rad.)   
C     SCALE - scaling from unit cell to plotter 
C                         (angstroms)   (0.1 mm)
C              frame (approx)  X: (A+B*COS(ANG))*SCALE < 1022
C                              Y: (  B*SIN(ANG))*SCALE <  767
C     NLEV - number of isolines for range ( 0 --> RMAX   )  and
C                                         ( - RMAX --> 0 ) (NEG.EQ.1)
C     JLEV - array label of isoline  (1-draw,0-no)
C     NPEN - number of pen   
C     ISHX,ISHY - shift (IN 0.1 mm) 
C     IFRM - /input/  - draw of frame & title (0-no,1-yes,2-frame only)
C            /output/ - normal >=0; abend -1
C     IAP - not used
C     MSG1 =0 no question for list, =1 yes
C     MSG2 - not used
C     MSG3 = 'N'
C---------------------------------------------------------------------
C             IYCP.......................................
C              ^               Y --------------------/  .
C              !               /  O        OO      /  T .
C              !             /     O O      O    /    I .<--FRAME
C              !           /     O   OO  O   O /      T .
C              !         /            O      /        L .
C              !........+------------------->X        E .
C              ^ISHY    .                               .
C              !    ISHX.                               .
C              +------->-----------------------------------> IXCP
C =====================================================================
C --
      COMMON /COM_STEREO/ IZORG,IZOOO,IZ000,IZDEL,IXCENTR,IYCENTR
     *                ,IBASE,IVIEW,ISIZEP,IZSIZEP2,ISITE,STER
C
C     ISITE - 1= L 2 = R
C     STER    N/P/S
C
      CHARACTER     STER*1
C ----
      INTEGER*2 IR(NXR,NYR)
C ---
C case REAL IRR(INDXY) INTEGER*2 IRM(INDXY4)
C     REAL      IR(NXR,NYR)
C ---
      INTEGER*2 IRM(NX4,NY4)
C     
C ---
      INTEGER   JLEV(20),ICOL(20)
      CHARACTER LINE*80,LEV*20
C                 1 2 3 4 5 6 7 8 9 . 1 2 3 4 5 6 7 8 9 . 
      DATA  ICOL /4,4,4,4,5,5,5,5,6,6,6,6,7,7,7,7,8,8,8,8/
C                 n y n y n y n y n y n y n y n y n y n y
      DATA  LEV /'NYNYNYNYNYNYNYNYNYNY'/
C                 123456789 123456789 
C --------------------------------------------------------------------
      IERR = 0
C -----------------------
      CALL SET_BT
      CALL GET_BOX_TX(IBOXX,IBOXY,ISHX_PS,ISHY_PS,IX0_PS,IY0_PS
     *   ,LIM_XMIN,LIM_XMAX,LIM_YMIN,LIM_YMAX)
C --
      SCALE = 1.0
      ISITE = 0
      STER  = 'N'
C ----
      NLEV  =20
      DO      I=1,NLEV
        IF(LEV(I:I).EQ.'Y') THEN
          JLEV(I)=1
        ELSE
          JLEV(I)=0
        ENDIF
      ENDDO
C -------------------------
      COSA  = 1.0
      SINA  = 0.0
      IF(IPICT.GE.0.AND.IPICT.LE.1) THEN
        FLENX = 2.0*B
        FLENY = 2.0*B
        ORGX  = B
        ORGY  = B
      ELSE
        COSA  = 1.0
        SINA  = 0.0
        IFX   = B*COSA*SCALE
        IFY   = B*SINA*SCALE
        IF(IFX.LE.0) THEN
          DX = ABS(IFX)
        ELSE
          DX = 0.0
        ENDIF
        FLENX = A
        FLENY = B
        ORGX  = 0
        ORGY  = 0
      ENDIF
C -------------------------
C --- size of picture ---
C input SCALE_R

      IF(SCALE_R.LT.1.0E-4) SCALE_R=1.0
      IF(SCALE_R.GT.1.0   ) SCALE_R=1.0

      TSCALEX= IBOXX   /(FLENX)
      TSCALEY=(IBOXY-5)/(FLENY)
      IF(TSCALEX.GT.TSCALEY) TSCALEX=TSCALEY
      TSCALEX=TSCALEX*0.99
      SCALE = TSCALEX
      SCALE = SCALE*SCALE_R
C ------------------------
      PSHFTX = 0.0
      PSHFTY = 0.0
      DELX_TITLE = 80.0
      IF(MODE.GE.0.AND.MODE.LE.1) THEN
        PSHFTX = DELX_TITLE 
        PSHFTY = 0.0
      ELSE IF(MODE.EQ.2) THEN
        PSHFTX = DELX_TITLE
        PSHFTY = 2.0 * B * SCALE + 10.0
      ELSE IF(MODE.EQ.3) THEN
        PSHFTX = 2.0 * B * SCALE + 55.0 + DELX_TITLE
        PSHFTY = 0.0 
      ELSE IF(MODE.EQ.4) THEN
        PSHFTX = 2.0 * B * SCALE + 55.0 + DELX_TITLE
        PSHFTY = 2.0 * B * SCALE + 10.0 
      ENDIF
C --
      ISHX = ORGX * SCALE + 0.5 + PSHFTX
      ISHY = ORGY * SCALE + 0.5 + PSHFTY
C -------------------------
      IX0 = ISHX
      IY0 = ISHY
      IZ0 = 0
      CALL ORITXZ(IX0,IY0,IZ0)

C ---
      IRAD = B*SCALE

      ICL = 5
      CALL NEWPEN(ICL)
      IT  =-IRAD                        
      IT1 = 0                        
      CALL MOVTXXZ(IT,IT1,IZ0)           
      IT  = IRAD                     
      IT1 = 0                        
      CALL VECTXXZ(IT,IT1,IZ0)           
      IT  = 0                        
      IT1 =-IRAD                        
      CALL MOVTXXZ(IT,IT1,IZ0)           
      IT  = 0                     
      IT1 = IRAD                      
      CALL VECTXXZ(IT,IT1,IZ0)           

      IT  = IRAD                     
      IT1 = 0                        
      CALL MOVTXXZ(IT,IT1,IZ0)
           
      DELF=A/36.                   
      DELF=(DELF*3.1415926)/180.   

      ICL = 9
      CALL NEWPEN(ICL)
      DO     I=1,37                
        FAN =DELF*(I-1)             
        COSF=COS(FAN)              
        SINF=SIN(FAN)              
        IT  = B*COSF*SCALE          
        IT1 = B*SINF*SCALE          
        CALL VECTXXZ(IT,IT1,IZ0)
      ENDDO

C -------------
      ICL = 1
      CALL NEWPEN(ICL)

      DO     I=1,37
        IT  = 0                        
        IT1 = 0                       
        CALL MOVTXXZ(IT,IT1,IZ0)          
        FI = I*10.0                   
        IF(FI.GT.A) GO TO 1910      
        FI = (FI*3.1415926)/180.      
        COSF = COS(FI)                
        SINF = SIN(FI)                
        G    = 80.
        G    = (G*3.1415926)/180.        
        COSG = COS(G)                 
        SING = SIN(G)                 
        BB   = (B*B*COSG)/(B+B*SING)    
        IT   = BB*COSF*SCALE          
        IT1  = BB*SINF*SCALE          
        CALL MOVTXXZ(IT,IT1,IZ0)          
        IT   = B*COSF*SCALE           
        IT1  = B*SINF*SCALE
        IF(I.EQ.9 ) IT1 = IT1 + 7
        IF(I.EQ.36) IT  = IT  + 10
        CALL VECTXXZ(IT,IT1,IZ0)          
      ENDDO                         
1910  CONTINUE                      

      ICL = 1
      CALL NEWPEN(ICL)

      DO     J=1,9                  
        FI   = J*10.
        FI   = (FI*3.1415926)/180.
        COSF = COS(FI)
        SINF = SIN(FI)
        BB   = (B*B*COSF)/(B+B*SINF)
        IT   = BB
        IT1  = 0
        CALL MOVTXXZ(IT,IT1,IZ0)
        DELF = A/36.
        DELF = (DELF*3.1415926)/180.
        DO     I=1,37
          FAN  = DELF*(I-1)
          COSF = COS(FAN)
          SINF = SIN(FAN)
          IT   = BB*COSF*SCALE
          IT1  = BB*SINF*SCALE
          CALL VECTXXZ(IT,IT1,IZ0)
        ENDDO
      ENDDO
C ---
      IROT  = 0
      WRITE(LINE,'('' Chi = '',F6.1)') CHI
      ISIZEX = 12
      IX     = -B*SCALE - 15
      IY     = -30
      CALL LENSTR_BL(LINE,LEN)
      CALL TXSYMB(LINE(1:LEN),ISIZEX,IX,IY,IROT)

      IROT   =0
      ISIZEX = 10
      IX     = B*SCALE + 7
      IY     = 5
      CALL TXSYMB('X',ISIZEX,IX,IY,IROT)

      ISIZEX = 10
      IX     = 7
      IY     = B*SCALE + 4
      CALL TXSYMB('Y',ISIZEX,IX,IY,IROT)

      IROT   = 0
      ISIZEX = 8
      IX     =  B*SCALE + 16

      IF(IPICT.EQ.0) THEN
        IY     =  - 40
        WRITE(LINE,'('' RFmax = '',G14.4)') RMAX1
      ELSE IF(IPICT.EQ.1) THEN
        IY     =  - 80
        WRITE(LINE,
     *'(''Peak:'',I2,'' Theta:'',F6.1,'' Phi:'',F6.1,'' RFmax:'',G14.4)'
     *) MODE,THETA,PHI,RMAX_CROSS
      ENDIF

      CALL TXSYMB(LINE,ISIZEX,IX,IY,IROT)
C --------------------------------------------------
      IT =0
      IT1=0
      IZ =0
      CALL MOVTXXZ(IT,IT1,IZ)
      DO      I=1,NLEV
        IF(JLEV(I).EQ.0) GO TO 700
        IT = ICOL(I)
        CALL NEWPEN(IT)
        FLV = (RMAX/FLOAT(NLEV+1))*FLOAT(I)
        IZ  = 0
        NX0 = 0
        NY0 = 0
        IX0C= 0
        IY0C= 0

        CALL ISOL(MTOUT,NX,NY,NX4,NY4,A,B,ANG,SCALE,FLV,IR,IRM,IPICT,
     *  IX0C,IY0C,NX0,NY0,NXR,NYR,IZ)

        IT  = 0
        IT1 = 0
        IZ0 = 0
        CALL MOVTXXZ(IT,IT1,IZ0)
700     CONTINUE

      ENDDO

99999 CONTINUE
      RETURN
      END


      SUBROUTINE ISOL(MTOUT,NX,NY,NX4,NY4,A,B,ANG,SCALE,FLV,
     * IR,IRM,IPICT,IX0,IY0,NX0,NY0,NXR,NYR,IZ)
C=============================================================
C     drawing of one isoline in array (NX+1,NY+1)
C-------------------------------------------------------------
C
C       !<- - - - - - A  - - - - ->!
C       !--------------------------!
C       0                         NX  
C       .
C       .
C   !---+-----------------------------------!
C   0   IX0                                 NXR-1
C-------------------------------------------------------------------
      INTEGER*2 IR (NXR,NYR)
C ---
C case REAL IRR(INDXY) INTEGER*2 IRM(INDXY4)
C     REAL      IR(NXR,NYR)
C ---
      INTEGER*2 IRM(NX4,NY4)
C-------------------------------------------------
C     initialize  array of labels
C-------------------------------------------------
      DO      I=1,NX4
      DO      J=1,NY4
        IRM(I,J)=0
      ENDDO
      ENDDO
C-------------------------------------------------
C     cycle of triangle chech
C-------------------------------------------------
      NX1=NX+1
      NY1=NY+1
      DX=1./FLOAT(NX)
      DY=1./FLOAT(NY)
      COSA =ANG
      ISINA=IPICT
      X=0.
      Y=0.
      DO      ITR=1,NX
      DO      JTR=1,NY
      ICOUNT=0
      IPEN  =1
      CALL STLBL(0,ILB,ITR,JTR,IRM,NX4,NY4)
      IF(ILB.EQ.0) THEN
3100    IF(ICOUNT.GT.1) GO TO 1000
        I=ITR
        J=JTR
        I1=I
        J1=J+1
        I2=I
        J2=J
        I3=I+1
        J3=J
C SSSSSS
        CALL LINE(IT,X,Y,I,J,I1,J1,I2,J2,I3,J3,IPEN,IR,
     &  MTOUT,NX1,NY1,DX,DY,COSA,ISINA,A,B,FLV,SCALE,
     &  IX0,IY0,NX0,NY0,NXR,NYR,IZ)
C FFFFFF
        IF(ICOUNT.EQ.1) THEN
          IF(IT.EQ.0) THEN
            IOUT=0
            IPEN=0
            GO TO 3200
          ELSE IF(IT.EQ.1) THEN
            IOUT=2
            IPEN=0
            GO TO 3200
          ELSE
            GO TO 3000
          ENDIF
        ELSE
          IF(IT.EQ.0) THEN
            INP=0
          ELSE IF(IT.EQ.1) THEN
            INP=2
          ELSE
            GO TO 3000
          ENDIF
        ENDIF
C-------------------------------------------------
C    DRAW ISOLINE
C-------------------------------------------------
C              INPUT IN TRIANGLE
C-------------------------------------------------
      IPEN=0
      I=ITR
      J=JTR
2000  CALL STLBL(0,ILB,I,J,IRM,NX4,NY4)
      IF(ILB.NE.0) GO TO 1000
      CALL STLBL(1,ILB,I,J,IRM,NX4,NY4)
      IF(INP.EQ.0) THEN
        I1=I
        J1=J+1
        I2=I+1
        J2=J
        I3=I
        J3=J
        CALL LINE(IT,X,Y,I,J,I1,J1,I2,J2,I3,J3,IPEN,IR,
     &  MTOUT,NX1,NY1,DX,DY,COSA,ISINA,A,B,FLV,SCALE,
     &  IX0,IY0,NX0,NY0,NXR,NYR,IZ)
        IF(IT.EQ.0) THEN
          IOUT=1
        ELSE IF(IT.GT.0) THEN
          IOUT=2
        ELSE
          GO TO 3000
        ENDIF
      ELSE IF(INP.EQ.1) THEN
        I1=I
        J1=J+1
        I2=I
        J2=J
        I3=I+1
        J3=J
        CALL LINE(IT,X,Y,I,J,I1,J1,I2,J2,I3,J3,IPEN,IR,
     &  MTOUT,NX1,NY1,DX,DY,COSA,ISINA,A,B,FLV,SCALE,
     &  IX0,IY0,NX0,NY0,NXR,NYR,IZ)
        IF(IT.EQ.0) THEN
          IOUT=0
        ELSE IF(IT.GT.0) THEN
          IOUT=2
        ELSE
          GO TO 3000
        ENDIF
      ELSE
        I1=I
        J1=J
        I2=I
        J2=J+1
        I3=I+1
        J3=J
        CALL LINE(IT,X,Y,I,J,I1,J1,I2,J2,I3,J3,IPEN,IR,
     &  MTOUT,NX1,NY1,DX,DY,COSA,ISINA,A,B,FLV,SCALE,
     &  IX0,IY0,NX0,NY0,NXR,NYR,IZ)
        IF(IT.EQ.0) THEN
          IOUT=0
        ELSE IF(IT.GT.0) THEN
          IOUT=1
        ELSE
          GO TO 3000
        ENDIF
      ENDIF
C------------------------------------------------
C            OUTPUT FROM TRIANGLE
C------------------------------------------------
3200  IF(IOUT.EQ.0) THEN
        I1=I
        J1=J
        I2=I-1
        J2=J+1
        I3=I
        J3=J+1
        IF(I.LE.1) GO TO 3000
        CALL LINE(IT,X,Y,I,J,I1,J1,I2,J2,I3,J3,IPEN,IR,
     &  MTOUT,NX1,NY1,DX,DY,COSA,ISINA,A,B,FLV,SCALE,
     &  IX0,IY0,NX0,NY0,NXR,NYR,IZ)
        IF(IT.EQ.0) THEN
          INP=1
          I=I-1
          J=J
        ELSE
          IF(J+1.GE.NY1) GO TO 3000
          INP=2
          I=I-1
          J=J+1
        ENDIF
      ELSE IF(IOUT.EQ.1) THEN
        I1=I+1
        J1=J
        I2=I+1
        J2=J+1
        I3=I
        J3=J+1
        CALL LINE(IT,X,Y,I,J,I1,J1,I2,J2,I3,J3,IPEN,IR,
     &  MTOUT,NX1,NY1,DX,DY,COSA,ISINA,A,B,FLV,SCALE,
     &  IX0,IY0,NX0,NY0,NXR,NYR,IZ)
        IF(IT.EQ.0) THEN
        IF(I+1.GE.NX1) GO TO 3000
          INP=0
          I=I+1
          J=J
        ELSE
          IF(J+1.GE.NY1) GO TO 3000
          INP=2
          I=I
          J=J+1
        ENDIF
      ELSE
        IF(J.LE.1) GO TO 3000
        I1=I
        J1=J
        I2=I+1
        J2=J-1
        I3=I+1
        J3=J
        CALL LINE(IT,X,Y,I,J,I1,J1,I2,J2,I3,J3,IPEN,IR,
     &  MTOUT,NX1,NY1,DX,DY,COSA,ISINA,A,B,FLV,SCALE,
     &  IX0,IY0,NX0,NY0,NXR,NYR,IZ)
        IF(IT.EQ.0) THEN
          INP=1
          I=I
          J=J-1
        ELSE
          IF(I+1.GE.NX1) GO TO 3000
          INP=0
          I=I+1
          J=J-1
        ENDIF
      ENDIF
      GO TO 2000
3000  CONTINUE
      ICOUNT=ICOUNT+1
      IPEN=1
      GO TO 3100
C------------------------------------------------
C     PASS TO NEXT TRIANGLE
C------------------------------------------------
1000  CONTINUE
      CALL STLBL(1,ILB,ITR,JTR,IRM,NX4,NY4)
      ENDIF
      ENDDO
      ENDDO
      RETURN
      END

      SUBROUTINE SET_BT
      COMMON/COM_BT/ IBYTE1,IBYTE2
      INTEGER   IN4
      INTEGER*2 IN2(2)
      EQUIVALENCE (IN4,IN2(1))
C -----
      IN2(1)=100
      IN2(2)=0
      IF(IN4.EQ.100) THEN
C          IN4
C          2 1
        IBYTE1=1
        IBYTE2=2
      ELSE
C          IN4
C          1 2
        IBYTE1=2
        IBYTE2=1
      ENDIF
      RETURN
      END

      SUBROUTINE STLBL(ITYP,ILB,I,J,IRM,NX,NY)
C-------------------------------------------------
C    SET OR GET FLAG
C-------------------------------------------------
      COMMON/COM_BT/ IBYTE1,IBYTE2
      INTEGER*2 IRM(NX,NY)
C ---
C ====
      INTEGER   IN4
      INTEGER*2 IN2(2)
      EQUIVALENCE (IN4,IN2(1))
C ====
C -------------------------------------------------
      IM=I/4
      JM=J/4
      IMM=I-IM*4
      JMM=(J-JM*4)*4
      IBT=JMM+IMM
      IM=IM+1
      JM=JM+1
C ====
      JBT=2**(IBT+1)
      KBT=2**(IBT  )
      IN2(IBYTE2)=0
      IN2(IBYTE1)=IRM(IM,JM)
C ====
      IF(ITYP.EQ.0) THEN
C---------------------------
C       GET
C---------------------------
C ====
        IT =IN4/JBT
        IT =IN4-IT*JBT
        ILB=IT/KBT
C ====
      ELSE
C---------------------------
C       SET
C---------------------------
C ====
        IT =IN4/JBT
        IT =IT*JBT
        JT =IN4/KBT
        JT =IN4-JT*KBT
        IN4=IT+KBT+JT
        IRM(IM,JM)=IN2(IBYTE1)
      ENDIF
      RETURN
      END

      SUBROUTINE LINE(IT,X,Y,I,J,I1,J1,I2,J2,I3,J3,IPEN,IR,
     &  MTOUT,NX1,NY1,DX,DY,ANG1,IPICT,A,B,FLV,SCALE,
     &  IX0,IY0,NX0,NY0,NXR,NYR,IZ)
C---------------------------------------------------------------------
C     line from point (X,Y) to [(I1,J1)-(I2,J2)] or [(I2,J2)-(I3,J3)]
C
C    I,J,I1,J1,I2,J2,I3,J3 in rang 1 - NX+1 or 1 - NY+1
C
C---------------------------------------------------------------------
      INTEGER*2 IR(NXR,NYR)
C ---
C case REAL IRR(INDXY) INTEGER*2 IRM(INDXY4)
C     REAL      IR(NXR,NYR)
C ---
C=====================================================================
      NX=NX1-1
      NY=NY1-1
      IF(IPEN.EQ.0) THEN
        ITR=1
      ELSE
        ITR=0
      ENDIF
      COSA = 1.0
      SINA = 0.0
      IF(IPICT.GE.2.AND.IPICT.LE.3) THEN
        COSA = COS(ANG1)
        IF(ABS(COSA).LT.1.E-5) COSA=0.0
        SINA = SIN(ANG1)
      ENDIF
      IF(COSA.LT.0) THEN
        KI1=NX-(I1-1)
        KI2=NX-(I2-1)
        KI3=NX-(I3-1)
      ELSE
        KI1=I1-1
        KI2=I2-1
        KI3=I3-1
      ENDIF
      KI1=KI1+IX0
10    IF(KI1.LT.0) THEN
        KI1=KI1+NXR
        GO TO 10
      ELSE IF(KI1.GE.NXR) THEN
        KI1=KI1-NXR
        GO TO 10
      ENDIF
      KI2=KI2+IX0
20    IF(KI2.LT.0) THEN
         KI2=KI2+NXR
         GO TO 20
      ELSE IF(KI2.GE.NXR) THEN
         KI2=KI2-NXR
         GO TO 20
      ENDIF
      KI3=KI3+IX0
30    IF(KI3.LT.0)  THEN
        KI3=KI3+NXR
        GO TO 30
      ELSE IF(KI3.GE.NXR) THEN
        KI3=KI3-NXR
        GO TO 30
      ENDIF
      KJ1=J1-1+IY0
40    IF(KJ1.LT.0) THEN
        KJ1=KJ1+NYR
        GO TO 40
      ELSE IF(KJ1.GE.NYR) THEN
        KJ1=KJ1-NYR
        GO TO 40
      ENDIF
      KJ2=J2-1+IY0
50    IF(KJ2.LT.0) THEN
        KJ2=KJ2+NYR
        GO TO 50
      ELSE IF(KJ2.GE.NYR) THEN
        KJ2=KJ2-NYR
        GO TO 50
      ENDIF
      KJ3=J3-1+IY0
60    IF(KJ3.LT.0) THEN
        KJ3=KJ3+NYR
        GO TO 60
      ELSE IF(KJ3.GE.NYR) THEN
        KJ3=KJ3-NYR
        GO TO 60
      ENDIF
C ---
      IR11=IR(KI1+1,KJ1+1)
      IR22=IR(KI2+1,KJ2+1)
      IR33=IR(KI3+1,KJ3+1)
C ---
      IF(FLV.LT.0) THEN
        IR11=-IR11
        IR22=-IR22
        IR33=-IR33
      ENDIF
      R1=FLOAT(IR11)-ABS(FLV)
      R2=ABS(FLV)-FLOAT(IR22)
      IF((R1.LT.0.AND.R2.LT.0).OR.(R1.GT.0.AND.R2.GT.0)) THEN
        II1=I1
        JJ1=J1
        II2=I2
        JJ2=J2
        IT =0
      ELSE
      R1=FLOAT(IR22)-ABS(FLV)
      R2=ABS(FLV)-FLOAT(IR33)
        IF((R1.LT.0.AND.R2.LT.0).OR.(R1.GT.0.AND.R2.GT.0)) THEN
          II1=I2
          JJ1=J2
          II2=I3
          JJ2=J3
          IT =1
        ELSE
          IT=-1
          RETURN
        ENDIF
      ENDIF
      R12 = R2/R1
      R13 = R12/(1+R12)
      X1  = FLOAT(II1-1)*DX
      Y1  = FLOAT(JJ1-1)*DY
      X2  = FLOAT(II2-1)*DX
      Y2  = FLOAT(JJ2-1)*DY
      XX  = R13*(X1-X2)+X2
      YY  = R13*(Y1-Y2)+Y2
      XT  = XX*A*SCALE
      YT  = YY*B*SCALE

      IF(IPICT.GE.2.AND.IPICT.LE.3) THEN
        IYYCP = YT*SINA      + 0.5              
        IXCPW = XT + YT*COSA + 0.5
      ELSE
        RR   = B*SCALE                         
        IXCP = XT+.5                         
        IYCP = YT+.5                         
        ANG  = (IXCP*ANG1)/(A*SCALE)          
                                         
        ANGL  = 1.5707963*(IYCP/(B*SCALE))
        YYY   = RR*COS(ANGL)                   
        XXX   = RR*SIN(ANGL)                   
        IYCPS = XXX*RR/(RR+YYY)              
        IXCP  = IYCPS*COS(ANG)               
        IYYCP = IYCPS*SIN(ANG)              
        IXCPW = IXCP
      ENDIF

      IZ    = 0
      IF(ITR.NE.0) THEN
        CALL VECTXXZ(IXCPW,IYYCP,IZ)
      ELSE
        CALL MOVTXXZ(IXCPW,IYYCP,IZ)
      ENDIF
      X=XX                               
      Y=YY                               
      RETURN                             
      END                                

      SUBROUTINE TXSYMBZ(SYM,ISIZEX,IX,IY,IZ)
C -----------------------------------------
C --
      COMMON /COM_STEREO/ IZORG,IZO,IZ0,IZDEL,IXCENTR,IYCENTR
     *                ,IBASE,IVIEW,ISIZEP,IZSIZEP2,ISITE,STER
C
C     ISITE - 1= L 2 = R
C     STER    N/P/S
C
      CHARACTER     STER*1
C --
      CHARACTER SYM *(*)
C ---- IMOD = 1 absolute coord. system
C --------------------------
      CALL GET_BOX_TX(IBX,IBY,ISHX,ISHY,IX0_PS,IY0_PS
     *   ,LIM_XMIN,LIM_XMAX,LIM_YMIN,LIM_YMAX)


C        IXT=IX+IX0_PS
C        IYT=IY+IY0_PS
C        IZT=IZ+IZ0

        CALL TXPROJ_PNT(IX,IY,IZ,IXT,IYT)

        IXP=IXT+IX0_PS
        IYP=IYT+IY0_PS

        IF(IXP.LT.0) IXP=0
        IF(IYP.LT.0) IYP=0
        IF(IXP.GT.IBX) IXP=IBX
        IF(IYP.GT.IBY) IYP=IBY

        IXT=IXP+ISHX
        IYT=IYP+ISHY


        IXTT=IYT+LIM_YMIN
        IYTT=LIM_XMAX-IXT

        IF(IXTT.LT.LIM_YMIN) IXTT=LIM_YMIN
        IF(IYTT.LT.LIM_XMIN) IYTT=LIM_XMIN
        IF(IXTT.GT.LIM_YMAX) IXTT=LIM_YMAX
        IF(IYTT.GT.LIM_XMAX) IYTT=LIM_XMAX

        XL=IXTT
        YL=IYTT

        IXT=ISIZEX+IXCENTR
        IYT=IYCENTR
    
        CALL TXPROJ_PNT(IXT,IYT,IZ,IXP,IYP)
        ISIZEP=IXP-IXCENTR

      SIZE=ISIZEP
      CALL PSTEXT(XL,YL,SIZE,SYM)

      RETURN
      END

      SUBROUTINE MOVTXXZ(IX,IY,IZ)
C --
      COMMON /COM_STEREO/ IZORG,IZO,IZ0,IZDEL,IXCENTR,IYCENTR
     *                ,IBASE,IVIEW,ISIZEP,IZSIZEP2,ISITE,STER
C
C     ISITE - 1= L 2 = R
C     STER    N/P/S
C
      CHARACTER     STER*1
C --
      COMMON /COMORG/ ITYPE,SLEN,IXORG,IYORG
C -----------------------------------------
      IXORG=IX
      IYORG=IY
      IZORG=IZ
      SLEN =0.0
      CALL MOVTXZ(IX,IY,IZ)
      RETURN
      END

      SUBROUTINE VECTXXZ(IX,IY,IZ)
C --
      COMMON /COM_STEREO/ IZORG,IZO,IZ0,IZDEL,IXCENTR,IYCENTR
     *                ,IBASE,IVIEW,ISIZEP,IZSIZEP2,ISITE,STER
C
C     ISITE - 1= L 2 = R
C     STER    N/P/S
C
      CHARACTER     STER*1
C --
      COMMON /COMORG/ ITYPE,SLEN,IXORG,IYORG
CN    DATA DLEN/ 7.0 /
CVX   DATA DLEN/ 7.0 /
CMS   DATA DLEN/ 1.0 /
      DATA DLEN/ 2.0 /
C -------------------------------------------
      IF(ITYPE.EQ.0) THEN
        CALL VECTXZ(IX,IY,IZ)
      ELSE
        IXC=IX
        IYC=IY
        IZC=IZ
        ALLL=FLOAT(IXORG-IX)*FLOAT(IXORG-IX)+
     *       FLOAT(IYORG-IY)*FLOAT(IYORG-IY)
        ALLL=SQRT(ABS(ALLL))
        IF(ALLL.GT.0.) THEN     
          STOT=SLEN+ALLL
          N2 =STOT/DLEN
          AN2=STOT-N2*DLEN
          IF(AN2.GT.0.0) THEN
            N2=N2+1
          ELSE
            AN2=DLEN
          ENDIF
          N1 =SLEN/DLEN
          AN1=SLEN-N1*DLEN
          N1 =N1+1
          IF(N1.EQ.N2) AN2=AN2-AN1
          COSA=(IX-IXORG)/ALLL
          SINA=(IY-IYORG)/ALLL
          DLENZ=(IZ-IZORG)
          IF(N2.GE.N1) THEN
            DO      I=N1,N2
              IF(I.EQ.N1.AND.I.NE.N2) THEN
                D=DLEN-AN1
                SX=D*COSA
                SY=D*SINA
              ELSE IF(I.EQ.N2) THEN
                D=AN2
                SX=D*COSA
                SY=D*SINA
              ELSE
                D =DLEN
                SX=DLEN*COSA
                SY=DLEN*SINA
              ENDIF
              IX=IXORG+SX
              IY=IYORG+SY
              T=DLEN
              IF(T.EQ.0.0) T=1.0
              IZ=IZORG+DLENZ*(D/T)
              IXORG=IX
              IYORG=IY
              IZORG=IZ
              IF(MOD(I,2).EQ.1) THEN
                CALL VECTXZ(IX,IY,IZ)
              ELSE
                CALL MOVTXZ(IX,IY,IZ)
              ENDIF
            ENDDO
          ENDIF
          SLEN=STOT
        ENDIF
        CALL MOVTXZ(IXC,IYC,IZC)
      ENDIF
      RETURN
      END
 
      SUBROUTINE PNTTXZ(IX,IY,IZ)
      CALL MOVTXZ(IX,IY,IZ)
      CALL VECTXZ(IX,IY,IZ)
      END
 
      SUBROUTINE MOVTXZ(IX,IY,IZ)
C --
      COMMON /COM_STEREO/ IZORG,IZO,IZ0,IZDEL,IXCENTR,IYCENTR
     *                ,IBASE,IVIEW,ISIZEP,IZSIZEP2,ISITE,STER
C
C     ISITE - 1= L 2 = R
C     STER    N/P/S
C
      CHARACTER     STER*1
C --
C ---
      COMMON/TX_ORIG/ IXO,IYO,IX0,IY0
C -----------------------------------------

      IXO=IX
      IYO=IY
      IZO=IZ

      RETURN
      END
 
      SUBROUTINE VECTXZ(IX,IY,IZ)
C --
      COMMON /COM_STEREO/ IZORG,IZO,IZ0,IZDEL,IXCENTR,IYCENTR
     *                ,IBASE,IVIEW,ISIZEP,IZSIZEP2,ISITE,STER
C
C     ISITE - 1= L 2 = R
C     STER    N/P/S
C
      CHARACTER     STER*1
C --
C ---
      COMMON /TX_BOX/ IBOXX,IBOXY,ISHX,ISHY
      INTEGER         IBOXX,IBOXY,ISHX,ISHY
C ----
      COMMON/TX_ORIG/  IXO,IYO,IX0,IY0
C ----
      COMMON /TX_SLCT/ IPAGE
      INTEGER          IPAGE
C ----------------
      COMMON /PS_BOX/ BBOXX1,BBOXX2,BBOXY1,BBOXY2
      INTEGER         BBOXX1,BBOXX2,BBOXY1,BBOXY2
C ---------------------------------------
      CALL MOVTXZ(IXO,IYO,IZO)

c      IXT1=IXO+IX0
c      IYT1=IYO+IY0
c      IZT1=IZO+IZ0

c      IXT2=IX+IX0
c      IYT2=IY+IY0
c      IZT2=IZ+IZ0

      IXT1=IXO
      IYT1=IYO
      IZT1=IZO

      IXT2=IX
      IYT2=IY
      IZT2=IZ

      CALL TXPROJZ(IXT1,IYT1,IZT1,IXT2,IYT2,IZT2
     *                             ,IX1,IY1,IX2,IY2)

      IX1=IX1+IX0
      IY1=IY1+IY0

      IX2=IX2+IX0
      IY2=IY2+IY0

      IF(IX2.LT.0) IX2=0
      IF(IY2.LT.0) IY2=0
      IF(IX2.GT.IBOXX) IX2=IBOXX
      IF(IY2.GT.IBOXY) IY2=IBOXY

      IX2=IX2+ISHX
      IY2=IY2+ISHY

      IX2T=IY2+BBOXX1
      IY2T=BBOXY2-IX2

      IF(IX2T.LT.BBOXX1) IX2T=BBOXX1
      IF(IY2T.LT.BBOXY1) IY2T=BBOXY1
      IF(IX2T.GT.BBOXX2) IX2T=BBOXX2
      IF(IY2T.GT.BBOXY2) IY2T=BBOXY2

      X2=IX2T
      Y2=IY2T

      IF(IX1.LT.0) IX1=0
      IF(IY1.LT.0) IY1=0
      IF(IX1.GT.IBOXX) IX1=IBOXX
      IF(IY1.GT.IBOXY) IY1=IBOXY

      IX1=IX1+ISHX
      IY1=IY1+ISHY

      IX1T=IY1+BBOXX1
      IY1T=BBOXY2-IX1

      IF(IX1T.LT.BBOXX1) IX1T=BBOXX1
      IF(IY1T.LT.BBOXY1) IY1T=BBOXY1
      IF(IX1T.GT.BBOXX2) IX1T=BBOXX2
      IF(IY1T.GT.BBOXY2) IY1T=BBOXY2

      X1=IX1T
      Y1=IY1T

      CALL PSLINE (X1, Y1, X2, Y2)

      IXO=IX
      IYO=IY 
      IZO=IZ 
 
      RETURN
C ---------------
      ENTRY  ORITXZ(IX,IY,IZ)
      IX0=IX
      IY0=IY
      IZ0=IZ
      RETURN
      END

      SUBROUTINE TXPROJZ(IXT1,IYT1,IZT1,IXT2,IYT2,IZT2
     *                             ,IX1,IY1,IX2,IY2)
C --
      COMMON /COM_STEREO/ IZORG,IZO,IZ0,IZDEL,IXCENTR,IYCENTR
     *                ,IBASE,IVIEW,ISIZEP,IZSIZEP2,ISITE,STER
C
C     ISITE - 1= L 2 = R
C     STER    N/P/S
C
      CHARACTER     STER*1
C ----------------------------------------------------------

C ----   CUTTING HERE 

      IF(STER.NE.'S') THEN
        IX1=IXT1
        IX2=IXT2
        IY1=IYT1
        IY2=IYT2
        RETURN
      ENDIF
 
      ICOEF=1
      IF(ISITE.EQ.1) ICOEF=-1

      IBYT=IYCENTR+IBASE*ICOEF

      IX1 = ((IXT1-IXCENTR)*IVIEW)/(IZT1+IVIEW) + IXCENTR
      IY1 = ((IYT1-IBYT   )*IVIEW)/(IZT1+IVIEW) + IBYT

      IX2 = ((IXT2-IXCENTR)*IVIEW)/(IZT2+IVIEW) + IXCENTR
      IY2 = ((IYT2-IBYT   )*IVIEW)/(IZT2+IVIEW) + IBYT


      RETURN
      END

      SUBROUTINE TXPROJ_PNT(IXT,IYT,IZT,IXP,IYP)
C --
      COMMON /COM_STEREO/ IZORG,IZO,IZ0,IZDEL,IXCENTR,IYCENTR
     *                ,IBASE,IVIEW,ISIZEP,IZSIZEP2,ISITE,STER
C
C     ISITE - 1= L 2 = R
C     STER    N/P/S
C
      CHARACTER     STER*1
C ----------------------------------------------------------

C ----   CUTTING HERE 

      IF(STER.NE.'S') THEN
        IXP=IXT
        IYP=IYT
        RETURN
      ENDIF
 
      ICOEF=1
      IF(ISITE.EQ.1) ICOEF=-1

      IBYT=IYCENTR+IBASE*ICOEF

      IXP = ((IXT-IXCENTR)*IVIEW)/(IZT+IVIEW) + IXCENTR
      IYP = ((IYT-IBYT   )*IVIEW)/(IZT+IVIEW) + IBYT

      RETURN
      END

      SUBROUTINE GET_PS_COOR(IXT,IYT,IZT,XP,YP)
C --
      COMMON /COM_STEREO/ IZORG,IZO,IZ0,IZDEL,IXCENTR,IYCENTR
     *                ,IBASE,IVIEW,ISIZEP,IZSIZEP2,ISITE,STER
C
C     ISITE - 1= L 2 = R
C     STER    N/P/S
C
      CHARACTER     STER*1
C ----------------------------------------------------------
C ---
      COMMON /TX_BOX/ IBOXX,IBOXY,ISHX,ISHY
      INTEGER         IBOXX,IBOXY,ISHX,ISHY
C ----
      COMMON/TX_ORIG/  IXO,IYO,IX0,IY0
C ----
      COMMON /TX_SLCT/ IPAGE
      INTEGER          IPAGE
C ----------------
      COMMON /PS_BOX/ BBOXX1,BBOXX2,BBOXY1,BBOXY2
      INTEGER         BBOXX1,BBOXX2,BBOXY1,BBOXY2
C ---------------------------------------

C ----   CUTTING HERE 

      IF(STER.EQ.'S') THEN
        ICOEF=1
        IF(ISITE.EQ.1) ICOEF=-1
        IBYT=IYCENTR+IBASE*ICOEF
        IX2 = ((IXT-IXCENTR)*IVIEW)/(IZT+IVIEW) + IXCENTR
        IY2 = ((IYT-IBYT   )*IVIEW)/(IZT+IVIEW) + IBYT
      ELSE
        IX2=IXT
        IY2=IYT
      ENDIF

      IX2=IX2+IX0
      IY2=IY2+IY0

      IF(IX2.LT.0) IX2=0
      IF(IY2.LT.0) IY2=0
      IF(IX2.GT.IBOXX) IX2=IBOXX
      IF(IY2.GT.IBOXY) IY2=IBOXY

      IX2=IX2+ISHX
      IY2=IY2+ISHY

      IX2T=IY2+BBOXX1
      IY2T=BBOXY2-IX2

      IF(IX2T.LT.BBOXX1) IX2T=BBOXX1
      IF(IY2T.LT.BBOXY1) IY2T=BBOXY1
      IF(IX2T.GT.BBOXX2) IX2T=BBOXX2
      IF(IY2T.GT.BBOXY2) IY2T=BBOXY2

      XP=IX2T
      YP=IY2T

      RETURN
      END

      SUBROUTINE CALCGRD_RTFFT(MDOC,LIST,NAMEC,NAMEF,NAME_PH,NAMEO
     * ,PATH_SCR,BOFF,BADD,F000I
     * ,RESMIN,RESMAX,SCALEG,ANISO,NCR,NCYCL,P1,IVAR,ITEST
     * ,RF_NEW,CC_NEW,RF_OLD,CC_OLD
     * ,RESULT,IPRROW,ISYM,IPRSYM,IERR)
C ------------------------------------------
      CHARACTER NAMEC*(*),NAMEF*(*),NAMEO*(*),ANISO*1,LIST*1
      CHARACTER NAME_PH*(*),F000I*1
      INTEGER*2 ISYM(5,3,IPRSYM)
      REAL      RESULT(IPRROW,51),RESULTA(51,51)
C ----------------------
      REAL      SHIFT(3),TCH(4),TSH(4)
      CHARACTER LINE*80,TTT*80,ITYPE*4,SOLV*1,PATT*1,P1*1,MOD*1
      CHARACTER LAP*1,ASYM*1,GRAD*1,POSITIV*1,MODE*1,PRINT*1,INVER*1
      CHARACTER NAME*256,NAMED_OBS*256,NAMED_MOD*256,NAMESF*256
      CHARACTER NAMED*256,NAMEFM*256,NAMEPH*256,NAMES*256,ACORR*1
      CHARACTER PATH_SCR*(*)
C ======================================================================
      MD   = -ABS(MDOC)-1
      M    = 99
      IERR = 0
      MMM  = M
      IF(LIST.EQ.'T') MMM = MDOC
C --------------
      NAME      =' '
      NAMED_OBS ='rotfft_do'
      CALL ADD_PATH(PATH_SCR,NAMED_OBS)

      NAMED_MOD ='rotfft_dm'
      CALL ADD_PATH(PATH_SCR,NAMED_MOD)
      NAMESF    ='rotfft_scr'
      CALL ADD_PATH(PATH_SCR,NAMESF)
      NAMED     ='rotfft_dns'
      CALL ADD_PATH(PATH_SCR,NAMED)
      NAMEFM    ='rotfft_f'
      CALL ADD_PATH(PATH_SCR,NAMEFM)
      NAMEPH    ='rotfft_ph'
      CALL ADD_PATH(PATH_SCR,NAMEPH)
C --------------------------------------------
C      CALL MSGDOC(MDOC,'--- generate density ---')
      RAD    = 0.0
      H2OBG  = 0.0
      BADDD  = 0.0

      IF(P1.EQ.'Y') THEN

        CALL LIMHKL(RESMAX,IHMAX,IKMAX,ILMAX,NXMIN,NYMIN,NZMIN)

        NX = NXMIN 
        NY = NYMIN 
        NZ = NZMIN
        IZMAX = NZMIN-1
        IZMIN = 0
      ELSE 
        NX    = 0
        NY    = 0
        NZ    = 0
        IZMAX =-1
        IZMIN = 0
      ENDIF
      MODE  =' '
      TTT   =' '
      ZFADD = 0.0
      CALL GENDEN(MMM,NAMEC,NAMED_MOD,TTT
     * ,RESMAX,NX,NY,NZ,IZMIN,IZMAX,MODE,RAD,H2OBG,BADDD,P1,ZFADD
     * ,RESULTA,IPRROW,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) GO TO 500
C     NEL - RESULT(1)
C     NEL1 = RESULT(1,1)
C ---------------------------------------
C      CALL MSGDOC(MDOC,'--- real fft ---')
      CALL RFFT(MMM,RESMAX
     * ,NAMED_MOD,NAMESF,NAMEPH,PATH_SCR,ISYM,IPRSYM,RESULTA
     * ,IERR)
      IF(IERR.NE.0) GO TO 500
C ------------------------------------------------
C      CALL MSGDOC(MDOC,'--- scaling ---')

C     BOFFF  = 256.0
      BOFFF  = BOFF
      BADDD  = 0.0
      SOLV   = 'N'
      SCALE  = 0.0
      BOVER  = 0.0
      NC     = 0
      IF(ANISO.EQ.'Y') THEN
        PATT ='Y'
      ELSE
        PATT ='I'
      ENDIF

      RESMNI = RESMIN
      RESMXI = RESMAX
      ACORR = 'N'
      IPRX  = 21
      IPRW  = 21
      CALL MR_SCALING(MMM,LIST,NAMEF,NAMESF,NAMEFM,PATH_SCR
     * ,ANISO,SCALE,BOVER,ACORR,BOFFF,BADDD,RESMNI,RESMXI
     * ,SCALEP_NEW,BSCALE_NEW,RFAC_REF,CORR_REF
     * ,RESULTA,IPRX,IPRW,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) GO TO 500
C ---------------------------------------------------------
C     1. ACORR # N - anisothermal correction of Fmod
c        if ANISO = '-' return
C     2. ANISO = K - FSCALE with SCALEP,BSCALE
C                   if scale = 0 - scaling by Fobs (cell must be the same)
C                      only scale , set BOVER = 0
C                   if scalei>0  - scaling by SCALEI,BOVERI without FN file,
C                                  no info: rfac, corr
C        else  CALL PSCALE
C      output: SCALEP_NEW,BSCALE_NEW,RFAC_REF,CORR_REF and NAMEFM2
C ---------------------------------------------------------
      COEFP  = SCALEP_NEW 
      BTEMPP = BSCALE_NEW
      CC_NEW = CORR_REF
      RF_NEW = RFAC_REF

C      CALL ANISOSCL(MMM,NAMEF,NAMESF,NAMEFM
C     * ,RESMNI,RESMXI,SCALE,BOVER,NC,BOFFF,BADDD,SOLV,PATT
C     * ,ISYM,IPRSYM,RESULTA,IPRROW,IERR)
C      IF(IERR.NE.0) GO TO 500
C      COEFP  = RESULTA(2,3)  
C      BTEMPP = RESULTA(1,3)

      WRITE(LINE,'('' scale,B_scale :'',2F8.3)') 
     * COEFP,BTEMPP
      CALL MSGDOC(MD,LINE)

c      WRITE(LINE,'('' Rfac,Corr :'',2F8.3)') 
c     * RFAC_REF,CORR_REF
c      CALL MSGDOC(MDOC,LINE)

C      IF(ANISO.EQ.'Y') THEN
C        CALL MSGDOC(MDOC,
C     *  ' Anisotropic scaling , Beta:')
C        WRITE(LINE,'(6F8.4)')
C     *   RESULTA(5,1),RESULTA(6,1),RESULTA(7,1)    
C     *  ,RESULTA(8,1),RESULTA(9,1),RESULTA(10,1)    
C        CALL MSGDOC(MDOC,LINE)
C      ENDIF
C      CC_NEW = RESULTA(15,1)
C      RF_NEW = RESULTA(14,1)

      CALL LENSTR_BL(NAME_PH,LEN)
      IF(LEN.GT.0.AND.NAME_PH(1:1).NE.'.'.AND.NAME_PH(1:1).NE.' ') THEN

        BOFFF  = BOFF
        BADDD  = 0.0
        SCALE  = 1.0
        RESMNI = RESMIN
        RESMXI = RESMAX
        NAMES  = ' '
        NAME   = ' '
        MODE   = ' '
        INVER  = 'N'
        SHIFT(1) = 0.0
        SHIFT(2) = 0.0
        SHIFT(3) = 0.0
C        CALL SFVSUM(M,MODE,SCALE,INVER,F000I
C     *    ,NAMEF,NAME_PH,NAMEFM,NAMEPH,NAMES,NAME 
C     *    ,SHIFT,BOFFF,BADDD,RESMNI,RESMXI
C     *    ,ISYM,IPRSYM,RESULTA,IPRROW,IERR)
C        IF(IERR.NE.0) GO TO 500
C !!!
        CALL SFVSUM(M,MODE,SCALE,INVER
     *    ,NAMEF,NAME_PH,NAMEFM,NAMEPH,NAMES,NAME 
     *    ,SHIFT,BOFFF,BADDD,RESMNI,RESMXI
     *    ,ISYM,IPRSYM,RESULTA,IPRROW,IERR)
        IF(IERR.NE.0) GO TO 500
C !!!
        CC_NEW = RESULTA(4,1) 
 
      ENDIF
      
      NDOM = RESULT(20,1)
      NDOM_N = NDOM
      IF(NDOM_N.GT.3) NDOM_N = 3 
        DO I=1,NDOM_N
        II = I*2 + 10
        TCH(I) = RESULT(II-1,1) 
        TSH(I) = RESULT(II,1)   
      ENDDO

      IF(NDOM_N.GT.0.AND.ITEST.GT.0) THEN  

      WRITE(LINE,1000)
     * NCR,ITEST,RF_NEW,CC_NEW,(TCH(III),TSH(III),III=1,NDOM_N)
 1000 FORMAT('|  ',I4,' [',I2,']) R,C:',2F8.4,' !',6F6.1,'     |') 
C     * '(''|    '',I4,'' ['',I2,'']) R,C:'',2F8.4,'' !'',6F6.1,''    |'')') 

      ELSE

      WRITE(LINE,1010)
     * NCR,ITEST,RF_NEW,CC_NEW
 1010 FORMAT('|  ',I4,' [',I2,']) R,C:',2F8.4) 
C     * '(''Sol_'',I4,'' ['',I2,'']) R,C:'',2F8.4)') 
      CALL LENSTR_BL(LINE,LEN)
      LINE = LINE(1:LEN)//
     *       '                                           |'

      ENDIF
      CALL MSGDOC(MDOC,LINE)

      IF(ITEST.GT.0) GO TO 100
      IF(CC_NEW .LT. CC_OLD.AND.IVAR.EQ.0) GO TO 100
      IF(NCR    .GE. NCYCL ) GO TO 100
C --------------------------------------------
C ---
C      CALL MSGDOC(MDOC,'--- calculate D_obs ---')
      NAME   = ' '
      IF(P1.EQ.'Y') THEN
        NX = NXMIN 
        NY = NYMIN 
        NZ = NZMIN
        IZMAX = NZMIN-1
        IZMIN = 0
      ELSE 
        NX     = 0
        NY     = 0
        NZ     = 0
        IZMIN  = 0
        IZMAX  =-1
      ENDIF
      F000    = 0.0
      LAP     = 'N'
      ASYM    = 'N'
      SCALEC  = 0.0
      RES_MIN = RESMIN     
      RES_MAX = RESMAX     
      NAMES   = NAMEPH    
      CALL LENSTR_BL(NAME_PH,LEN)
      IF(LEN.GT.0.AND.NAME_PH(1:1).NE.'.'.AND.NAME_PH(1:1).NE.' ') THEN
        NAMES   = NAME_PH    
        IF(F000I.EQ.'Y') F000    =-1.0
      ENDIF

      CALL CFFT(MMM,LAP,NX,NY,NZ,IZMIN,IZMAX,F000,NAMEF
     * ,NAMED_OBS,NAMES,NAME,RES_MIN,RES_MAX,BADD,BOFF,ASYM,SCALEC
     * ,RESULTA,IPRROW,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) GO TO 500
C
C      RESULT(1,1) = number of points
C      RESULT(2,1) = Dmax
C      RESULT(3,1) = Dmin
C      RESULT(4,1) = RMS
C      RESULT(5,1) = <D>
C      RESULT(6,1) = N_positive points
C      RESULT(7,1) = N_negative points
C      RESULT(8,1) = RMS for positive and =0 density
C      RESULT(9,1) = RMS for negative and =0 density
C      RESULT(10,1) = <D> for positive and =0 density
C      RESULT(11,1) = <D> for negative and =0 density
C      IF(IPRROW.GE.15) THEN
C        RESULT(12,1) = 3-moment of density 
C        RESULT(13,1) = 4-moment of density
C        RESULT(14,1) = P_000 - value of origine Patterson peak.
C        RESULT(15,1) = N points with density = 0
C      ENDIF    
C -----------------------------------------------
C      CALL MSGDOC(MDOC,'--- calculate D_mod ---')
      IF(P1.EQ.'Y') THEN
        NX = NXMIN 
        NY = NYMIN 
        NZ = NZMIN
        IZMAX = NZMIN-1
        IZMIN = 0
      ELSE 
        NX     = 0
        NY     = 0
        NZ     = 0
        IZMIN  = 0
        IZMAX  =-1
      ENDIF
      NAME    = ' '
      F000    = 0.0
      CALL LENSTR_BL(NAME_PH,LEN)
      IF(LEN.GT.0.AND.NAME_PH(1:1).NE.'.'.AND.NAME_PH(1:1).NE.' ') THEN
        IF(F000I.EQ.'Y') F000    =-1.0
      ENDIF
      LAP     = 'N'
      ASYM    = 'N'
      SCALEC  = 0.0     
      RES_MIN = RESMIN     
      RES_MAX = RESMAX     
      CALL CFFT(MMM,LAP,NX,NY,NZ,IZMIN,IZMAX,F000,NAMEFM
     * ,NAMED_MOD,NAMEPH,NAME,RES_MIN,RES_MAX,BADD,BOFF,ASYM,SCALEC
     * ,RESULTA,IPRROW,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) GO TO 500
C -----------------------------------------------

C      CALL MSGDOC(MDOC,'--- calculate gradients ---')

C      SCALEF =RESULT(5,20) 
C      BADDF  =RESULT(6,20)
C      DISP_FOUR =RESULTA( 9,1)
C      BEFF      =RESULTA(10,1) 
C      BRES      =RESULTA( 8,1) 
C      SCALEF    =RESULTA(18,3)
C      BADDF     =RESULTA(19,3)

C      BADDD=BRES-BEFF
C      IF(BADDD.LT.0.0) BADDD=0.0
C -----------------------------------------------
      MOD      = ' '
      PRINT    = ' '
      POSITIV  = ' '
      MODE     = ' '
      GRAD     = ' '
      BADDD    = 0.0
      SCALEF   = 0.0

      SCALEF   = COEFP

      BADDF    = 0.0
      DISP_FOUR= 0.0
      NAME     = ' '

      CALL GRAD_X(MMM,NAMEC,NAMED_OBS,NAMED_MOD,NAMEO,NAME
     * ,BADDD,SCALEF,BADDF,DISP_FOUR,GRAD,P1
     * ,RESULTA,IPRROW,ISYM,IPRSYM,IERR)
C ---------------------------------------------------
 500  CONTINUE

      RESULT(2,1) = COEFP
      RESULT(3,1) = BTEMPP

 100  CONTINUE

      RESULT(4,1) = RF_NEW
      RESULT(5,1) = CC_NEW
      IF(NCR.EQ.0) THEN
        RESULT(6,1) = RF_NEW
        RESULT(7,1) = CC_NEW
      ENDIF
C --------------------------

      NAME='molrp_scratch_rft'
      CALL DELETE_FILE(PATH_SCR,NAME)
      NAME='molrp_scratch_rdc.dat'
      CALL DELETE_FILE(PATH_SCR,NAME)

C --------------------------

      RETURN
      END

      SUBROUTINE RB_REFINE_FFT(MDOC,LIST,NAMEC,NAMEG,NAMEFF,NAME_PH
     * ,PATH_SCR
     * ,BOFF,BADD,DOM,NCR,MODE,P1,SCALEG,REFA,REFX,REFB
     * ,RESMIN,RESMAX,ANISO,F000I  
     * ,IFIRST,CC_CUR,P_OLD,MEM  
     * ,X0,NUMDOM,GRADX,DIAG,DXDA,X
     * ,BFAC0,BFAC,BSHFT
     * ,NCRDMAX,RESULT,IPRROW,NSYM,ISYM,IPRSYM,IERR)
C ----------------------------------------------------------
      REAL    X0(MEM,3),GRADX(MEM,3),DIAG(MEM)
      REAL    X(MEM,3),DXDA(MEM,3,3)
      REAL    BFAC0(MEM),BFAC(MEM),BSHFT(MEM)
      INTEGER NUMDOM(MEM)
C ----------------------------------------------------------
C ===
      PARAMETER ( IPRDOM = 300    )
      PARAMETER ( IPRVAR =IPRDOM*6     )
      PARAMETER ( IPRVR2 =IPRVAR*IPRVAR)

      COMMON /VITALS_FFT/ NATOM,FUNCT,NDOM,NP,NV,DFDA,DFDT,INDX
     *               ,AM,BV,DV,P,KI,THETA,TX,R,Q,SCALES
C ---
      REAL      THETA(3,IPRDOM),TX(3,IPRDOM)
      REAL      AM(IPRVR2),BV(IPRVAR),DV(IPRVAR),P(IPRVAR)
      REAL      P_OLD(IPRVAR)
      INTEGER   KI(IPRVAR),INDX(IPRVAR,3)
      REAL      R(3,3,IPRDOM),Q(3,3,3,IPRDOM)
      REAL      DFDA(3,IPRDOM),DFDT(3,IPRDOM),DXDV(3,6)
C ===
      COMMON /DOMAIN_ROTFFT/ NA_TOTAL,NM_TOTAL,NA_MOL,ANGLES_RESTR
     *                      ,ND_TOTAL,NA_DOM,ID_MOL,ID_DOM,CENTRE,RADI
     *                      ,NP_TOTAL,NMD_TOTAL,ANGLES_OBS,CENTRE_COM
     *                      ,CENTRE_MOL,SHIFT_MOL
      INTEGER   NP_TOTAL,NA_TOTAL,NM_TOTAL,NA_MOL(IPRDOM),NMD_TOTAL
      INTEGER   ND_TOTAL
      REAL      ANGLES_RESTR(3,IPRDOM),ANGLES_OBS(3,IPRDOM)
      INTEGER   NA_DOM(IPRDOM),ID_MOL(IPRDOM),ID_DOM(IPRDOM)    
      REAL      CENTRE(3,IPRDOM),RADI(IPRDOM),CENTRE_COM(3)
      REAL      CENTRE_MOL(3,IPRDOM),SHIFT_MOL(3,IPRDOM)
C ------------------------------------------------------------
      INTEGER*2 ISYM(5,3,IPRSYM)
      REAL      RESULT(IPRROW,51)
      CHARACTER NAMEC*(*),NAMEG*(*),P1*1,DOM*1,REFA*1,REFX*1,MODE*1
      CHARACTER NAMES*256,NAMEFF*(*),PATH_SCR*(*),NAME_PH*(*)
      CHARACTER LIST*1,ANISO*1,F000I*1,REFB*1    
C ----------------------
      REAL      SMAT1(3,3),SMAT2(3,3)
      REAL      ANG(3),RM(3,3),RM1(3,3),V1(3),V2(3)
      CHARACTER LINE*80
C ======================================================================
      MD     = -ABS(MDOC)-1
      M      = 99
      IERR   = 0
C --
      PI     = 4.0*ATAN(1.0)
      RTODEG = 180./PI
      DEGTOR = 1.0/RTODEG
C --------------------------------------------

      CALL RD_CRD_RTFFT(M,NAMEC,NAMEG,DOM,SCALEG
     *               ,X0,GRADX,DIAG,NUMDOM,BFAC0,BSHFT
     *               ,NCRDMAX,MEM
     *               ,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) RETURN

C ----------------------------------------------
      NA = NATOM      
C     NA_TOTAL
      IF(NA.NE.NA_TOTAL) THEN
        IF(LIST.EQ.'T') THEN
          WRITE(*,*) '!!!--> NA,NA_TOTAL:', NA,NA_TOTAL
        ENDIF
        CALL MSGERR(MDOC,' WARNING: (rotfft) Na # Na_total')
      ENDIF 

      SHIFT_AVER = 0.0
      DIAG_AVER = 0.0
      COEF = SCALEG * 1.0
      DO IA=1,NA
        BFAC(IA) = BFAC0(IA)
        IF(DIAG(IA).LT.0.000001) THEN
          GRADX(IA,1)=0.0
          GRADX(IA,2)=0.0
          GRADX(IA,3)=0.0
          BSHFT(IA)  =0.0
          DIAG(IA)   =0.0
        ELSE
          GRADX(IA,1)=GRADX(IA,1)*COEF
          GRADX(IA,2)=GRADX(IA,2)*COEF
          GRADX(IA,3)=GRADX(IA,3)*COEF
          BSHFT(IA)  =BSHFT(IA)  *COEF
          DIAG(IA)   =DIAG(IA)   
          SHFTX = GRADX(IA,1)/DIAG(IA)
          SHFTY = GRADX(IA,2)/DIAG(IA)
          SHFTZ = GRADX(IA,3)/DIAG(IA)
          DS2   = SHFTX*SHFTX+SHFTY*SHFTY+SHFTZ*SHFTZ
          SHIFT_AVER = SHIFT_AVER + SQRT(ABS(DS2))
          DIAG_AVER  = DIAG_AVER  + DIAG(IA)
        ENDIF
      ENDDO
      SHIFT_AVER = SHIFT_AVER/FLOAT(NA)
      DIAG_AVER = DIAG_AVER/FLOAT(NA)

      IF(LIST.EQ.'T') THEN
        write(*,*)'--c:',NAMEC
        write(*,*)'--g:',NAMEG
        write(*,*) '<s>,<d>,coef:',SHIFT_AVER,DIAG_AVER,coef
        stop
      ENDIF
      
      NDOM_M = NDOM
      NMA    = NA
C ---------------
      IF(DOM.EQ.'S') THEN
        DO IA=1,NA
          ID   = NUMDOM(IA)
          IMOL = ID_MOL(ID)
          IF(IMOL.EQ.1) THEN
            X(IA,1) = 0.0
            X(IA,2) = 0.0
            X(IA,3) = 0.0
            DXDA(IA,1,1) = 0.0
          ENDIF
        ENDDO        
        NDOM_M = 0
        DO IM=1,NM_TOTAL
          A1 = ANGLES_RESTR(1,IM)*DEGTOR
          A2 = ANGLES_RESTR(2,IM)*DEGTOR
          A3 = ANGLES_RESTR(3,IM)*DEGTOR
          CALL POLTOM(A1,A2,A3,RM)
          IF(IM.EQ.1) THEN
            DO I=1,3
            DO J=1,3
              RM(I,J) = 0.0
            ENDDO        
            ENDDO        
            RM(1,1) = 1.0
            RM(2,2) = 1.0
            RM(3,3) = 1.0
          ENDIF
          CALL MTRANS(RM,RM1)
          IA1    = 0
          NMA    = 0
          IFIRST = 0
          DO IA=1,NA
            ID   = NUMDOM(IA)
            IMOL = ID_MOL(ID)
            IF(IMOL.EQ.1) THEN
              NMA    = IA
              IF(NDOM_M.LT.ID) NDOM_M = ID
            ENDIF
            IF(IM.EQ.IMOL) THEN
              IF(IFIRST.EQ.0) THEN
                IAM    = IA - 1
                IFIRST = 1
              ENDIF
              IA1 = IA - IAM
              IF(IA1.GT.0) THEN
                V1(1) = GRADX(IA,1)
                V1(2) = GRADX(IA,2)
                V1(3) = GRADX(IA,3)
                CALL MVMULT(RM1,V1,V2)
                X(IA1,1) = X(IA1,1) + V2(1)
                X(IA1,2) = X(IA1,2) + V2(2)
                X(IA1,3) = X(IA1,3) + V2(3)
                DXDA(IA1,1,1) = DXDA(IA1,1,1) + DIAG(IA)

C        IF(IA1.EQ.8) THEN
C        WRITE(*,*) '----0:'
C     *  ,IMOL,V1(1),V1(2),V1(3),DIAG(IA)
C        WRITE(*,*) '-----:'
C     *  ,IMOL,V2(1),V2(2),V2(3),DIAG(IA)
C        ENDIF

              ENDIF
            ENDIF
          ENDDO
        ENDDO

        DO IA=1,NMA
          X(IA,1) = X(IA,1)/FLOAT(NM_TOTAL)
          X(IA,2) = X(IA,2)/FLOAT(NM_TOTAL) 
          X(IA,3) = X(IA,3)/FLOAT(NM_TOTAL)
          DXDA(IA,1,1) = DXDA(IA,1,1)/FLOAT(NM_TOTAL)

C        IF(IA.EQ.8)
C     *  WRITE(*,*) '-0000:'
C     *  ,X(IA,1),X(IA,2),X(IA,3),DXDA(IA,1,1)

        ENDDO

c        WRITE(*,*) 'NDOM,NDOM_M,NA,NMA:',NDOM,NDOM_M,NA,NMA

      ENDIF
C ----------------------------------------------------
C ---
      NSYM_R = NSYM
      IF(P1.EQ.'Y') NSYM_R=1

      CALL CHECK_REF(NSYM_R,ISYM,IFX,IFY,IFZ)             
      DO I=1,IPRVAR
        KI(I)=1
      ENDDO

      DO I=1,IPRDOM
        IND=(I-1)*6
        IF(REFA.EQ.'N') THEN
          KI(IND+1)=0
          KI(IND+2)=0
          KI(IND+3)=0
        ENDIF
        IF(REFX.EQ.'N') THEN
          KI(IND+4)=0
          KI(IND+5)=0
          KI(IND+6)=0
        ENDIF
      ENDDO
      CALL LENSTR_BL(NAME_PH,LEN)
      IF(LEN.GT.0.AND.NAME_PH(1:1).NE.'.'.AND.NAME_PH(1:1).NE.' ') THEN
      ELSE  
        IF(IFX.EQ.0) KI(4)=0
        IF(IFY.EQ.0) KI(5)=0
        IF(IFZ.EQ.0) KI(6)=0
        IF(P1.EQ.'Y') THEN
          KI(4)=0
          KI(5)=0
          KI(6)=0
        ENDIF
      ENDIF
C ---------------------------------------------------
      EULSIG = 5.0
      NP     = NDOM_M*6
      NV     = NP
C -----------------------
C --VAR - 
      IF(NCR.EQ.0) THEN

        DO     J=1,NDOM
          DO     I=1,3
            THETA(I,J)=0.0
            TX   (I,J)=0.0
          ENDDO
          A1 = THETA(1,J)*DEGTOR
          A2 = THETA(2,J)*DEGTOR
          A3 = THETA(3,J)*DEGTOR
          CALL EUL_RTFFT(A1,A2,A3,R(1,1,J),Q(1,1,1,J))
        ENDDO

      ENDIF
C --VAR -
C---
      IF(NCR.EQ.0) THEN
        DO     I=1,NP
          P(I)=0.0
        ENDDO
      ENDIF

      IF(MODE.EQ.'U') THEN

        COEF      = 0.5*SCALEG
        SHIFT_LIM = 0.5

        DO IA=1,NA

          IF(DIAG(IA).GT.0.000001) THEN

             SHFTX = GRADX(IA,1)/DIAG(IA)
             SHFTY = GRADX(IA,2)/DIAG(IA)
             SHFTZ = GRADX(IA,3)/DIAG(IA)
             DS2 = SHFTX*SHFTX+SHFTY*SHFTY+SHFTZ*SHFTZ
             DS=SQRT(ABS(DS2))
             SHFTB = BSHFT(IA)         
           
             IF(DS.GT.SHIFT_LIM) THEN
               SHFTX=(SHFTX*SHIFT_LIM)/DS
               SHFTY=(SHFTY*SHIFT_LIM)/DS
               SHFTZ=(SHFTZ*SHIFT_LIM)/DS
             ENDIF

          ELSE

           SHFTX = 0.0
           SHFTY = 0.0
           SHFTZ = 0.0
           SHFTB = 0.0
           DS2   = 0.0
           DS    = 0.0

          ENDIF

          IF(REFX.EQ.'Y') THEN
            X(IA,1) = X0(IA,1) + SHFTX
            X(IA,2) = X0(IA,2) + SHFTY
            X(IA,3) = X0(IA,3) + SHFTZ
          ELSE
            X(IA,1) = X0(IA,1) 
            X(IA,2) = X0(IA,2) 
            X(IA,3) = X0(IA,3) 
          ENDIF
          IF(REFB.EQ.'Y') THEN
            BF       = BFAC0(IA) + SHFTB
            IF(BF.LT. 2) BF = 2.0
            IF(BF.GT.99) BF = 99.0
            BFAC(IA) = BF
          ELSE
            BFAC(IA) = BFAC0(IA)
          ENDIF

        ENDDO
        GO TO 900
      ENDIF
C
C     EVALUATE THE ROTATION AND DERIVATIVE MATRICES
C
C      DO     I=1,NDOM_M
C        A1 = THETA(1,I)*DEGTOR
C        A2 = THETA(2,I)*DEGTOR
C        A3 = THETA(3,I)*DEGTOR
C        CALL EUL_RTFFT(A1,A2,A3,R(1,1,I),Q(1,1,1,I))
C      ENDDO
C
C     INITIALIZATION THE NORMAL EQUATIONS MATRIX AND RHS VECTOR
C
      DO     I=1,NP
        BV(I) = 0.0
        DO     J=1,NP
          IND     = (J-1)*NP+I
          AM(IND) = 0.0
        ENDDO
      ENDDO
C
C     PRE-CONDITION THETA+ AND THETA- REFINEMENT
C
      IF(EULSIG.GT.0.0) THEN
        DO     I=1,NDOM_M
          J       = (I-1)*6
          IND     = (J+1-1)*NP+J+1
          AM(IND) = 1.0/(EULSIG*DEGTOR)**2
          IND     = (J+3-1)*NP+J+3
          AM(IND) = 1.0/(EULSIG*DEGTOR)**2
        ENDDO
      ENDIF
C
C     EVALUATE POSITIONAL DERIVATIVES WRT EULER ANGLES
C

      DO     KA=1,3
      DO     IX=1,3
      DO     IA=1,NMA
        ID             = NUMDOM(IA)
        DXDA(IA,IX,KA) = 0.0
        DO     JX=1,3
c          DXDA(IA,IX,KA) = DXDA(IA,IX,KA) + 
c     *                     Q(IX,JX,KA,ID)*X0(IA,JX) 
          DXDA(IA,IX,KA) = DXDA(IA,IX,KA) + 
     *                     Q(IX,JX,KA,ID)*(X0(IA,JX) - CENTRE(JX,ID))
        ENDDO
      ENDDO
      ENDDO
      ENDDO

C --------------
        DO  IA=1,NMA

          DO  KA=1,3
            DO  ID=1,NDOM_M
              DFDA(KA,ID) = 0.0
            ENDDO
 
            DO  JX=1,3
              ID = NUMDOM(IA)
              DFDA(KA,ID) = DFDA(KA,ID) + GRADX(IA,JX)*DXDA(IA,JX,KA)
            ENDDO
          ENDDO

C         TRANSLATION VECTOR DERIVATIVES
C
          DO  LT=1,3
            DO  ID=1,NDOM_M
              DFDT(LT,ID) = 0.0
            ENDDO

            ID = NUMDOM(IA)
            DFDT(LT,ID) =  DFDT(LT,ID) + GRADX(IA,LT)

          ENDDO
C
C       TRANSFORM TO LATTMAN'S THETA+/THETA- SYSTEM
C
          DO  ID=1,NDOM_M
            J = (ID-1)*6
            DV(J+1) = 0.5*(DFDA(1,ID)+DFDA(3,ID))
            DV(J+2) =      DFDA(2,ID)            
            DV(J+3) = 0.5*(DFDA(1,ID)-DFDA(3,ID))
            DO     I=1,3
              IJ=I+J
              DV(IJ+3) = DFDT(I,ID)
            ENDDO
          ENDDO
C
C       INCREMENT MATRIX AND VECTOR ELEMENTS
C

C          DO   I=1,NV
C            IDOM  = (I-1)/6+1
C            DO   J=1,NV
C              JDOM  = (J-1)/6+1
C              IF(IDOM.EQ.JDOM) THEN
C                IND     =(J-1)*NP+I
C                AM(IND) = AM(IND) + DV(I)*DV(J)
C              ENDIF
C            ENDDO
C          ENDDO

          DO   I=1,NV
            BV(I) = BV(I) + DV(I)
          ENDDO

        ENDDO

C ====
        DO  IA=1,NMA
          ID = NUMDOM(IA)

          DO  IV=1,6
            DO  IX=1,3
              IF(IV.LE.3) THEN
                DXDV(IX,IV) = DXDA(IA,IX,IV)
              ELSE
                DXDV(IX,IV) = 0.0
                IF(IX.EQ.(IV-3)) DXDV(IX,IV) = 1.0
              ENDIF
            ENDDO
          ENDDO

          DO IX=1,3
            T          = (DXDV(IX,1)+DXDV(IX,3))*0.5
            DXDV(IX,3) = (DXDV(IX,1)-DXDV(IX,3))*0.5
            DXDV(IX,1) =  T
          ENDDO

          DO  I=1,6
          DO  J=1,6

            IND = ((ID-1)*6+(I-1))*NP + (ID-1)*6 + J

            DO IX=1,3
              AM(IND) = AM(IND) + DXDV(IX,I)*DXDV(IX,J)*DIAG(IA)
            ENDDO

          ENDDO
          ENDDO

        ENDDO
C --------------
C
C     APPLY THE VARIABLE FREEZE OPERATOR TO THE NORMAL EQUATIONS
C
      DO  I=1,NP
        BV(I) = KI(I)*BV(I)
        DO  J=1,NP
          IND     = (J-1)*NP+I
          AM(IND) = KI(I)*KI(J)*AM(IND)
        ENDDO
        IND = (I-1)*NP+I
C
C ??        IF(AM(IND).EQ.0.0) AM(IND)=1.0
C
      ENDDO
C
C     INVERT THE MATRIX AND OBTAIN NEW PARAMETERS
C

      DMAX=-1.0E30          
      DO I=1,NP
        IND=(I-1)*NP+I
        IF(ABS(AM(IND)).GT.DMAX) DMAX=AM(IND)
      ENDDO

      TOL=1.0E-7
      DO   I=1,NP
        IND=(I-1)*NP         
        IF(ABS(AM(IND+I))/DMAX.LE.TOL) THEN
          BV(I) = 0.0
          DO    J=1,NP
            AM(IND+J) = 0.0
            INDJ=(J-1)*NP 
            AM(INDJ+I) = 0.0
          ENDDO
        ENDIF  
      ENDDO

      CALL SVSOLV_RBFFT(AM,NP,NP,NP,NP,BV,DV,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,
     *  ' WARNING: subroutine: "rotfft" is terminated')
        RETURN
      ENDIF

C --- DV -- SHIFTS

      NSTEP  = 8
      CC_OLD = CC_CUR
      RESULT(20,1) = NDOM

      DO ISTEP=1,NSTEP
        SCALE = FLOAT(ISTEP)*SCALES
C ---
        DO IM=1,NV
          P(IM) = P_OLD(IM) + DV(IM)*SCALE
        ENDDO
C
C
C     LIST THE REVISED PARAMETERS AFTER CONVERSION BACK TO THETA1/THETA3
C
        DO     ID=1,NDOM_M
          J=(ID-1)*6
          ANG(1)      = 0.5*(P(J+1)+P(J+3))
          ANG(2)      =      P(J+2)        
          ANG(3)      = 0.5*(P(J+1)-P(J+3))
          THETA(1,ID) = ANG(1) * RTODEG
          THETA(2,ID) = ANG(2) * RTODEG
          THETA(3,ID) = ANG(3) * RTODEG
          DO     I=1,3
            IJ=I+J
            TX(I,ID) = P(IJ+3)
          ENDDO

          CALL EUL_RTFFT(ANG(1),ANG(2),ANG(3),R(1,1,ID),Q(1,1,1,ID))

        ENDDO
C ---
        IF(DOM.EQ.'S') THEN

        DO ID=NDOM_M+1,NDOM
          IM  = ID_MOL(ID)
          IMD = ID_DOM(ID)
          DO JD=1,NDOM_M
            JMD = ID_DOM(JD)
            IF(IMD.EQ.JMD) THEN
              IDR = JD
              GO TO 100
            ENDIF    
          ENDDO      
 100      CONTINUE

          ANG(1) = ANGLES_RESTR(1,IM)*DEGTOR
          ANG(2) = ANGLES_RESTR(2,IM)*DEGTOR
          ANG(3) = ANGLES_RESTR(3,IM)*DEGTOR
          CALL POLTOM(ANG(1),ANG(2),ANG(3),RM)
          IF(IM.EQ.1) THEN
            DO I=1,3
            DO J=1,3
              RM(I,J) = 0.0
            ENDDO        
            ENDDO        
            RM(1,1) = 1.0
            RM(2,2) = 1.0
            RM(3,3) = 1.0
          ENDIF
          CALL MTRANS(RM,RM1)

C          ANG(1) = THETA(1,IDR)*DEGTOR
C          ANG(2) = THETA(2,IDR)*DEGTOR
C          ANG(3) = THETA(3,IDR)*DEGTOR
C          CALL EULERM(ANG(1),ANG(2),ANG(3),SMAT1)

          CALL MTRANS(R(1,1,IDR),SMAT1)
          CALL MATMLT(SMAT1,RM1,SMAT2)
          CALL MATMLT(RM,SMAT2,SMAT1)

C          CALL MTOANG(SMAT1,ANG(1),ANG(2),ANG(3))
C          THETA(1,ID) = ANG(1)
C          THETA(2,ID) = ANG(2)
C          THETA(3,ID) = ANG(3) 

          CALL MTRANS(SMAT1,R(1,1,ID))

          V1(1) = TX(1,IDR)
          V1(2) = TX(2,IDR)
          V1(3) = TX(3,IDR)
          CALL MVMULT(RM,V1,V2)
          TX(1,ID) = V2(1) 
          TX(2,ID) = V2(2) 
          TX(3,ID) = V2(3)
 
        ENDDO

        ENDIF
C ---
                
        CALL MSGDOC(MD,
     *   '  Idom    Theta     Phi      Chi       Tx       Ty       Tz')
        DO     ID=1,NDOM

C          ANG(1) = THETA(1,ID) * DEGTOR
C          ANG(2) = THETA(2,ID) * DEGTOR
C          ANG(3) = THETA(3,ID) * DEGTOR
C          CALL EULERM(ANG(1),ANG(2),ANG(3),RM)
C          CALL MTOPOL(RM,ANG(1),ANG(2),ANG(3))

          CALL MTRANS(R(1,1,ID),RM)
          CALL MTOPOL(RM,ANG(1),ANG(2),ANG(3))
          THETA(1,ID) = ANG(1)
          THETA(2,ID) = ANG(2)
          THETA(3,ID) = ANG(3)

          WRITE(LINE,'(I4,'') '',6F9.3)') 
     *    ID,(ANG(I),I=1,3),(TX(I,ID),I=1,3)
          CALL MSGDOC(MD,LINE)
          
          IF(ID.LE.4) THEN

            TSHIFT = SQRT(ABS(TX(1,ID)*TX(1,ID)+TX(2,I)*TX(2,ID)
     *                         +TX(3,ID)*TX(3,ID)))
            II = ID*2 + 10
            RESULT(II-1,1) = ANG(3)
            RESULT(II,1)   = TSHIFT

          ENDIF

        ENDDO
C
C     TRANSFORM COORDINATES TO THE CURRENT POSITION
C

C        WRITE(*,*) '--istep:',istep,scale
C        WRITE(*,*) '--x0   :',X0(1,1),X0(1,2),X0(1,3)
C        WRITE(*,*) '--tx   :',tx(1,1),tx(2,1),tx(3,1)

        DO IA=1,NA
          ID     = NUMDOM(IA)

C          ANG(1) = THETA(1,ID) * DEGTOR
C          ANG(2) = THETA(2,ID) * DEGTOR
C          ANG(3) = THETA(3,ID) * DEGTOR
C          CALL EULERM(ANG(1),ANG(2),ANG(3),RM)

          CALL MTRANS(R(1,1,ID),RM)
          V1(1) = X0(IA,1) - CENTRE(1,ID)
          V1(2) = X0(IA,2) - CENTRE(2,ID)
          V1(3) = X0(IA,3) - CENTRE(3,ID)
          CALL MVMULT(RM,V1,V2)
          X(IA,1) = V2(1) + TX(1,ID) + CENTRE(1,ID) 
          X(IA,2) = V2(2) + TX(2,ID) + CENTRE(2,ID) 
          X(IA,3) = V2(3) + TX(3,ID) + CENTRE(3,ID) 
        ENDDO

C        WRITE(*,*) '--x   :',X(1,1),X(1,2),X(1,3)
C
C          WRITE(LINE,'(''centre1:'',3F10.3)') 
C     *    CENTRE(1,1), CENTRE(2,1),CENTRE(3,1)    
C          CALL MSGDOC(MDOC,LINE)
C
C          WRITE(LINE,'(''centre2:'',3F10.3)') 
C     *    CENTRE(1,2), CENTRE(2,2),CENTRE(3,2)    
C          CALL MSGDOC(MDOC,LINE)


        NAMES  = 'rotfft_scr'
        CALL ADD_PATH(PATH_SCR,NAMES)
        CALL WR_CRD_RTFFT(M,NAMEC,NAMES,X,DOM,NUMDOM,BFAC0
     *   ,NATOM,NCRDMAX,MEM,P1,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) RETURN
        NCYCL = 0
        IVAR  = 0
        ITEST = ISTEP

        CALL CALCGRD_RTFFT(MDOC,LIST,NAMES,NAMEFF,NAME_PH,NAMEG
     *   ,PATH_SCR,BOFF,BADD,F000I
     *   ,RESMIN,RESMAX,SCALEG,ANISO,NCR,NCYCL,P1,IVAR,ITEST
     *   ,RF_NEW,CC_NEW,RF_OLD,CC_OLD
     *   ,RESULT,IPRROW,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) RETURN
   
        IF(CC_NEW.LT.CC_OLD) THEN
          SCALE = (FLOAT(ISTEP-1) + 0.5)*SCALES
          GO TO 800  
        ELSE
          CC_OLD = CC_NEW
        ENDIF
        
      ENDDO

 800  CONTINUE

        DO IM=1,NV
          P(IM) = P_OLD(IM) + DV(IM)*SCALE
        ENDDO

        DO     ID=1,NDOM_M
          J=(ID-1)*6
          ANG(1)      = 0.5*(P(J+1)+P(J+3))
          ANG(2)      =      P(J+2)        
          ANG(3)      = 0.5*(P(J+1)-P(J+3))
          THETA(1,ID) = ANG(1) * RTODEG
          THETA(2,ID) = ANG(2) * RTODEG
          THETA(3,ID) = ANG(3) * RTODEG
          DO     I=1,3
            IJ=I+J
            TX(I,ID) = P(IJ+3)
          ENDDO

          CALL EUL_RTFFT(ANG(1),ANG(2),ANG(3),R(1,1,ID),Q(1,1,1,ID))
 
        ENDDO

C ---
        IF(DOM.EQ.'S') THEN
        DO ID=NDOM_M+1,NDOM
          IM  = ID_MOL(ID)
          IMD = ID_DOM(ID)
          DO JD=1,NDOM_M
            JMD = ID_DOM(JD)
            IF(IMD.EQ.JMD) THEN
              IDR = JD
              GO TO 200
            ENDIF    
          ENDDO      
 200      CONTINUE

          ANG(1) = ANGLES_RESTR(1,IM)*DEGTOR
          ANG(2) = ANGLES_RESTR(2,IM)*DEGTOR
          ANG(3) = ANGLES_RESTR(3,IM)*DEGTOR
          CALL POLTOM(ANG(1),ANG(2),ANG(3),RM)
          IF(IM.EQ.1) THEN
            DO I=1,3
            DO J=1,3
              RM(I,J) = 0.0
            ENDDO        
            ENDDO        
            RM(1,1) = 1.0
            RM(2,2) = 1.0
            RM(3,3) = 1.0
          ENDIF
          CALL MTRANS(RM,RM1)

C          ANG(1) = THETA(1,IDR)*DEGTOR
C          ANG(2) = THETA(2,IDR)*DEGTOR
C          ANG(3) = THETA(3,IDR)*DEGTOR
C          CALL EULERM(ANG(1),ANG(2),ANG(3),SMAT1)

          CALL MTRANS(R(1,1,IDR),SMAT1)
          CALL MATMLT(SMAT1,RM1,SMAT2)
          CALL MATMLT(RM,SMAT2,SMAT1)

C          CALL MTOANG(SMAT1,ANG(1),ANG(2),ANG(3))
C          THETA(1,ID) = ANG(1)
C          THETA(2,ID) = ANG(2)
C          THETA(3,ID) = ANG(3) 

          CALL MTRANS(SMAT1,R(1,1,ID))

          V1(1) = TX(1,IDR)
          V1(2) = TX(2,IDR)
          V1(3) = TX(3,IDR)
          CALL MVMULT(RM,V1,V2)
          TX(1,ID) = V2(1) 
          TX(2,ID) = V2(2) 
          TX(3,ID) = V2(3)
 
        ENDDO
        ENDIF
C ---
        DO IA=1,NA
          ID     = NUMDOM(IA)

C          ANG(1) = THETA(1,ID) * DEGTOR
C          ANG(2) = THETA(2,ID) * DEGTOR
C          ANG(3) = THETA(3,ID) * DEGTOR
C          CALL EULERM(ANG(1),ANG(2),ANG(3),RM)

          CALL MTRANS(R(1,1,ID),RM)
          V1(1) = X0(IA,1) - CENTRE(1,ID)
          V1(2) = X0(IA,2) - CENTRE(2,ID)
          V1(3) = X0(IA,3) - CENTRE(3,ID)
          CALL MVMULT(RM,V1,V2)
          X(IA,1) = V2(1) + TX(1,ID) + CENTRE(1,ID) 
          X(IA,2) = V2(2) + TX(2,ID) + CENTRE(2,ID) 
          X(IA,3) = V2(3) + TX(3,ID) + CENTRE(3,ID) 
          BFAC(IA) = BFAC0(IA)
        ENDDO


      DO IM=1,NV
        P_OLD(IM) = P(IM)
      ENDDO


 900  CONTINUE

      RESULT( 8,1) = TX(1,1)
      RESULT( 9,1) = TX(2,1)
      RESULT(10,1) = TX(3,1)
      IF(IPRROW.GE.13) THEN
        RESULT(11,1) = THETA(1,1)
        RESULT(12,1) = THETA(2,1)
        RESULT(13,1) = THETA(3,1)
        RESULT(14,1) = TX(1,2)
        RESULT(15,1) = TX(2,2)
        RESULT(16,1) = TX(3,2)
        RESULT(17,1) = THETA(1,2)
        RESULT(18,1) = THETA(2,2)
        RESULT(19,1) = THETA(3,2)
        RESULT(20,1) = NDOM
        NDOM_N = NDOM
        IF(NDOM_N.GT.4) NDOM_N = 4 
        DO I=1,NDOM_N
          TH = DEGTOR*THETA(1,I)
          PH = DEGTOR*THETA(2,I)
          CH = DEGTOR*THETA(3,I)
          CALL EULERM(TH,PH,CH,RM)
          CALL MTOPOL(RM,TH,PH,CH)
          TSHIFT = SQRT(ABS(TX(1,I)*TX(1,I)+TX(2,I)*TX(2,I)
     *                         +TX(3,I)*TX(3,I)))
          II = I*2 + 10
          RESULT(II-1,1) = CH
          RESULT(II,1)   = TSHIFT
        ENDDO
        RESULT(19,1) = 0.0
      ENDIF

      RETURN
      END

      SUBROUTINE EUL_RTFFT(T1,T2,T3,R,Q)
      REAL R(3,3),Q(3,3,3)
C -------------------------------------------
      S1 = SIN(T1)
      S2 = SIN(T2)
      S3 = SIN(T3)
      C1 = COS(T1)
      C2 = COS(T2)
      C3 = COS(T3)
C
C     EULERIAN ROTATION MATRIX
C
      R(1,1) = -S1*C2*S3+C1*C3
      R(1,2) =  C1*C2*S3 + S1*C3
      R(1,3) =  S2*S3
      R(2,1) = -S1*C2*C3 -C1*S3
      R(2,2) =  C1*C2*C3 -S1*S3
      R(2,3) =  S2*C3
      R(3,1) =  S1*S2
      R(3,2) = -C1*S2
      R(3,3) =  C2
C
C     DERIVATIVE WITH RESPECT TO THETA1
C
      DO     I=1,3
        Q(I,1,1) = -R(I,2)
        Q(I,2,1) =  R(I,1)
        Q(I,3,1) =  0.0
      ENDDO
C
C     DERIVATIVE WITH RESPECT TO THETA2
C
      Q(1,1,2) =  S1*S2*S3
      Q(1,2,2) = -C1*S2*S3
      Q(1,3,2) =  C2*S3
      Q(2,1,2) =  S1*S2*C3
      Q(2,2,2) = -C1*S2*C3
      Q(2,3,2) =  C2*C3
      Q(3,1,2) =  S1*C2
      Q(3,2,2) = -C1*C2
      Q(3,3,2) = -S2
C
C     DERIVATIVE WITH RESPECT TO THETA3
C
      DO     J=1,3
        Q(1,J,3) =  R(2,J)
        Q(2,J,3) = -R(1,J)
        Q(3,J,3) =  0.0
      ENDDO
      RETURN
      END


C -I-
      SUBROUTINE RD_CRD_RTFFT(MDOC,NAMEC,NAMEG,DOM,SCALEG
     * ,X0,GRADX,DIAGX,NUMDOM,BFAC0,BSHFT,NCRDMAX,MEM
     * ,NSYM,ISYM,IPRSYM,IERR)
C ----------------------------------------------------------
      REAL    X0(MEM,3),GRADX(MEM,3),DIAGX(MEM),BFAC0(MEM),BSHFT(MEM)
      INTEGER NUMDOM(MEM)
C ----------------------------------------------------------
C ===
      PARAMETER ( IPRDOM = 300    )
      PARAMETER ( IPRVAR =IPRDOM*6     )
      PARAMETER ( IPRVR2 =IPRVAR*IPRVAR)

      COMMON /VITALS_FFT/ NATOM,FUNCT,NDOM,NP,NV,DFDA,DFDT,INDX
     *               ,AM,BV,DV,P,KI,THETA,TX,R,Q,SCALES
C ---
      REAL      THETA(3,IPRDOM),TX(3,IPRDOM)
      REAL      AM(IPRVR2),BV(IPRVAR),DV(IPRVAR),P(IPRVAR)

      INTEGER   KI(IPRVAR),INDX(IPRVAR,3)
      REAL      R(3,3,IPRDOM),Q(3,3,3,IPRDOM)
      REAL      DFDA(3,IPRDOM),DFDT(3,IPRDOM)
C ---
C      COMMON /DOMAIN_ROTFFT/ NA_TOTAL,NM_TOTAL,NA_MOL,ANGLES_RESTR
C     *                      ,ND_TOTAL,NA_DOM,ID_MOL,ID_DOM,CENTRE,RADI
C     *                      ,NP_TOTAL,NMD_TOTAL,ANGLES_OBS,CENTRE_COM
C     *                      ,CENTRE_MOL,SHIFT_MOL
C      INTEGER   NP_TOTAL,NA_TOTAL,NM_TOTAL,NA_MOL(IPRDOM),NMD_TOTAL
C      INTEGER   ND_TOTAL
C      REAL      ANGLES_RESTR(3,IPRDOM),ANGLES_OBS(3,IPRDOM)
C      INTEGER   NA_DOM(IPRDOM),ID_MOL(IPRDOM),ID_DOM(IPRDOM)    
C      REAL      CENTRE(3,IPRDOM),RADI(IPRDOM),CENTRE_COM(3)
C      REAL      CENTRE_MOL(3,IPRDOM),SHIFT_MOL(3,IPRDOM)
C ===
      INTEGER     MDOC,IPRSYM,IERR
      INTEGER*2   ISYM(5,3,IPRSYM)
      CHARACTER   NAMEC*(*),NAMEG*(*),DOM*1
C ----------------------------------------------------------------
C ------
C BLANC -common
C
      COMMON/CRYSTL/ A_CELL,B_CELL,C_CELL,AL_CELL,BE_CELL,GA_CELL
     *              ,A_STAR,B_STAR,C_STAR,COALST,COBEST,COGAST
     *              ,SIALST,SIBEST,SIGAST
     *              ,FRTOCR,CRTOFR,VOLUME
     *              ,PDB_SCALE,PDB_U
     *              ,NSP_GROUP,N_SETT,PDB_MODEL
     *              ,PDB_CODE,PDB_NAME,PDB_DATE
     *              ,PDB_RESL,PDB_RFAC
     *              ,SP_GROUP,USER_TITLE
C -
      REAL      FRTOCR(3,3),CRTOFR(3,3),VOLUME
      REAL      PDB_SCALE(3,3),PDB_U(3) 
      INTEGER*4 NSP_GROUP,N_SETT,PDB_MODEL
      CHARACTER PDB_CODE*4,PDB_NAME*40,PDB_DATE*9 
      CHARACTER PDB_RESL*40,PDB_RFAC*40
C !!!!
      CHARACTER SP_GROUP*24,USER_TITLE*80
C !!!!
C --------------
      INCLUDE 'mr_crd_com.fh'
      INCLUDE 'mr_crd2_com.fh'
C ----------------------------------------------------------------
      CHARACTER LINE*80
C==================================================================
      IERR = 0
      PI   = 4.0*ATAN(1.0)
      MD   = -ABS(MDOC)-1
      M    = 99
      MDD  = MDOC
      MDC  = MDOC
      IF(MDOC.EQ.-2) THEN
        MDD = 1
        MDC =99
      ENDIF 
C --------
      IN  = 10
      CALL ORCRD(M,IN,NAMEC,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERR: OPEN INPUT_FILE/CRD/')
        RETURN
      ENDIF
C --------
      IN2   = 11
      CALL ORCRD(M,IN2,NAMEG,NS,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CLOSE(IN)
        CALL MSGERR(MDOC,' ERR: OPEN INPUT_GRADIENTS/CRD/')
        RETURN
      ENDIF
C --------
C      CALL LENSTR_BL(NAMEO,LEN)
C      IF(LEN.GT.0.AND.NAMEO(1:1).NE.','.AND.NAMEO(1:1).NE.' ') THEN 
C        IOUT=12
C        CALL OWCRD(M,IOUT,NAMEO,NSYM,ISYM,IPRSYM,IERR)
C        IF(IERR.NE.0) THEN
C          CALL MSGERR(MDOC,' ERR: OPEN OUTPUT_FILE/CRD/')
C          CLOSE(IN) 
C          CLOSE(IN2)
C          RETURN
C        ENDIF
C      ELSE
C        IOUT=0
C      ENDIF
C -------------------------------------------------
      RATIO  = 1.0
C      IF(MOD.EQ.'e') MOD='E'
C      IF(MOD.EQ.'d') MOD='D'
C      IF(MOD.EQ.'i') MOD='I'
C      IF(MOD.NE.'E'.AND.MOD.NE.'D'.AND.MOD.NE.'I') MOD='S'
      TOP    = 1.0
      IF(SCALEG.EQ.0.0) SCALEG = 1.0
C -------------------------------------------------
      NATOM  = 0
      IEND   =-1
      IEND2  =-1
      IENDW  =-1
      IATOM1 =-3
      IATOM2 =-2

      DEL_AVER =0.0
      DELW_AVER=0.0
      DELA_AVER=0.0
      DELP_AVER=0.0

      SHFT_AVER=0.0
      SHFT_MAX =0.0
      SHFT_RMS =0.0
      N_SHFT   =0
      SHFTW_AVER=0.0
      SHFTW_MAX =0.0
      SHFTW_RMS =0.0
      N_SHFTW   =0
      SHFTA_AVER=0.0
      SHFTA_MAX =0.0
      SHFTA_RMS =0.0
      N_SHFTA   =0
      SHFTP_AVER=0.0
      SHFTP_MAX =0.0
      SHFTP_RMS =0.0
      N_SHFTP   =0
      NRES_MAX  =50
      IRES_OLD  =-100
      IGRP_OLD  =-100
      I_RES     =0
      SIGMAD    =0.0
      SIGMA     =0.0
      SHESSX    =0.0
      SHESSD    =0.0
      DRV_RMS   =0.0
      DRV_AVER  =0.0
      SCALEF    =0.0
      DISP_FOUR =0.0
      DIFF_TOT  =0.0
C -------------------------------------------------
 200  CONTINUE

      IF(IATOM1.LT.IATOM2) THEN 

 210    CONTINUE 
        CALL RDCRD(M,IN,MODE,IEND,IERR)
        IF(IERR.NE.0) THEN
          CLOSE(IN2)
C         CLOSE(IOUT)
          RETURN
        ENDIF
        IF(IEND.NE.0) GO TO 300
        IF(MODE.NE.0) THEN
          GO TO 210
        ENDIF
        IATOM1=CR_IATOLD

      ELSE IF(IATOM1.GT.IATOM2) THEN 

 110    CONTINUE
        CALL RDCRD2(M,IN2,MODE2,IEND2,IERR)
        IF(IERR.NE.0) THEN
          CLOSE(IN)
C         CLOSE(IOUT)
          RETURN
        ENDIF
        IF(IEND2.NE.0) GO TO 300
        IF(MODE2.NE.0) THEN
          IF(CR2_LINE(1:21).EQ.'#sigma_do,sigma_diff:') THEN
            READ(CR2_LINE,'(22X,2F12.5)') SIGMA,SIGMAD
            WRITE(LINE,'(''sigma_do,sigma_diff :'',2F12.5)') 
     *      SIGMA,SIGMAD
            CALL MSGDOC(MDC,LINE)    
            GO TO 110
          ENDIF

          IF(CR2_LINE(1:22).EQ.'#hessian,hessian_diff:') THEN
            READ(CR2_LINE,'(23X,2F12.5)') SHESSX,SHESSD
            WRITE(LINE,'(''HESS,diff :'',2F12.5)') 
     *      SHESSX,SHESSD
            CALL MSGDOC(MDC,LINE)    
            GO TO 110
          ENDIF

          IF(CR2_LINE(1:23).EQ.'#deriv_rms,deriv_aver:') THEN
            READ(CR2_LINE,'(23X,2F12.5)') DRV_RMS,DRV_AVER
            WRITE(LINE,'(''DERIV rms,aver :'',2F12.5)') 
     *      DRV_RMS,DRV_AVER
            CALL MSGDOC(MDC,LINE)    
            GO TO 110
          ENDIF

          IF(CR2_LINE(1:18).EQ.'#scalef,disp_four:') THEN
            READ(CR2_LINE,'(19X,3F12.5)') SCALEF,DISP_FOUR,DIFF_TOT
            WRITE(LINE,'(''SCALEF,DISP_FOUR,DIFF_TOT :'',3F12.5)') 
     *      SCALEF,DISP_FOUR,DIFF_TOT
            CALL MSGDOC(MDC,LINE)    
            GO TO 110
          ENDIF

C        ENDIF

        IF(SIGMAD   .LE.0.0) SIGMAD=1.0
        IF(SIGMA    .LE.0.0) SIGMA =1.0
        IF(SHESSX   .LE.0.0) SHESSX=1.0
        IF(SHESSD   .LE.0.0) SHESSD=1.0
        IF(DRV_RMS  .LE.0.0) DRV_RMS =1.0
        IF(DRV_AVER .LE.0.0) DRV_AVER=1.0
        IF(SCALEF   .LE.0.0) SCALEF=1.0
        IF(DISP_FOUR.LE.0.0) DISP_FOUR=1.0
        IF(DIFF_TOT .LE.0.0) DIFF_TOT=1.0

        FUNCT = DIFF_TOT

        GO TO 110

        ENDIF

        IATOM2=CR2_IATOLD

      ELSE

        IF((CR_ATYPE.NE.'.'.AND.CR_ATYPE.NE.' '.AND.
     *      CR_ATYPE.NE.'y'.AND.CR_ATYPE.NE.'Y'.AND.
     *      CR_ATYPE.NE.'r'.AND.CR_ATYPE.NE.'R').OR.
     *      CR_OCC .LT.0.0001                       ) GO TO 1000
C ----
C           CHECK STORAGE REQUIREMENTS
C
            IF(NATOM.GT.NCRDMAX) THEN
              WRITE(LINE,130) NCRDMAX
  130         FORMAT(' ERR0R : (rotfft) THE NUMBER OF ATOMS >',I6)
              CALL MSGERR(MDOC,LINE)
              CLOSE(IN)
              CLOSE(IN2)
              IERR=1
              RETURN
            ENDIF

            NATOM         = NATOM + 1
            X0(NATOM,1)   = CR_XYZ(1)
            X0(NATOM,2)   = CR_XYZ(2)
            X0(NATOM,3)   = CR_XYZ(3)
            BFAC0(NATOM)  = CR_BISO

           GX   = CR2_XYZ(1)*SCALEF
           GY   = CR2_XYZ(2)*SCALEF
           GZ   = CR2_XYZ(3)*SCALEF
           DIAG = CR2_OCC   *SCALEF
C          HESSD= CR2_BISO  *SCALEF
           SHFTB= CR2_BISO  

c /////
C         if(DIAG.le.0.000001) then
C           CR2_OCC = 0.01
C           DIAG = CR2_OCC*SCALEF
C         endif
c /////

           GRADX(NATOM,1) = GX
           GRADX(NATOM,2) = GY
           GRADX(NATOM,3) = GZ
           DIAGX(NATOM)   = DIAG
           BSHFT(NATOM)   = SHFTB
           COEF      = SCALEG*0.5
           SIGMAP    = DISP_FOUR/4.0
           SHIFT_LIM = 3.0*SIGMAP

         IF(DIAG.GT.0.000001) THEN

             SHFTX = (GX*COEF)/DIAG
             SHFTY = (GY*COEF)/DIAG
             SHFTZ = (GZ*COEF)/DIAG

             DS2 = SHFTX*SHFTX+SHFTY*SHFTY+SHFTZ*SHFTZ
             DS=SQRT(ABS(DS2))
           
             IF(DS.GT.SHIFT_LIM) THEN
               SHFTX=(SHFTX*SHIFT_LIM)/DS
               SHFTY=(SHFTY*SHIFT_LIM)/DS
               SHFTZ=(SHFTZ*SHIFT_LIM)/DS
               DS2=SHIFT_LIM*SHIFT_LIM
               DS =SHIFT_LIM
             ENDIF
 
           SHFT_RMS =SHFT_RMS +DS2
           SHFT_AVER=SHFT_AVER+DS
c           DEL_AVER=DEL_AVER+ABS(DEL)
           IF(DS.GT.SHFT_MAX) SHFT_MAX=DS

           N_SHFT=N_SHFT+1    
           IF(CR_RNAME.EQ.'HOH'.OR.CR_RNAME.EQ.'DOD') THEN
c             DELW_AVER=DELW_AVER+ABS(DEL)
             SHFTW_RMS =SHFTW_RMS +DS2
             SHFTW_AVER=SHFTW_AVER+DS
             IF(DS.GT.SHFTW_MAX) SHFTW_MAX=DS
             N_SHFTW=N_SHFTW+1    
           ENDIF 
           IF(CR_ASYMB.EQ.'H   '.OR.CR_ASYMB.EQ.'D   ') THEN
c             DELA_AVER=DELA_AVER+ABS(DEL)
             SHFTA_RMS =SHFTA_RMS +DS2
             SHFTA_AVER=SHFTA_AVER+DS
             IF(DS.GT.SHFTA_MAX) SHFTA_MAX=DS
             N_SHFTA=N_SHFTA+1    
           ENDIF 
           IF(CR_ASYMB.NE.'H   '.AND.CR_ASYMB.NE.'D   '.AND.
     *        CR_RNAME.NE.'HOH'.AND.CR_RNAME.NE.'DOD') THEN
c             DELP_AVER=DELP_AVER+ABS(DEL)
             SHFTP_RMS =SHFTP_RMS +DS2
             SHFTP_AVER=SHFTP_AVER+DS
             IF(DS.GT.SHFTP_MAX) SHFTP_MAX=DS
             N_SHFTP=N_SHFTP+1    
           ENDIF 
           IFLAG=1
         ELSE
           SHFTX=0.0
           SHFTX=0.0
           SHFTX=0.0
           SHFTB=0.0
           DS2=0.0
           DS =0.0
           IFLAG=0
           IF(DS.LT.0.0) IFLAG=-1
         ENDIF
C ----
C
 1000    CONTINUE
C ----

C        IF(IOUT.GT.0) THEN
C          CALL WRCRD(M,IOUT,MODE,IENDW,IERR)
C          IF(IERR.NE.0) THEN
C            CLOSE(IN) 
C            CLOSE(IN2) 
C            RETURN
C          ENDIF
C        ENDIF

        IATOM1=-3
        IATOM2=-2

      ENDIF      
      GO TO 200
C ------------------------------------------------------
 300  CONTINUE

      CALL MSGDOC(MDD
     *       ,'--------------------------------------------------')
      WRITE(LINE,'('' Number of atoms   :'',I8)') NATOM
      CALL MSGDOC(MDC,LINE)

      CLOSE(IN) 
      CLOSE(IN2)
C ---
      IF(N_SHFT.GT.0) THEN
c        DEL_AVER =DEL_AVER/N_SHFT
        SHFT_AVER=SHFT_AVER/N_SHFT
        SHFT_RMS =SHFT_RMS/N_SHFT
        SHFT_RMS =SQRT(ABS(SHFT_RMS))
      ELSE
        SHFT_RMS=0.0
        SHFT_AVER=0.0
      ENDIF
      IF(N_SHFTW.GT.0) THEN
c        DELW_AVER =DELW_AVER/N_SHFTW
        SHFTW_AVER=SHFTW_AVER/N_SHFTW
        SHFTW_RMS =SHFTW_RMS/N_SHFTW
        SHFTW_RMS =SQRT(ABS(SHFTW_RMS))
      ELSE
        SHFTW_RMS=0.0
        SHFTW_AVER=0.0
      ENDIF
      IF(N_SHFTA.GT.0) THEN
c        DELA_AVER =DELA_AVER/N_SHFTA
        SHFTA_AVER=SHFTA_AVER/N_SHFTA
        SHFTA_RMS =SHFTA_RMS/N_SHFTA
        SHFTA_RMS =SQRT(ABS(SHFTA_RMS))
      ELSE
        SHFTA_RMS=0.0
        SHFTA_AVER=0.0
      ENDIF
      IF(N_SHFTP.GT.0) THEN
c        DELP_AVER =DELP_AVER/N_SHFTP
        SHFTP_AVER=SHFTP_AVER/N_SHFTP
        SHFTP_RMS =SHFTP_RMS/N_SHFTP
        SHFTP_RMS =SQRT(ABS(SHFTP_RMS))
      ELSE
        SHFTP_RMS=0.0
        SHFTP_AVER=0.0
      ENDIF

      WRITE(LINE,'(''RMS_shift :'',G12.4)') SHFT_RMS
      CALL MSGDOC(MDC,LINE)    
      WRITE(LINE,'(''<shift>   :'',G12.4)') SHFT_AVER
      CALL MSGDOC(MDC,LINE)    
      WRITE(LINE,'(''MAX_shift :'',G12.4)') SHFT_MAX
      CALL MSGDOC(MDC,LINE)    
      IF(N_SHFTP.GT.0) THEN
        CALL MSGDOC(MDC,' Shifts for non-solvent and non H_atoms :')    
        WRITE(LINE,'(''RMS_shift :'',G12.4)') SHFTP_RMS
        CALL MSGDOC(MDC,LINE)    
        WRITE(LINE,'(''<shift>   :'',G12.4)') SHFTP_AVER
        CALL MSGDOC(MDC,LINE)    
        WRITE(LINE,'(''MAX_shift :'',G12.4)') SHFTP_MAX
        CALL MSGDOC(MDC,LINE)
      ENDIF    
      IF(N_SHFTW.GT.0) THEN
        CALL MSGDOC(MDC,' Shifts for solvent :')    
        WRITE(LINE,'(''RMS_shift :'',G12.4)') SHFTW_RMS
        CALL MSGDOC(MDC,LINE)    
        WRITE(LINE,'(''<shift>   :'',G12.4)') SHFTW_AVER
        CALL MSGDOC(MDC,LINE)    
        WRITE(LINE,'(''MAX_shift :'',G12.4)') SHFTW_MAX
        CALL MSGDOC(MDC,LINE)
      ENDIF    
      IF(N_SHFTA.GT.0) THEN
        CALL MSGDOC(MDC,' Shifts for H_atoms :')    
        WRITE(LINE,'(''RMS_shift :'',G12.4)') SHFTA_RMS
        CALL MSGDOC(MDC,LINE)    
        WRITE(LINE,'(''<shift>   :'',G12.4)') SHFTA_AVER
        CALL MSGDOC(MDC,LINE)    
        WRITE(LINE,'(''MAX_shift :'',G12.4)') SHFTA_MAX
        CALL MSGDOC(MDC,LINE)
      ENDIF
C --------------------------------------
      RETURN
      END

      SUBROUTINE COPY_CRD_RTFFT(MDOC,NAMEC,NAMEO,DOM
     * ,NSYM,ISYM,IPRSYM,IERR)
C ----------------------------------------------------------
C ===
      PARAMETER ( IPRDOM = 300    )
      PARAMETER ( IPRVAR =IPRDOM*6     )
      PARAMETER ( IPRVR2 =IPRVAR*IPRVAR)

      COMMON /VITALS_FFT/ NATOM,FUNCT,NDOM,NP,NV,DFDA,DFDT,INDX
     *               ,AM,BV,DV,P,KI,THETA,TX,R,Q,SCALES
C ---
      REAL      THETA(3,IPRDOM),TX(3,IPRDOM)
      REAL      AM(IPRVR2),BV(IPRVAR),DV(IPRVAR),P(IPRVAR)

      INTEGER   KI(IPRVAR),INDX(IPRVAR,3)
      REAL      R(3,3,IPRDOM),Q(3,3,3,IPRDOM)
      REAL      DFDA(3,IPRDOM),DFDT(3,IPRDOM)
C ---
      COMMON /DOMAIN_ROTFFT/ NA_TOTAL,NM_TOTAL,NA_MOL,ANGLES_RESTR
     *                      ,ND_TOTAL,NA_DOM,ID_MOL,ID_DOM,CENTRE,RADI
     *                      ,NP_TOTAL,NMD_TOTAL,ANGLES_OBS,CENTRE_COM
     *                      ,CENTRE_MOL,SHIFT_MOL
      INTEGER   NP_TOTAL,NA_TOTAL,NM_TOTAL,NA_MOL(IPRDOM),NMD_TOTAL
      INTEGER   ND_TOTAL
      REAL      ANGLES_RESTR(3,IPRDOM),ANGLES_OBS(3,IPRDOM)
      INTEGER   NA_DOM(IPRDOM),ID_MOL(IPRDOM),ID_DOM(IPRDOM)    
      REAL      CENTRE(3,IPRDOM),RADI(IPRDOM),CENTRE_COM(3)
      REAL      CENTRE_MOL(3,IPRDOM),SHIFT_MOL(3,IPRDOM)
C ===
      INTEGER     MDOC,IPRSYM,IERR
      INTEGER*2   ISYM(5,3,IPRSYM)
      CHARACTER   NAMEC*(*),NAMEO*(*),DOM*1
C ----------------------------------------------------------------
C ------
C BLANC -common
C
      COMMON/CRYSTL/ A_CELL,B_CELL,C_CELL,AL_CELL,BE_CELL,GA_CELL
     *              ,A_STAR,B_STAR,C_STAR,COALST,COBEST,COGAST
     *              ,SIALST,SIBEST,SIGAST
     *              ,FRTOCR,CRTOFR,VOLUME
     *              ,PDB_SCALE,PDB_U
     *              ,NSP_GROUP,N_SETT,PDB_MODEL
     *              ,PDB_CODE,PDB_NAME,PDB_DATE
     *              ,PDB_RESL,PDB_RFAC
     *              ,SP_GROUP,USER_TITLE
C -
      REAL      FRTOCR(3,3),CRTOFR(3,3),VOLUME
      REAL      PDB_SCALE(3,3),PDB_U(3) 
      INTEGER*4 NSP_GROUP,N_SETT,PDB_MODEL
      CHARACTER PDB_CODE*4,PDB_NAME*40,PDB_DATE*9 
      CHARACTER PDB_RESL*40,PDB_RFAC*40
C !!!!
      CHARACTER SP_GROUP*24,USER_TITLE*80
C !!!!
C --------------
C ---
      INCLUDE 'mr_crd_com.fh'
C ----------------------------------------------------------------
      REAL      ANGLES(3),TRMAT(3,3),TR(3),V(3),C_INP(3),C(3)
      REAL      V1(3),V2(3)
      CHARACTER LINE*80
      CHARACTER NCSF*1,GID*4
C==================================================================
      IERR = 0
      PI   = 4.0*ATAN(1.0)
      MD   = -ABS(MDOC)-1
      M    = 99
C --------
      IN  = 10
      CALL ORCRD(M,IN,NAMEC,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERROR: in rotfft: OPEN INPUT_FILE/CRD/')
        RETURN
      ENDIF
C --------
      NWORDS   = 8
      C_INP(1) = 0.0
      C_INP(2) = 0.0
      C_INP(3) = 0.0
      ICNTR    = 0
      ISET     = 1
      IDOM     = 1
      IDOM_OLD = 1
      NDOM     = 0
      IMOL     = 1
      IM_DOM   = 1
      IR0      = 0
      IRES     = 0
      NA_TOTAL = 0
      NM_TOTAL = 0
      ND_TOTAL = 1
      NP_TOTAL = 0
      NMD_TOTAL= 0
      DO I=1,IPRDOM
        NA_MOL(I) = 0
        NA_DOM(I) = 0 
        ANGLES_RESTR(1,I) = 0.0
        ANGLES_RESTR(2,I) = 0.0
        ANGLES_RESTR(3,I) = 0.0
        ANGLES_OBS(1,I)   = 0.0
        ANGLES_OBS(2,I)   = 0.0
        ANGLES_OBS(3,I)   = 0.0
        CENTRE(1,I)       = 0.0
        CENTRE(2,I)       = 0.0
        CENTRE(3,I)       = 0.0
        RADI(I)           = 0.0
        CENTRE_COM(1)     = 0.0
        CENTRE_COM(2)     = 0.0
        CENTRE_COM(3)     = 0.0
        CENTRE_MOL(1,I)   = 0.0
        CENTRE_MOL(2,I)   = 0.0
        CENTRE_MOL(3,I)   = 0.0
        SHIFT_MOL(1,I)    = 0.0
        SHIFT_MOL(2,I)    = 0.0
        SHIFT_MOL(3,I)    = 0.0
        ID_MOL(I) = 0
        ID_DOM(I) = 0 
      ENDDO   
      ID_MOL(1) = 1
      ID_DOM(1) = 1 
C -------------------------------------------------
      NATOM  = 0
      IEND   =-1
      IGR    = 0
C ---
      CALL SET_ASYMM(MDOC,NMAX,NGR,NCH,IGR,ICH,INC,MLT,IATM
     *                    ,NCSF,GID,IERR)
C -------------------------------------------------
 200  CONTINUE
      CALL RDCRD(M,IN,MODE,IEND,IERR)
      IF(IERR.NE.0) THEN
        RETURN
      ENDIF
      IF(IEND.NE.0) GO TO 300
      IF(MODE.NE.0) THEN


        IF((CR_LINE(1:7).EQ.'#DOMAIN'.OR.CR_LINE(1:9).EQ.'#MOLECULE')
     *    .AND.DOM.NE.'N') THEN

          IDOM_OLD = IDOM

          CALL RD_LINE_ROTFFT(CR_LINE,NW,NUMB_INP,ANGLES,C)

          IF(CR_LINE(1:9).EQ.'#MOLECULE') THEN
            IF(NATOM.GT.0) IMOL = IMOL + 1

            IF(IMOL.LE.NMAX) THEN
              IGR      = IMOL
              ICH      = IGR
              IGOLD    = IGR
              ICHOLD   = IGR
              INC      = 0
              MLT      = 0
              IATM     = 0
              NCSF     = 'Y'
              GID      = '    '
              GID(1:2) = 'AA'
              CALL SET_ASYMM(MDOC,NMAX,NGR,ICHOLD,IGR,ICH,INC,MLT
     *                 ,IGOLD,NCSF,GID,IERR)
              IF(IERR.NE.0) RETURN
            ENDIF

            IM_DOM = 1
            IF(IMOL.GT.IPRDOM) THEN
              WRITE(LINE,*) 
     *        ' ERROR: in rotfft: number of domains >',IPRDOM
              CALL MSGERR(MDOC,LINE)
              CLOSE(IN)
              IERR=1
              RETURN
            ENDIF
            IF(NATOM.GT.0) THEN
              IDOM = ND_TOTAL + 1              
              IF(IDOM.GT.IPRDOM) THEN
                WRITE(LINE,*) 
     *          ' ERROR: in rotfft: number of domains >',IPRDOM
                CALL MSGERR(MDOC,LINE)
                CLOSE(IN)
                IERR=1
                RETURN
              ENDIF
              ND_TOTAL     = IDOM
              ID_MOL(IDOM) = IMOL
              ID_DOM(IDOM) = IM_DOM
            ENDIF
            IF(NW.LT.NWORDS) NWORDS = NW
            ANGLES_RESTR(1,IMOL) = ANGLES(1)
            ANGLES_RESTR(2,IMOL) = ANGLES(2)
            ANGLES_RESTR(3,IMOL) = ANGLES(3)
            IF(IMOL.EQ.1.AND.NW.GE.8) THEN
              C_INP(1) = C(1)
              C_INP(2) = C(2)
              C_INP(3) = C(3)
              CENTRE_COM(1) = C_INP(1)
              CENTRE_COM(2) = C_INP(2)
              CENTRE_COM(3) = C_INP(3)
              ICNTR    = 1
            ENDIF
            ANGLES_OBS(1,IMOL)  = 0.0
            ANGLES_OBS(2,IMOL)  = 0.0
            ANGLES_OBS(3,IMOL)  = 0.0
          ELSE IF(CR_LINE(1:7).EQ.'#DOMAIN') THEN
            IF(NUMB_INP.GT.IPRDOM) NUMB_INP = 0
            IF(NATOM.GT.0) THEN
              IF(NUMB_INP.LE.0) THEN
                IM_DOM = IM_DOM + 1
              ELSE
                IM_DOM = NUMB_INP             
              ENDIF
              IF(IM_DOM.GT.IPRDOM) THEN
                WRITE(LINE,*) 
     *          ' ERROR: in rotfft: number of domains >',IPRDOM
                CALL MSGERR(MDOC,LINE)
                CLOSE(IN)
                IERR=1
                RETURN
              ENDIF
              DO ID=1,ND_TOTAL
                IF(ID_MOL(ID).EQ.IMOL.AND.ID_DOM(ID).EQ.IM_DOM) THEN 
                  IDOM = ID
                  GO TO 400           
                ENDIF
              ENDDO
              IDOM = ND_TOTAL + 1
              IF(IDOM.GT.IPRDOM) THEN
                WRITE(LINE,*) 
     *          ' ERROR: (in rotfft) number of domains >',IPRDOM
                CALL MSGERR(MDOC,LINE)
                CLOSE(IN)
                IERR=1
                RETURN
              ENDIF
              ND_TOTAL     = IDOM
              ID_MOL(IDOM) = IMOL
              ID_DOM(IDOM) = IM_DOM
 400          CONTINUE
            ENDIF
          ENDIF

          IF(NATOM.GT.0) THEN
            IM_OLD  = ID_MOL(IDOM_OLD)
            IMD_OLD = ID_DOM(IDOM_OLD)
            WRITE(LINE,
     *      '(I3,A,I3,A,I3,''('',I2,'') RES:'',I4,'' - '',I4)')
     *       ISET,') DOM',IDOM_OLD,' MOL:',IM_OLD,IMD_OLD,IR0,IRES
            CALL MSGDOC(MDOC,LINE)   
            ISET=ISET+1
          ENDIF
          IR0          = 0
C         ID_MOL(IDOM) = IMOL
C         ID_DOM(IDOM) = IM_DOM
        ENDIF
        GO TO 200
      ENDIF

      IF((CR_ATYPE.NE.'.'.AND.CR_ATYPE.NE.' '.AND.
     *    CR_ATYPE.NE.'y'.AND.CR_ATYPE.NE.'Y'.AND.
     *    CR_ATYPE.NE.'r'.AND.CR_ATYPE.NE.'R').OR.
     *    CR_OCC .LT.0.0001                       ) GO TO 100
C ----
      NATOM = NATOM+1
      IF(IR0.EQ.0) IR0=CR_IRES
      IF(IMOL.GT.0) NA_MOL(IMOL) = NA_MOL(IMOL) + 1
      NA_DOM(IDOM)  = NA_DOM(IDOM) + 1

 100   CONTINUE
      GO TO 200
C ------------------------------------------------------
 300  CONTINUE
      IDOM_OLD = IDOM
      NA_TOTAL = NATOM
C     ND_TOTAL = IDOM
      NM_TOTAL = IMOL
      NP_TOTAL = ISET
      NDOM     = ND_TOTAL
      IF(DOM.NE.'N'.AND.NATOM.GT.0) THEN
        IM_OLD  = ID_MOL(IDOM_OLD)
        IMD_OLD = ID_DOM(IDOM_OLD)
C        WRITE(LINE,
C     *      '(I3,A,I3,A,I3,''('',I2,'') RES:'',I4,'' - '',I4)')
C     *       ISET,') DOM',IDOM_OLD,' MOL:',IM_OLD,IMD_OLD,IR0,IRES
C        CALL MSGDOC(MDOC,LINE)   
C        CALL MSGDOC(MDOC,' ')   
      ENDIF

      CALL MSGDOC(MDOC
     *       ,'--------------------------------------------------')
      WRITE(LINE,'('' Number of atoms   :'',I8)') NA_TOTAL
      CALL MSGDOC(MDOC,LINE)

      IF(DOM.NE.'N') THEN
        WRITE(LINE,'('' Number of molecules:'',I4)') NM_TOTAL
        CALL MSGDOC(MDOC,LINE)   
        WRITE(LINE,'('' Number of domains  :'',I4)') ND_TOTAL
        CALL MSGDOC(MDOC,LINE)   
      ENDIF

      NA_TOTAL = NA_MOL(1)*NM_TOTAL
      WRITE(LINE,'('' New number of atoms :'',I8)') NA_TOTAL
      CALL MSGDOC(MDOC,LINE)

      CALL CHECK_CHAIN_ID(INEW)

      CLOSE(IN) 
C --------------------------------------
      IOUT = 32
      CALL OWCRD(M,IOUT,NAMEO,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,
     *  ' ERROR: (rotfft_rb) OPEN OUTPUT FILE-CRD-TMP')
        CLOSE(IN)
        RETURN
      ENDIF
C --------
      NWORDS = 8
      IENDW  =-1
C -------------------------------------------------
      DO IM=1,NM_TOTAL

      IN  = 10
      CALL ORCRD(M,IN,NAMEC,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,
     *          ' ERROR: (rotfft_rb): open input file(crd)')
        RETURN
      ENDIF
      IEND   =-1
      IMOL   = 1
      NATOM  = 0

 1200 CONTINUE

      CALL RDCRD(M,IN,MODE,IEND,IERR)
      IF(IERR.NE.0) THEN
        CLOSE(IOUT)
        RETURN
      ENDIF
      IF(IEND.NE.0) GO TO 1300

      IF(MODE.NE.0) THEN
        IF(CR_LINE(1:7).EQ.'#DOMAIN'.OR.
     *     CR_LINE(1:9).EQ.'#MOLECULE') THEN

          IF(CR_LINE(1:9).EQ.'#MOLECULE') THEN

            IF(NATOM.GT.0) IMOL = IMOL + 1
            IF(IMOL.GT.1) GO TO 1300

            IF(IM.EQ.1) THEN
              WRITE(CR_LINE,'(A,I6,2X,3(F9.4,1X),3F8.3)') 
     *        '#MOLECULE',IM
     *       ,ANGLES_RESTR(1,IM),ANGLES_RESTR(2,IM),ANGLES_RESTR(3,IM)
     *       ,CENTRE_COM(1),CENTRE_COM(2),CENTRE_COM(3)
            ELSE
              WRITE(CR_LINE,'(A,I6,2X,3(F9.4,1X))') '#MOLECULE',IM
     *       ,ANGLES_RESTR(1,IM),ANGLES_RESTR(2,IM),ANGLES_RESTR(3,IM)
            ENDIF

          ELSE IF(CR_LINE(1:7).EQ.'#DOMAIN') THEN

          ENDIF

          CALL WRCRD(M,IOUT,MODE,IENDW,IERR)

        ENDIF

        GO TO 1200
      ENDIF

      IF((CR_ATYPE.NE.'.'.AND.CR_ATYPE.NE.' '.AND.
     *    CR_ATYPE.NE.'y'.AND.CR_ATYPE.NE.'Y'.AND.
     *    CR_ATYPE.NE.'r'.AND.CR_ATYPE.NE.'R').OR.
     *    CR_OCC .LT.0.0001                       ) GO TO 1100
C ----
      NATOM     = NATOM + 1
      CR_IGROUP = IM

      CALL WRCRD(M,IOUT,MODE,IENDW,IERR)

 1100 CONTINUE
      GO TO 1200
C ------------------------------------------------------
 1300  CONTINUE
       CLOSE(IN) 

      ENDDO

      IENDW = 1
      MODE  = 0
      CALL WRCRD(M,IOUT,MODE,IENDW,IERR)
C --------------------------------------
      RETURN
      END

C -I-
      SUBROUTINE RD_INI_CRD_RTFFT(MDOC,NAMEC,DOM
     * ,X0,X,GRADX,NUMDOM,BFAC0,BFAC,BSHFT
     * ,MEM,NCRDMAX
     * ,NSYM,ISYM,IPRSYM,IERR)
C ----------------------------------------------------------
      REAL    X0(MEM,3),GRADX(MEM,3),X(MEM,3)
     *       ,BFAC0(MEM),BFAC(MEM),BSHFT(MEM)
      INTEGER NUMDOM(MEM)
C ----------------------------------------------------------
C ===
      PARAMETER ( IPRDOM = 300    )
      PARAMETER ( IPRVAR =IPRDOM*6     )
      PARAMETER ( IPRVR2 =IPRVAR*IPRVAR)

      COMMON /VITALS_FFT/ NATOM,FUNCT,NDOM,NP,NV,DFDA,DFDT,INDX
     *               ,AM,BV,DV,P,KI,THETA,TX,R,Q,SCALES
C ---
      REAL      THETA(3,IPRDOM),TX(3,IPRDOM)
      REAL      AM(IPRVR2),BV(IPRVAR),DV(IPRVAR),P(IPRVAR)

      INTEGER   KI(IPRVAR),INDX(IPRVAR,3)
      REAL      R(3,3,IPRDOM),Q(3,3,3,IPRDOM)
      REAL      DFDA(3,IPRDOM),DFDT(3,IPRDOM)
C ---
      COMMON /DOMAIN_ROTFFT/ NA_TOTAL,NM_TOTAL,NA_MOL,ANGLES_RESTR
     *                      ,ND_TOTAL,NA_DOM,ID_MOL,ID_DOM,CENTRE,RADI
     *                      ,NP_TOTAL,NMD_TOTAL,ANGLES_OBS,CENTRE_COM
     *                      ,CENTRE_MOL,SHIFT_MOL
      INTEGER   NP_TOTAL,NA_TOTAL,NM_TOTAL,NA_MOL(IPRDOM),NMD_TOTAL
      INTEGER   ND_TOTAL
      REAL      ANGLES_RESTR(3,IPRDOM),ANGLES_OBS(3,IPRDOM)
      INTEGER   NA_DOM(IPRDOM),ID_MOL(IPRDOM),ID_DOM(IPRDOM)    
      REAL      CENTRE(3,IPRDOM),RADI(IPRDOM),CENTRE_COM(3)
      REAL      CENTRE_MOL(3,IPRDOM),SHIFT_MOL(3,IPRDOM)
C ===
      INTEGER     MDOC,IPRSYM,IERR
      INTEGER*2   ISYM(5,3,IPRSYM)
      CHARACTER   NAMEC*(*),DOM*1
C ----------------------------------------------------------------
C ------
C BLANC -common
C
      COMMON/CRYSTL/ A_CELL,B_CELL,C_CELL,AL_CELL,BE_CELL,GA_CELL
     *              ,A_STAR,B_STAR,C_STAR,COALST,COBEST,COGAST
     *              ,SIALST,SIBEST,SIGAST
     *              ,FRTOCR,CRTOFR,VOLUME
     *              ,PDB_SCALE,PDB_U
     *              ,NSP_GROUP,N_SETT,PDB_MODEL
     *              ,PDB_CODE,PDB_NAME,PDB_DATE
     *              ,PDB_RESL,PDB_RFAC
     *              ,SP_GROUP,USER_TITLE
C -
      REAL      FRTOCR(3,3),CRTOFR(3,3),VOLUME
      REAL      PDB_SCALE(3,3),PDB_U(3) 
      INTEGER*4 NSP_GROUP,N_SETT,PDB_MODEL
      CHARACTER PDB_CODE*4,PDB_NAME*40,PDB_DATE*9 
      CHARACTER PDB_RESL*40,PDB_RFAC*40
C !!!!
      CHARACTER SP_GROUP*24,USER_TITLE*80
C !!!!
C --------------
C ---
      INCLUDE 'mr_crd_com.fh'
C ----------------------------------------------------------------
      REAL      ANGLES(3),TRMAT(3,3),TR(3),V(3),C_INP(3),C(3)
      REAL      V1(3),V2(3)
      CHARACTER LINE*80
C==================================================================
      IERR = 0
      PI   = 4.0*ATAN(1.0)
      MD   = -ABS(MDOC)-1
      M    = 99
C --------
      IN  = 10
      CALL ORCRD(M,IN,NAMEC,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERROR: in rotfft: OPEN INPUT_FILE/CRD/')
        RETURN
      ENDIF
C --------
      NWORDS   = 8
      C_INP(1) = 0.0
      C_INP(2) = 0.0
      C_INP(3) = 0.0
      ICNTR    = 0
      ISET     = 1
      IDOM     = 1
      IDOM_OLD = 1
      NDOM     = 0
      IMOL     = 1
      IM_DOM   = 1
      IR0      = 0
      IRES     = 0
      NA_TOTAL = 0
      NM_TOTAL = 0
      ND_TOTAL = 1
      NP_TOTAL = 0
      NMD_TOTAL= 0
      DO I=1,IPRDOM
        NA_MOL(I) = 0
        NA_DOM(I) = 0 
        ANGLES_RESTR(1,I) = 0.0
        ANGLES_RESTR(2,I) = 0.0
        ANGLES_RESTR(3,I) = 0.0
        ANGLES_OBS(1,I)   = 0.0
        ANGLES_OBS(2,I)   = 0.0
        ANGLES_OBS(3,I)   = 0.0
        CENTRE(1,I)       = 0.0
        CENTRE(2,I)       = 0.0
        CENTRE(3,I)       = 0.0
        RADI(I)           = 0.0
        CENTRE_COM(1)     = 0.0
        CENTRE_COM(2)     = 0.0
        CENTRE_COM(3)     = 0.0
        CENTRE_MOL(1,I)   = 0.0
        CENTRE_MOL(2,I)   = 0.0
        CENTRE_MOL(3,I)   = 0.0
        SHIFT_MOL(1,I)    = 0.0
        SHIFT_MOL(2,I)    = 0.0
        SHIFT_MOL(3,I)    = 0.0
        ID_MOL(I) = 0
        ID_DOM(I) = 0 
      ENDDO   
      ID_MOL(1) = 1
      ID_DOM(1) = 1 
C -------------------------------------------------
      NATOM  = 0
      IEND   =-1
C -------------------------------------------------
 200  CONTINUE
      CALL RDCRD(M,IN,MODE,IEND,IERR)
      IF(IERR.NE.0) THEN
        RETURN
      ENDIF
      IF(IEND.NE.0) GO TO 300
      IF(MODE.NE.0) THEN


c        IF((CR_LINE(1:7).EQ.'#DOMAIN'.OR.CR_LINE(1:9).EQ.'#MOLECULE')
c     *    .AND.DOM.NE.'N') THEN

        IF((CR_LINE(1:7).EQ.'#DOMAIN'.OR.CR_LINE(1:9).EQ.'#MOLECULE'
     *    .OR.CR_LINE(1:6).EQ.'#MODEL')
     *    .AND.DOM.NE.'N') THEN

          IDOM_OLD = IDOM

          CALL RD_LINE_ROTFFT(CR_LINE,NW,NUMB_INP,ANGLES,C)

          IF(CR_LINE(1:6).EQ.'#MODEL') THEN
            ANGLES(1)  = 0.0
            ANGLES(2)  = 0.0
            ANGLES(3)  = 0.0
            NW = 1
          ENDIF

c          IF(CR_LINE(1:9).EQ.'#MOLECULE') THEN

          IF(CR_LINE(1:9).EQ.'#MOLECULE'.OR.
     *       CR_LINE(1:6).EQ.'#MODEL'       ) THEN

            write(*,*) '--',imol,natom

            IF(NATOM.GT.0) IMOL = IMOL + 1
            IM_DOM = 1
            IF(IMOL.GT.IPRDOM) THEN
              WRITE(LINE,*) 
     *        ' ERROR: in rotfft: number of domains >',IPRDOM
              CALL MSGERR(MDOC,LINE)
              CLOSE(IN)
              IERR=1
              RETURN
            ENDIF
            IF(NATOM.GT.0) THEN
              IDOM = ND_TOTAL + 1              
              IF(IDOM.GT.IPRDOM) THEN
                WRITE(LINE,*) 
     *          ' ERROR: in rotfft: number of domains >',IPRDOM
                CALL MSGERR(MDOC,LINE)
                CLOSE(IN)
                IERR=1
                RETURN
              ENDIF
              ND_TOTAL     = IDOM
              ID_MOL(IDOM) = IMOL
              ID_DOM(IDOM) = IM_DOM
            ENDIF
            IF(NW.LT.NWORDS) NWORDS = NW
            ANGLES_RESTR(1,IMOL) = ANGLES(1)
            ANGLES_RESTR(2,IMOL) = ANGLES(2)
            ANGLES_RESTR(3,IMOL) = ANGLES(3)
            IF(IMOL.EQ.1.AND.NW.GE.8) THEN
              C_INP(1) = C(1)
              C_INP(2) = C(2)
              C_INP(3) = C(3)
              ICNTR    = 1
            ENDIF
            ANGLES_OBS(1,IMOL)  = 0.0
            ANGLES_OBS(2,IMOL)  = 0.0
            ANGLES_OBS(3,IMOL)  = 0.0
          ELSE IF(CR_LINE(1:7).EQ.'#DOMAIN') THEN
            IF(NUMB_INP.GT.IPRDOM) NUMB_INP = 0
            IF(NATOM.GT.0) THEN
              IF(NUMB_INP.LE.0) THEN
                IM_DOM = IM_DOM + 1
              ELSE
                IM_DOM = NUMB_INP             
              ENDIF
              IF(IM_DOM.GT.IPRDOM) THEN
                WRITE(LINE,*) 
     *          ' ERROR: in rotfft: number of domains >',IPRDOM
                CALL MSGERR(MDOC,LINE)
                CLOSE(IN)
                IERR=1
                RETURN
              ENDIF
              DO ID=1,ND_TOTAL
                IF(ID_MOL(ID).EQ.IMOL.AND.ID_DOM(ID).EQ.IM_DOM) THEN 
                  IDOM = ID
                  GO TO 140           
                ENDIF
              ENDDO
              IDOM = ND_TOTAL + 1
              IF(IDOM.GT.IPRDOM) THEN
                WRITE(LINE,*) 
     *          ' ERROR: (in rotfft) number of domains >',IPRDOM
                CALL MSGERR(MDOC,LINE)
                CLOSE(IN)
                IERR=1
                RETURN
              ENDIF
              ND_TOTAL     = IDOM
              ID_MOL(IDOM) = IMOL
              ID_DOM(IDOM) = IM_DOM
 140          CONTINUE
            ENDIF
          ENDIF

          IF(NATOM.GT.0) THEN
            IM_OLD  = ID_MOL(IDOM_OLD)
            IMD_OLD = ID_DOM(IDOM_OLD)
            WRITE(LINE,
     *      '(I3,A,I3,A,I3,''('',I2,'') RES:'',I4,'' - '',I4)')
     *       ISET,') DOM',IDOM_OLD,' MOL:',IM_OLD,IMD_OLD,IR0,IRES
            CALL MSGDOC(MDOC,LINE)   
            ISET=ISET+1
          ENDIF
          IR0          = 0
C         ID_MOL(IDOM) = IMOL
C         ID_DOM(IDOM) = IM_DOM
        ENDIF
        GO TO 200
      ENDIF

      IF((CR_ATYPE.NE.'.'.AND.CR_ATYPE.NE.' '.AND.
     *    CR_ATYPE.NE.'y'.AND.CR_ATYPE.NE.'Y'.AND.
     *    CR_ATYPE.NE.'r'.AND.CR_ATYPE.NE.'R').OR.
     *    CR_OCC .LT.0.0001                       ) GO TO 1000
C ----
C         CHECK STORAGE REQUIREMENTS
C

        IRES  = CR_IRES
          
        NATOM = NATOM+1
        IF(IR0.EQ.0) IR0=CR_IRES

        X0(NATOM,1)   = CR_XYZ(1)
        X0(NATOM,2)   = CR_XYZ(2)
        X0(NATOM,3)   = CR_XYZ(3)
        BFAC0(NATOM)  = CR_BISO
        NUMDOM(NATOM) = IDOM
        IF(IMOL.GT.0) NA_MOL(IMOL)  = NA_MOL(IMOL) + 1
        NA_DOM(IDOM)  = NA_DOM(IDOM) + 1

 1000   CONTINUE
C      ENDIF
      GO TO 200
C ------------------------------------------------------
 300  CONTINUE
      IDOM_OLD = IDOM
      NA_TOTAL = NATOM
C     ND_TOTAL = IDOM
      NM_TOTAL = IMOL
      NP_TOTAL = ISET
      NDOM     = ND_TOTAL
      IF(DOM.NE.'N'.AND.NATOM.GT.0) THEN
            IM_OLD  = ID_MOL(IDOM_OLD)
            IMD_OLD = ID_DOM(IDOM_OLD)
            WRITE(LINE,
     *      '(I3,A,I3,A,I3,''('',I2,'') RES:'',I4,'' - '',I4)')
     *       ISET,') DOM',IDOM_OLD,' MOL:',IM_OLD,IMD_OLD,IR0,IRES
         CALL MSGDOC(MDOC,LINE)   
         CALL MSGDOC(MDOC,' ')   
      ENDIF

      CALL MSGDOC(MDOC
     *       ,'--------------------------------------------------')
      WRITE(LINE,'('' Number of atoms   :'',I8)') NA_TOTAL
      CALL MSGDOC(MDOC,LINE)

      IF(DOM.NE.'N') THEN
        WRITE(LINE,'('' Number of domains :'',I4)') ND_TOTAL
        CALL MSGDOC(MDOC,LINE)   
      ENDIF

      CLOSE(IN) 
C --------------------------------------
      CALL MSGDOC(MDOC,'--- Domains ---')
      DO  JD=1,NDOM
        XS  = 0.0
        YS  = 0.0
        ZS  = 0.0
        XS2 = 0.0
        YS2 = 0.0
        ZS2 = 0.0
        N  = 0
        DO  IA=1,NA_TOTAL
          ID = NUMDOM(IA)
          IF(JD.EQ.ID) THEN
            XS  = XS + X0(IA,1)
            YS  = YS + X0(IA,2)
            ZS  = ZS + X0(IA,3)
            N   = N  + 1
            XS2 = XS2 + X0(IA,1)*X0(IA,1)
            YS2 = YS2 + X0(IA,2)*X0(IA,2)
            ZS2 = ZS2 + X0(IA,3)*X0(IA,3)
          ENDIF
        ENDDO
        IF(N.GT.0) THEN
          XS           = XS/FLOAT(N)
          YS           = YS/FLOAT(N)
          ZS           = ZS/FLOAT(N)
          CENTRE(1,JD) = XS
          CENTRE(2,JD) = YS
          CENTRE(3,JD) = ZS
          XS2          = XS2/FLOAT(N)
          YS2          = YS2/FLOAT(N)
          ZS2          = ZS2/FLOAT(N)
          RX           = XS2-XS*XS
          RY           = YS2-YS*YS
          RZ           = ZS2-ZS*ZS
          RADI(JD)     = SQRT(ABS(RX+RY+RZ))
          IM = ID_MOL(JD)
          WRITE(LINE,'(I4,'') Radius of inertia :'',F10.3,A,I8)') 
     *            JD,RADI(JD),' Na_dom:',NA_DOM(JD) 
          CALL MSGDOC(MDOC,LINE)
        ELSE
          CENTRE(1,JD) = 0.0
          CENTRE(2,JD) = 0.0
          CENTRE(3,JD) = 0.0
          RADI(JD)     = 100.0
        ENDIF
      ENDDO
C --------------------------------------
      NMD_TOTAL = 1
      IF(DOM.EQ.'Y'.OR.DOM.EQ.'N') RETURN
C --------------------------------------
      DO IM=1,NM_TOTAL
        NMD = 0
        DO ID=1,ND_TOTAL
          IF(ID_MOL(ID).EQ.IM) NMD = NMD + 1
        ENDDO
        IF(IM.EQ.1) THEN
          NMD_TOTAL = NMD
        ELSE
          IF(NMD.NE.NMD_TOTAL) THEN
            LINE = ' ERROR: (in rotfft) diff. molecules'//
     *      ' have diff. number of domains'
            CALL MSGERR(MDOC,LINE)
            IERR = 1
            RETURN
          ENDIF
        ENDIF
      ENDDO
C --
      IF(NM_TOTAL.GT.1) THEN
        NMA = NA_MOL(1)
        DO IM=2,NM_TOTAL
          IF(NMA.NE.NA_MOL(IM)) THEN
            LINE = ' ERROR: (in rotfft) diff. molecules'//
     *      ' have diff. number of atoms'
            CALL MSGERR(MDOC,LINE)
            IERR = 1
            RETURN
          ENDIF
        ENDDO
      ENDIF
C ---
      IF(NMD_TOTAL.GT.1) THEN
        DO IM=1,NM_TOTAL
          DO ID=1,NMD_TOTAL

            DO IR=1,ND_TOTAL
              IMOLR = ID_MOL(IR)
              IMDR  = ID_DOM(IR)
              IF(IMOLR.EQ.1.AND.IMDR.EQ.ID) THEN                  
                NAD = NA_DOM(IR)                  
              ENDIF
            ENDDO

            DO IS=1,ND_TOTAL
              IMOL = ID_MOL(IS)
              IMD  = ID_DOM(IS)
              IF(IM.EQ.IMOL.AND.ID.EQ.IMD) THEN
                IF(NAD.NE.NA_DOM(IS)) THEN
                  LINE = ' ERROR: (in rotfft) domains'//
     *            ' have diff. number of atoms'
                  CALL MSGERR(MDOC,LINE)
                  IERR = 1
                  RETURN
                ENDIF
              ENDIF  
            ENDDO

          ENDDO
        ENDDO
      ENDIF
C ---
      XS_COM  = 0.0
      YS_COM  = 0.0
      ZS_COM  = 0.0
      XS2_COM = 0.0
      YS2_COM = 0.0
      ZS2_COM = 0.0
      N_COM   = 0
      CALL MSGDOC(MDOC,'--- Molecules ---')
      DO  JM=1,NM_TOTAL
        XS  = 0.0
        YS  = 0.0
        ZS  = 0.0
        XS2 = 0.0
        YS2 = 0.0
        ZS2 = 0.0
        N  = 0
        DO  IA=1,NA_TOTAL
          ID = NUMDOM(IA)
          IM = ID_MOL(ID)
          XS_COM  = XS_COM + X0(IA,1)
          YS_COM  = YS_COM + X0(IA,2)
          ZS_COM  = ZS_COM + X0(IA,3)
          N_COM   = N_COM  + 1
          XS2_COM = XS2_COM + X0(IA,1)*X0(IA,1)
          YS2_COM = YS2_COM + X0(IA,2)*X0(IA,2)
          ZS2_COM = ZS2_COM + X0(IA,3)*X0(IA,3)
          IF(JM.EQ.IM) THEN
            XS  = XS + X0(IA,1)
            YS  = YS + X0(IA,2)
            ZS  = ZS + X0(IA,3)
            N   = N  + 1
            XS2 = XS2 + X0(IA,1)*X0(IA,1)
            YS2 = YS2 + X0(IA,2)*X0(IA,2)
            ZS2 = ZS2 + X0(IA,3)*X0(IA,3)
          ENDIF
        ENDDO
        IF(N.GT.0) THEN
          XS   = XS/FLOAT(N)
          YS   = YS/FLOAT(N)
          ZS   = ZS/FLOAT(N)
          V(1) = XS
          V(2) = YS
          V(3) = ZS
          CALL OTOF(V,CENTRE_MOL(1,JM),IERR)
          XS2          = XS2/FLOAT(N)
          YS2          = YS2/FLOAT(N)
          ZS2          = ZS2/FLOAT(N)
          RX           = XS2-XS*XS
          RY           = YS2-YS*YS
          RZ           = ZS2-ZS*ZS
          RADI_MOL     = SQRT(ABS(RX+RY+RZ))
          WRITE(LINE,'(I4,'') Radius of inertia :'',F10.3,A,I8)') 
     *            JM,RADI_MOL,' Na_mol:',NA_MOL(JM) 
          CALL MSGDOC(MDOC,LINE)
        ENDIF
      ENDDO

      IF(N_COM.GT.0) THEN
        XS_COM  = XS_COM/FLOAT(N_COM)
        YS_COM  = YS_COM/FLOAT(N_COM)
        ZS_COM  = ZS_COM/FLOAT(N_COM)
        V(1)    = XS_COM
        V(2)    = YS_COM
        V(3)    = ZS_COM
        CALL OTOF(V,CENTRE_COM,IERR)
        XS2_COM      = XS2_COM/FLOAT(N_COM)
        YS2_COM      = YS2_COM/FLOAT(N_COM)
        ZS2_COM      = ZS2_COM/FLOAT(N_COM)
        RX           = XS2_COM-XS_COM*XS_COM
        RY           = YS2_COM-YS_COM*YS_COM
        RZ           = ZS2_COM-ZS_COM*ZS_COM
        RADI_COM     = SQRT(ABS(RX+RY+RZ))
      ENDIF
C ----
      WRITE(LINE,'(''Nmol:'',I5,'' centre:'',3F8.3,'' Radi:'',F8.2)') 
     * NM_TOTAL,CENTRE_COM(1),CENTRE_COM(2),CENTRE_COM(3),RADI_COM
      CALL MSGDOC(MDOC,LINE)

      IF(NM_TOTAL.GT.1) THEN
        CALL MSGDOC(MDOC,'---------------------')

        IAA = 0
        DO IA=1,NA_TOTAL
          ID = NUMDOM(IA)
          JM = ID_MOL(ID)
          IF(JM.EQ.1) THEN
            IAA = IAA + 1
            X(IAA,1) = X0(IA,1)
            X(IAA,2) = X0(IA,2)
            X(IAA,3) = X0(IA,3)
          ENDIF
        ENDDO
 
        IF(ICNTR.EQ.1.AND.DOM.EQ.'C') THEN
          CENTRE_COM(1) = C_INP(1)
          CENTRE_COM(2) = C_INP(2)
          CENTRE_COM(3) = C_INP(3)
        ENDIF

        NN = NA_MOL(1)
        IM = 1
C    
        V(1) = CENTRE_MOL(1,IM) - CENTRE_COM(1)
        V(2) = CENTRE_MOL(2,IM) - CENTRE_COM(2)
        V(3) = CENTRE_MOL(3,IM) - CENTRE_COM(3)

        CALL FTOO(V,V1,IERR)

        DIST = SQRT(V1(1)*V1(1)+V1(2)*V1(2)+V1(3)*V1(3))
        WRITE(LINE,'(I4,A,3F8.2,3X,3F8.2)') IM,' Angl_rest,obs:'
     *  ,ANGLES_RESTR(1,IM),ANGLES_RESTR(2,IM),ANGLES_RESTR(3,IM)
     *  ,ANGLES_OBS(1,IM),ANGLES_OBS(2,IM),ANGLES_OBS(3,IM)
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,'(4X,A,3F8.3)') ' Centre:' 
     *  ,CENTRE_MOL(1,IM),CENTRE_MOL(2,IM),CENTRE_MOL(3,IM)
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,'(4X,A,4F8.3)') 
     *  ' VectorC,Dist:',V(1),V(2),V(3),DIST
        CALL MSGDOC(MDOC,LINE)
C
        DO IM=2,NM_TOTAL

          IAA = 0
          DO IA=1,NA_TOTAL
            ID = NUMDOM(IA)
            JM = ID_MOL(ID)
            IF(JM.EQ.1) THEN
              IAA = IAA + 1
              X(IAA,1) = X0(IA,1)
              X(IAA,2) = X0(IA,2)
              X(IAA,3) = X0(IA,3)
            ENDIF
          ENDDO

          IF(DOM.EQ.'C') THEN
            V1(1) = (ANGLES_RESTR(1,IM)*PI)/180.0
            V1(2) = (ANGLES_RESTR(2,IM)*PI)/180.0
            V1(3) = (ANGLES_RESTR(3,IM)*PI)/180.0
            CALL POLTOM(V1(1),V1(2),V1(3),TRMAT)
            IAA = 0
            DO IA=1,NA_TOTAL
              ID  = NUMDOM(IA)
              JM  = ID_MOL(ID)
              IF(IM.EQ.JM) THEN
                IAA = IAA + 1
                CALL FTOO(CENTRE_COM,V,IERR)   
                V1(1) = X(IAA,1) - V(1)
                V1(2) = X(IAA,2) - V(2)
                V1(3) = X(IAA,3) - V(3)
                CALL MVMULT(TRMAT,V1,V2)
                X0(IA,1) = V2(1) + V(1)
                X0(IA,2) = V2(2) + V(2)
                X0(IA,3) = V2(3) + V(3)
              ENDIF
            ENDDO

            V(1) = CENTRE_MOL(1,1) - CENTRE_COM(1)
            V(2) = CENTRE_MOL(2,1) - CENTRE_COM(2)
            V(3) = CENTRE_MOL(3,1) - CENTRE_COM(3)
            CALL FTOO(V,V1,IERR)
            CALL MVMULT(TRMAT,V1,V2)
            CALL OTOF(V2,V1,IERR)
            CENTRE_MOL(1,IM) = V1(1) + CENTRE_COM(1)
            CENTRE_MOL(2,IM) = V1(2) + CENTRE_COM(2)
            CENTRE_MOL(3,IM) = V1(3) + CENTRE_COM(3)
          ENDIF

          IAA = 0
          DO IA=1,NA_TOTAL
            ID = NUMDOM(IA)
            JM = ID_MOL(ID)
            IF(IM.EQ.JM) THEN
              IAA = IAA + 1
              GRADX(IAA,1) = X0(IA,1)
              GRADX(IAA,2) = X0(IA,2)
              GRADX(IAA,3) = X0(IA,3)
            ENDIF
          ENDDO

          CALL LSKAB_FIT(M,X,GRADX,NN,TRMAT,TR,DRMS,DISMAX
     *                ,MEM,IERR)
C ---------------------------------------------------------
C     X      CONTAINS THE NX COORD. OF THE WORKING MOLECULE.
C     GRADX  CONTAINS THE NY COORD. OF THE REFERENCE MOLECULE.
C     NN     THE NUMBER OF CRESTS TO BE USED TO GENERATE THE ROTATION MATRIX
C --------------------------------------------------------
          IF(IERR.NE.0) THEN
            RETURN
          ENDIF        

          CALL MTOPOL(TRMAT,ANGLES_OBS(1,IM),ANGLES_OBS(2,IM)
     *    ,ANGLES_OBS(3,IM))
C
          V(1) = CENTRE_MOL(1,IM) - CENTRE_COM(1)
          V(2) = CENTRE_MOL(2,IM) - CENTRE_COM(2)
          V(3) = CENTRE_MOL(3,IM) - CENTRE_COM(3)

          CALL FTOO(V,V1,IERR)

          DIST = SQRT(V1(1)*V1(1)+V1(2)*V1(2)+V1(3)*V1(3))
          WRITE(LINE,'(I4,A,3F8.2,3X,3F8.2)') IM,' Angl_rest,obs:'
     *    ,ANGLES_RESTR(1,IM),ANGLES_RESTR(2,IM),ANGLES_RESTR(3,IM)
     *    ,ANGLES_OBS(1,IM),ANGLES_OBS(2,IM),ANGLES_OBS(3,IM)
          CALL MSGDOC(MDOC,LINE)
          WRITE(LINE,'(4X,A,3F8.3,A,2F8.3)') ' Centre:' 
     *    ,CENTRE_MOL(1,IM),CENTRE_MOL(2,IM),CENTRE_MOL(3,IM)
     *    ,' Rms,Dmax:',DRMS,DISMAX
          CALL MSGDOC(MDOC,LINE)
          WRITE(LINE,'(4X,A,4F8.3)') 
     *    ' VectorC,Dist:',V(1),V(2),V(3),DIST
          CALL MSGDOC(MDOC,LINE)
C
        ENDDO
        CALL MSGDOC(MDOC,'---------------------')
        IF(NWORDS.LE.4) THEN
          DO IM=1,NM_TOTAL
            ANGLES_RESTR(1,IM) = ANGLES_OBS(1,IM)
            ANGLES_RESTR(2,IM) = ANGLES_OBS(2,IM)
            ANGLES_RESTR(3,IM) = ANGLES_OBS(3,IM)
          ENDDO
        ENDIF
      ENDIF

C --------------------------------------
      RETURN
      END

      SUBROUTINE RD_LINE_ROTFFT(CR_LINE,NW,NUMB_INP,ANGLES,C)
C --------------------------------
      INTEGER   NUMB_INP
      REAL      ANGLES(3),C(3)
      CHARACTER LINE*80,CR_LINE*(*)
C ---
      PARAMETER ( NWORDSMAX = 40 )
      COMMON /FREAD_RB/ FWORDS,IFRD_ERR,NWORDS,LEN_WORDS,IWORDS
     *                 ,WORDS,IN_STRING
      REAL      FWORDS   (NWORDSMAX)
      INTEGER*4 LEN_WORDS(NWORDSMAX)
      INTEGER*4 IWORDS   (NWORDSMAX)
      INTEGER*4 NWORDS,IFRD_ERR
      CHARACTER WORDS(NWORDSMAX)*80
      CHARACTER IN_STRING*80
C --------------------------------------------------------------
      NUMB_INP  = 0
      ANGLES(1) = 0.0
      ANGLES(2) = 0.0
      ANGLES(3) = 0.0
      C(1)      = 0.0
      C(2)      = 0.0
      C(3)      = 0.0
      NW        = 0
C ---
      IN_STRING = CR_LINE        
      CALL LENSTR_BL(IN_STRING,LEN)
      IF(LEN.GT.0.AND.IN_STRING(1:1).EQ.'#') THEN
        CALL FRD_PARM_RB
        NW = NWORDS
        IF(NWORDS.LE.1) RETURN
        NUMB_INP  = IWORDS(2)
        IF(NWORDS.LE.4) RETURN
        ANGLES(1) = FWORDS(3)
        ANGLES(2) = FWORDS(4)
        ANGLES(3) = FWORDS(5)
        IF(NWORDS.LE.7) RETURN
        C(1) = FWORDS(6)
        C(2) = FWORDS(7)
        C(3) = FWORDS(8)
      ENDIF
      RETURN
      END
C ******
      SUBROUTINE FRD_PARM_RB
C -------------------------------------------------------
C -P- FRD_PARM_CIF - free format reading of the string of characters.
C                See common /FREAD_CIF/
C
C     input:     IN_STRING - input string; a word is the part of the string
C                            between two blancs or two "'".
C     output:    NWORDS    - number of words of the string
C                IWORDS    - array of integer value of each word.
C                FWORDS    - array of real value of each word.
C                WORDS     - array of words
C                LEN_WORDS - array of lengths of the words
C                IFRD_ERR  - signal of error. 
C                            0  means OK.
C                            1 - number of words > NWORDSMAX = 40
C -----------------------------------------------------------
      PARAMETER ( NWORDSMAX = 40 )
      COMMON /FREAD_RB/ FWORDS,IFRD_ERR,NWORDS,LEN_WORDS,IWORDS
     *                 ,WORDS,IN_STRING
      REAL      FWORDS   (NWORDSMAX)
      INTEGER*4 LEN_WORDS(NWORDSMAX)
      INTEGER*4 IWORDS   (NWORDSMAX)
      INTEGER*4 NWORDS,IFRD_ERR
      CHARACTER WORDS(NWORDSMAX)*80
      CHARACTER IN_STRING*80
C --------------------------------------------------------------
C ******
      REAL      FA
      INTEGER*4 NW,IS,IW,IAP,LEN,IP,IA
      CHARACTER CH*1,CK*1,STR*80
C --------------------------------------------------------------
      IFRD_ERR=0
      NWORDS=0
      NW=0
      IW=0
      IS=0
      IAP=0
      CALL LENSTR_BL(IN_STRING,LEN)
      IF(LEN.LE.0) RETURN
      IF(LEN.GT.80) LEN=80
C -----------------
      DO   IP=1,LEN
        CH=IN_STRING(IP:IP)
        CALL CHKSMB(CH,CK)
        IF(CK.EQ.'?') CH=' '
        IF(CH.EQ.'''') THEN
          IAP=IAP+1
          IF(IAP.GE.2) IAP=0
        ENDIF
        IF(CH.NE.' '.OR.IAP.EQ.1) THEN
C         start of a word
          IF(IS.EQ.0) THEN
            IS=1
            NW=NW+1
            IF(NW.GT.20) THEN
              IFRD_ERR=1
              RETURN
            ENDIF
          ENDIF
          IF(CH.NE.'''') THEN
            IW=IW+1
            STR(IW:IW)=CH       
          ELSE
            IF(IW.GT.0) THEN
            ENDIF
          ENDIF
        ENDIF
        IF((CH.EQ.' '.AND.IS.EQ.1.AND.IAP.EQ.0).OR.
     *       (IP.EQ.LEN.AND.IW.NE.0)) THEN
          IF(IW.LE.0) THEN
            WORDS(NW)='?'
            LEN_WORDS(NW)=1
          ELSE
            WORDS(NW)=STR(1:IW)
            LEN_WORDS(NW)=IW
          ENDIF
          NWORDS=NW
          CALL WTODIG(STR,IW,FA,IA)
          IWORDS(NW)=IA
          FWORDS(NW)=FA
          IS=0
          IW=0
          IAP=0
        ENDIF
      ENDDO
C -----------------
      RETURN
      END      

      SUBROUTINE LSKAB_FIT(MDOC,X,Y,NX,TRMAT,TR,DRMS,DISMAX,MEM,IERR)
C ---------------------------------------------------------
C
C     X      CONTAINS THE NX COORD. OF THE WORKING MOLECULE.
C     Y      CONTAINS THE NY COORD. OF THE REFERENCE MOLECULE.
C     NX     THE NUMBER OF CRESTS TO BE USED TO GENERATE THE ROTATION
C            MATRIX
C --------------------------------------------------------
      REAL X(MEM,3),Y(MEM,3),CNTRX(3),CNTRY(3)
      REAL TR(3),TRMAT(3,3),RK(3,3),RKTRK(3,3),R(3),VP(3,3)
      REAL RA(3,3),RANR(3,3),E(3),XT(3),XNORM(3)
      CHARACTER LINE*80
C ----------------------------------------------------------------
      IERR=0
C
C     CALCULATE CENTROIDS
C
      DO     I=1,3
        CNTRY(I) = 0.0
        CNTRX(I) = 0.0
      ENDDO
      WSY = 0.0
      WSX = 0.0
      DO     I=1,NX
        DO     J=1,3
          CNTRY(J) = CNTRY(J) + Y(I,J) 
          CNTRX(J) = CNTRX(J) + X(I,J) 
        ENDDO
        WSY = WSY + 1.0
        WSX = WSX + 1.0
      ENDDO
      DO     J=1,3
        CNTRX(J) = CNTRX(J)/WSX
        CNTRY(J) = CNTRY(J)/WSY
      ENDDO

C
C     TRANSLATE WORKING AND REFERENCE MOLECULES TO ORIGIN
C
      DO     I=1,NX
      DO     J=1,3
        X(I,J) = X(I,J) - CNTRX(J)
        Y(I,J) = Y(I,J) - CNTRY(J)
      ENDDO
      ENDDO
C
      DISMAX = 0.0
      SUMD2  = 0.0
      SUMDIS = 0.0
C
C    GET MATRIX R = SUM(Y.X)
C
      DO     I=1,3
      DO     J=1,3
        RK(I,J) = 0.0
      ENDDO
      ENDDO
      DO     IA=1,NX
        DO     I=1,3
        DO     J=1,3
          RK(I,J) = RK(I,J)+Y(IA,I)*X(IA,J)
        ENDDO
        ENDDO
      ENDDO
C
C      EZERO VALUE
C
      EZERO = 0.0
      DO     IA=1,NX
        DO     I=1,3
          EZERO = EZERO + (X(IA,I)*X(IA,I)+Y(IA,I)*Y(IA,I))
        ENDDO
      ENDDO
      EZERO = EZERO*0.5
C
C      GET RKTRK  =  RKTRANSPSED  *  RK
C
      DO     I=1,3
      DO     J=1,3
        RKTRK(I,J) = 0.0
        DO     K=1,3
          RKTRK(I,J) = RKTRK(I,J)+RK(K,I)*RK(K,J)
        ENDDO
      ENDDO
      ENDDO
C
C      CALL NAG ROUTINE :  EIGENVALUES IN  R
C                       :  EIGENVECTORS NORMALIZED IN VP
C                           (SORTED IN ASCENDING ORDER)
C                           (E   WORKING ARRAY)
C
      IFAIL = 0
      CALL F02ABF(RKTRK,3,3,R,VP,3,E,IFAIL)
      IF (IFAIL.NE.0) THEN
        IERR = 1
        WRITE(MDOC,10) IFAIL
   10   FORMAT
     *(' ERROR: (rotfft) DETECTED BY NAG LIBRARY ROUTINE - IFAIL=',I5)
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,11) IFAIL
   11   FORMAT ('     ',I5,5X,' DIAGONALISATION FAILED')
        CALL MSGDOC(MDOC,LINE)
        RETURN
      ENDIF
C
C      SET VP(.1)=VP(.,3) X VP(.,2)
C
      VP(1,1) = VP(2,3)*VP(3,2)-VP(3,3)*VP(2,2)
      VP(2,1) = VP(3,3)*VP(1,2)-VP(1,3)*VP(3,2)
      VP(3,1) = VP(1,3)*VP(2,2)-VP(2,3)*VP(1,2)
C
C     GET  RA = R . V
C
      DO     K=1,3
      DO     I=1,3
        RA(I,K) = 0.0
        DO     J=1,3
          RA(I,K) = RA(I,K)+RK(I,J)*VP(J,K)
        ENDDO
      ENDDO
      ENDDO
C
C      NORM.   RA(.,2) & RA(.3)
C
      DO     J=2,3
        XNORM(J) = 0.0
        DO     I=1,3
          XNORM(J) = XNORM(J)+RA(I,J)*RA(I,J)
        ENDDO
        XNORM(J) = 1./SQRT(ABS(XNORM(J)))
      ENDDO
      DO     J=2,3
      DO     I=1,3
        RANR(I,J) = RA(I,J)*XNORM(J)
      ENDDO
      ENDDO
C
C      SET RANR(.,1) = RANR(.,3) X RANR(.,2)
C
      RANR(1,1) = RANR(2,3)*RANR(3,2) - RANR(3,3)*RANR(2,2)
      RANR(2,1) = RANR(3,3)*RANR(1,2) - RANR(1,3)*RANR(3,2)
      RANR(3,1) = RANR(1,3)*RANR(2,2) - RANR(2,3)*RANR(1,2)
C
C   GET SCALAR PRODUCT  RANR(.,1) . RA(.,1)     & SIGMA VALUE
C
C     SCPD=0.0
C     DO     I=1,3
C       SCPD=RANR(I,1)*RA(I,1)
C     ENDDO
C     SIGMA = 1.
C     IF (SCPD.LT.0) SIGMA=-1.
C     RES = EZERO -SQRT(ABS(R(2)))-SQRT(ABS(R(3)))-SIGMA*SQRT(ABS(R(1)))
C
C      TRANSFORMATION MATRIX
C
      DO     I=1,3
      DO     J=1,3
        TRMAT(I,J) = 0.0
        DO     K=1,3
          TRMAT(I,J) = TRMAT(I,J)+RANR(I,K)*VP(J,K)
        ENDDO
      ENDDO
      ENDDO
C
C
C      CALCULATE RESIDUALS & FIGURES OF MERIT
C
      DO     IA=1,NX
        DO     I=1,3
          XT(I) = 0.0
          DO     J=1,3
            XT(I) = XT(I) + TRMAT(I,J)*X(IA,J)
          ENDDO
        ENDDO
        DO     I=1,3
          X(IA,I) = XT(I)
        ENDDO
        D = 0.0
        DO     J=1,3
          D = D +(X(IA,J)-Y(IA,J))*(X(IA,J)-Y(IA,J))
        ENDDO
        SUMD2  = SUMD2 + D
        D      = SQRT(ABS(D))
        SUMDIS = SUMDIS +D
        DISMAX = AMAX1(DISMAX,D)
      ENDDO
      DRMS   = SQRT(ABS(SUMD2/NX))
      SUMDIS = SUMDIS/NX
C
      WRITE(LINE,40) SUMD2
 40   FORMAT('SUM DISPLACEMENTS**2      =',F8.3)
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,41) DRMS
 41   FORMAT('RMS DISPLACEMENT          =',F8.3)
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,42) SUMDIS
 42   FORMAT('AVERAGE DISPLACEMENT      =',F8.3)
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,43) DISMAX
 43   FORMAT('MAXIMUM DISPLACEMENT      =',F8.3)
      CALL MSGDOC(MDOC,LINE)
C
C
C     ADD REFERENCE MOLECULE CENTROID TO WORKING MOLECULE COORDS.
C
      DO     I=1,NX
      DO     J=1,3
        X(I,J) = X(I,J)+CNTRY(J)
      ENDDO
      ENDDO
C
C     SHIFT REFERENCE MOLECULE TO ORIGINAL POSITION
C
      DO     II=1,NX
      DO     J=1,3
        Y(II,J) = Y(II,J)+CNTRY(J)
      ENDDO
      ENDDO
C
C  FIND TRANSLATION  T = -TRMAT * CTRX   +CNTRY
C
      TR(1)=
     *  -TRMAT(1,1)*CNTRX(1)-TRMAT(1,2)*CNTRX(2)-TRMAT(1,3)*CNTRX(3)
     *  +CNTRY(1)
      TR(2)=
     *  -TRMAT(2,1)*CNTRX(1)-TRMAT(2,2)*CNTRX(2)-TRMAT(2,3)*CNTRX(3)
     *  +CNTRY(2)
      TR(3)=
     *  -TRMAT(3,1)*CNTRX(1)-TRMAT(3,2)*CNTRX(2)-TRMAT(3,3)*CNTRX(3)
     *  +CNTRY(3)
      TEMP       = TRMAT(1,2)
      TRMAT(1,2) = TRMAT(2,1)
      TRMAT(2,1) = TEMP
      TEMP       = TRMAT(1,3)
      TRMAT(1,3) = TRMAT(3,1)
      TRMAT(3,1) = TEMP
      TEMP       = TRMAT(2,3)
      TRMAT(2,3) = TRMAT(3,2)
      TRMAT(3,2) = TEMP

      RETURN
      END

      SUBROUTINE F02ABF(A, IA, N, R, V, IV, E, IFAIL)
C
C     MARK 2 RELEASE. NAG COPYRIGHT 1972
C     MARK 3 REVISED.
C     MARK 4.5 REVISED
C
C     EIGENVALUES AND EIGENVECTORS OF A REAL SYMMETRIX MATRIX
C     1ST AUGUST 1971
C
      INTEGER  ISAVE, IFAIL, N, IA, IV
      REAL     A(IA,N), R(N), V(IV,N), E(N)
      REAL     X02AAF,TOL
C ----------------------------
      X02AAF = 2.380 E-7
C -----------
      ISAVE = IFAIL
      IFAIL = 1
      TOL   = X02AAF
      CALL F01AJF(N, TOL, A, IA, R, E, V, IV)
      TOL = X02AAF
      CALL F02AMF(N, TOL, R, E, V, IV, IFAIL)
      IF (IFAIL.NE.0) THEN
        ISAVE = IFAIL
      ENDIF
      RETURN
      END

C      FUNCTION X02AAF
C      DOUBLE PRECISION FUNCTION X02AAF
C      X02AAF = 2.380 E-7
C      RETURN
C      END

      SUBROUTINE F02AMF(N, ACHEPS, D, E, Z, IZ, IFAIL)
C
C     MARK 2 RELEASE. NAG COPYRIGHT 1972
C     MARK 3 REVISED.
C     MARK 4 REVISED.
C     MARK 4.5 REVISED
C     MARK 9 REVISED. IER-326 (SEP 1981).
C
C     TQL2
C     THIS SUBROUTINE FINDS THE EIGENVALUES AND EIGENVECTORS OF A
C     TRIDIAGONAL MATRIX, T, GIVEN WITH ITS DIAGONAL ELEMENTS IN
C     THE ARRAY D(N) AND ITS SUB-DIAGONAL ELEMENTS IN THE LAST N
C     - 1 STORES OF THE ARRAY E(N), USING QL TRANSFORMATIONS. THE
C     EIGENVALUES ARE OVERWRITTEN ON THE DIAGONAL ELEMENTS IN THE
C     ARRAY D IN ASCENDING ORDER. THE EIGENVECTORS ARE FORMED IN
C     THE ARRAY Z(N,N), OVERWRITING THE ACCUMULATED
C     TRANSFORMATIONS AS SUPPLIED BY THE SUBROUTINE F01AJF. THE
C     SUBROUTINE WILL FAIL IF ALL EIGENVALUES TAKE MORE THAN 30*N
C     ITERATIONS.
C     1ST APRIL 1972
C
      INTEGER ISAVE, IFAIL, N, I, L, J, M, I1, M1, II, K, IZ
      REAL    B, F, H, G, P, R, C, S, D(N), E(N), Z(IZ,N)
      REAL    ACHEPS
C -----------------------------------
      ISAVE = IFAIL
      IF(N.NE.1) THEN
        DO     I=2,N
           E(I-1) = E(I)
        ENDDO
      ENDIF
      E(N) = 0.0
      B    = 0.0
      F    = 0.0
      J    = 30*N
      DO     L=1,N
         H = ACHEPS*(ABS(D(L))+ABS(E(L)))
         IF(B.LT.H) B = H
C        LOOK FOR SMALL SUB-DIAG ELEMENT
         DO     M=L,N
            IF (ABS(E(M)).LE.B) GO TO 80
         ENDDO
   80    IF(M.EQ.L) GO TO 280
  100    IF(J.LE.0) THEN
           IFAIL = 1
           RETURN
         ENDIF
         J = J - 1
C        FORM SHIFT
         G = D(L)
         H = D(L+1) - G
         IF(ABS(H).LT.ABS(E(L))) THEN
           P = H*0.5/E(L)
           R = SQRT(ABS(P*P+1.0))
           H = P + R
           IF (P.LT.0.0) H = P - R
           D(L) = E(L)/H
         ELSE
           P = 2.0*E(L)/H
           R = SQRT(ABS(P*P+1.0))
           D(L) = E(L)*P/(1.0+R)
         ENDIF
         H  = G - D(L)
         I1 = L + 1
         IF(I1.LE.N) THEN
           DO     I=I1,N
             D(I) = D(I) - H
           ENDDO
         ENDIF
         F = F + H
C     QL TRANSFORMATION
         P = D(M)
         C = 1.0
         S = 0.0
         M1 = M - 1
         DO     II=L,M1
            I = M1 - II + L
            G = C*E(I)
            H = C*P
            IF(ABS(P).GE.ABS(E(I))) THEN
              C      = E(I)/P
              R      = SQRT(ABS(C*C+1.0))
              E(I+1) = S*P*R
              S      = C/R
              C      = 1.0/R
            ELSE
              C      = P/E(I)
              R      = SQRT(ABS(C*C+1.0))
              E(I+1) = S*E(I)*R
              S      = 1.0/R
              C      = C/R
            ENDIF
            P      = C*D(I) - S*G
            D(I+1) = H + S*(C*G+S*D(I))
C           FORM VECTOR
            DO     K=1,N
               H        = Z(K,I+1)
               Z(K,I+1) = S*Z(K,I) + C*H
               Z(K,I)   = C*Z(K,I) - S*H
            ENDDO
         ENDDO
         E(L) = S*P
         D(L) = C*P
         IF(ABS(E(L)).GT.B) GO TO 100
  280    D(L) = D(L) + F
      ENDDO
C     ORDER EIGENVALUES AND EIGENVECTORS
      DO     I=1,N
         K  = I
         P  = D(I)
         I1 = I + 1
         IF(I1.LE.N) THEN
           DO     J=I1,N
              IF(D(J).LT.P) THEN
                K = J
                P = D(J)
              ENDIF
           ENDDO
         ENDIF
         IF(K.NE.I) THEN
           D(K) = D(I)
           D(I) = P
           DO     J=1,N
              P = Z(J,I)
              Z(J,I) = Z(J,K)
              Z(J,K) = P
           ENDDO
         ENDIF
      ENDDO
      IFAIL = 0
      END

      SUBROUTINE F01AJF(N, ATOL, A, IA, D, E, Z, IZ)
C
C     MARK 2 RELEASE. NAG COPYRIGHT 1972
C     MARK 4 REVISED.
C     MARK 4.5 REVISED
C     MARK 5C REVISED
C
C     TRED2
C     THIS SUBROUTINE REDUCES THE GIVEN LOWER TRIANGLE OF A
C     SYMMETRIC MATRIX, A, STORED IN THE ARRAY A(N,N), TO
C     TRIDIAGONAL FORM USING HOUSEHOLDERS REDUCTION. THE DIAGONAL
C     OF THE RESULT IS STORED IN THE ARRAY D(N) AND THE
C     SUB-DIAGONAL IN THE LAST N - 1 STORES OF THE ARRAY E(N)
C     (WITH THE ADDITIONAL ELEMENT E(1) = 0). THE TRANSFORMATION
C     MATRICES ARE ACCUMULATED IN THE ARRAY Z(N,N). THE ARRAY
C     A IS LEFT UNALTERED UNLESS THE ACTUAL PARAMETERS
C     CORRESPONDING TO A AND Z ARE IDENTICAL.
C     1ST AUGUST 1971
C
      INTEGER I, IA, II, IZ, J1, J, K, L, N
      REAL F, G, H, HH, A(IA,N), D(N), E(N), Z(IZ,N)
      REAL*4 ATOL
      DO     I=1,N
        DO     J=1,I
          Z(I,J) = A(I,J)
        ENDDO
      ENDDO
      IF(N.NE.1) THEN
        DO     II=2,N
          I = N - II + 2
          L = I - 2
          F = Z(I,I-1)
          G = 0.0
          IF(L.GT.0) THEN
            DO     K=1,L
              G = G + Z(I,K)*Z(I,K)
            ENDDO
          ENDIF
          H = G + F*F
C         IF G IS TOO SMALL FOR ORTHOGONALITY TO BE
C         GUARANTEED THE TRANSFORMATION IS SKIPPED
          IF(G.LE.ATOL) THEN
            E(I) = F
            H    = 0.0
            GO TO 240
          ENDIF
  100     L = L + 1
          G = SQRT(ABS(H))
          IF(F.GE.0.0) G = -G
          E(I) = G
          H    = H - F*G
          Z(I,I-1) = F - G
          F = 0.0
          DO     J=1,L
            Z(J,I) = Z(I,J)/H
            G      = 0.0
C           FORM ELEMENT OF A*U
            DO     K=1,J
              G = G + Z(J,K)*Z(I,K)
            ENDDO
            J1 = J + 1
            IF(J1.LE.L) THEN
              DO     K=J1,L
                G = G + Z(K,J)*Z(I,K)
              ENDDO
            ENDIF
C           FORM ELEMENT OF P
            E(J) = G/H
            F    = F + G*Z(J,I)
          ENDDO
C         FORM K
          HH = F/(H+H)
C         FORM REDUCED A
          DO     J=1,L
            F = Z(I,J)
            G = E(J) - HH*F
            E(J) = G
            DO     K=1,J
              Z(J,K) = Z(J,K) - F*E(K) - G*Z(I,K)
            ENDDO
          ENDDO
  240     D(I) = H
        ENDDO
      ENDIF
      E(1) = 0.0
      D(1) = 0.0
C     ACCUMULATION OF TRANSFORMATION MATRICES
      DO     I=1,N
        L = I - 1
        IF(D(I).NE.0.0) THEN
          DO     J=1,L
            G = 0.0
            DO     K=1,L
              G = G + Z(I,K)*Z(K,J)
            ENDDO
            DO     K=1,L
              Z(K,J) = Z(K,J) - G*Z(K,I)
            ENDDO
          ENDDO
        ENDIF
        D(I)   = Z(I,I)
        Z(I,I) = 1.0
        IF(L.NE.0) THEN
          DO     J=1,L
            Z(I,J) = 0.0
            Z(J,I) = 0.0
          ENDDO
        ENDIF
      ENDDO
      RETURN
      END

      SUBROUTINE WR_CRD_RTFFT(MDOC,NAMEC,NAMEO,X0,DOM,NUMDOM,BFAC0
     *           ,NATOM,NCRDMAX,MEM,P1,NSYM,ISYM,IPRSYM,IERR)
C ---
C ------------------------------------------
      REAL      X0(MEM,3),BFAC0(MEM)
      INTEGER   NUMDOM(MEM)
      CHARACTER P1*1,DOM*1
C ---
      PARAMETER ( IPRDOM = 300    )
      PARAMETER ( IPRVAR =IPRDOM*6     )
      PARAMETER ( IPRVR2 =IPRVAR*IPRVAR)
      COMMON /DOMAIN_ROTFFT/ NA_TOTAL,NM_TOTAL,NA_MOL,ANGLES_RESTR
     *                      ,ND_TOTAL,NA_DOM,ID_MOL,ID_DOM,CENTRE,RADI
     *                      ,NP_TOTAL,NMD_TOTAL,ANGLES_OBS,CENTRE_COM
     *                      ,CENTRE_MOL,SHIFT_MOL
      INTEGER   NP_TOTAL,NA_TOTAL,NM_TOTAL,NA_MOL(IPRDOM),NMD_TOTAL
      INTEGER   ND_TOTAL
      REAL      ANGLES_RESTR(3,IPRDOM),ANGLES_OBS(3,IPRDOM)
      INTEGER   NA_DOM(IPRDOM),ID_MOL(IPRDOM),ID_DOM(IPRDOM)    
      REAL      CENTRE(3,IPRDOM),RADI(IPRDOM),CENTRE_COM(3)
      REAL      CENTRE_MOL(3,IPRDOM),SHIFT_MOL(3,IPRDOM)
C ===
C ----------------------------------------------------------
      INCLUDE 'mr_crd_com.fh'
C -------------------------------------------------
      REAL      ANGLES(3),C(3)
      CHARACTER NAMEC*(*),NAMEO*(*),LINE*80,LINE2*80
      INTEGER*2 ISYM(5,3,IPRSYM)
C ----------------------
      IERR =0
      M    =99
      IATMR=10
      CALL ORCRD(M,IATMR,NAMEC,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERR: OPEN INPUT COORD_FILE')
        RETURN
      ENDIF

      CALL LENSTR_BL(NAMEO,LEN)
      IF(LEN.LE.0.OR.NAMEO(1:1).EQ.','.OR.NAMEO(1:1).EQ.' ') THEN
        NAMEO='rotfft'
      ENDIF

      IF(P1.EQ.'Y') NSYM = 1

c      CALL CHECK_CHAIN_ID(INEW)

      IXYZB = 32
      CALL OWCRD(M,IXYZB,NAMEO,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        WRITE(LINE,*) ' ERR: OPEN OUTPUT FILE-CRD'
        CALL MSGERR(MDOC,LINE)
        CLOSE(IATMR)
        RETURN
      ENDIF
C -----------------------------------------
      IDOM   = 0
      I      = 0
      M      = 99
      IEND   =-1
      IENDW  =-1
      NAMAX  = NCRDMAX*2
      NCS_ID = 1
      IM_OLD =-1
      DO     IARD=1,NAMAX

        CALL RDCRD(M,IATMR,MODE,IEND,IERR)
        IF(IERR.NE.0) THEN
          CLOSE(IXYZB)
          RETURN
        ENDIF
        IF(IEND.NE.0) GO TO 300

        IF(MODE.NE.0) THEN
          IW = 1
          IF(DOM.NE.'N'.AND.DOM.NE.'Y') THEN
            IF(CR_LINE(1:9).EQ.'#MOLECULE'.OR.
     *         CR_LINE(1:7).EQ.'#DOMAIN') THEN
              CALL RD_LINE_ROTFFT(CR_LINE,NW,NUMB_INP,ANGLES,C)
              IF(I.LE.0) NCS_ID = NUMB_INP
              IW = 0
            ENDIF

          ENDIF
          IF(IW.EQ.1) CALL WRCRD(M,IXYZB,MODE,IENDW,IERR)

        ELSE

          IF((CR_ATYPE .EQ.' '.OR.CR_ATYPE .EQ.'.'.OR.
     *        CR_ATYPE .EQ.'y'.OR.CR_ATYPE .EQ.'Y'.OR.
     *        CR_ATYPE .EQ.'r'.OR.CR_ATYPE .EQ.'R').AND.
     *        CR_OCC .GT.0.0001                        ) THEN

            I=I+1
            IF(DOM.NE.'N'.AND.DOM.NE.'Y') THEN
              ID = NUMDOM(I)
              IF(ID.NE.IDOM) THEN
                IDOM = ID
                IM   = ID_MOL(ID)
                IMD  = ID_DOM(ID)
                MODE = 1
                LINE = CR_LINE
                LINE2= CR_LINE2

                IF(IMD.EQ.1.AND.IM.NE.IM_OLD) THEN
                  IF(IM.EQ.1) THEN
                    WRITE(CR_LINE,'(A,I6,2X,3(F9.4,1X),3F8.3)') 
     *              '#MOLECULE',NCS_ID
     *       ,ANGLES_RESTR(1,IM),ANGLES_RESTR(2,IM),ANGLES_RESTR(3,IM)
     *       ,CENTRE_COM(1),CENTRE_COM(2),CENTRE_COM(3)
                  ELSE
              WRITE(CR_LINE,'(A,I6,2X,3(F9.4,1X))') '#MOLECULE',IM
     *       ,ANGLES_RESTR(1,IM),ANGLES_RESTR(2,IM),ANGLES_RESTR(3,IM)
                 ENDIF
                 CR_IGROUP = IM
                ELSE
                  WRITE(CR_LINE,'(A,I5)') '#DOMAIN',IMD
                ENDIF

                CR_LINE2 = ' '
                CALL WRCRD(M,IXYZB,MODE,IENDW,IERR)

              ENDIF

              CR_IGROUP = IM
              IM_OLD = IM

            ENDIF
            MODE = 0
            CR_XYZ(1) = X0(I,1)
            CR_XYZ(2) = X0(I,2)
            CR_XYZ(3) = X0(I,3)
            CR_BISO   = BFAC0(I)

            CALL WRCRD(M,IXYZB,MODE,IENDW,IERR)

          ELSE

            MODE = 1
            CALL WRCRD(M,IXYZB,MODE,IENDW,IERR)

          ENDIF
        ENDIF
      ENDDO
  300 CONTINUE

      IENDW = 1
      MODE  = 0
      CALL WRCRD(M,IXYZB,MODE,IENDW,IERR)
      CLOSE(IATMR)

      RETURN
      END


C ===================================
C----linalgebra_block
C Subroutines and functions to deal with problems of linear algebra
C
C  Strange eanough it begins with singular value decomposition.
C  But I need it now.
C
      SUBROUTINE SVDCMP_RBFFT(A,M,N,MP,NP,W,V,IERR)

C----This subroutine makes singular value decomposition
C----as   A = U.W.VT
C----See Press, Flannery, Teukolsky, Vettering  Numerical recipes
C----M and N are physical sizes of matrix MP and NP are logical
C---sizes. M >= N. Otherwise routine will fail
C---Note: Output is VT but not V
C---A will be destroyed and replaced by U
C
      PARAMETER (NMAX = 1000)
      REAL A(MP,NP),W(NP),V(NP,NP),RV1(NMAX)
      CHARACTER LINE*80,CHAR4*4
      DATA TOL/1.0E-7/
C ------------------------
C
C      IF(M.LT.N) CALL ERRWRT(1,'SVDMP: M Should be > N')
      IF(M.LT.N) THEN
C        CALL MSGERR(0,' ERROR in SVDMP: M Should be > N')
        MDOC = 0
        CALL MSGERR(MDOC,' ERROR in SVDMP(rbfft): M Should be > N')
        IERR=1
        RETURN
      ENDIF
      G     = 0.0
      SCALE = 0.0
      ANORM = 0.0
      NCONV = 100
      DO   I=1,N
        L      = I+1
        RV1(I) = SCALE*G
        G      = 0.0
        S      = 0.0
        SCALE  = 0.0
        IF(I.LE.M) THEN
          DO   K=I,M
            SCALE = SCALE+ABS(A(K,I))
          ENDDO
          IF(ABS(SCALE).GT.TOL) THEN
            DO    K=I,M
              A(K,I) = A(K,I)/SCALE
              S      = S + A(K,I)*A(K,I)
            ENDDO
            F = A(I,I)
            G = -SIGN(SQRT(S),F)
            H = F*G-S
            A(I,I) = F-G
            IF(I.NE.N) THEN
              DO   J=L,N
                S = 0.0
                DO   K=I,M
                  S = S+A(K,I)*A(K,J)
                ENDDO
                F = S/H
                DO    K=I,M
                  A(K,J) =A(K,J)+F*A(K,I)
                ENDDO
              ENDDO
            ENDIF
            DO   K=I,M
              A(K,I) = SCALE*A(K,I)
            ENDDO
          ENDIF
        ENDIF
        W(I)  = SCALE*G
        G     = 0.0
        S     = 0.0
        SCALE = 0.0
        IF((I.LE.M).AND.(I.NE.N)) THEN
          DO   K=L,N
            SCALE = SCALE+ABS(A(I,K))
          ENDDO
          IF(ABS(SCALE).GT.TOL) THEN
            DO   K=L,N
              A(I,K) = A(I,K)/SCALE
              S      = S + A(I,K)*A(I,K)
            ENDDO
            F = A(I,L)
            G = -SIGN(SQRT(S),F)
            H = F*G-S
            A(I,L) = F-G
            DO   K=L,N
              RV1(K) = A(I,K)/H
            ENDDO
            IF(I.NE.M) THEN
              DO   J=L,M
                S = 0.0
                DO   K=L,N
                  S = S+A(J,K)*A(I,K)
                ENDDO
                DO   K=L,N
                  A(J,K) = A(J,K)+S*RV1(K)
                ENDDO
              ENDDO
            ENDIF
            DO    K=L,N
              A(I,K) = SCALE*A(I,K)
            ENDDO
          ENDIF
        ENDIF
        ANORM = MAX(ANORM,(ABS(W(I))+ABS(RV1(I))))
      ENDDO
C
C Accumulation of right hand transformation
C
      DO   I=N,1,-1
        IF(I.LT.N) THEN
          IF(ABS(G).GT.TOL) THEN
            DO   J=L,N
C
C   Doulde division to avoid underflow (????
C
              V(J,I) = A(I,J)/A(I,L)/G
            ENDDO
            DO   J=L,N
              S = 0.0
              DO   K=L,N
                S = S+A(I,K)*V(K,J)
              ENDDO
              DO   K=L,N
                V(K,J) = V(K,J)+S*V(K,I)
              ENDDO
            ENDDO
          ENDIF
          DO   J=L,N
            V(I,J) = 0.0
            V(J,I) = 0.0
          ENDDO
        ENDIF
        V(I,I) = 1.0
        G      = RV1(I)
        L      = I
      ENDDO
C
C Accumulation of left hand transformation
C
      DO    I=N,1,-1
        L = I+1
        G = W(I)
        IF(I.LT.N) THEN
          DO  J=L,N
            A(I,J) = 0.0
          ENDDO
        ENDIF
        IF(ABS(G).GT.TOL) THEN
          G = 1.0/G
          IF(I.NE.N) THEN
            DO   J=L,N
              S = 0.0
              DO   K=L,M
                S=S+A(K,I)*A(K,J)
              ENDDO
              F = (S/A(I,I))*G
              DO    K=I,M
                A(K,J) = A(K,J)+F*A(K,I)
              ENDDO
            ENDDO
          ENDIF
          DO    J=I,M
            A(J,I) = A(J,I)*G
          ENDDO
        ELSE
          DO    J=I,M
            A(J,I) = 0.0
          ENDDO
        ENDIF
        A(I,I) = A(I,I)+1.0
      ENDDO
C
C  Diagonalisation fo bidiagonal form
C
      DO   K=N,1,-1
C
C  Loop over singular values
C
        DO   ITS=1,NCONV
C
C Loop over iteration. 
C
          DO    L=K,1,-1
C
C  Test for splitting
C
            NM = L-1
C            IF(ABS(RV1(L))+ANORM.EQ.ANORM) GOTO 2
C            IF(ABS(W(NM)) +ANORM.EQ.ANORM)  GOTO 1
            IF(ABS(RV1(L)).LT.TOL)  GOTO 2
            IF(ABS(W(NM)) .LT.TOL)  GOTO 1
          ENDDO
 1        C = 0.0
          S = 1.0
          DO   I=L,K
            F = S*RV1(I)  
C           IF(ABS(F)+ANORM.NE.ANORM) THEN
            IF(ABS(F).GT.TOL) THEN
              G = W(I)
              H = SQRT(F*F+G*G)
              W(I) = H
              H = 1.0/H
              C = G*H
              S = -F*H
              DO    J=1,M
                Y = A(J,NM)
                Z = A(J,I)
                A(J,NM) = Y*C+Z*S
                A(J,I)  = -Y*S+Z*C
              ENDDO
            ENDIF
          ENDDO
 2        Z = W(K)
          IF(L.EQ.K) THEN
            IF(Z.LT.0.0) THEN
              W(K) = -Z
              DO   J=1,N
                V(J,K) = -V(J,K)
              ENDDO
            ENDIF
            GOTO 3
          ENDIF
C          IF(ITS.EQ.30) 
C     .        CALL ERRWRT(-1,
C     .         'SVDCMP: No convergence in 30 iterations')
          IF(ITS.EQ.NCONV) THEN
            MDOC = 0
            WRITE(CHAR4,'(I4)') NCONV
            LINE = ' ERROR in SVDCMP(rbfft): No convergence in'
     *             //CHAR4//' iterations'
            CALL MSGERR(MDOC,LINE)
        LINE = '                         try to change resolution'
            CALL MSGERR(MDOC,LINE)
            IERR=2
            RETURN
          ENDIF
          X = W(L)
          NM= K-1
          Y = W(NM)
          G = RV1(NM)
          H = RV1(K)
          F = ((Y-Z)*(Y+Z)+(G-H)*(G+H))/(2.0*H*Y)
          G = SQRT(ABS(F*F+1.0))
          F = ((X-Z)*(X+Z)+H*((Y/(F+SIGN(G,F)))-H))/X
C
C  Next QR transformation
C
          C = 1.0
          S = 1.0
          DO   J=L,NM
            I = J+1
            G = RV1(I)
            Y = W(I)
            H = S*G
            G = C*G
            Z = SQRT(F*F+H*H)
            RV1(J) = Z
            C = F/Z
            S = H/Z
            F =  X*C+G*S
            G = -X*S+G*C
            H = Y*S
            Y = Y*C
            DO   JJ=1,N
              X = V(JJ,J)
              Z = V(JJ,I)
              V(JJ,J) =  X*C+Z*S
              V(JJ,I) = -X*S+Z*C
            ENDDO
            Z = SQRT(F*F+H*H)
            W(J) = Z
            IF(ABS(Z).GT.TOL) THEN
              Z = 1.0/Z
              C = F*Z
              S = H*Z
            ENDIF
            F =  C*G+S*Y
            X = -S*G+C*Y
            DO   JJ=1,M
              Y = A(JJ,J)
              Z = A(JJ,I)
              A(JJ,J) =   Y*C+Z*S
              A(JJ,I) =  -Y*S+Z*C
            ENDDO
          ENDDO
          RV1(L) = 0.0
          RV1(K) = F
          W(K)   = X
        ENDDO
 3      CONTINUE
      ENDDO
      RETURN
      END      
C
      SUBROUTINE SVBKSB_RBFFT(U,W,V,M,N,MP,NP,B,X)
C
C  Solves AX = B. A should be decomposed by SVDCMP subrouitne
C  A = U.W.VT
C
      PARAMETER (NMAX = 1000)
      REAL U(MP,NP),W(NP),V(NP,NP),B(NP),X(NP),TMP(NMAX)
      DATA TOL/1.0E-7/
C
C Calculate Ut.B
C
      DO   J=1,N
        S = 0.0
        IF(ABS(W(J)).GT.TOL) THEN
          DO   I=1,M
            S = S+U(I,J)*B(I)
          ENDDO
          S = S/W(J)
        ENDIF
        TMP(J) = S
      ENDDO
C
C Multiply by V to get answer
C
      DO   J=1,N
        S = 0.0
        DO   JJ=1,N
          S = S+V(J,JJ)*TMP(JJ)
        ENDDO
        X(J) = S
      ENDDO
      RETURN
      END
C
      SUBROUTINE SVSOLV_RBFFT(A,M,N,MP,NP,B,X,IERR)
C -------------------------------------------------
C
C   Solve Ax=B by calling singular value decomposition 
C   subroutines
C
C -------------------------------------------------
      INTEGER M,N,MP,NP,IERR
      REAL A(MP,NP),B(NP),X(NP)
      INTEGER NMAX,NMAX21
      PARAMETER (NMAX   = 1000)
      PARAMETER (NMAX21 = NMAX+NMAX*NMAX)      
      REAL WV(NMAX21)
      DATA TOL/1.0E-7/
C -------------------------------------------------
      IERR=0
C
C---First call SVDCMP to decompose A = U.W.Vt
C
      CALL SVDCMP_RBFFT(A,M,N,MP,NP,WV(1),WV(NMAX+1),IERR)
      IF(IERR.NE.0) RETURN
C  
C  Now edit W-s
C
      WMAX = 0.0
      DO    I=1,N
        IF(WMAX.LT.WV(I)) WMAX = WV(I)
      ENDDO
      WMIN = WMAX*TOL
      DO   I=1,N
        IF(WV(I).LT.WMIN) THEN
cd          WRITE(LINE,'(A,I5)')
cd     .      ' Singular values for parameter',I
cd          CALL ERRWRT(0,LINE)
          WV(I) = 0.0
        ENDIF
      ENDDO
C
C--Now call SVBKSB to solve equation
C
      CALL SVBKSB_RBFFT(A,WV(1),WV(NMAX+1),M,N,MP,NP,B,X)

      RETURN
      END
C
      SUBROUTINE SVDVAR_RBFFT(V,MA,W,CVM,NCVM)
C
C---Evaluation of covariance matrix after using singular
C---value decomposition. Parameters with singular contribution
C---to matrix will have 0.0 variance.
C
      PARAMETER (NMAX = 1000)
      REAL V(MA,MA),W(MA),CVM(NCVM,NCVM),WTI(NMAX)
      DATA TOL/1.0E-7/
C
      DO   I=1,MA
        WTI(I) = 0.0
        IF(ABS(W(I)).GT.TOL) WTI(I) = 1.0/(W(I)*W(I))
      ENDDO
      DO   I=1,MA
        DO   J=1,I
          SUM = 0.0
          DO    K=1,MA
            SUM = SUM + V(I,K)*V(J,K)*WTI(K)
          ENDDO
          CVM(I,J) = SUM
          CVM(J,I) = SUM
        ENDDO
      ENDDO
      RETURN
      END

      SUBROUTINE SGENGRD(MDOC,NAMEC,NAMED,NAMEM,NAMEO,NAMEE
     * ,P1R,POSIT,MODE,GRAD,BADDD,SCALEF,BADDF,DISPFR
     * ,RESULT,IPRROW,ISYM,IPRSYM,IERR)
C ----------------------------------------------------------
      REAL RESULT(IPRROW)
C ----------------------------------------------------------

      COMMON/CELL/ A,B,C,ALPHA,BETA,GAMMA,ISPHR,DLIM,HH2OBG,ICELL
     *             ,VOLUME,SSCALEF,GMODE,DMODE,POSITIV,P1
      CHARACTER GMODE*1,DMODE*1,POSITIV*1,P1*1
C ---
      COMMON/DIM/  DMAX,NX,NY,NZ,IZMIN,IZMAX,IHMAX,IKMAX,ILMAX
C ---------------------------------------
c      INTEGER   ICOORD(*)
c      INTEGER         IBFACT(NCOORM),IZMOCC(NCOORM)
c     *                ,IXC(NCOORM),IYC(NCOORM),IZC(NCOORM)
c     *                ,ISCODE(NCOORM),IANUMB(NCOORM),IRECRD(NCOORM)        

      integer,   allocatable :: IBFACT(:)
      integer,   allocatable :: IZMOCC(:)
      integer,   allocatable :: IXC(:)
      integer,   allocatable :: IYC(:)
      integer,   allocatable :: IZC(:)
      integer,   allocatable :: ISCODE(:)
      integer,   allocatable :: IANUMB(:)
      integer,   allocatable :: IRECRD(:)

C ---
c      REAL             GRADX(NCOORM),GRADY(NCOORM),GRADZ(NCOORM)
c     *                ,GRADB(NCOORM),GRADQ(NCOORM),GRADW(NCOORM)
c     *                ,SDENS1(NCOORM),SDENS2(NCOORM)
C     *                ,GHESSX(NCOORM),GHESSB(NCOORM)
     
      real,      allocatable :: GRADX(:)
      real,      allocatable :: GRADY(:)
      real,      allocatable :: GRADZ(:)
      real,      allocatable :: GRADB(:)
      real,      allocatable :: GRADQ(:)
      real,      allocatable :: GRADW(:)
      real,      allocatable :: SDENS1(:)
      real,      allocatable :: SDENS2(:)
      real,      allocatable :: GHESSX(:)
      real,      allocatable :: GHESSB(:)
C ---
C     REAL             X(IPRMAP)
C      INTEGER*2        X(IPRMAP)
C      INTEGER*2        DEN1(NXY,*),DEN2(NXY,*)

      integer*2,   allocatable :: DEN1(:,:)
      integer*2,   allocatable :: DEN2(:,:)

C --
      INTEGER*2        ISYM(5,3,IPRSYM)
C --------------------------------------------------------------
      CHARACTER NAMEC*(*),NAMED*(*),NAMEO*(*),TITLE*80,POSIT*1
      CHARACTER NAMEM*(*),LINE*80,STR*80,PATH*1,EXT*3,MODE*1,GRAD*1
      CHARACTER P1R*1,NAMEE*(*),TYPE*4
C==================================================================
      IERR=0
      MT  =10
      MD  =-ABS(MDOC)-1
      CALL ORCRD(MD,MT,NAMEC,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERR: OPEN COORD_FILE')
        GO TO 500
      ENDIF
      CALL C_AT_CR
      CLOSE(MT)
C -------------------------------------------
      MTIN =11
      TYPE = 'RI  '
      M    = 99
      CALL ORFILE(M,MTIN,NAMED,TYPE,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.GT.0) THEN
        IERR=1
        RETURN
      ENDIF
      CALL GET_TITLE(M,A,B,C,AL,BE,GA
     *        ,F1,F2,F3,F4,NX,NY,NZ,IZMIN,IZMAX,TITLE,IERR)
      CLOSE(MTIN)
      IF(IERR.GT.0) THEN
        IERR=2
        RETURN
      ENDIF

      NXY    = NX*NY
      NNZ    = IZMAX -IZMIN +1
      IPRMAP = NXY * NNZ

      IT = 0
      allocate(DEN1(1:NXY,1:NNZ),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(DEN2(1:NXY,1:NNZ),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      IF(IT.NE.0) THEN
        IERR = 1
        CALL MSGERR(MDOC,
     *    ' ERROR: in SGENGRD(DEN) : problem with memory allocation')
        CALL MSGERR(MDOC,
     *    '                          try to change resolution')
        RETURN
      ENDIF

      MT     =11
      ITYPE  =0
      CALL IRDENS(MT,NAMED,MDOC,ITYPE,ICNTZ,NX,NY,NZ,IZMAX,
     * IZMIN,RMAX,RMIN,DEN1,RSCALE1,A,B,C,ALPHA,BETA,GAMMA,DRMS,
     * RAVER,RESOL,IX0,IY0,IZ0,ITR,TITLE
     *   ,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        deallocate(DEN1,STAT=ISTAT)
        deallocate(DEN2,STAT=ISTAT)
        CALL MSGERR(MDOC,' ERR: OPEN FILE-DENS')
        CLOSE(MT)
        IERR=1
        RETURN
      ENDIF
      NXY=NX*NY
      IF(NXY.GT.IPRMAP) THEN
        deallocate(DEN1,STAT=ISTAT)
        deallocate(DEN2,STAT=ISTAT)
        CALL MSGERR(MDOC,' ERR: NOT MEMORY FOR DENSITY')
        CLOSE(MT)
        IERR=1
        RETURN
      ENDIF
      CLOSE(MT)
C -------------------------------------------
      MT     =12
      ITYPE  =0
      CALL IRDNS2(MT,NAMEM,MDOC,ITYPE,ICNTZ,NX,NY,NZ,IZMAX,
     *   IZMIN,RMAX,RMIN,DEN2,RSCALE2,A,B,C,AL,BE,GA,DRMS,
     *   RAVER,RESOL,IX0,IY0,IZ0,ITR,TITLE
     *     ,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        deallocate(DEN1,STAT=ISTAT)
        deallocate(DEN2,STAT=ISTAT)
        CALL MSGERR(MDOC,' ERR: OPEN MODEL_FILE-DENS')
        CLOSE(MT)
        IERR=1
        RETURN
      ENDIF
      CLOSE(MT)
C -------------------------------------------
      H2OBG=0.0
      IF(SCALEF.LE.0.0) SCALEF=1.0
      SSCALEF=SCALEF
      BADD=BADDD
      BADD=BADD+BADDF
      IF(BADD.LT.0.0) BADD=0.0
C -------------------------------------------

c      PRINTR='N'
      MODE  ='D'
      GRAD  ='G'
      POSIT ='N'

c      IF(PRINTR.EQ.'y') PRINTR='Y'
c      IF(PRINTR.NE.'Y') PRINTR='N'
      IF(MODE.EQ.'o') MODE='O'
      IF(MODE.NE.'O') MODE='D'
      IF(GRAD.EQ.'e') GRAD='E'
      IF(GRAD.EQ.'d') GRAD='D'
      IF(GRAD.NE.'E'.AND.GRAD.NE.'D') GRAD='G'
      IF(POSIT.EQ.'y') POSIT='Y'
      IF(POSIT.NE.'Y') POSIT='N'

      P1 = P1R

      IF(P1.EQ.'y') P1='Y'
      IF(P1.NE.'Y') P1='N'

      GMODE=GRAD
      DMODE=MODE
      POSITIV=POSIT
C      PRINT=PRINTR
C ---------------------------------------------
      DMAX=RESOL
      IF(DISPFR.LE.0.0) DISPFR=RESOL/3.0
C ------------------------------------------------
      ISPHR=0
      ICELL=0
      DLIM  = 2.8
      HH2OBG=H2OBG
      MD=-ABS(MDOC)-1
      WRITE(LINE,*) ' DENSITY OF SOLVENT :',HH2OBG
      CALL MSGDOC(MD,LINE)
C --------------------------------------
      MEM_TEST = 1
      NCOORM = 100
      allocate(IBFACT(1:NCOORM),STAT=ISTAT)
      allocate(IZMOCC(1:NCOORM),STAT=ISTAT)
      allocate(IXC(1:NCOORM),STAT=ISTAT)
      allocate(IYC(1:NCOORM),STAT=ISTAT)
      allocate(IZC(1:NCOORM),STAT=ISTAT)
      allocate(ISCODE(1:NCOORM),STAT=ISTAT)
      allocate(IANUMB(1:NCOORM),STAT=ISTAT)
      allocate(IRECRD(1:NCOORM),STAT=ISTAT)
      allocate(GRADX(1:NCOORM),STAT=ISTAT)
      allocate(GRADY(1:NCOORM),STAT=ISTAT)
      allocate(GRADZ(1:NCOORM),STAT=ISTAT)
      allocate(GRADB(1:NCOORM),STAT=ISTAT)
      allocate(GRADQ(1:NCOORM),STAT=ISTAT)
      allocate(GRADW(1:NCOORM),STAT=ISTAT)
      allocate(SDENS1(1:NCOORM),STAT=ISTAT)
      allocate(SDENS2(1:NCOORM),STAT=ISTAT)
      allocate(GHESSX(1:NCOORM),STAT=ISTAT)
      allocate(GHESSB(1:NCOORM),STAT=ISTAT)
      CALL ATSORTG(MDOC,NAMEC,BAVER,BMAX,BMIN,BAVERW,BAVERF,BADD
     *  ,NEL,SUMFI2
     *  ,NCOORD,NCOORM,IBFACT,IZMOCC,IXC,IYC,IZC,ISCODE,IANUMB
     *  ,IRECRD,GRADX,GRADY,GRADZ,GRADB,GRADQ,GRADW,SDENS1,SDENS2
     *  ,NSYM,ISYM,IPRSYM,MEM_TEST,IERR)
      IF(IERR.GT.0) GO TO 500

      deallocate(IBFACT,STAT=ISTAT)
      deallocate(IZMOCC,STAT=ISTAT)
      deallocate(IXC,STAT=ISTAT)
      deallocate(IYC,STAT=ISTAT)
      deallocate(IZC,STAT=ISTAT)
      deallocate(ISCODE,STAT=ISTAT)
      deallocate(IANUMB,STAT=ISTAT)
      deallocate(IRECRD,STAT=ISTAT)
      deallocate(GRADX,STAT=ISTAT)
      deallocate(GRADY,STAT=ISTAT)
      deallocate(GRADZ,STAT=ISTAT)
      deallocate(GRADB,STAT=ISTAT)
      deallocate(GRADQ,STAT=ISTAT)
      deallocate(GRADW,STAT=ISTAT)
      deallocate(SDENS1,STAT=ISTAT)
      deallocate(SDENS2,STAT=ISTAT)
      deallocate(GHESSX,STAT=ISTAT)
      deallocate(GHESSB,STAT=ISTAT)

      MEM_TEST = 0
      NCOORM = NCOORD
      IT = 0
      allocate(IBFACT(1:NCOORM),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(IZMOCC(1:NCOORM),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(IXC(1:NCOORM),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(IYC(1:NCOORM),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(IZC(1:NCOORM),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(ISCODE(1:NCOORM),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(IANUMB(1:NCOORM),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(IRECRD(1:NCOORM),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(GRADX(1:NCOORM),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(GRADY(1:NCOORM),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(GRADZ(1:NCOORM),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(GRADB(1:NCOORM),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(GRADQ(1:NCOORM),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(GRADW(1:NCOORM),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(SDENS1(1:NCOORM),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(SDENS2(1:NCOORM),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(GHESSX(1:NCOORM),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      allocate(GHESSB(1:NCOORM),STAT=ISTAT)
      IT = IT + ABS(ISTAT)
      IF(IT.NE.0) THEN
        IERR = 1
        CALL MSGERR(MDOC,
     *    ' ERROR: in SGENGRD : problem with memory allocation')
        CALL MSGERR(MDOC,
     *    '                     try to change resolution')
        RETURN
      ENDIF
      CALL ATSORTG(MDOC,NAMEC,BAVER,BMAX,BMIN,BAVERW,BAVERF,BADD
     *  ,NEL,SUMFI2
     *  ,NCOORD,NCOORM,IBFACT,IZMOCC,IXC,IYC,IZC,ISCODE,IANUMB
     *  ,IRECRD,GRADX,GRADY,GRADZ,GRADB,GRADQ,GRADW,SDENS1,SDENS2
     *  ,NSYM,ISYM,IPRSYM,MEM_TEST,IERR)
      IF(IERR.GT.0) GO TO 500
      WRITE(LINE,*) 'ADDITIONAL B-FACTOR :',BADD
      CALL MSGDOC(MDOC,LINE)
C ---------------------------------------
      CALL ATMDENG(MDOC,NAMED,NAMEM,BADD,DEN1,DEN2,NXY,IPRMAP
     *  ,NCOORD,NCOORM,IBFACT,IZMOCC,IXC,IYC,IZC,ISCODE,IANUMB
     *  ,IRECRD,GRADX,GRADY,GRADZ,GRADB,GRADQ,GRADW
     *  ,SDENS1,SDENS2
     *  ,SUMDEN,NEL,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) GO TO 500
C ---------------------------------------
      CALL HESS_X(MDOC,BADD
     * ,NCOORD,NCOORM,IBFACT,IZMOCC,IXC,IYC,IZC,ISCODE,IANUMB
     * ,IRECRD,GRADX,GRADY,GRADZ,GRADB,GRADQ,GRADW,GHESSX,GHESSB
     * ,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.GT.0) THEN
        GO TO 500
      ENDIF
C ---------------------------------------
C      CALL HESS_B(MDOC,BADD
C     *  ,NCOORD,NCOORM
C     *  ,ICOORD(1),ICOORD(NCOORM+1),ICOORD(2*NCOORM+1)
C     *  ,ICOORD(3*NCOORM+1),ICOORD(4*NCOORM+1)
C     *  ,ICOORD(5*NCOORM+1),ICOORD(6*NCOORM+1),ICOORD(7*NCOORM+1)
C     *  ,ICOORD(8*NCOORM+1),ICOORD(9*NCOORM+1)
C     *  ,ICOORD(10*NCOORM+1),ICOORD(11*NCOORM+1)
C     *  ,ICOORD(12*NCOORM+1),ICOORD(13*NCOORM+1)
C     *  ,ICOORD(14*NCOORM+1),ICOORD(15*NCOORM+1)
C     *  ,NSYM,ISYM,IPRSYM,IERR)
C
C      IF(IERR.GT.0) THEN
C        GO TO 500
C      ENDIF
C ---------------------------------------
      CALL SORT_BACKG(MDOC,NAMEC,NAMEO,NAMEE
     * ,NCOORD,NCOORM,IBFACT,IZMOCC,IXC,IYC,IZC,ISCODE,IANUMB
     * ,IRECRD,GRADX,GRADY,GRADZ,GRADB,GRADQ,GRADW,GHESSX,GHESSB
     * ,SDENS1,SDENS2,NX,NY,NZ,NSYM,ISYM,DISPFR,RESULT,IERR)
      IF(IERR.NE.0) GO TO 500
C ---------------------------------------

      H2OBG=HH2OBG
      RAD=DLIM
      RESULT(6)  =BADD

 510  CONTINUE

      deallocate(DEN1,STAT=ISTAT)
      deallocate(DEN2,STAT=ISTAT)
      deallocate(IBFACT,STAT=ISTAT)
      deallocate(IZMOCC,STAT=ISTAT)
      deallocate(IXC,STAT=ISTAT)
      deallocate(IYC,STAT=ISTAT)
      deallocate(IZC,STAT=ISTAT)
      deallocate(ISCODE,STAT=ISTAT)
      deallocate(IANUMB,STAT=ISTAT)
      deallocate(IRECRD,STAT=ISTAT)
      deallocate(GRADX,STAT=ISTAT)
      deallocate(GRADY,STAT=ISTAT)
      deallocate(GRADZ,STAT=ISTAT)
      deallocate(GRADB,STAT=ISTAT)
      deallocate(GRADQ,STAT=ISTAT)
      deallocate(GRADW,STAT=ISTAT)
      deallocate(SDENS1,STAT=ISTAT)
      deallocate(SDENS2,STAT=ISTAT)
      deallocate(GHESSX,STAT=ISTAT)
      deallocate(GHESSB,STAT=ISTAT)

      RETURN
 500  CONTINUE
      IERR=1
      GO TO 510
      END

      SUBROUTINE ATMDENG(MDOC,NAMED,NAMEM,BADD,DEN1,DEN2,NXY,ISIZE
     *  ,NCOORD,NCOORM,IBFACT,IZMOCC,IXC,IYC,IZC,ISCODE,IANUMB
     *  ,IRECRD,GRADX,GRADY,GRADZ,GRADB,GRADQ,GRADW
     *  ,SDENS1,SDENS2
     *  ,SUMD,NEL,NSYM,ISYM,IPRSYM,IERR)
C -----------------------------------------------------
      INTEGER*2        DEN1(NXY,*),DEN2(NXY,*)
      INTEGER         IBFACT(NCOORM),IZMOCC(NCOORM)
     *                ,IXC(NCOORM),IYC(NCOORM),IZC(NCOORM)
     *                ,ISCODE(NCOORM),IANUMB(NCOORM),IRECRD(NCOORM)
C ---
      REAL             GRADX(NCOORM),GRADY(NCOORM),GRADZ(NCOORM)
     *                ,GRADB(NCOORM),GRADQ(NCOORM),GRADW(NCOORM)
     *                ,SDENS1(NCOORM),SDENS2(NCOORM)
      INTEGER          NCOORD,NCOORM
      CHARACTER        NAMED*(*),NAMEM*(*)
      INTEGER*2        ISYM(5,3,IPRSYM)
      INTEGER*4        NSYM,IPRSYM
C --------------------------------------
      COMMON/COMINF/ NDENSP,NDENSM,NZERO,SUMRP,SUMRM,SD1T,SD2T,CFVOL
     *               ,DOBS_AV,DMOD_AV,SCALED,SIGMA,SIGMAD,SDIFFT
      COMMON/CELL/   A,B,C,ALPHA,BETA,GAMMA,ISPHR,DLIM,H2OBG,ICELL
     *             ,VOLUME,SCALEF,GMODE,DMODE,POSITIV,P1
      CHARACTER     GMODE*1,DMODE*1,POSITIV*1,P1*1
      COMMON/DIM/    DMAX,NX,NY,NZ,IZMIN,IZMAX,IHMAX,IKMAX,ILMAX
      PARAMETER ( MAXSCALE  = 1000)
      COMMON/COM_RSCL/ RSCALE1(MAXSCALE),RSCALE2(MAXSCALE)
C --------------------------------------
      CHARACTER LINE*80,TITLE*80,TITLEM*80
      CHARACTER TYPE*4
      REAL      XS(3),XT(3),AX(3)
      EQUIVALENCE (X,XS(1)),(Y,XS(2)),(Z,XS(3))
C-----------------------------------------------
      MD    =-ABS(MDOC)-1
      IERR  = 0
      MT    = 11
      M     = 99
      ITYPE =0
      CALL IRDENS(MT,NAMED,MD,ITYPE,ICNTZ,NX,NY,NZ,IZMAX,
     * IZMIN,RMAX,RMIN,DEN1,RSCALE1(1),A,B,C,AL,BE,GA,DRMS,
     * RAVER,RESOL,IX0,IY0,IZ0,ITR,TITLE
     *   ,NS,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERR: OPEN DENS-FILE')
        CLOSE(MT)
        IERR=1
        RETURN
      ENDIF
C ---
      MTM    = 12
      M      = 99
      ITYPEM = 0
      CALL IRDNS2(MTM,NAMEM,MD,ITYPEM,ICNTZM,NXM,NYM,NZM,IZMAXM,
     *   IZMINM,RMAXM,RMINM,DEN2,RSCALE2(1),A,B,C,AL,BE,GA,DRMSM,
     *   RAVERM,RESOLM,IX0,IY0,IZ0,ITR,TITLEM
     *     ,NS,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERR: OPEN MODEL-DENS-FILE')
        CLOSE(MTM)
        IERR=1
        RETURN
      ENDIF
C ----------------------------------------------
      ICNTZ  =-999
      ICNTZM =-999
C ----
      SD1T  =0.0
      SD2T  =0.0
      SD1T2 =0.0
      SD2T2 =0.0
      SD12T =0.0
      SDIF2T=0.0
      SDIFFT=0.0
      S=(ALPHA+BETA+GAMMA)*0.5
      VOL=2.0*A*B*C*
     *    SQRT(SIN(S)*SIN(S-ALPHA)*SIN(S-BETA)*SIN(S-GAMMA))
      COEF=(VOL)/(FLOAT(NX)*FLOAT(NY)*FLOAT(NZ))
      VOLUME=VOL
C ---------------------------------------------------
      NUMB  =0
      SUMRP =0.
      SUMRM =0.
      NDENSP=0
      NDENSM=0
      NZERO =0
      IZ000 =0

      DOBS_AV=RAVER
      DMOD_AV=RAVERM
C -----------------------------------------------------
      IP1  =ISIZE/NXY
      IR   =IZMIN
      IREND=IZMAX
C -----------------------------------------------------
C     RESOL=DMAX
      N1=NX
      N2=NY
      ITYPE =-1
      ITYPEM=-1
      NXY=NX*NY

100   CONTINUE
      IF(IR+IP1.GT.IREND) IP1 =IREND-IR+1
      N3=IP1

      DO     K=1,N3

        CALL IRDENS(MT,NAMED,MD,ITYPE,ICNTZ,NX,NY,NZ,IZMX
     *  ,IZMN,RMAX,RMIN,DEN1(1,K),RSCALE1(K),A,B,C,AL,BE,GA,DRMS
     *  ,RAVER,RESOL,IX0,IY0,IZ0,ITR,TITLE
     *   ,NS,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MDOC,' ERR: READ FILE-DENS')
          IERR=1
          CLOSE(MT)
          CLOSE(MTM)
          RETURN
        ENDIF

        IF(MTM.GT.0) THEN
          CALL IRDNS2(MTM,NAMEM,MD,ITYPEM,ICNTZM,NXM,NYM,NZM,IZMAXM,
     *    IZMINM,RMAXM,RMINM,DEN2(1,K),RSCALE2(K),A,B,C,AL,BE,GA,
     *    DRMSM,RAVERM,RESOLM,IX0,IY0,IZ0,ITR,TITLEM
     *    ,NS,ISYM,IPRSYM,IERR)
          IF(IERR.NE.0) THEN
            CALL MSGERR(MDOC,' ERR: READ FILE-MODEL-DENS')
            CLOSE(MTM)
            CLOSE(MT)
            IERR=1
            RETURN
          ENDIF
        ENDIF



      ENDDO
C ---
      DO     IZR=1,N3
        IZ=IR+IZR-1
        Z=IZ/FLOAT(NZ)
        DO     IY=1,NY
          Y=(IY-1)/FLOAT(NY)
          IND0 =(IY-1)*NX
          DO     IX=1,NX
            X=(IX-1)/FLOAT(NX)
            IND =IND0+IX
            D1=DEN1(IND,IZR)/RSCALE1(IZR)
            D2=DEN2(IND,IZR)/RSCALE2(IZR)
            IF(POSITIV.EQ.'Y') THEN
              IF(D1.LT.0.0) D1=0.0
              IF(D2.LT.0.0) D2=0.0
            ENDIF
            IT=1
            NN=1
            DO     I=2,NSYM
              DO     J=1,3
                IF(ISYM(5,J,I).EQ. 0) ISYM(5,J,I)=1
                XT(J)=ISYM(4,J,I)/REAL(ISYM(5,J,I))
                DO     K=1,3
                  XT(J)=XT(J)+ISYM(K,J,I)*XS(K)
                ENDDO
              ENDDO
              DO     J=1,3
                T=ABS(XT(J))
                IAX=T
                AX(J)=T-IAX
                IF(XT(J).LT.0) AX(J)=1.-AX(J)
                IF(AX(J).GE.1.0) AX(J)=0.
                AX(J)=XS(J)-AX(J)
                IF(ABS(AX(J)).LT.1.E-5) AX(J)=0.
              ENDDO

C              IF(AX(3)) 160,150,140
C 150          IF(AX(2)) 160,151,140
C 151          IF(AX(1)) 160,152,140

              IF(AX(3).LT.0.0) GO TO 160
              IF(AX(3).EQ.0.0) GO TO 150
              IF(AX(3).GT.0.0) GO TO 140
 150          IF(AX(2).LT.0.0) GO TO 160
              IF(AX(2).EQ.0.0) GO TO 151
              IF(AX(2).GT.0.0) GO TO 140
 151          IF(AX(1).LT.0.0) GO TO 160
              IF(AX(1).EQ.0.0) GO TO 152
              IF(AX(1).GT.0.0) GO TO 140

 152          CONTINUE
              NN=NN+1
              GO TO 160
 140          CONTINUE
              IT=0
              GO TO 170
 160          CONTINUE
            ENDDO
 170        CONTINUE
            IF(IT.GE.1) THEN
              NUMB=NUMB+1
              D1=D1/FLOAT(NN)
              D2=D2/FLOAT(NN)

              SD1T =SD1T +D1
              SD2T =SD2T +D2
              SD1T2=SD1T2+D1*D1
              SD2T2=SD2T2+D2*D2
              SD12T=SD12T+D1*D2
              SDIF2T=SDIF2T+(D1-D2)*(D1-D2)
              SDIFFT=SDIFFT+ABS(D1-D2)
              IDNS1=D1*RSCALE1(IZR)
              IF(IDNS1.LE.-32766) THEN
                IDNS1=-32765
              ENDIF
              DEN1(IND,IZR)=IDNS1
              DEN2(IND,IZR)=D2*RSCALE2(IZR)
            ELSE
              DEN1(IND,IZR)=-32766
              DEN2(IND,IZR)= 0
            ENDIF
          ENDDO
        ENDDO
      ENDDO
C ---
      CALL GETDENG(MDOC,DEN1,DEN2,N1,N2,N3,IR,IZ000,BADD
     *   ,NCOORD,NCOORM,IBFACT,IZMOCC,IXC,IYC,IZC,ISCODE,IANUMB
     *   ,IRECRD,GRADX,GRADY,GRADZ,GRADB,GRADQ,GRADW
     *   ,SDENS1,SDENS2
     *   ,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.GT.0) THEN
        CLOSE(MT)
        CLOSE(MTM)
        RETURN
      ENDIF

      IR=IR+IP1
      IF(IR.LE.IREND) GO TO 100
C-----------------------------------------------------
      SCALED=0.0
      CFVOL=(VOL*NUMB)/(NX*NY*NZ)
      RCORR=0.0
      CALL MSGDOC(MDOC,' D_corr / for density map / = ')
      CALL MSGDOC(MDOC,
     * '(<R1*R2>-<R1><R2>)/SQRT((<R1**2>-<R1>**2)*(<R2**2>-<R2>**2))')
C        WRITE(*,*) SD12T,SD1T2,SD2T2,SD1T,SD2T,coef,cfvol

      IF(NUMB.GT.0) THEN

        SD1T =SD1T   *COEF
        SD2T =SD2T   *COEF
        SD12T=SD12T  *COEF

        SD1T =SD1T   /CFVOL
        SD2T =SD2T   /CFVOL
        SD12T=SD12T  /CFVOL

        SDIFFT=SDIFFT *COEF
        SDIF2T=SDIF2T *COEF
        SD1T2 =SD1T2  *COEF
        SD2T2 =SD2T2  *COEF

        SDIFFT=SDIFFT /CFVOL
        SDIF2T=SDIF2T /CFVOL
        SD1T2 =SD1T2  /CFVOL
        SD2T2 =SD2T2  /CFVOL

        IF(SDIF2T.GT.0.0) THEN
          SIG_DIF=SQRT(ABS(SDIF2T))
        ELSE
          SIG_DIF=0.0
        ENDIF

        SIGMAD=SIG_DIF
        SIGMA=0.0
        IF(SD2T2.GT.0.0000001) THEN
          SCALED=SQRT(ABS(SD1T2/SD2T2))
          SC1=SQRT(ABS(SD1T2))
          SC2=SQRT(ABS(SD2T2))
          SIGMA=SC1
        ELSE
          SCALED=0.0
        ENDIF

        DMOD1=SQRT(ABS(SD1T2-SD1T*SD1T))
        DMOD2=SQRT(ABS(SD2T2-SD2T*SD2T))
        TEMP1=(SD12T-SD1T*SD2T)
        TEMP=DMOD1*DMOD2
        IF(TEMP.GT.0.0000001) THEN
          RCORR=TEMP1/TEMP
        ELSE
          RCORR=0.0
        ENDIF
      ENDIF

      WRITE(LINE,'('' D_corr:'',F8.3)') RCORR
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,'('' <Dobs>,<Dmod>,scale:'',3F8.3)') SD1T,SD2T,SCALED
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,'('' SIG_1,2,DIF:'',3F8.3)') SC1,SC2,SIG_DIF
      CALL MSGDOC(MDOC,LINE)

      CLOSE(MT)
      CLOSE(MTM)

      RETURN
      END

      SUBROUTINE ATSORTG(MDOC,NAME,BAVER,BPEAK,BMIN,BAVERW,BAVERF
     *  ,BADD,NEL,SUMFI2
     *  ,NCOORD,NCOORM,IBFACT,IZMOCC,IXC,IYC,IZC,ISCODE,IANUMB
     *  ,IRECRD,GRADX,GRADY,GRADZ,GRADB,GRADQ,GRADW,SDENS1,SDENS2
     *  ,NSYM,ISYM,IPRSYM,MEM_TEST,IERR)
C -------------------------
      INTEGER   MDOC,IERR
      CHARACTER NAME*(*),NCS_FLAG*1
      INTEGER   IPRSYM
      INTEGER*2 ISYM(5,3,IPRSYM)
      INTEGER         IBFACT(NCOORM),IZMOCC(NCOORM)
     *                ,IXC(NCOORM),IYC(NCOORM),IZC(NCOORM)
     *                ,ISCODE(NCOORM),IANUMB(NCOORM),IRECRD(NCOORM)        
C ---
      REAL             GRADX(NCOORM),GRADY(NCOORM),GRADZ(NCOORM)
     *                ,GRADB(NCOORM),GRADQ(NCOORM),GRADW(NCOORM)
     *                ,SDENS1(NCOORM),SDENS2(NCOORM)
      INTEGER          NCOORD,NCOORM
C ---
C ------------------------------------------------------------
      INCLUDE 'mr_crd_com.fh'
C -------------------------------------------------
      PARAMETER (NFMMAX=15)
      COMMON/FORMS_FFT/   NFMFC,IZFMFC(15),FMFCA(5,15),
     *                FMFCB(5,15),HESS_A(15),CATOM
      CHARACTER       CATOM(15)*2
C ---
      COMMON/DIM/    DMAX,NX,NY,NZ,IZMIN,IZMAX,IHMAX,IKMAX,ILMAX
      COMMON/CELL/   A,B,C,ALPHA,BETA,GAMMA,ISPHR,DLIM,H2OBG,ICELL
     *             ,VOLUME,SCALEF,GMODE,DMODE,POSITIV,P1
      CHARACTER     GMODE*1,DMODE*1,POSITIV*1,P1*1
C -----------------------------------------------------------------
      INTEGER     NCSOP
      REAL        AMNCS(3,3),TRNCS(3)
C------------------------------------------------------------------
      REAL        XA(3),YA(3),XSU(3),XFU(3)
      REAL        TRNS(3,2),XS(3),XF(3),Y(3)
      INTEGER     IPOINT(3)
C----------------------------------------------------------------
      INTEGER     MODE
      REAL        FRTOCR(3,3),CRTOFR(3,3)
      REAL        ROT(9),TR(3)
      CHARACTER   ATOM*4,CHAR4*4,CHAR2*2,RES3*3
      CHARACTER   STR*80,NCSF*1,GID*4
C==================================================================
      ICOUNT= 0
      NONH  = 0
      NEL   = 0
      SUMFI2= 0
      NFMFC = 0
C      P1='N'
C --- integer*2 version
C     IPACK =10000
C --- integer*4 version
      IPACK =100000
C ---
      IERR  = 0
      NIN   = 10
      M     = 99
      MD    = -ABS(MDOC)-1
C --------
      CALL ORCRD(MD,NIN,NAME,NSYM_R,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) RETURN

      NSYM =NSYM_R

      IF(P1.EQ.'Y') NSYM=1

      A     = CR_CELL(1)
      B     = CR_CELL(2)
      C     = CR_CELL(3)
      ALPHA = CR_CELL(4)
      BETA  = CR_CELL(5)
      GAMMA = CR_CELL(6)
      CALL FRORTH(CR_CELL(1),CR_CELL(2),CR_CELL(3)
     *           ,CR_CELL(4),CR_CELL(5),CR_CELL(6)
     *                            ,FRTOCR,CRTOFR,IERR)
C -----------------------------------------
      NCRSYM=0
      NCS_FLAG='N'
      NCSOP=0
      CALL GET_NCS(MDOC,NCMAX,NCSOP,AMNCS,TRNCS,IERR)
      IF(IERR.NE.0) RETURN      
      IF(NCSOP.GT.0) THEN
        IGR=0
        CALL GET_ASYMM(MDOC,NASMAX,NGR,ICHOLD,IGR,ICH,INC,MLT
     *                 ,IGOLD,NCSF,GID,IERR)
        IF(IERR.NE.0) THEN
          WRITE(STR,
     *    '('' ERR: wrong NCS description'')') 
          CALL MSGERR(MDOC,STR)
          RETURN
        ENDIF
        IF(NGR.GT.0) THEN
          DO IGR=1,NGR
            CALL GET_ASYMM(MDOC,NASMAX,NGR,ICHOLD,IGR,ICH,INC,MLT
     *                    ,IGOLD,NCSF,GID,IERR)
            IF(IERR.NE.0) THEN
              WRITE(STR,
     *        '('' ERR: wrong NCS description'')') 
              CALL MSGERR(MDOC,STR)
              RETURN
            ENDIF
            IF(NCSF.EQ.'N'.OR.NCSF.EQ.'n') THEN
              NCS_FLAG='Y'
              GO TO 520
            ENDIF
          ENDDO
        ENDIF
      ENDIF
 520  CONTINUE
      IF(NCS_FLAG.EQ.'Y') THEN
        WRITE(STR,
     *  '(''NUMBER OPERATORS OF NON-CRYST.SYMMETRY:'',I5)') NCSOP
        CALL MSGDOC(MDOC,STR)
        IF(NCSOP.GT.0) THEN
          CALL MSGDOC(MD,' ')
          CALL MSGDOC(MD,'  X-NEW           X-0      TX')
          CALL MSGDOC(MD,'  Y-NEW  = [M] *  Y-0  +   TY')
          CALL MSGDOC(MD,'  Z-NEW           Z-0      TZ')
          CALL MSGDOC(MD,' ')
          CALL MSGDOC(MD,' ORTOGONAL COORDINATE SYSTEM')
          CALL MSGDOC(MD,'  COORDINATES IN ANGSTROMS')
          CALL MSGDOC(MD,' ')
          DO     I=1,NCSOP
            CALL GET_NCS(MD,NCMAX,I,AMNCS,TRNCS,IERR)
            IF(IERR.NE.0) THEN
              WRITE(STR,
     *        '('' ERR: wrong NCS description'')') 
              CALL MSGERR(MDOC,STR)
              RETURN
            ENDIF
            WRITE(STR,500) I
            CALL MSGDOC(MD,STR)
  500       FORMAT('  OPERATORS OF NON-CRYST.SYMMETRY :',I5)
            CALL ANGFIX(MD,AMNCS,ALPH,BET,GAMM)
            WRITE(STR,510) (TRNCS(L),L=1,3)
            CALL MSGDOC(MD,STR)
  510       FORMAT(' TRANSLATION VECTOR :',3F10.5,' /ANGSTROM/')
          ENDDO
        ELSE
          WRITE(STR,
     *    '('' ERR: NUMBER OF NCS-OPERATORS:'',I5)') NCSOP
          CALL MSGERR(MDOC,STR)
          IERR=1
          RETURN
        ENDIF
      ENDIF
C--------------------------------------------------
      DLM=DLIM+0.5
      XS(1) =0.
      XS(2) =0.
      XS(3) =0.
      XF(1) =1.
      XF(2) =1.
      XF(3) =1.

      ZFFS  =FLOAT(IZMIN)/FLOAT(NZ)-DLM/C
      ZFFF  =FLOAT(IZMAX)/FLOAT(NZ)+DLM/C

      XSU(1)=DLM/A
      XSU(2)=DLM/B
      XSU(3)=DLM/C
      XFU(1)=1.-DLM/A
      XFU(2)=1.-DLM/B
      XFU(3)=1.-DLM/C
C
      BAVER  = 0.0
      BMIN   = 1.E30
      BPEAK  =-1.E30
      BAVERW = 0.0 
      BAVERF = 0.0
      MATOMW =0
      NINALL =0
      IATT   =0
      IAT_IN =0
      I      =0
      NSUME  =0.
      NCRSYM =0
      SCHRG=0.0
      CHRGP=0.0
      CHRGM=0.0
      D1=0.0
      D2=0.0
      D3=0.25/(DMAX*DMAX)
C ===========================================
      IEND=-1
1100  CONTINUE

        IF(NCS_FLAG.EQ.'Y'.AND.NCRSYM.GT.NCSOP) NCRSYM=0

        IF(NCRSYM.NE.0) THEN


        ELSE

          MODE = 0
          CALL RDCRD(M,NIN,MODE,IEND,IERR)
          IF(IERR.EQ.1) RETURN


          IF(IEND.NE.0) GO TO 2000
          IF(MODE.GT.0) GO TO 1000    

          IF(CR_ATYPE.NE.'.'.AND.CR_ATYPE.NE.' '.AND.
     *       CR_ATYPE.NE.'y'.AND.CR_ATYPE.NE.'Y'.AND.
     *       CR_ATYPE.NE.'r'.AND.CR_ATYPE.NE.'R')
     *    GO TO 1000
          IAT_IN=IAT_IN+1
        ENDIF
C--------------------------------------------------------

        ATOM=CR_ANAME
        IRES=CR_IRES
        RES3=CR_RNAME
        OCC =CR_OCC
        BT  =CR_BISO

        ISERIAL=CR_IATOM

        IF(CR_MULT_FACTOR.GT.1) THEN
          OCC = OCC / FLOAT(CR_MULT_FACTOR)
        ENDIF
        RVDW = 1.5
C--------------------------------------------------------
        XA(1)=CR_XYZ(1)
        XA(2)=CR_XYZ(2)
        XA(3)=CR_XYZ(3)
        INC=0
        IF(NCS_FLAG.EQ.'Y') THEN

          IF(NCRSYM.EQ.0) THEN
            IGR_OLD=CR_IGROUP
            DO IGR=1,NGR
              CALL GET_ASYMM(MDOC,NASMAX,NGR,ICHOLD,IGR,ICH,INC,MLT
     *                     ,IGOLD,NCSF,GID,IERR)
              IF(IERR.NE.0) THEN
                WRITE(STR,
     *          '('' ERR: wrong NCS description'')') 
                CALL MSGERR(MDOC,STR)
                RETURN
              ENDIF
              IF(IGOLD.EQ.IGR_OLD.AND.INC.EQ.0) GO TO 410
            ENDDO
            WRITE(STR,
     *      '('' ERR: wrong NCS description'')') 
            CALL MSGERR(MDOC,STR)
            IERR=1
            RETURN

 410        CONTINUE
            ICHAIN=ICHOLD
            NCRSYM=1
          ELSE
            DO IGR=1,NGR
              CALL GET_ASYMM(MDOC,NASMAX,NGR,ICHOLD,IGR,ICH,INC,MLT
     *                      ,IGOLD,NCSF,GID,IERR)
              IF(IERR.NE.0) THEN
                WRITE(STR,
     *          '('' ERR: wrong NCS description'')') 
                CALL MSGERR(MDOC,STR)
                RETURN
              ENDIF
              IF((NCSF.EQ.'N'.OR.NCSF.EQ.'n').AND.
     *           INC.EQ.NCRSYM.AND.ICHOLD.EQ.ICHAIN) GO TO 530
            ENDDO
            NCRSYM=NCRSYM+1
            GO TO 1000  

 530        CONTINUE
            CALL GET_NCS(MDOC,NCMAX,INC,AMNCS,TRNCS,IERR)
            IF(IERR.NE.0) THEN
              WRITE(STR,
     *        '('' ERR: wrong NCS description'')') 
              CALL MSGERR(MDOC,STR)
              RETURN
            ENDIF      
            CALL MVMULT(AMNCS,CR_XYZ,XA)
            XA(1)=XA(1)+TRNCS(1)
            XA(2)=XA(2)+TRNCS(2)
            XA(3)=XA(3)+TRNCS(3)
            NCRSYM=NCRSYM+1
          ENDIF
        ENDIF

        CALL MVMULT(CRTOFR,XA,YA)

        XA(1)=YA(1)
        XA(2)=YA(2)
        XA(3)=YA(3)

C --------------------------------------------------------
        IZZ=1
        CHAR2=CR_ASYMB(1:2)
        CHAR4=CR_ASYMB
 610    CONTINUE
        IF(NFMFC.GT.0) THEN
          DO IM=1,NFMFC
            IF(CHAR2.EQ.CATOM(IM)) THEN
              IZZ=IM
              IZE=IZFMFC(IZZ)
              GO TO 600
            ENDIF
          ENDDO
        ENDIF
        CALL GET_SFA(CHAR4
     *      ,N,NELC,A1,A2,A3,A4,B1,B2,B3,B4,CC,FI,FII,RAD,IERR)
        IF(IERR.NE.0.OR.NFMFC.GE.NFMMAX) THEN
          IF(IERR.NE.0) THEN
            IF(ICOUNT.LT.4) THEN
              WRITE(STR,*) ' ERR: atom"s type "',CHAR4,'" not found'
              CALL MSGERR(MDOC,STR)
              WRITE(STR,
     *        '('' ERR: for atom '',I6,'' name:'',A4,I5,'' '',A3)')
     *        I+1,ATOM,IRES,RES3
              CALL MSGERR(MDOC,STR)
              ICOUNT=ICOUNT+1
            ELSE IF(ICOUNT.EQ.4) THEN
              CALL MSGERR(MDOC,'   ... more ...')
              ICOUNT=ICOUNT+1
            ENDIF
            IERR=0
          ELSE IF(NFMFC.GE.NFMMAX) THEN
            IF(ICOUNT.LT.4) THEN
              WRITE(STR,*) ' ERR: too many atom"s type > ',NFMMAX
              CALL MSGERR(MDOC,STR)
              ICOUNT=ICOUNT+1
            ELSE IF(ICOUNT.EQ.4) THEN
              CALL MSGERR(MDOC,'   ... more ...')
              ICOUNT=ICOUNT+1
            ENDIF
          ENDIF
          IF(ICOUNT.LE.4) THEN
            WRITE(STR,*) ' ERR: default type  is "N   "'
            CALL MSGERR(MDOC,STR)
          ENDIF
          CHAR2='N '
          CHAR4='N   '
          GO TO 610
        ENDIF
        NFMFC=NFMFC+1
        IZFMFC(NFMFC)=NELC
        FMFCA(1,NFMFC)=A1
        FMFCB(1,NFMFC)=B1
        FMFCA(2,NFMFC)=A2
        FMFCB(2,NFMFC)=B2
        FMFCA(3,NFMFC)=A3
        FMFCB(3,NFMFC)=B3
        FMFCA(4,NFMFC)=A4
        FMFCB(4,NFMFC)=B4
        FMFCA(5,NFMFC)=CC
        FMFCB(5,NFMFC)=0.0
        CATOM(NFMFC)=CHAR2
        IZZ=NFMFC
        IZE=NELC
        RVDW=RAD
 600    CONTINUE
C ----------------------------------------
        I=I+1
        IF(CR_ASYMB(1:2).NE.'H '.AND.CR_ASYMB(1:2).NE.'D ') THEN
          NONH  = NONH +1
        ENDIF
        NEL=NEL+IZE*OCC
        SUMFI2 = SUMFI2+IZE*IZE*OCC*OCC
        IF(BT.LT.2.0)  BT = 2.0
        IF(BT.GT.99.0) BT =99.0
        IZR=BT*10.0
        IF(CR_ASYMB(1:2).NE.'H '.AND.CR_ASYMB(1:2).NE.'D ') THEN
          D2=D2+IZE*IZE*OCC*OCC
          D4=0.0
          DO IGS=1,5
            D4= D4+FMFCA(IGS,IZZ)*EXP(-(BT+FMFCB(IGS,IZZ))*D3)
          ENDDO
          D4= OCC * D4
          D1=D1+D4*D4
        ENDIF
        IF(OCC.GT.99.9) OCC=99.9
        IOCC        =OCC*10.0
        INEOCC=IZZ*1000+IOCC

        IF(ABS(INEOCC).GT.32766.0) 
     *  INEOCC=(ABS(INEOCC)/INEOCC)*32766.0
        IF(ABS(IZR).GT.32600.0) IZR=(ABS(IZR)/IZR)*32600.0
C -----
        BAVER   = BAVER+BT
        IF(CR_RNAME.NE.'HOH'.AND.CR_RNAME.NE.'DOD') THEN
          BAVERW = BAVERW +BT 
          MATOMW = MATOMW +1
        ENDIF
        IF(BMIN .GT.BT ) BMIN =BT
        IF(BPEAK.LT.BT ) BPEAK=BT
C ------------------------------
        JJNS=0

        N_SYM=NSYM
        IF(P1.EQ.'Y') N_SYM=1

        DO     ISM=1,N_SYM
          ROT(1) = ISYM(1,1,ISM)
          ROT(2) = ISYM(2,1,ISM)
          ROT(3) = ISYM(3,1,ISM)
          ROT(4) = ISYM(1,2,ISM)
          ROT(5) = ISYM(2,2,ISM)
          ROT(6) = ISYM(3,2,ISM)
          ROT(7) = ISYM(1,3,ISM)
          ROT(8) = ISYM(2,3,ISM)
          ROT(9) = ISYM(3,3,ISM)
          TR(1)  = ISYM(4,1,ISM)/REAL(ISYM(5,1,ISM))
          TR(2)  = ISYM(4,2,ISM)/REAL(ISYM(5,2,ISM))
          TR(3)  = ISYM(4,3,ISM)/REAL(ISYM(5,3,ISM))

          X =ROT(1)*XA(1 ) +ROT(2)*XA(2) +ROT(3)*XA(3)
     .       + TR(1)
          YY=ROT(4)*XA(1 ) +ROT(5)*XA(2) +ROT(6)*XA(3)
     .       + TR(2)
          Z =ROT(7)*XA(1 ) +ROT(8)*XA(2) +ROT(9)*XA(3)
     .       + TR(3)

          Y(1)=X
          Y(2)=YY
          Y(3)=Z

          DO     J=1,3
21          IF(Y(J).LT.XS(J)) THEN
              Y(J)=Y(J)+1.
              GO TO 21
            ENDIF
22          IF(Y(J).GE.XF(J)) THEN
              Y(J)=Y(J)-1.
              GO TO 22
            ENDIF
            IPOINT(J)=1
            TRNS(J,1)=0.
            IF(Y(J).LE.XSU(J)) THEN
              IPOINT(J)=IPOINT(J)+1
              TRNS(J,2)=1.
            ELSE IF(Y(J).GE.XFU(J)) THEN
              IPOINT(J)=IPOINT(J)+1
              TRNS(J,2)=-1.
            ENDIF
          ENDDO

          INALL=0

          DO     IX=1,IPOINT(1)
            DO     IY=1,IPOINT(2)
              DO     IZ=1,IPOINT(3)
C                DO     JZ=1,3
                  JZ=2
                  ZZZ =Y(3)+TRNS(3,IZ)+FLOAT(JZ-2)

                  IF(ZZZ.GE.ZFFS.AND.ZZZ.LE.ZFFF) THEN

                    IXXX=(Y(1)+TRNS(1,IX))*FLOAT(IPACK)
                    IYYY=(Y(2)+TRNS(2,IY))*FLOAT(IPACK)
                    IZZZ= ZZZ             *FLOAT(IPACK)
                    IATT=IATT+1
                    IF(IX.EQ.1.AND.IY.EQ.1.AND.IZ.EQ.1) INALL=1
                    IF(MEM_TEST.LE.0) THEN
                    IF(IATT.GT.NCOORM ) THEN
       WRITE(STR,*) ' ERROR: too many atoms > ',NCOORM
                      CALL MSGERR(MDOC,STR)
                      IERR=1
                      RETURN
                    ENDIF
                    NSUME       = NSUME+IZE
                    IBFACT(IATT)  =IZR
                    IZMOCC(IATT)  =INEOCC
C --- integer*2 version
c                    IF(IXXX.LT.-32766.OR.IXXX.GT.32766.OR.
c     *                 IYYY.LT.-32766.OR.IYYY.GT.32766.OR.
c     *                 IZZZ.LT.-32766.OR.IZZZ.GT.32766) THEN
c                      CALL MSGERR(MDOC,' ERR: !X,Y,Z!(u.c.) > 3.2766')
c                      IERR=1
c                      RETURN
c                    ENDIF
C -----------------------
                    IXC(IATT)   =IXXX
                    IYC(IATT)   =IYYY
                    IZC(IATT)   =IZZZ
                    GRADX(IATT) =0.0
                    GRADY(IATT) =0.0
                    GRADZ(IATT) =0.0
                    GRADB(IATT) =0.0
                    GRADQ(IATT) =0.0
                    GRADW(IATT) =0.0
                    SDENS1(IATT)=0.0
                    SDENS2(IATT)=0.0
                    ITRX=TRNS(1,IX)+1.001
                    ITRY=TRNS(2,IY)+1.001
                    ITRX=TRNS(3,IZ)+1.001

                    ISCODE(IATT)=ISM*100+INC

                    IANUMB(IATT)=ISERIAL
                    IRECRD(IATT)=IATT        
          
                    ENDIF

                  ENDIF
               
C                ENDDO
              ENDDO
            ENDDO
          ENDDO
        ENDDO
C ------------------------
        NINALL=NINALL+INALL
1000    CONTINUE
      GO TO 1100
C==================================================
 2000 MATOMS =I
      NATOMS =IATT
      IF(MATOMS.GT.0) THEN
        BAVER=BAVER/MATOMS
      ENDIF
      IF(MATOMW.GT.0) THEN
        BAVERW=BAVERW/MATOMW
      ENDIF

C ------------------------------------------------------
      M=99
      IF(IATT.LE.0) THEN
        CALL MSGERR(MDOC,' ERR: N-ATOMS = 0 in ATSORTG')
        IERR=1
        CLOSE(NIN)
        RETURN
      ENDIF
      IF(MEM_TEST.GT.0) THEN
        NCOORD=IATT     
        RETURN
      ENDIF
      CALL MSGDOC(M,' --- START SORT ---')
C --- integer*2 version
C     CALL I2SORT1(IZC,IATT,IRECRD)
C --- integer*4 version
      CALL ISORT1(IZC,IATT,IRECRD)
C ---
      CALL MSGDOC(M,' --- END   SORT ---')
C ------------------------------------------------------
      D1=SQRT(ABS(D1))
      D2=SQRT(ABS(D2))
      IF(ABS(D3).LT.0.0000000000001) D3=1.0
      BAVE=ALOG(D2/D1)/D3
      BAVERF = BAVE
      CALL SETBADD(DMAX,BAVE,NX,NY,NZ,BCALC)

      IF(BADD.LE.0.000001) BADD=BCALC        

c      BADD=BADD+BCALC        

      WRITE(STR,'('' BADD_CALC:'',F10.3)') BCALC
      CALL MSGDOC(MDOC,STR)

      WRITE(STR,430) IAT_IN
      CALL MSGDOC(MDOC,STR)
      IF(NCS_FLAG.EQ.'Y') THEN
        WRITE(STR,434) MATOMS
        CALL MSGDOC(MDOC,STR)
      ENDIF
      IF(MATOMS.NE.NONH) THEN
        WRITE(STR,433) NONH
        CALL MSGDOC(MDOC,STR)
      ENDIF
      WRITE(STR,431) NATOMS
      CALL MSGDOC(MDOC,STR)
      WRITE(STR,432) NINALL
      CALL MSGDOC(MDOC,STR)
 430  FORMAT('ATOMS INPUT                       :',I6)
 433  FORMAT('ATOMS INPUT/non H /               :',I6)
 431  FORMAT('ATOMS INCLUDED IN SORT            :',I6)
 432  FORMAT('ATOMS IN ONCE ONLY                :',I6)
 434  FORMAT('ATOMS INPUT/including NCS-atoms / :',I6)

      WRITE(STR,440) BMIN,BPEAK,BAVE
      CALL MSGDOC(MDOC,STR)
 440  FORMAT('MINIMUM B - MAXIMUM B - AVERAGE B:',3F10.4)
c     WRITE(STR,442) NSUME
c 442 FORMAT('SUM-ELECTRONS :',I10)
c     CALL MSGDOC(MDOC,STR)
      FAVER=SQRT(SUMFI2*NSYM)
      WRITE(STR,441) NEL,FAVER
 441  FORMAT('SUM-ELECTRONS /IN MODEL/ :',I10,' <!F!> :',F12.0)
      CALL MSGDOC(MDOC,STR)
      AVERI=SUMFI2*NSYM
      WRITE(STR,443) AVERI
 443  FORMAT('                                  <I> :',F12.0)
      CALL MSGDOC(MDOC,STR)

      NCOORD=IATT
      IF(NCOORD.EQ.0) THEN
        CALL MSGERR(MDOC,' ERR: N-ATOMS =0 in ATSORTG')
        IERR=1
      ENDIF
      CLOSE(NIN)
      RETURN
      END

      SUBROUTINE GETDENG(MDOC,DOBS,DEN,N1,N2,N3,R,IATRC1,BADD
     * ,NCOORD,NCOORM,IBFACT,IZMOCC,IXCC,IYCC,IZCC,ISCODE,IANUMB
     * ,IRECRD,GRADX,GRADY,GRADZ,GRADB,GRADQ,GRADW
     * ,SDENS1,SDENS2
     * ,NSYM,ISYM,IPRSYM,IERR)
C------------------------------------------------------
CMS     : DEN
CMS     : IBFACT,IZMOCC,IXCC,IYCC,IZCC
      INTEGER*2 DEN(N1,N2,N3),DOBS(N1,N2,N3)
      INTEGER   R,IATRC1
C --- integer*2 version
C     INTEGER*2        IBFACT(NCOORM),IZMOCC(NCOORM)
C    *                ,IXCC(NCOORM),IYCC(NCOORM),IZCC(NCOORM)
C    *                ,ISCODE(NCOORM),IANUMB(NCOORM),IRECRD(NCOORM)
C --- integer*4 version
      INTEGER         IBFACT(NCOORM),IZMOCC(NCOORM)
     *                ,IXCC(NCOORM),IYCC(NCOORM),IZCC(NCOORM)
     *                ,ISCODE(NCOORM),IANUMB(NCOORM),IRECRD(NCOORM)
C ---
      REAL             GRADX(NCOORM),GRADY(NCOORM),GRADZ(NCOORM)
     *                ,GRADB(NCOORM),GRADQ(NCOORM),GRADW(NCOORM)
     *                ,SDENS1(NCOORM),SDENS2(NCOORM)
      INTEGER          NCOORD,NCOORM
      INTEGER*2        ISYM(5,3,IPRSYM)
      INTEGER*4        NSYM,IPRSYM
C------------------------------------------------------
      COMMON/COMINF/ NDENSP,NDENSM,NZERO,SUMRP,SUMRM,SD1T,SD2T,CFVOL
     *               ,DOBS_AV,DMOD_AV,SCALED,SIGMA,SIGMAD,SDIFFT
C------------------------------------------------------
      COMMON/CELL/   A,B,C,ALPHA,BETA,GAMMA,ISPHR,DLIM,H2OBG,ICELL
     *             ,VOLUME,SCALEF,GMODE,DMODE,POSITIV,P1
      CHARACTER     GMODE*1,DMODE*1,POSITIV*1,P1*1
      COMMON/DIM/    DMAX,NX,NY,NZ,IZMIN,IZMAX,IHMAX,IKMAX,ILMAX
      PARAMETER ( MAXSCALE  = 1000)
      COMMON/COM_RSCL/ RSCALE1(MAXSCALE),RSCALE2(MAXSCALE)
C --------------------------
      PARAMETER (NFMMAX=15)
      COMMON/FORMS_FFT/   NFMFC,IZFMFC(15),FMFCA(5,15),
     *                FMFCB(5,15),HESS_A(15),CATOM
      CHARACTER       CATOM(15)*2
C-------------------------------------------------------------
      REAL            BLL(5),CLL(5),BLLL(5),BBL(5)
C------------------------------------------------------------------
      IERR=0
C --- integer*2 version
C     IPACK=10000
C --- integer*4 version
      IPACK=100000
C ---
      NATREC=NCOORD
      COEF=(FLOAT(NX)*FLOAT(NY)*FLOAT(NZ))

C      IF(R.EQ.IZMIN) IATRC1=0

C
      DLIMIT=DLIM*DLIM

      SX=A/NX
      SY=B/NY
      SZ=C/NZ
C
      PI   =4.0*ATAN(1.0)
      PISQ4=4.0*PI*PI
      COSA =COS(ALPHA)
      SINA =SIN(ALPHA)
      COSG =COS(GAMMA)
      SING =SIN(GAMMA)
      COSB =COS(BETA)
      SINB =SIN(BETA)
      CSA2 =COSA*2.
      CSB2 =COSB*2.
      CSG2 =COSG*2
      SYCOSG=SY*COSG
      SXSING=SX*SING
      SYSING=SY*SING
      SZCOSB=SZ*COSB
      SZCOSA=SZ*COSA
C      COSZ  DEFINES THE ANGLE BETWEEN C AND CSTAR
      COSZ=SQRT(1.-COSA**2-COSB**2-COSG**2+2.*COSA*COSB*COSG)/SING

      DV=8.0*SX*SY*SZ*COSZ*SING*PI**1.5
C
C  CELL VOLUME
C
      S=(ALPHA+BETA+GAMMA)*0.5
      VOL=2.0*A*B*C*
     *    SQRT(SIN(S)*SIN(S-ALPHA)*SIN(S-BETA)*SIN(S-GAMMA))
      COEF=COEF/VOL
      VOLUME=VOL
      ITETR=0
      ANGSUM=ABS(ALPHA+BETA+GAMMA-(3.0*PI)/2.)
      IF(ANGSUM.GT.0.01) ITETR=1
      IMON=0
      ANGSUM=ABS(BETA+ALPHA-PI/2.)
      IF(ANGSUM.GT.0.01) IMON=1

      DLM= SQRT(DLIMIT)

      IF(IMON.EQ.1) DLM=DLM+0.5

      ZSFG  =FLOAT(R)/NZ     -DLM/C
      ZFFG  =FLOAT(R+N3-1)/NZ+DLM/C
      ZSFNXT=ZFFG-2.*DLM/C
C
      IATREC=IATRC1
C==========================================
1     IATREC=IATREC+1
      IF(IATREC.GT.NATREC) GO TO 400
      
      IATM_P=IRECRD(IATREC)
      IAN   =IANUMB(IATM_P)

      IBOCC =IZMOCC(IATM_P)
      IXIN  =IXCC  (IATM_P)
      IYIN  =IYCC  (IATM_P)
      IZIN  =IZCC  (IATREC)
      Z     =IZIN/FLOAT(IPACK)
      ISCD  =ISCODE(IATM_P)
      BAT   =IBFACT(IATM_P)/10.0
C
      IF(Z.LT.ZSFNXT) IATRC1=IATREC
      IF(Z.LT.ZSFG)   GO TO 1
      IF(Z.GT.ZFFG)   GO TO 400
C
      SCALE=1.0
      BT=BAT+BADD
      IF(BT.GT.99.0) BT=99.0
      IZZ=IBOCC/1000
      IT =IBOCC-IZZ*1000
      OCC=IT/10.

      IF(OCC.LT.0.0001) GO TO 1
      X  =IXIN/FLOAT(IPACK)
      Y  =IYIN/FLOAT(IPACK)
      X1=X *A
      Y1=Y *B
      Z1=Z *C
      IF(BT.LT.0.0) THEN
        CALL MSGERR(MDOC,' ERR: B-FACTOR < 0.0 ')
        IERR=1
        RETURN
      ENDIF
      IF(IZZ.LE.0.OR.IZZ.GT.NFMFC) THEN 
        CALL MSGERR(MDOC,' ERR: IDENTIFY FORMFACTORS = ?')
        IERR=1
        RETURN
      ENDIF
      DVOCC=OCC*DV*SCALE
      IM=IZZ
     
      NEL=IZFMFC(IM)
      DDLIM=DLM
CCCC      IF(NEL.EQ.1) DDLIM=3.5
      DMAXSQ=DDLIM*DDLIM

C      B11=BAT
C      IF(NEL.GT.16) B11=AMAX1(BT,20.0)
C      IF(NEL.LT.16) B11=AMIN1(BT,15.0)
C      IF(NEL.EQ. 1) B11=AMAX1(BT, 5.0)
C      B11=B11+BADD
C      RADSQ=DDLIM*(B11+25.0)/PISQ4
C      RAD  =SQRT(RADSQ)
C      DMAXSQ=RADSQ

      RRADZ=SQRT(ABS(DMAXSQ))/(SZ*COSZ)

      GQSK=0.0
      DO     J=1,5
        GQSK = GQSK + FMFCA(J,IM)
      ENDDO
      DO     J=1,5
        BLL(J) =PISQ4 /(FMFCB(J,IM)+BT )
        BLLL(J)=BLL(J)/(FMFCB(J,IM)+BT )
        BBL(J) =1.5   /(FMFCB(J,IM)+BT )
        CLL(J)=DVOCC*FMFCA(J,IM)*(FMFCB(J,IM)+BT )**(-1.5)
      ENDDO
C
      XC=X1/SX
      IXC=NINT(XC)
      YC=Y1/SY
      IYC=NINT(YC)
      ZC=Z1/SZ
      IZC=NINT(ZC)
C

      SZL=ZC-RRADZ
      SZU=ZC+RRADZ
      ISZL=INT(SZL+501.)
      ISZU=INT(SZU+500.)
C
C     CALCULATE THE DENSITY AT ALL POINTS TO WHICH ATOM CONTRIBUTES
C     (IE IN SPHERE OF RADIUS RRADZ)
C
      DO     IZ1=ISZL,ISZU
        IZ=IZ1-500
C
C     TEST WHETHER THIS ATOM LIES IN REQUIRED BLOCK OF FOURIER SECTIONS
C
        IZ2=IZ+1-R
        IF(IZ2.GT.N3 .OR. IZ2.LE.0)       GO TO 301
        DDZ=1.0-ABS(ZC-IZ)
        IF(DDZ.LE.0.0) DDZ=0.0
        DZ=IZ*SZ-Z1
        D2=DZ*DZ
        IF(D2.GT.DMAXSQ .AND. ITETR.EQ.1) GO TO 301
 
        D3=DMAXSQ-DZ*DZ*SINA*SINA

        IF(D3.LE.0.00000000001)           GO TO 301
        RRADY=SQRT(ABS(D3))/SYSING

        ZCOSA=DZ*COSA/SY
        SYL=YC-RRADY-ZCOSA
        SYU=YC+RRADY-ZCOSA
        ISYL=INT(SYL+501.)
        ISYU=INT(SYU+500.)
        DELZ1=2.*DZ
        DZCSA2=DZ*CSA2
        DZCOSB=DZ*COSB
        DO     IY1=ISYL,ISYU
          IY=IY1 - 500
          IY2=IY+1
          IF(IY2.LE.N2.AND.IY2.GE.1) THEN
            DDY=1.0-ABS(YC-IY)
            IF(DDY.LE.0.0) DDY=0.0
            DY=IY*SY-Y1
            DYZ=D2+DY*(DZCSA2+DY)
            IF(DYZ.LE.DMAXSQ.OR.IMON.EQ.0) THEN
C
C             FOR GIVEN X AND Y  THE MINIMUM DSQ IS GIVEN
C             FOR DX=-DY*COSG-DZCOSB
C
              DXMIN=-DY*COSG-DZCOSB
              DSQMIN=DYZ-DXMIN**2
              IF(DSQMIN.LT.DMAXSQ) THEN
                DFACT2=-2.*DXMIN
                D4=DMAXSQ-DSQMIN
                DELZ2=DELZ1+DY*CSA2
                DELY1=2.*DY+DZCSA2
                DELY=2.*DY
                RRADX=SQRT(ABS(D4))/SXSING
                XDELTA=DXMIN/SX
                SXL=XC-RRADX + XDELTA
                SXU=XC+RRADX + XDELTA
                ISXL=INT(SXL+501.)
                ISXU=INT(SXU+500.)
                DO     IX1=ISXL,ISXU
                  IX=IX1-500
                  IX2=IX+1

                  IF(IX2.LE.N1.AND.IX2.GE.1) THEN

C                   DNS1=DOBS(IX2,IY2,IZ2)
C                   DNS2=DEN (IX2,IY2,IZ2)
                    IDNS1=DOBS(IX2,IY2,IZ2)
                    IDNS2=DEN (IX2,IY2,IZ2)

                    IF(IDNS1.GT.-32766 ) THEN

                      DNS1=IDNS1/RSCALE1(IZ2)
                      DNS2=IDNS2/RSCALE2(IZ2)
                      D2OM=2.0*DNS1-DNS2
                      IF(DMODE.EQ.'D') DNS1=DNS1-DNS2
                    
                      DDX=1.- ABS(XC-IX)
                      IF(DDX.LE.0.0) DDX=0.0
                      DX=IX*SX-X1
                      DSQ=DX*(DX+DFACT2) + DYZ

                      IF(DSQ.LE.DMAXSQ) THEN

                        DROM =0.0
                        ROM  =0.0
                        DBM  =0.0
                        D2ROM=0.0
                        DO     J=1,5

C       ROm(R-Rm)=SUM(ROmj)=SUM(V/N*OCC*(Aj*(4*pi/Bj)^3/2*EXP(-4*pi^2/Bj)
C                                Bj=(Bj+Bm)
C       DROM=SUM(DROMJ): dROm/drm=SUM((dROm/drm)j)=SUM(2*(4pi^2/Bj)*ROmj)
C       D2ROM=SUM(D2ROMJ): d2ROm/drm2=SUM(DROMJ*(2*(r-rm)^2*(4pi^2/Bj)-3))

                          DSQ1  =-DSQ*BLL(J)
                          ROMJ  =CLL(J)*EXP(DSQ1)
                          DROMJ =2.0*ROMJ*BLL(J)
                          D2ROMJ=DROMJ*(2.0*BLL(J)*DSQ-3.0)
C                          D2ROMJ=DROMJ*(2.0*BLL(J)*DSQ-1.0)

                          DBMJ=ROMJ*(BLLL(J)*DSQ-BBL(J))
                          DBM =DBM+DBMJ
                          
                          ROM=ROM    +ROMJ
                          DROM=DROM  +DROMJ
                          D2ROM=D2ROM+D2ROMJ
                        ENDDO

                        DBDN  =DNS1*DBM

                        DRDN  =DNS1*DROM
                        DNSWT2=DNS2*D2ROM

                        SDEN1  =D2OM*ROM
                        SDEN2  =DNS2*ROM


                        DXP=DX+DY*COSG+DZ*COSB
                        DYP=DY+DX*COSG+DZ*COSA
                        DZP=DZ+DX*COSB+DY*COSA
                        ISM=ISCD/100

                        DXAU=ISYM(1,1,ISM)*DXP+
     *                       ISYM(1,2,ISM)*DYP*A/B+
     *                       ISYM(1,3,ISM)*DZP*A/C
                        DYAU=ISYM(2,1,ISM)*DXP*B/A+
     *                       ISYM(2,2,ISM)*DYP+
     *                       ISYM(2,3,ISM)*DZP*B/C
                        DZAU=ISYM(3,1,ISM)*DXP*C/A+
     *                       ISYM(3,2,ISM)*DYP*C/B+
     *                       ISYM(3,3,ISM)*DZP


C            WRITE(*,*) ISM,iscd,DXAU,DYAU,DZAU 


                        GRADX(IATM_P)=GRADX(IATM_P)+DXAU*DRDN
                        GRADY(IATM_P)=GRADY(IATM_P)+DYAU*DRDN
                        GRADZ(IATM_P)=GRADZ(IATM_P)+DZAU*DRDN
                        GRADB(IATM_P)=GRADB(IATM_P)+DBDN
                        GRADQ(IATM_P)=GRADQ(IATM_P)+ROM
                        GRADW(IATM_P)=GRADW(IATM_P)+DNSWT2

                        SDENS1(IATM_P)=SDENS1(IATM_P)+SDEN1
                        SDENS2(IATM_P)=SDENS2(IATM_P)+SDEN2
                        
                      ENDIF
                    ENDIF
                  ENDIF
                ENDDO
              ENDIF
            ENDIF
          ENDIF
        ENDDO
301     CONTINUE
300     CONTINUE
      ENDDO
      GO TO 1

C -----------------------------------------------
400   CONTINUE
      RETURN
      END

      SUBROUTINE SORT_BACKG(MDOC,NAMEC,NAMEO,NAMEE
     * ,NCOORD,NCOORM,IBFACT,IZMOCC,IXCC,IYCC,IZCC,ISCODE,IANUMB
     * ,IRECRD,GRADX,GRADY,GRADZ,GRADB,GRADQ,GRADW,GHESSX,GHESSB
     * ,SDENS1,SDENS2,NX,NY,NZ,NSYM,ISYM,DISPFR,RESULT,IERR)
C------------------------------------------------------
CMS     : IBFACT,IZMOCC,IXCC,IYCC,IZCC
C --- integer*2 version
C     INTEGER*2        IBFACT(NCOORM),IZMOCC(NCOORM)
C    *                ,IXCC(NCOORM),IYCC(NCOORM),IZCC(NCOORM)
C    *                ,ISCODE(NCOORM),IANUMB(NCOORM),IRECRD(NCOORM)
C --- integer*4 version
      INTEGER          IBFACT(NCOORM),IZMOCC(NCOORM)
     *                ,IXCC(NCOORM),IYCC(NCOORM),IZCC(NCOORM)
     *                ,ISCODE(NCOORM),IANUMB(NCOORM),IRECRD(NCOORM)
C ---
      REAL             GRADX(NCOORM),GRADY(NCOORM),GRADZ(NCOORM)
     *                ,GRADB(NCOORM),GRADQ(NCOORM),GRADW(NCOORM)
     *                ,GHESSX(NCOORM),GHESSB(NCOORM)
     *                ,SDENS1(NCOORM),SDENS2(NCOORM)
      INTEGER          NCOORD,NCOORM
      REAL             RESULT(*)
      INTEGER*2        ISYM(5,3,*)
      INTEGER*4        NSYM
      CHARACTER NAMEC*(*),NAMEO*(*),NAMEE*(*)
C --------------------------
      PARAMETER (NFMMAX=15)
      COMMON/FORMS_FFT/   NFMFC,IZFMFC(15),FMFCA(5,15),
     *                FMFCB(5,15),HESS_A(15),CATOM
      CHARACTER       CATOM(15)*2
C -------------------------------------------------
      INCLUDE 'mr_crd_com.fh'
C------------------------------------------------------
      COMMON/COMINF/ NDENSP,NDENSM,NZERO,SUMRP,SUMRM,SD1T,SD2T,CFVOL
     *               ,DOBS_AV,DMOD_AV,SCALED,SIGMA,SIGMAD,SDIFFT
C------------------------------------------------------
      COMMON/CELL/  A,B,C,ALPHA,BETA,GAMMA,ISPHR,DLIM,H2OBG,ICELL
     *             ,VOLUME,SCALEF,GMODE,DMODE,POSITIV,P1
      CHARACTER     GMODE*1,DMODE*1,POSITIV*1,P1*1
C ---
      REAL        FRTOCR(3,3),CRTOFR(3,3)
      REAL X(3),Y(3),TR(3),AM(3,3),BM(3,3)
      CHARACTER LINE*80
C------------------------------------------------------------------
      IERR=0
C --- integer*2 version
C     IPACK=10000
C --- integer*4 version
      IPACK=100000
C ---
      PI   =4.0*ATAN(1.0)
      NIN   = 10
      M     = 99
      MD    = -ABS(MDOC)-1
C ---------------------------------------
C
C  CELL VOLUME
C
      SX=A/NX
      SY=B/NY
      SZ=C/NZ
      COSA =COS(ALPHA)
      SINA =SIN(ALPHA)
      COSG =COS(GAMMA)
      SING =SIN(GAMMA)
      COSB =COS(BETA)
      SINB =SIN(BETA)
C      COSZ  DEFINES THE ANGLE BETWEEN C AND CSTAR
      COSZ=SQRT(1.-COSA**2-COSB**2-COSG**2+2.*COSA*COSB*COSG)/SING
      DV=8.0*SX*SY*SZ*COSZ*SING*PI**1.5
      S=(ALPHA+BETA+GAMMA)*0.5
      VOL=2.0*A*B*C*
     *    SQRT(SIN(S)*SIN(S-ALPHA)*SIN(S-BETA)*SIN(S-GAMMA))
      COEF=(VOL)/(FLOAT(NX)*FLOAT(NY)*FLOAT(NZ))
C --------------------------------------
      VOLUME=VOL

C      IF(PRINT.EQ.'Y') THEN
C        WRITE(LINE,*) ' coef,dv:',coef,dv 
C        CALL MSGDOC(MDOC,LINE)    
C      ENDIF
C -------------------
      CALL FRORTH(A,B,C
     *           ,ALPHA,BETA,GAMMA
     *                            ,FRTOCR,CRTOFR,IERR)
C -------------------
      IF(NCOORD.LE.0) THEN
        CALL MSGERR(MDOC,' ERR: N-ATOMS = 0')
        IERR=1
        RETURN
      ENDIF
      CALL MSGDOC(M,' --- START SORT ---')
C --- integer*2 version
C     CALL I2SORT1(IRECRD,NCOORD,IZCC)
C --- integer*4 version
      CALL ISORT1(IRECRD,NCOORD,IZCC)
C ---
      CALL MSGDOC(M,' --- END   SORT ---')
C ------------------------------------------------------
      SGX=0.0
      SGY=0.0
      SGZ=0.0
      SGB=0.0
      SWT=0.0
      SD2=0.0
      SHX=0.0
      SHB=0.0
      SDN1=0.0
      SDN2=0.0
      NA   = 0
      IOLD=-1
      IBOCC_OLD=0
      INC_OLD=-1

      DO I=1,NCOORD

        IATM =IANUMB(I)
        IREC =IRECRD(I)
        IBOCC=IZMOCC(IREC)
        IXIN =IXCC  (IREC)
        IYIN =IYCC  (IREC)
        IZIN =IZCC  (IREC)
        ISCD =ISCODE(IREC)

        ISM  =ISCD/100
        INC  =ISCD-ISM*100

        GX   =GRADX (IREC)
        GY   =GRADY (IREC)
        GZ   =GRADZ (IREC)
        GB   =GRADB (IREC)
        WT   =GRADQ (IREC)
        D2   =GRADW (IREC)
        HX   =GHESSX(IREC)
        HB   =GHESSB(IREC)
        DN1  =SDENS1(IREC)
        DN2  =SDENS2(IREC)
      
        IF((IATM.NE.IOLD.OR.INC_OLD.NE.INC).AND.I.NE.1) THEN
          NA=NA+1

          IANUMB(NA)=IOLD

          GRADX (NA)=SGX
          GRADY (NA)=SGY
          GRADZ (NA)=SGZ
          GRADB (NA)=SGB
          GRADQ (NA)=SWT
          GRADW (NA)=SD2
          GHESSX(NA)=SHX
          GHESSB(NA)=SHB
          SDENS1(NA)=SDN1
          SDENS2(NA)=SDN2
          ISCODE(NA)=INC_OLD

          SGX=0.0
          SGY=0.0
          SGZ=0.0
          SGB=0.0
          SWT=0.0
          SD2=0.0
          SHX=0.0
          SHB=0.0
          SDN1=0.0
          SDN2=0.0
          IOLD     =IATM
          INC_OLD  =INC
          IBOCC_OLD=IBOCC
        ENDIF

        IF(I.EQ.1) THEN
          IOLD=IATM
          INC_OLD  =INC
          IBOCC_OLD=IBOCC
        ENDIF        

        SGX=SGX+GX
        SGY=SGY+GY
        SGZ=SGZ+GZ
        SGB=SGB+GB
        SWT=SWT+WT
        SD2=SD2+D2
        SDN1=SDN1+DN1
        SDN2=SDN2+DN2
        SHX=HX
        SHB=HB
        IF(I.EQ.NCOORD) THEN
          NA=NA+1

          IANUMB(NA)=IOLD

          GRADX (NA)=SGX
          GRADY (NA)=SGY
          GRADZ (NA)=SGZ
          GRADB (NA)=SGB
          GRADQ (NA)=SWT
          GRADW (NA)=SD2
          GHESSX(NA)=SHX
          GHESSB(NA)=SHB
          SDENS1(NA)=SDN1
          SDENS2(NA)=SDN2
          ISCODE(NA)=INC_OLD

          IZMOCC(NA)=IBOCC

        ENDIF
      ENDDO
C -----------------------------------------------
      SGX=0.0
      SGY=0.0
      SGZ=0.0
      SGB=0.0
      SWT=0.0
      SD2=0.0
      SHX=0.0
      SHB=0.0
      SDN1=0.0
      SDN2=0.0
      IBOCC_OLD=0
      SHESSX=0.0
      SHESSB=0.0
      SHESSD=0.0
      RATIO=0.0
      DENS_AVER=0.0
      SHFT_AVER=0.0
      SHFT_MAX =0.0
      SHFT_RMS =0.0
      DRV_RMS =0.0
      DRV_AVER=0.0
      N_SHFT   =0
      IOLD     =-1
      DO IA=1,NA

        IATM= IANUMB (IA)
        INC = ISCODE (IA)
        IBOCC=IZMOCC(IA)
        IZZ=IBOCC/1000
        IT =IBOCC-IZZ*1000
        OCC=IT/10.
        GX  = GRADX  (IA)
        GY  = GRADY  (IA)
        GZ  = GRADZ  (IA)
        GB  = GRADB  (IA)
        WT  = GRADQ  (IA)
        D2  = GRADW  (IA)
        HX  = GHESSX (IA)
        HB  = GHESSB (IA)
        DN1  =SDENS1 (IA)
        DN2  =SDENS2 (IA)

        IF(INC.GT.0) THEN
          CALL GET_NCS(MDOC,NCMAX,INC,AM,TR,IERR)
          IF(IERR.NE.0) THEN
            WRITE(LINE,
     *      '('' ERR: wrong NCS description'')') 
            CALL MSGERR(MDOC,LINE)
            RETURN
          ENDIF      
          CALL INVERT(AM,BM,IERR)
          X(1)=GX/A
          X(2)=GY/B
          X(3)=GZ/C
          CALL MVMULT(FRTOCR,X,Y)
C          X(1)=Y(1)-TR(1)
C          X(2)=Y(2)-TR(2)
C          X(3)=Y(3)-TR(3)
          CALL MVMULT(BM,Y,X)
C         CALL MVMULT(CRTOFR,Y,X)
          GX=X(1)
          GY=X(2)
          GZ=X(3)
        ELSE
          X(1)=GX/A
          X(2)=GY/B
          X(3)=GZ/C
          CALL MVMULT(FRTOCR,X,Y)
          GX=Y(1)
          GY=Y(2)
          GZ=Y(3)
        ENDIF
   
        IF(IATM.NE.IOLD.AND.IA.NE.1) THEN

          N_SHFT=N_SHFT+1    

          IZZ=IBOCC_OLD/1000
          IT =IBOCC_OLD-IZZ*1000
          OCC=IT/10.
          NELC=IZFMFC(IZZ)

          IF(SWT.GT.0.0) THEN
C           SD2=-SD2/SWT
            SD2=-(SD2)/3.0
          ENDIF

C
C         SHB & SHX * OCC
C
C         SHB=SHB*SCALEF*SCALEF*OCC*OCC*VOL
          SHX=SHX*SCALEF*SCALEF
          SGX=SGX*SCALEF
          SGY=SGY*SCALEF
          SGZ=SGZ*SCALEF
          SGB=SGB*SCALEF
          SD2=SD2*SCALEF
          SDN1=SDN1*SCALEF
          SDN2=SDN2*SCALEF
          SWT =SWT *SCALEF

          DIAG=SHX

          IF(DIAG.GT.0.000001) THEN
            SHFTX = SGX/DIAG
            SHFTY = SGY/DIAG
            SHFTZ = SGZ/DIAG
            DS2   = SHFTX*SHFTX+SHFTY*SHFTY+SHFTZ*SHFTZ
            DS    = SQRT(ABS(DS2))
            DSS2   = SGX*SGX+SGY*SGY+SGZ*SGZ
            DSS    = SQRT(ABS(DSS2))
          ELSE
            IF(SD2.LT.-0.0000001.AND.SHX.GT.0.0) THEN 
              SD2= -1.0
            ELSE
              SD2= 0.0
            ENDIF
            SHFTX=0.0
            SHFTX=0.0
            SHFTX=0.0
            DSS2  =0.0
            DSS  =0.0
            DS2  =0.0
            DS   =0.0
          ENDIF
          IF(SWT.GT.0.000000001) THEN
            DENS_AVER=DENS_AVER+SDN1/SWT
          ENDIF

          SHESSX=SHESSX+SHX
          SHESSB=SHESSB+SHB

          IF(SD2.GT.0.000000001) SHESSD=SHESSD+SD2
          SHFT_RMS=SHFT_RMS+DS2
          SHFT_AVER=SHFT_AVER+DS
          DRV_RMS =DRV_RMS +DSS2
          DRV_AVER=DRV_AVER+DSS
          IF(DS.GT.SHFT_MAX) SHFT_MAX=DS
           
          IF(SHX.GT.0.000001) RATIO=RATIO+SD2/SHX

          GRADX (N_SHFT)=SGX
          GRADY (N_SHFT)=SGY
          GRADZ (N_SHFT)=SGZ
          GRADB (N_SHFT)=SGB
          GRADW (N_SHFT)=SD2
          GRADQ (N_SHFT)=SWT
          GHESSX(N_SHFT)=SHX
          GHESSB(N_SHFT)=SHB
          SDENS1(N_SHFT)=SDN1
          SDENS2(N_SHFT)=SDN2
          IANUMB(N_SHFT)=IOLD
          ISCODE(N_SHFT)=0
          IZMOCC(N_SHFT)=IBOCC_OLD

          SGX=0.0
          SGY=0.0
          SGZ=0.0
          SGB=0.0
          SD2=0.0
          SWT=0.0
          SHX=0.0
          SHB=0.0
          SDN1=0.0
          SDN2=0.0
          IBOCC_OLD=IBOCC
          IOLD=IATM
        ENDIF

        IF(IA.EQ.1) THEN
          IOLD=IATM
          IBOCC_OLD=IBOCC
        ENDIF

        SGX=SGX+GX
        SGY=SGY+GY
        SGZ=SGZ+GZ
        SGB=SGB+GB
        SWT=SWT+WT
        SD2=SD2+D2
        SDN1=SDN1+DN1
        SDN2=SDN2+DN2
        SHX=HX
        SHB=HB

        IF(IA.EQ.NA) THEN


          N_SHFT=N_SHFT+1    

          IZZ=IBOCC_OLD/1000
          IT =IBOCC_OLD-IZZ*1000
          OCC=IT/10.
          NELC=IZFMFC(IZZ)
          IF(SWT.GT.0.0) THEN
C           SD2=-SD2/SWT
            SD2=-(SD2)/3.0
          ENDIF
          SD2=SD2
C
C         SHB & SHX * OCC
C
C         SHB=SHB*SCALEF*SCALEF*OCC*OCC*VOL
          SHX=SHX*SCALEF*SCALEF
          SGX=SGX*SCALEF
          SGY=SGY*SCALEF
          SGZ=SGZ*SCALEF
          SGB=SGB*SCALEF
          SD2=SD2*SCALEF
          SDN1=SDN1*SCALEF
          SDN2=SDN2*SCALEF
          SWT=SWT  *SCALEF

          DIAG=SHX

          IF(DIAG.GT.0.000001) THEN
            SHFTX = SGX/DIAG
            SHFTY = SGY/DIAG
            SHFTZ = SGZ/DIAG
            DS2   = SHFTX*SHFTX+SHFTY*SHFTY+SHFTZ*SHFTZ
            DS    = SQRT(DS2)
            DSS2   = SGX*SGX+SGY*SGY+SGZ*SGZ
            DSS    = SQRT(DSS2)
          ELSE
            IF(SD2.LT.-0.0000001.AND.SHX.GT.0.0) THEN 
              SD2= -1.0
            ELSE
              SD2= 0.0
            ENDIF
            SHFTX=0.0
            SHFTX=0.0
            SHFTX=0.0
            DS2  =0.0
            DS   =0.0
            DSS2  =0.0
            DSS  =0.0
          ENDIF
          IF(SWT.GT.0.0) THEN
            DENS_AVER=DENS_AVER+SDN1/SWT
          ENDIF

          SHESSX=SHESSX+SHX
          SHESSB=SHESSB+SHB
          IF(SD2.GT.0.0) SHESSD=SHESSD+SD2
          SHFT_RMS =SHFT_RMS+DS2
          SHFT_AVER=SHFT_AVER+DS
          DRV_RMS  =DRV_RMS +DSS2
          DRV_AVER =DRV_AVER+DSS
          IF(DS.GT.SHFT_MAX) SHFT_MAX=DS

          IF(SHX.GT.0.000001) RATIO=RATIO+SD2/SHX

          GRADX (N_SHFT)=SGX
          GRADY (N_SHFT)=SGY
          GRADZ (N_SHFT)=SGZ
          GRADB (N_SHFT)=SGB
          GRADW (N_SHFT)=SD2
          GRADQ (N_SHFT)=SWT
          GHESSX(N_SHFT)=SHX
          GHESSB(N_SHFT)=SHB
          SDENS1(N_SHFT)=SDN1
          SDENS2(N_SHFT)=SDN2
          IANUMB(N_SHFT)=IOLD
          ISCODE(N_SHFT)=0
          IZMOCC(N_SHFT)=IBOCC_OLD

        ENDIF             

      ENDDO

      NA=N_SHFT
C ---
      IF(N_SHFT.GT.0) THEN
        SHFT_AVER= SHFT_AVER/N_SHFT
        SHFT_RMS = SHFT_RMS/N_SHFT
        SHFT_RMS = SQRT(ABS(SHFT_RMS))
        DRV_RMS  = DRV_RMS/N_SHFT
        DRV_AVER = DRV_AVER/N_SHFT
        DRV_RMS  = SQRT(ABS(DRV_RMS))
        DENS_AVER= DENS_AVER/N_SHFT
        SHESSX   = SHESSX/N_SHFT
        SHESSB   = SHESSB/N_SHFT
        SHESSD   = SHESSD/N_SHFT
        RATIO    = RATIO/N_SHFT
      ELSE
        SHFT_RMS=0.0
        SHFT_AVER=0.0
      ENDIF
      DIFF_TOT=SDIFFT/SCALEF
C --------
      CALL ORCRD(M,NIN,NAMEC,NSYM_R,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) RETURN
C --------
      CALL LENSTR_BL(NAMEO,LEN)
      IF(LEN.GT.0.AND.NAMEO(1:1).NE.','.AND.NAMEO(1:1).NE.' ') THEN
        NOUT  = 11
        CALL OWCRD(M,NOUT,NAMEO,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) RETURN
      ELSE
        NOUT  = 0
      ENDIF
C --------
      CALL LENSTR_BL(NAMEE,LEN)
      IF(LEN.GT.0.AND.NAMEE(1:1).NE.','.AND.NAMEE(1:1).NE.' ') THEN
        NOUT1  = 12
        CALL OWCRD(M,NOUT1,NAMEE,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) RETURN
      ELSE
        NOUT1  = 0
      ENDIF
C --------
      IEND  =-1
      IENDW =-1
      IENDW1=-1
      IA=1
C --------
      WRITE(LINE,'('' SIGMA:'',2F12.5)') SIGMA,SIGMAD
      CALL MSGDOC(MDOC,LINE)    
      WRITE(LINE,'('' <HESS>:'',2F12.5)') SHESSX,SHESSB
      CALL MSGDOC(MDOC,LINE)    
      WRITE(LINE,'('' <HESSD,RATIO>:'',2F12.5)') SHESSD,RATIO
      CALL MSGDOC(MDOC,LINE)    
      SHIFT_LIM=2.0*SIGMAD

      IF(SCALEF.GT.0.00000001) DENS_AVER=DENS_AVER/SCALEF
      WRITE(CR_LINE,'(''#sigma_do,sigma_diff:'',1X,3F12.5)') 
     *  SIGMA,SIGMAD,DENS_AVER
      MODE=1
      IF(NOUT.GT.0) THEN
         CR_LINE2 = ' '
         CALL WRCRD(M,NOUT,MODE,IENDW,IERR)
      ENDIF
      IF(IERR.NE.0) THEN
        CLOSE(NIN) 
        IF(NOUT1.GT.0) CLOSE(NOUT1) 
        RETURN
      ENDIF
      IF(NOUT1.GT.0) THEN
        CR_LINE2 = ' '
        CALL WRCRD(M,NOUT1,MODE,IENDW1,IERR)
      ENDIF
      IF(IERR.NE.0) THEN
        CLOSE(NIN) 
        IF(NOUT.GT.0) CLOSE(NOUT) 
        RETURN
      ENDIF

      WRITE(CR_LINE,'(''#hessian,hessian_diff:'',1X,2F12.5)') 
     * SHESSX,SHESSD 
      MODE=1
      IF(NOUT.GT.0) THEN
       CR_LINE2 = ' '
       CALL WRCRD(M,NOUT,MODE,IENDW,IERR)
      ENDIF
      IF(IERR.NE.0) THEN
        CLOSE(NIN) 
        IF(NOUT1.GT.0) CLOSE(NOUT1) 
        RETURN
      ENDIF
      IF(NOUT1.GT.0) THEN
        CR_LINE2 = ' '
        CALL WRCRD(M,NOUT1,MODE,IENDW1,IERR)
      ENDIF
      IF(IERR.NE.0) THEN
        CLOSE(NIN) 
        IF(NOUT.GT.0) CLOSE(NOUT) 
        RETURN
      ENDIF

      WRITE(CR_LINE,'(''#deriv_rms,deriv_aver:'',1X,2F12.5)') 
     *  DRV_RMS,DRV_AVER
      MODE=1
      IF(NOUT.GT.0) THEN
        CR_LINE2 = ' '
        CALL WRCRD(M,NOUT,MODE,IENDW,IERR)
      ENDIF
      IF(IERR.NE.0) THEN
        CLOSE(NIN) 
        IF(NOUT1.GT.0) CLOSE(NOUT1) 
        RETURN
      ENDIF
      IF(NOUT1.GT.0) THEN
        CR_LINE2 = ' '
        CALL WRCRD(M,NOUT1,MODE,IENDW1,IERR)
      ENDIF
      IF(IERR.NE.0) THEN
        CLOSE(NIN) 
        IF(NOUT.GT.0) CLOSE(NOUT) 
        RETURN
      ENDIF

      WRITE(CR_LINE,'(''#scalef,disp_four:'',1X,3F12.5)') 
     *  SCALEF,DISPFR,DIFF_TOT
      MODE=1
      IF(NOUT.GT.0) THEN
        CR_LINE2 = ' '
        CALL WRCRD(M,NOUT,MODE,IENDW,IERR)
      ENDIF
      IF(IERR.NE.0) THEN
        CLOSE(NIN) 
        IF(NOUT1.GT.0) CLOSE(NOUT1) 
        RETURN
      ENDIF
      IF(NOUT1.GT.0) THEN
        CR_LINE2 = ' '
        CALL WRCRD(M,NOUT1,MODE,IENDW1,IERR)
      ENDIF
      IF(IERR.NE.0) THEN
        CLOSE(NIN) 
        IF(NOUT.GT.0) CLOSE(NOUT) 
        RETURN
      ENDIF

 1000 CONTINUE
      IF(IA.GT.NA) GO TO 2000
      INC = ISCODE(IA)
      IF(INC.EQ.0) THEN
        CALL RDCRD(M,NIN,MODE,IEND,IERR)
        IF(IERR.EQ.1) RETURN

        IF(IEND.NE.0) GO TO 2000
      ENDIF

      IF(MODE.EQ.0) THEN    
        ISR=CR_IATOM
         

        IF(CR_ATYPE.NE.'.'.AND.CR_ATYPE.NE.' '.AND.
     *     CR_ATYPE.NE.'y'.AND.CR_ATYPE.NE.'Y'.AND.
     *     CR_ATYPE.NE.'r'.AND.CR_ATYPE.NE.'R') THEN
C         CR_IATOLD=IA
          GO TO 1100
        ENDIF
        IF(IANUMB(IA).EQ.ISR.AND.IA.LE.NA) THEN 

            HX       = GHESSX(IA)
            HB       = GHESSB(IA)
            GB       = GRADB (IA)
            D2       = GRADW (IA)

            WT       = GRADQ (IA)
            DNS1     = SDENS1(IA)
            DNS2     = SDENS2(IA)
            IF(WT.GT.0.00000000001) THEN
              DNS1=DNS1/WT
              DNS2=DNS2/WT
            ELSE
              DNS1=0.0
              DNS2=0.0
            ENDIF
           
            DIAG=HX

            IF(DIAG.GT.0.000001) THEN
              SHFTX = GRADX(IA)/DIAG
              SHFTY = GRADY(IA)/DIAG
              SHFTZ = GRADZ(IA)/DIAG
              DS2   = SHFTX*SHFTX+SHFTY*SHFTY+SHFTZ*SHFTZ
              DS2   = SQRT(DS2)
              IF(D2.GT.0.0) THEN
                SHFX = GRADX(IA)/D2
                SHFY = GRADY(IA)/D2
                SHFZ = GRADZ(IA)/D2
                DS2D2 = SHFX*SHFX+SHFY*SHFY+SHFZ*SHFZ
                DS2D2=SQRT(DS2D2)
              ELSE
                DS2D2=0.0
              ENDIF
              DSS2   = GRADX(IA)*GRADX(IA)+GRADY(IA)*GRADY(IA)+
     *                 GRADZ(IA)*GRADZ(IA)
              DSS    = SQRT(DSS2)
            ELSE
              DS2=0.0
              DSS=0.0
              DS2D2=0.0
            ENDIF

            WHX=HX
            IF(WHX.GT.999.9) WHX=999.9
            WHXD=GRADW(IA)
            IF(WHXD.GT.999.9) WHXD=999.9

            GRADXIA = GRADX (IA)
            GRADYIA = GRADY (IA)
            GRADZIA = GRADZ (IA)

C            IF(GMODE.EQ.'D') THEN
C              CR_XYZ(1)= DSS /SCALEF
C              CR_XYZ(2)= DNS1/SCALEF
C              CR_XYZ(3)= DNS2/SCALEF
C              CR_OCC   = WHX /SCALEF
C              CR_BISO  = WT  /SCALEF
C            ELSE
C              CR_XYZ(1)= GRADX (IA)/SCALEF
C              CR_XYZ(2)= GRADY (IA)/SCALEF
C              CR_XYZ(3)= GRADZ (IA)/SCALEF
C              CR_OCC   = WHX       /SCALEF
C              CR_BISO  = WHXD      /SCALEF
C            ENDIF

C            IF(PRINT.EQ.'Y') THEN
C              WRITE(LINE,'(I5,8F8.3)') 
C     *        IA,GRADX(IA),DS2,DS2D2,DSS,HB,HX
C     *        ,D2,wT
C              CALL MSGDOC(MDOC,LINE)    
C            ENDIF

          IA=IA+1
        ELSE
          MODE=1
        ENDIF     

      ELSE

      ENDIF
 1100 CONTINUE
      IF(SCALEF.LT.0.0000000000001) SCALEF=1.0
      IF(NOUT.GT.0) THEN
        IF(MODE.EQ.0) THEN
          CR_XYZ(1)= GRADXIA/SCALEF
          CR_XYZ(2)= GRADYIA/SCALEF
          CR_XYZ(3)= GRADZIA/SCALEF
C --      DIAG=HX
          CR_OCC   = WHX    /SCALEF
          IF(DIAG.GT.0.000001.AND.CR_OCC.LT.0.01) THEN
            CR_OCC = 0.01
          ENDIF

C         CR_BISO  = WHXD   /SCALEF
c !!!
          SHFTB = 0.0
          IF(HB.GT.0.000001) THEN
            SHFTB = (GB/HB)*100.0
          ENDIF
          IF(SHFTB.GT. 99.99) SHFTB= 99.99
          IF(SHFTB.LT.-99.99) SHFTB=-99.99
          CR_BISO = SHFTB
C !!!
          CR_SURF = 0.0
        ENDIF
        CALL WRCRD(M,NOUT,MODE,IENDW,IERR)
      ENDIF
      IF(IERR.NE.0) THEN
        CLOSE(NIN) 
        IF(NOUT1.GT.0) CLOSE(NOUT1) 
        RETURN
      ENDIF
      IF(NOUT1.GT.0) THEN
        IF(MODE.EQ.0) THEN
          CR_XYZ(1)= DSS /SCALEF
          CR_XYZ(2)= DNS1/SCALEF
          CR_XYZ(3)= DNS2/SCALEF
          CR_OCC   = WHX /SCALEF
          CR_BISO  = WT  /SCALEF
          CR_SURF  = 0.0
        ENDIF
        CALL WRCRD(M,NOUT1,MODE,IENDW1,IERR)
      ENDIF
      IF(IERR.NE.0) THEN
        CLOSE(NIN) 
        IF(NOUT.GT.0) CLOSE(NOUT) 
        RETURN
      ENDIF
      GO TO 1000
C ----------------------------
 2000 CONTINUE
      WRITE(LINE,'(''N_atoms   :'',I8)') N_SHFT
      CALL MSGDOC(MDOC,LINE)    
      WRITE(LINE,'(''RMS_shift :'',G12.4)') SHFT_RMS
      CALL MSGDOC(MDOC,LINE)    
      WRITE(LINE,'(''<shift>   :'',G12.4)') SHFT_AVER
      CALL MSGDOC(MDOC,LINE)    
      WRITE(LINE,'(''MAX_shift :'',G12.4)') SHFT_MAX
      CALL MSGDOC(MDOC,LINE)    
      WRITE(LINE,'(''RMS_deriv :'',G12.4)') DRV_RMS
      CALL MSGDOC(MDOC,LINE)    
      WRITE(LINE,'(''<deriv>   :'',G12.4)') DRV_AVER
      CALL MSGDOC(MDOC,LINE)    

      CLOSE(NIN)
      IEND=1
      MODE=0     
      IF(NOUT.GT.0) THEN
        CALL WRCRD(MDOC,NOUT,MODE,IEND,IERR)
        CLOSE(NOUT)
      ENDIF
      IF(NOUT1.GT.0) THEN
        CALL WRCRD(MDOC,NOUT1,MODE,IEND,IERR)
        CLOSE(NOUT1)
      ENDIF

      RESULT(1)  =CFVOL
      RESULT(2)  =COEF
      RESULT(3)  =SIGMA
      RESULT(4)  =SIGMAD  
      RESULT(5)  =SCALEF
C     RESULT(6)  =BADD
      RESULT(7)  =SHESSX
      RESULT(8)  =SHESSD
      RESULT(9)  =DRV_RMS
      RESULT(10) =SHFT_RMS
      RESULT(11) =DISPFR

      RETURN
      END

      SUBROUTINE HESS_X(MDOC,BADD
     * ,NCOORD,NCOORM,IBFACT,IZMOCC,IXCC,IYCC,IZCC,ISCODE,IANUMB
     * ,IRECRD,GRADX,GRADY,GRADZ,GRADB,GRADQ,GRADW,GHESSX,GHESSB
     * ,NSYM,ISYM,IPRSYM,IERR)
C-----------------------------------------------------------------------
C- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
C      <<<< HESSIAN >>>> CALC  FOR XYZ
C     PRINCIPLE IS THAT SUMMATION OVER HKL CONVERTED TO 1 DIMENSIONAL
C     INTEGRATION OVER S (SEE EQUATION 62 & 63 (PAPER))
C     ACTUALLY CALCULATES H1(XM,XM)/A1**2 (DENOTED AS HX) WITH OTHER
C     ELEMENTS OF MATRIX OBTAINED FROM SYMMETRY RELATIONS IN PAPER.
C- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
C        (SPACE GROUP GENERAL, MULT BY VOLUME &
C     OCC**2 & SCALE**2  OUTSIDE THIS SUBROUTINE
C-----------------------------------------------------------------------
C------------------------------------------------------
CMS     : IBFACT,IZMOCC,IXCC,IYCC,IZCC
C --- integer*2 version
C     INTEGER*2        IBFACT(NCOORM),IZMOCC(NCOORM)
C    *                ,IXCC(NCOORM),IYCC(NCOORM),IZCC(NCOORM)
C    *                ,ISCODE(NCOORM),IANUMB(NCOORM),IRECRD(NCOORM)
C --- integer*4 version
      INTEGER         IBFACT(NCOORM),IZMOCC(NCOORM)
     *                ,IXCC(NCOORM),IYCC(NCOORM),IZCC(NCOORM)
     *                ,ISCODE(NCOORM),IANUMB(NCOORM),IRECRD(NCOORM)
C ---
      REAL             GRADX(NCOORM),GRADY(NCOORM),GRADZ(NCOORM)
     *                ,GRADB(NCOORM),GRADQ(NCOORM),GRADW(NCOORM)
     *                ,GHESSX(NCOORM),GHESSB(NCOORM)
      INTEGER          NCOORD,NCOORM
      INTEGER*2        ISYM(5,3,IPRSYM)
      INTEGER*4        NSYM,IPRSYM
C------------------------------------------------------
      COMMON/COMINF/ NDENSP,NDENSM,NZERO,SUMRP,SUMRM,SD1T,SD2T,CFVOL
     *               ,DOBS_AV,DMOD_AV,SCALED,SIGMA,SIGMAD,SDIFFT
C------------------------------------------------------
      COMMON/CELL/   A,B,C,ALPHA,BETA,GAMMA,ISPHR,DLIM,H2OBG,ICELL
     *             ,VOLUME,SCALEF,GMODE,DMODE,POSITIV,P1
      CHARACTER     GMODE*1,DMODE*1,POSITIV*1,P1*1
      COMMON/DIM/    DMAX,NX,NY,NZ,IZMIN,IZMAX,IHMAX,IKMAX,ILMAX
C --------------------------
      PARAMETER (NFMMAX=15)
      COMMON/FORMS_FFT/   NFMFC,IZFMFC(15),FMFCA(5,15),
     *                FMFCB(5,15),HESS_A(15),CATOM
      CHARACTER       CATOM(15)*2
C-------------------------------------------------------------
      REAL   BD(50),HD(50)
C------------------------------------------------------------------
      IERR=0
C --- integer*2 version
C     IPACK=10000
C --- integer*4 version
      IPACK=100000
C ---
      NATREC=NCOORD
      COEF=(FLOAT(NX)*FLOAT(NY)*FLOAT(NZ))
      SX=A/NX
      SY=B/NY
      SZ=C/NZ
C
      PI   =4.0*ATAN(1.0)
      PISQ4=4.0*PI*PI
      COSA =COS(ALPHA)
      SINA =SIN(ALPHA)
      COSG =COS(GAMMA)
      SING =SIN(GAMMA)
      COSB =COS(BETA)
      SINB =SIN(BETA)
C      COSZ  DEFINES THE ANGLE BETWEEN C AND CSTAR
      COSZ=SQRT(1.-COSA**2-COSB**2-COSG**2+2.*COSA*COSB*COSG)/SING
      DV=8.0*SX*SY*SZ*COSZ*SING*PI**1.5
C
C  CELL VOLUME
C
      S=(ALPHA+BETA+GAMMA)*0.5
      VOL=2.0*A*B*C*
     *    SQRT(SIN(S)*SIN(S-ALPHA)*SIN(S-BETA)*SIN(S-GAMMA))
      COEF=COEF/VOL
      VOLUME=VOL
C      write(*,*) ' coef,dmax,dv ', coef ,dmax, dv
C --------------------------
      IBDMAX=40
      DO    I=1,20
        BD(I)=I
        HD(I)=0.
      ENDDO
      DO    I=21,IBDMAX
        BD(I)=4*I-60
        HD(I)=0.
      ENDDO
      SMAX=1.0/(DMAX)
      SSQMAX=SMAX*SMAX
      IS=INT(.5+200.*SSQMAX)
      DO    I=1,IS
        SSQ=.005*I-.0025
        S=SQRT(SSQ)
        D1=.0025*(S**(3.))*(8./3.)*PI**3
        DO    J=1,IBDMAX
          HD(J)=HD(J)+D1*EXP(-.25*SSQ*BD(J))
        ENDDO
      ENDDO
      DO    IATREC=1,NATREC
        IATM_P=IRECRD(IATREC)
        IAN   =IANUMB(IATM_P)
        IBOCC =IZMOCC(IATM_P)
        BAT   =IBFACT(IATM_P)/10.0
        SCALE=1.0
        BT=BAT+BADD
        IF(BT.GT.99.0) BT=99.0
        IZZ=IBOCC/1000
        IT =IBOCC-IZZ*1000
        OCC=IT/10.
        IF(OCC.LT.0.0001) THEN
          GHESSB(IATM_P)=0.0
          GHESSX(IATM_P)=0.0
          GO TO 100
        ENDIF
        IF(BT.LT.0.0) THEN
          CALL MSGERR(MDOC,' ERR: B-FACTOR < 0.0 ')
          IERR=1
          RETURN
        ENDIF
        IF(IZZ.LE.0.OR.IZZ.GT.NFMFC) THEN 
          CALL MSGERR(MDOC,' ERR: IDENTIFY FORMFACTORS = ?')
          IERR=1
          RETURN
        ENDIF
        NELC=IZFMFC(IZZ)
        DVOCC=OCC*DV
        HESSX=0.0
        B2 = 2.0*BT
        DO     I=1,5
        DO     J=1,5
          BDD=FMFCB(I,IZZ) + FMFCB(J,IZZ) + B2
          IF(BDD.GE.BD(IBDMAX)) BDD=BD(IBDMAX) -.01
          IF(BDD.LT.BD(1)) BDD=BD(1)
          IF(BDD.LE.BD(20)) THEN
            I1=INT(BDD)
            F1=BDD-I1
          ELSE
            D2=15+0.25*BDD
            I1=INT(D2)
            F1=D2-I1
          ENDIF
          FMC = FMFCA(I,IZZ)*FMFCA(J,IZZ)
          HESSX=HESSX+FMC*((1.-F1)*HD(I1)+F1*HD(I1+1))
        ENDDO
        ENDDO

C        SHX=HESSX*4.0*DMAX*DMAX
        BBADD=BADD
        IF(BBADD.LT.4.0) BBADD=4.0
        SHX=(HESSX*SQRT(BBADD))/2.0

        IF(NELC.EQ.1) SHX=SHX*8.0
        GHESSX(IATM_P)=SHX

        BTT=BAT+(4.0*DMAX*DMAX)+4.0
        SHB = NELC*(((8.0*PI*PI)/BTT)**2.5)*((1.0/(2.0*PI))**1.5)
        IF(NELC.EQ.1) SHB=SHB*8.0
        GHESSB(IATM_P)=SHB

 100    CONTINUE
      ENDDO
      RETURN
      END

      SUBROUTINE HESS_B(MDOC,BADD
     * ,NCOORD,NCOORM,IBFACT,IZMOCC,IXCC,IYCC,IZCC,ISCODE,IANUMB
     * ,IRECRD,GRADX,GRADY,GRADZ,GRADB,GRADQ,GRADW,GHESSX,GHESSB
     * ,NSYM,ISYM,IPRSYM,IERR)
C-----------------------------------------------------------------------
C- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
C      <<< HESSIAN >>> FOR B   (SPACE GROUP GENERAL, MULT BY VOLUME &
C     OCC**2 & SCALE**2  OUTSIDE THIS SUBROUTINE
C- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
C------------------------------------------------------
CMS     : IBFACT,IZMOCC,IXCC,IYCC,IZCC
C --- integer*2 version
C     INTEGER*2        IBFACT(NCOORM),IZMOCC(NCOORM)
C    *                ,IXCC(NCOORM),IYCC(NCOORM),IZCC(NCOORM)
C    *                ,ISCODE(NCOORM),IANUMB(NCOORM),IRECRD(NCOORM)
C --- integer*4 version
      INTEGER        IBFACT(NCOORM),IZMOCC(NCOORM)
     *                ,IXCC(NCOORM),IYCC(NCOORM),IZCC(NCOORM)
     *                ,ISCODE(NCOORM),IANUMB(NCOORM),IRECRD(NCOORM)
C ---
      REAL             GRADX(NCOORM),GRADY(NCOORM),GRADZ(NCOORM)
     *                ,GRADB(NCOORM),GRADQ(NCOORM),GRADW(NCOORM)
     *                ,GHESSX(NCOORM),GHESSB(NCOORM)
      INTEGER          NCOORD,NCOORM
      INTEGER*2        ISYM(5,3,IPRSYM)
      INTEGER*4        NSYM,IPRSYM
C------------------------------------------------------
      COMMON/COMINF/ NDENSP,NDENSM,NZERO,SUMRP,SUMRM,SD1T,SD2T,CFVOL
     *               ,DOBS_AV,DMOD_AV,SCALED,SIGMA,SIGMAD,SDIFFT
C------------------------------------------------------
      COMMON/CELL/   ACL,BCL,CCL,ALPHA,BETA,GAMMA,ISPHR,DLIM,H2OBG,ICELL
     *             ,VOLUME,SCALEF,GMODE,DMODE,POSITIV,P1
      CHARACTER     GMODE*1,DMODE*1,POSITIV*1,P1*1
      COMMON/DIM/    DMAX,NX,NY,NZ,IZMIN,IZMAX,IHMAX,IKMAX,ILMAX
C --------------------------
      PARAMETER (NFMMAX=15)
      COMMON/FORMS_FFT/   NFMFC,IZFMFC(15),FMFCA(5,15),
     *                FMFCB(5,15),HESS_A(15),CATOM
      CHARACTER       CATOM(15)*2
C-------------------------------------------------------------
      REAL*4          BD(50),HD(50)
C-------------------------------------------------------------
      IERR=0
C --- integer*2 version
C     IPACK=10000
C --- integer*4 version
      IPACK=100000
C ---
      NATREC = NCOORD
      COEF   = (FLOAT(NX)*FLOAT(NY)*FLOAT(NZ))
      SX     = ACL/NX
      SY     = BCL/NY
      SZ     = CCL/NZ

C
      PI    = 4.0*ATAN(1.0)
      PISQ4 = 4.0*PI*PI
      COSA  = COS(ALPHA)
      SINA  = SIN(ALPHA)
      COSG  = COS(GAMMA)
      SING  = SIN(GAMMA)
      COSB  = COS(BETA)
      SINB  = SIN(BETA)
C      COSZ  DEFINES THE ANGLE BETWEEN C AND CSTAR
      COSZ  = SQRT(1.-COSA**2-COSB**2-COSG**2+2.*COSA*COSB*COSG)/SING
      DV    = 8.0*SX*SY*SZ*COSZ*SING*PI**1.5
C
C  CELL VOLUME
C
      S      = (ALPHA+BETA+GAMMA)*0.5
      VOL    = 2.0*ACL*BCL*CCL*
     *         SQRT(SIN(S)*SIN(S-ALPHA)*SIN(S-BETA)*SIN(S-GAMMA))
      COEF   = COEF/VOL
      VOLUME = VOL
      IBDMAX = 40
      DO    I=1,20
        BD(I) = I
        HD(I) = 0.
      ENDDO
      DO    I=21,IBDMAX
        BD(I) = 4*I-60
        HD(I) = 0.0
      ENDDO
      SMAX    = 1.0/(DMAX)
      SSQMAX  = SMAX*SMAX
      IS      = INT(.5+200.*SSQMAX)
      DO    I=1,IS
        SSQ  = .005*I-.0025
        S    = SQRT(ABS(SSQ))
        D1   = .0025*(S**(6.))*PI/8.
        DO    J=1,IBDMAX
          HD(J)=HD(J)+D1*EXP(-.25*SSQ*BD(J))
        ENDDO
      ENDDO
      DO    IATREC=1,NATREC
        IATM_P = IRECRD(IATREC)
        IAN    = IANUMB(IATM_P)
        IBOCC  = IZMOCC(IATM_P)
        BT     = IBFACT(IATM_P)/10.0
        BT     = BT+BADD
        IZZ    = IBOCC/1000
        IT     = IBOCC-IZZ*1000
        OCC    = IT/10.
        IF(OCC.LT.0.0001) THEN
          GHESSB(IATM_P) = 0.0
          GO TO 100
        ENDIF
        IF(BT.LT.0.0) THEN
          CALL MSGERR(MDOC,' ERR: B-FACTOR < 0.0 ')
          IERR=1
          RETURN
        ENDIF
        IF(IZZ.LE.0.OR.IZZ.GT.NFMFC) THEN 
          CALL MSGERR(MDOC,' ERR: IDENTIFY FORMFACTORS = ?')
          IERR=1
          RETURN
        ENDIF
        DVOCC = OCC*DV
        SHB   = 0.0
        DO     I=1,5
        DO     J=1,5
          BDD = FMFCB(I,IZZ)+FMFCB(J,IZZ)+2.*BT
          IF(BDD.GE.BD(IBDMAX)) BDD = BD(IBDMAX) -.01
          IF(BDD.LT.BD(1)     ) BDD = BD(1)
          IF(BDD.LE.BD(20)) THEN
            I1 = INT(BDD)
            F1 = BDD-I1
          ELSE
            D2 = 15+0.25*BDD
            I1 = INT(D2)
            F1 = D2-I1
          ENDIF
          CD  = FMFCA(I,IZZ)*FMFCA(J,IZZ)
          SHB = SHB + CD*((1.-F1)*HD(I1)+F1*HD(I1+1))
        ENDDO
        ENDDO
C ?
        SHB = SHB*2.0
        
c        GHESSB(IATM_P) = SHB
 100    CONTINUE
      ENDDO
      RETURN
      END
C -I-
      SUBROUTINE FMINUSF(MDOC,F_NAME,F2_NAME,FO_NAME,SCALER
     *        ,ISYM,IPRSYM,RESULT,IPRROW,IERR)
C ----------------------------------------------------
C -P- FMINUSF : ! !F1! - scale * !F2! !
C -S-
C      Dialogue and Batch:
C
C     FILE_F: - input file_1 of the modules of structure factors.
C     FILE_2: - input file_2 of the modules of structure factors.
C     SCALE: <1.0> - scale : !F1! - scale * !F2!
C     FILE_O:         - output_file /" " means without output/
C
C       It is possible to use the subroutine READ_SF by program:
C
C      SUBROUTINE F-F(MDOC,F_NAME,F2_NAME,FO_NAME,SCALER
C     *          ,ISYM,IPRSYM,RESULT,IPRROW,IERR)
C
C  Parameters of subroutine: 
C
C    MDOC  - mode of writting messages to DOC-file
C            0 - only terminal , < - 0 only file, 0 < < 99 - both
C            >= 99 - don't write  
C    F_NAME  - input file_1 of the modules of structure factors.
C    F2_NAME - input file_2 of the modules of structure factors.
C    FO_NAME - output file /" " means without output/
C    SCALE: <1.0> - scale : !F1! - scale * !F2!
C    ISYM    - integer*2 array for cryst.symmetry operators.
C    IPRSYM  - dimension of integer*2 array ISYM(5,3,IPRSYM),
C              number of cryst. symm. operators.
C    IERR    - output signal of error / =1 -error , =o - OK / 
C
C    RESULT /real RESULT(IPRROW)/ - array for output information:
C
C    RESULT(1) - 
C    RESULT(2) - 
C -I-
C ------------------------------
      INTEGER*2 ISYM(5,3,IPRSYM)
      REAL      RESULT(IPRROW)
      INTEGER*4 MDOC,IERR
      CHARACTER F_NAME*(*),F2_NAME*(*),FO_NAME*(*)
C ==============================
      INTEGER*4 MTIN,MTNAT,MTOUT
      CHARACTER ITYPE*4,ITYP*4,ITF1*4,ITF2*4,ITFW*4
      CHARACTER LINE*80,TTT*80,TITLE*80,MODE*1
C -----------------------------------------------------------
      M    = 99
      MD   =-ABS(MDOC)-1
      MODE = 'F'
      IF(IERR.LT.0) MODE = 'I'
      IERR = 0
      SLIM = 0.0
C

      MT1 = 20
      CALL LENSTR_BL(F_NAME,LEN)
      IF(LEN.LE.0.OR.F_NAME(1:1).EQ.' '.OR.F_NAME(1:1).EQ.',') THEN
        IERR=1
        RETURN
      ENDIF
      ITYP = 'FF  '

      CALL ORFILE(MD,MT1,F_NAME,ITYP,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MD,' ERR: OPEN FILE-F-1')
        RETURN
      ENDIF
      CALL GET_TITLE(MD,A,B,C,AL,BE,GA
     *  ,COEF1,BET1,RN,RX,IDM,IDM,IDM,IDM,IDM,TITLE,IERR)
      ITF1 = ITYP
      CALL C_RD_CR
C -------------------------------------------------------------
      MT2   = 21
      ITYPE = 'FF  '
      CALL LENSTR_BL(F2_NAME,LEN)
      IF(LEN.LE.0.OR.F2_NAME(1:1).EQ.' '.OR.F2_NAME(1:1).EQ.',') THEN
        MT2 = 0
      ELSE
        CALL ORFILE(MD,MT2,F2_NAME,ITYPE,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MDOC,' ERR: OPEN FILE-2')
          CLOSE(MT1)
          RETURN
        ENDIF
        CALL GET_TITLE(MD,A1,B1,C1,AL1,BE1,GA1
     *  ,DM1,DM2,RN1,RX1,IDM,IDM,IDM,IDM,IDM,TTT,IERR)
        ITF2=ITYPE
      ENDIF
C -----------------
      SCALE = SCALER
      IF(ABS(SCALE).LT.0.000001) SCALE = 1.0
C ---
      RESMIN = 0.0
      RESMAX = 0.0
      IF(RESMIN.LE.0.0)   RESMIN = RN
      IF(RESMAX.LE.0.0)   RESMAX = RX
      IF(RN .LT.RESMIN)   RESMIN = RN
      IF(RX .GT.RESMAX)   RESMAX = RX
      IF(MT2.GT.0) THEN
        IF(RN1.LT.RESMIN)   RESMIN = RN1
        IF(RX1.GT.RESMAX)   RESMAX = RX1
      ENDIF
      WRITE(LINE,'(''RESOLUTION MIN,MAX '',2F7.2)') RESMIN,RESMAX
      CALL MSGDOC(MD,LINE)
      RHMIN = 1.0/(RESMIN)
      RHMAX = 1.0/(RESMAX)
C ---------------
      MTOUT = 0
      CALL LENSTR_BL(FO_NAME,LEN)
      IF(LEN.GT.0.AND.FO_NAME(1:1).NE.' '.AND.FO_NAME(1:1).NE.',') THEN
        MTOUT=30
        CALL C_CR_WR
        CALL SET_TITLE(MD,A,B,C,
     *  AL,BE,GA,COEF1,BET1,RESMIN,RESMAX,
     *  IDM,IDM,IDM,IDM,IDM,TITLE,IERR)
        ITFW = ITF1 
        CALL OWFILE(MD,MTOUT,FO_NAME,ITFW,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) THEN
          CLOSE (MT1)
          IF(MT2.GT.0) CLOSE (MT2)
          CALL MSGERR(MDOC,' ERR: OPEN FILE-OUTPUT')
          IERR=1
          RETURN
        ENDIF
      ENDIF
C ----------------------------------------------------------
      CALL INIT_CENTR(NSYM,ISYM)
      CALL ANOMF(M,NSYM,ISYM)
      CALL LIMHKL(RESMAX,IHMAX,IKMAX,ILMAX,NXMIN,NYMIN,NZMIN)
C ---
      SUMA  = 0.0
      SUMB  = 0.0
      NTOT1 = 0
      NTOT2 = 0
      NTOT  = 0
C ----
      KEYW  = 0
      IEND1 =-1
      IEND2 =-1
      IENDW =-1
      JH    =-200
      JK    =-200
      JL    =-200
      KH    =-200
      KK    =-200
      KL    =-200
C -----------------------------------------
      DO     IL=0,ILMAX
      DO     IK=-IKMAX,IKMAX
      DO     IH=-IHMAX,IHMAX
        IF(IH.EQ.0.AND.IK.EQ.0.AND.IL.EQ.0) GO TO 100
        IHP = IH
        IKP = IK
        ILP = IL
C                 IANOM    - 0   +h,+k,+l
C                            1   -h,-k,-l
C                 JJSYM    - number operator of symmetry :
C                                 in(h,k,l) -- JJSYM --> out(h,k,l)
        CALL ANOMSC(IHP,IKP,ILP,IANOM,JJSYM,NSYM,ISYM)
        IF(IANOM.NE.1.OR.JJSYM.NE.1) GO TO 100

        IF(NSYM.GT.1) THEN
C
C         SYSABS - check systematic absent for h,k,l: 1 - absent, 0 - no.
C
          CALL SYSABS_BL(IH,IK,IL,NSYM,ISYM,ICND)
        ELSE
          ICND = 0
        ENDIF
C
C ---   ICND NE 0 systematic absent
C
        IF(ICND.NE.0) GO TO 100
C 
C       DSTAR - gives value of (4pi*sin(theta))/lambda for H,K,L
C
        CALL DSTAR(IH,IK,IL,RSQ)
        RH = SQRT(RSQ)
        IF(RH.LT.RHMIN.OR.RH.GT.RHMAX) GO TO 100
C ---
C       CENTR_BL - Determine whether a reflection (IH,IK,IL) is centric or not

        CALL CENTR_BL(IH,IK,IL,JCENT)
C
C ---   JCENT = 1 centric reflection, JCENT = 0 acentric reflection
C ---
C ------
  200   CONTINUE
        IMISS1=1
        IF(IEND1.GT.0)                    GO TO 300

C        IF(JL-IL) 240,210,300
C  210   IF(JK-IK) 240,220,300
C  220   IF(JH-IH) 240,230,300

        IF(JL.LT.IL) GO TO 240
        IF(JL.GT.IL) GO TO 300
        IF(JK.LT.IK) GO TO 240
        IF(JK.GT.IK) GO TO 300
        IF(JH.LT.IH) GO TO 240
        IF(JH.GT.IH) GO TO 300
        GO TO 230

C ------
  240   CONTINUE
C 
        IF(ITF1.EQ.'FS  ') THEN
          CALL RRD1(MT1,JH,JK,JL,FN,FNA,SN,SNA,KEY1,IEND1)
        ELSE
          CALL RD1(MT1,JH,JK,JL,FN,FNA,KEY1,IEND1)

C         SIG-DUMMY
          SN  = 0.04*FN
          SNA = 0.04*FNA
        ENDIF

C       IFLAG_FREE = KEY1/2        
C       IFLAG_FREE = KEY1 - IFLAG_FREE*2 
C       if IFLAG_FREE = 1 - free reflection
 
        IF(MT1.LE.0) THEN
          CALL MSGERR(MDOC,' ERR: READ FILE_1')
          IF(MT2.GT.0)   CLOSE (MT2)
          IF(MTOUT.GT.0) CLOSE (MTOUT)
          IERR=1
          RETURN
        ENDIF
        IF(IEND1.GT.0)                   GO TO 300
        IF(FN.LE.1.E-6.AND.FNA.LE.1.E-6) GO TO 300
        FA  = FN
        FB  = FNA
        SFA = SN
        SFB = SNA
        IF(FN.GT.1.E-6.AND.FNA.GT.1.E-6) THEN
          WT1 = 1./(SN*SN)
          WT2 = 1./(SNA*SNA)
          WT  = WT1+WT2
          FN  = FN*WT1+FNA*WT2
          FN  = FN/WT
          SN  = 1./SQRT(WT)
        ELSE IF(FNA.GT.1.E-6) THEN
          FN = FNA
          SN = SNA
        ENDIF
        IF(MT2.LE.0) THEN
          IF(FB.GT.1.E-6.AND.FA.GT.1.E-6) THEN
            FN = FA
            FD = FB
            SN = SFA
            SF = SFB
          ELSE
            FN =-1.0
            FD =-1.0
            SF = 0.0
            SN = 0.0
          ENDIF
        ENDIF
        GO TO 200
  230   IMISS1=0
C ------
  300   CONTINUE
        IMISS2=1
        IF(IEND2.GT.0.OR.MT2.LE.0)                    GO TO 400

C        IF(KL-IL) 340,310,400
C  310   IF(KK-IK) 340,320,400
C  320   IF(KH-IH) 340,330,400

        IF(KL.LT.IL) GO TO 340
        IF(KL.GT.IL) GO TO 400
        IF(KK.LT.IK) GO TO 340
        IF(KK.GT.IK) GO TO 400
        IF(KH.LT.IH) GO TO 340
        IF(KH.GT.IH) GO TO 400
        GO TO 330
C ------
  340   CONTINUE
        IF(ITF2.EQ.'FS  ') THEN
          CALL RRD2(MT2,KH,KK,KL,FD,FDA,SF,SFA,KEY2,IEND2)
        ELSE
          CALL RD2(MT2,KH,KK,KL,FD,FDA,KEY2,IEND2)
C         SIG-DUMMY
          SF  = 0.04*FD
          SFA = 0.04*FDA
        ENDIF
        IF(MT2.LE.0) THEN
          CALL MSGERR(MDOC,' ERR: READ FILE_2')
          IF(MT1.GT.0)   CLOSE (MT1)
          IF(MTOUT.GT.0) CLOSE (MTOUT)
          IERR=1
          RETURN
        ENDIF
        IF(IEND2.GT.0)                   GO TO 400
        IF(FD.LE.1.E-6.AND.FDA.LE.1.E-6) GO TO 400
        IF(FD.GT.1.E-6.AND.FDA.GT.1.E-6) THEN
          WT1 = 1./(SF*SF)
          WT2 = 1./(SFA*SFA)
          WT  = WT1+WT2
          FD  = FD*WT1+FDA*WT2
          FD  = FD/WT
          SF  = 1./SQRT(WT)
        ELSE IF(FDA.GT.1.E-6) THEN
          FD = FDA
          SF = SFA
        ENDIF
        GO TO 300
  330   IMISS2=0
C --------------------------------------------
  400   CONTINUE
C -----------------------------------------------------
        IF(IMISS1.EQ.0.AND.(IMISS2.EQ.0.OR.MT2.LE.0)) THEN
          IF(MODE.EQ.'I') THEN
            FA    = SQRT(ABS(FN*FN - SCALE*FD*FD))
            SA    = SQRT(ABS(SN*SN+SF*SF*SCALE))
          ELSE
            IF(MT2.LE.0.AND.FN.LT.0.0) GO TO 100
            FA    = ABS(FN - SCALE*FD)
            SA    = ABS(SN + SF*SCALE)
          ENDIF
C          SA    = SN 
          NTOT  = NTOT + 1
          FB    = 0.0
          SB    = 0.0   
C ---
          IF(MTOUT.GT.0) THEN
            IF(ITFW.EQ.'F   ') THEN
              CALL WRT(MTOUT,IH,IK,IL,FA,FB,KEYW,IENDW)
            ELSE
              CALL WWRT(MTOUT,IH,IK,IL,FA,FB,SA,SB,KEYW,IENDW)
            ENDIF
            IF(MTOUT.LE.0) THEN
              CALL MSGERR(MDOC,' ERR: WRITE FILE_OUT')
              CLOSE(MT1)
              IF(MT2.GT.0) CLOSE(MT2)
              IERR=1
              RETURN
            ENDIF
          ENDIF
        ENDIF
C ----
 100  CONTINUE
      ENDDO
      ENDDO
      ENDDO
C ---------------------------------------
  110 CONTINUE
      CLOSE (MT1)
      IF(MT2.GT.0) CLOSE (MT2)
      IF(MTOUT.GT.0) THEN
        IF(NTOT.LE.0) THEN
          CALL MSGERR(MDOC,
     *    'ERROR: fminusf: number of refls to write = 0')
          CLOSE(MTOUT)
          IERR=1
          RETURN
        ENDIF
C ---
C       writes last record (  512,512,512,0,0 ) and close file
C                          
        IENDW = 2
        CALL WRT(MTOUT,IH,IK,IL,FN,FNA,KEYW,IENDW)
C ---
        IF(MTOUT.LE.0) THEN
          CALL MSGERR(MDOC,' ERR: CLOSE FILE_OUT')
          IERR=1
          RETURN
        ENDIF
      ENDIF
C ----------------------------------------------
      RESULT(1) = NTOT
      RESULT(2) = RESMIN
      RESULT(3) = RESMAX
C -----------------------------------------------------------
      WRITE(LINE,1000) NTOT
 1000 FORMAT('NUMB REFLS = ',I6)
      CALL MSGDOC(MDOC,LINE)
      RETURN
      END
C -I-
      SUBROUTINE COEF_FFT(MDOC,NAMEN,NAMED,NAMEPH,NAMEC,FOMMIN
     * ,RESMIN,RESMAX,BOFF,SLIM,DEL_LIM,DELA_LIM,DRMS,DRMS_A,LAP
     * ,SCALE,BTEMP,MSGA,ISIM,ISYM,IPRSYM,RESULT,IERR)
C -------------
C -P- COEF - calculation all kinds of the coefficients for FFT.
C            Program COEF calculates coefficients for Fourie transformation 
C            (input file for FFT). Coefficients are calculated for Patterson 
C            function, difference Patterson function, anomalous Patterson 
C            function, conventional Fourie transformation and difference Fourie
C            transformation. Sim's weighting sheme may be applied.  
C            Input files for the programm COEF are type of "F   ",
C            "FS  ", "PH  ", and output files type of "COEF".
C -S-
C  Programm calculates coefficients with phases and two file F:
C    F1 ( F1=Fnat or Fcalc ) means first file of modules SF,
C    F2 ( F2=Fder=Fobs ) - second.
C
C    A=W*FOM*(SCALE*F2-F2)*EXP(-TEMP*RSQ)*SIN(PH)
C    B=W*FOM*(SCALE*F2-F1)*EXP(-TEMP*RSQ)*COS(PH)
C                      where W - Sim''s weight, if you want it.
C                            if Sim'' weight is used SCALE=1 TEMP=0
C
C  With phases and one file which contains F(hkl) and F(-h-k-l):
C  Anomalous Furier function.
C
C    A=FOM*(SCALE * F+ - F-)*EXP(-TEMP*RSQ)*SIN(PH)
C    B=FOM*(SCALE * F+ - F-)*EXP(-TEMP*RSQ)*COS(PH)
C                                    where F+ is F(hkl), F- is F(-h-k-l)
C  With phases but 
C     ( F1 = Fnat = Fobs ) 
C    Fourie transformation
C    A=FOM*(SCALE*F1)*EXP(-TEMP*RSQ)*SIN(PH)
C    B=FOM*(SCALE*F1)*EXP(-TEMP*RSQ)*COS(PH)
C
C  Without phases and without second file F:
C     ( F1 = Fnat = Fobs ) 
C    Patterson function
C    A=(SCALE*F1)**2
C    B=2.0*SCALE*F1*sd(SCALE*F1)
C
C  Without phases and with two files F:
C  Difference Patterson function.
C    F1 ( F1=Fnat or Fcalc ) , F2 ( F2=Fder=Fobs ) 
C    A=(SCALE *F2-F1)**2
C    B=2.0*(SCALE*F2-F1)*sd(SCALE*F2-F1)
C
C  Without phases and one file which contains F(hkl) and F(-h-k-l):
C  Anomalous Patterson function.
C    A=(SCALE * F+ - F- )**2
C    B=2.0*(SCALE * F+ - F-)*sd(SCALE * F+ - F-)
C                                    where F+ is F(hkl), F- is F(-h-k-l)
C
C  With phases and one file which contains F(hkl) and F(-h-k-l):
C  Anomalous Furier function.
C    A=W*FOM*(SCALE*F2-F2)*EXP(-TEMP*RSQ)*SIN(PH)
C    B=W*FOM*(SCALE*F2-F1)*EXP(-TEMP*RSQ)*COS(PH)
C                      where W - Sim''s weight, if you want it.
C                            if Sim'' weight is used SCALE=1 TEMP=0
C
C       where RSQ - distance between planes in reciprocal space.
C             FOM - figure of merit.
C             Sim's weight - W = I1(X)/I0(X), X=(2*F1*F2)/<!F1-F2!**2>
C                                             I1,I2 - bessel functions      
C---------------------------------------------------------------
C  Dialog and Batch: 
C
C   FILE_1:  -   input file-1 of the structure factors.
C   FILE_2:  -   name of FILE-DERIV, if you want it 
C   FILE_PH: -   name of FILE-PHASE, if you want it
C   FILE_O:  -   output file of the coefficients.
C   RESOL:   MIN,MAX <from files> resolution
C   BOFF     <0> , 240 corresponds to RESmin=10 /aprox./
C                For suppressing low resolutin reflections, kind of 
C                modeling desordered solvent: Fnew=(1-exp(-Boff*s**2))*Fold    
C   ANOM:    <N>,Y     Y - if you want to use anomal-scattering,
C   FOM:     <0.0>   limit of fig-of-merit
C                     / -1 means don''t use FOM/
C   SLIM:    <0.0>   limit for F or DEL.
C                     Coefficients will be calculated
C                     only for such structure factors which are: 
C                     !F! > sd(F) * SLIM or !DEL! > sd(DEL) * SLIM
C                             where  sd -standard deviation
C   SIM:     <N>,Y    Y - if you want to use Sim"s scheme
C   LAP:     <N>,Y  - coefficients of the curvature (second derivative)
C                     will be calculated: COEF = 4 * PI**2 * S**2 * F(hkl) 
C   SCALE:   <1.0>
C   BTEMP:   <0.0>
C                     SCALE and BTEMP will be applyed:
C                     DEL = (Fder*SCALE-Fnat)*EXP(-BTEMP*RSQ
C                     or F = ( Fnat*SCALE )*EXP(-BTEMP*RSQ)
C
C      SUBROUTINE COEF(MDOC,NAMEN,NAMED,NAMEPH,NAMEC,FOMMIN
C     * ,RESMIN,RESMAX,BOFF,SLIM,LAP
C     * ,SCALE,BTEMP,MSGA,ISIM,ISYM,IPRSYM,IERR)
C
C  Parameters: 
C
C    MDOC  - mode of writting messages to DOC-file
C            0 - only terminal , < - 0 only file, 0 < < 99 - both
C            >= 99 - don't write  
C    NAMEN  - input file-1 of the structure factors.
C    NAMED  - input file-2 of the structure factors, if you want to calculate
C             difference Pattersomn or Fourie./ if not define = " " /
C    NAMEPH - input file of the phases, if you want to calculate Fourie 
C             transformation. / if not define = " " /
C    NAMEC  - output file of the coefficients.
C    MSGA   = "Y" if you want to calculate anomalous Patterson or Fourie.
C    ISIM   = 1   if you want to use Sim's sheme.
C    FOMMIN - limit of figure of merit. If reflection has FOM < FOMMIN
C             it will not used. Value FOMMIN=-1 means don't use FOM. 
C    RESMIN,RESMAX  - resolution MIN , MAX. Default values will be taken
C                     from files.
C    SCALE,BTEMP - scale and temperature factor. See above.
C    SLIM  -  Coefficients will be calculated for such structure factors 
C              which are:  
C                 !F1! > sd(F1) * SLIM  or  
C                 !(F2-F1)! > sd(F2-F1) * SLIM  or
C                 !(F(h,k,l)-F(-h,-k,-l))! > sd(F(h,k,l)-F(-h,-k,-l)) * SLIM
C    BOFF     <0> , 240 corresponds to RESmin=10 /aprox./
C    LAP     <N>,Y , "y" - coefficients of the curvature will be calculated.
C    ISYM    - integer*2 array for cryst.symmetry operators.
C    IPRSYM  - dimension of integer*2 array ISYM(5,3,IPRSYM),
C              number of cryst. symm. operators.
C    IERR    - output signal of error / =1 -error , =o - OK / 
C -I-
C--------------
      INTEGER*2 ISYM(5,3,IPRSYM)
      INTEGER   NGR(22),NBAD(22),NOUT(22),NGRA(22),NDBAD(22)
      REAL      RLATT(6)
      REAL      SMD2(22),SMDA2(22)
      REAL      SMD(22),FSD(22),ANRH(22),SUMFP(22),RFAC(22)
      REAL      SUMDA(22),AKEMP(22),SUMDF2(22),SUMDA2(22)
      REAL      RESULT(21,10)
      CHARACTER TDP*4,TCP*4,TDD*4,TCD*4
      CHARACTER TTT*80
      CHARACTER ITYP*4,ITYP1*4,ITYP2*4,ITYP3*4
      CHARACTER TARR1*4,TARR2*4
      CHARACTER LINE*80
      CHARACTER MSGA*1,LAP*1
      CHARACTER NAMEN*(*),NAMED*(*),NAMEC*(*),NAMEPH*(*)
C --------------------------------------------------------------
      IERR    = 0
      PI      = 4.0*ATAN(1.0)
      FOURPI2 =-4.0*PI*PI
C --------------------
      MD =-ABS(MDOC)-1

      ITYP1 = 'FF  '
      MTNAT = 20
      CALL LENSTR_BL(NAMEN,LEN)
      IF(LEN.LE.0.OR.NAMEN(1:1).EQ.' '.OR.NAMEN(1:1).EQ.',') THEN
        CALL MSGERR(MDOC,' ERR: FILE-F-NATI')
        IERR = 1
        RETURN
      ENDIF
      CALL ORFILE(MD,MTNAT,NAMEN,ITYP1,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERR: OPEN FILE-1')
        RETURN
      ENDIF
      CALL GET_TITLE(MD,RLATT(1),RLATT(2),RLATT(3),RLATT(4),RLATT(5)
     * ,RLATT(6),CF,BT,RN1,RX1,IDM,IDM,IDM,IDM,IDM,TTT,IERR)
      CALL C_RD_CR
      TDP   = TTT(1:4)
      TCP   = TTT(5:8)
      TARR1 = TDP
C ----
      MTDER = 21
      CALL LENSTR_BL(NAMED,LEN)
      IF(LEN.LE.0.OR.NAMED(1:1).EQ.' '.OR.NAMED(1:1).EQ.',') THEN
        MTDER = 0
      ENDIF
      IF(MTDER.GT.0) THEN
        ITYP2='FF  '
        CALL ORFILE(MD,MTDER,NAMED,ITYP2,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MDOC,' ERR: OPEN FILE-2')
          CLOSE(MTNAT)
          CLOSE(MTDER)
          RETURN
        ENDIF
        CALL GET_TITLE(MD,RLATT(1),RLATT(2),RLATT(3),RLATT(4),RLATT(5)
     *   ,RLATT(6),CF,BT,RN2,RX2,IDM,IDM,IDM,IDM,IDM,TTT,IERR)
        TDD   = TTT(1:4)
        TCD   = TTT(5:8)
        TARR2 = TDD
      ENDIF
C  -----
      MTPH = 23
      CALL LENSTR_BL(NAMEPH,LEN)
      IF(LEN.LE.0.OR.NAMEPH(1:1).EQ.' '.OR.NAMEPH(1:1).EQ.',') THEN
        MTPH = 0
      ENDIF
      IF(MTPH.GT.0) THEN
        ITYP3 = 'PH  '
        CALL ORFILE(MD,MTPH,NAMEPH,ITYP3,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MDOC,' ERR: OPEN FILE-PH')
          CLOSE(MTNAT)
          CLOSE(MTPH)
          IF(MTDER.GT.0) CLOSE(MTDER)
          RETURN
        ENDIF
        CALL GET_TITLE(MD,RLATT(1),RLATT(2),RLATT(3),RLATT(4),RLATT(5)
     *  ,RLATT(6),CF,BT,RN3,RX3,IDM,IDM,IDM,IDM,IDM,TTT,IERR)
        TDD = TTT(1:4)
        TCD = TTT(5:8)
      ENDIF
C ---
      IF(LAP .EQ.'y') LAP  = 'Y'
      IF(LAP .NE.'Y'.AND.LAP.NE.'0') LAP  = 'N'
      IF(MSGA.EQ.'y') MSGA = 'Y'
      IF(MSGA.NE.'Y') MSGA = 'N'
C ------
C     OPEN OUTPUT-FILE AND WRITE OF TITLES
C
      TTT = ' '
      IF(MTPH.EQ.0) THEN
        IF(MTDER.EQ.0) THEN
          TTT='         PATTERSON -'//TARR1
        ELSE
          TTT='         DIFF.PATT  '//TARR1//' - '//TARR2
        ENDIF
        TTT(1:4)='PATT'
        IF(MSGA.EQ.'Y') THEN
          TTT(5:8)='ANOM'
        ELSE IF(LAP.EQ.'Y') THEN
          TTT(5:8)='LAP '
        ELSE IF(LAP.EQ.'0') THEN
          TTT(5:8)='LAP0'
        ELSE
          TTT(5:8)='    '
        ENDIF
      ELSE
        IF(MTDER.EQ.0) THEN
          TTT='          FOURIE  - '//TARR1
        ELSE
          TTT='         DIFF.FOUR  '//TARR1//' - '//TARR2
        ENDIF
        TTT(1:4)='FOUR'
        IF(MSGA.EQ.'Y') THEN
          TTT(5:8)='ANOM'
        ELSE IF(LAP.EQ.'Y') THEN
          TTT(5:8)='LAP '
        ELSE
          TTT(5:8)='    '
        ENDIF
      ENDIF
C -----------
      ITYP  = 'COEF'
      MTOUT = 30
      CALL LENSTR_BL(NAMEC,LEN)
      IF(LEN.LE.0.OR.NAMEC(1:1).EQ.' '.OR.NAMEC(1:1).EQ.',') THEN
        MTOUT = 0
      ENDIF
      IF(MTOUT.GT.0) THEN
        CALL C_CR_WR
        CALL SET_TITLE(MDOC,RLATT(1),RLATT(2),RLATT(3),RLATT(4)
     *  ,RLATT(5),RLATT(6),SCALE,BTEMP,RESMIN,RESMAX,IDM,IDM,IDM,IDM
     *  ,IDM,TTT,IERR)
        CALL OWFILE(MDOC,MTOUT,NAMEC,ITYP,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MDOC,' ERR: OPEN FILE-COEF')
          CLOSE(MTOUT)
          CLOSE(MTNAT)
          IF(MTDER.GT.0) CLOSE(MTDER)
          IF(MTPH.GT.0)  CLOSE(MTPH)
          RETURN
        ENDIF
      ENDIF
C -----
      IF(MSGA.EQ.'Y')
     *  CALL MSGDOC(MD,'ANOMAL-SCATTERING WILL USED')
      IF(ISIM.EQ.1) 
     *  CALL MSGDOC(MD,'SIM"S WEIGHTING SCHEME WILL BE USED')
      IF(FOMMIN.GE.0.0.AND.MTPH.GT.0) 
     *  CALL MSGDOC(MD,'FOM WILL USED')
      CALL MSGDOC(MD, 
     * ' !F! > sd(F) * SLIM  or !DEL! > sd(DEL) * SLIM')
      WRITE(LINE,'('' SLIM :'',G12.4)') SLIM 
      CALL MSGDOC(MD,LINE)
      IF(ISIM.EQ.0) THEN
        CALL MSGDOC(MD,' SCALE AND BTEMP WILL BE APPLYED :')
        CALL MSGDOC(MD,
     *  '    DEL  = (Fder*SCALE-Fnat)*EXP(-BTEMP*RSQ)')
        CALL MSGDOC(MD,
     *   ' or  F   = ( Fnat *SCALE   )*EXP(-BTEMP*RSQ)')
        WRITE(LINE,'(''SCALE,BTEMP :'',2F8.3)') SCALE,BTEMP
        CALL MSGDOC(MD,LINE)
      ENDIF
C -----
      CALL DSTARF(RLATT,AS,BS,CS,ALS,BES,GAS,VOL)
C -----
      IF(RESMIN.LT.RESMAX) THEN
        T      = RESMIN
        RESMIN = RESMAX
        RESMAX = T
      ENDIF
      IF(RESMIN.LE.0.0) RESMIN=1.0E30
      IF(RESMIN.GT.RN1) RESMIN=RN1
      IF(MTDER.GT.0) THEN
        IF(RESMIN.GT.RN2) RESMIN=RN2
      ENDIF
      IF(MTPH.GT.0) THEN
        IF(RESMIN.GT.RN3) RESMIN=RN3
      ENDIF
      IF(RESMAX.LT.RX1) RESMAX=RX1
      IF(MTDER.GT.0) THEN
        IF(RESMAX.LT.RX2) RESMAX=RX2
      ENDIF
      IF(MTPH.GT.0) THEN
        IF(RESMAX.LT.RX3) RESMAX=RX3
      ENDIF
      WRITE(LINE,'(''RESOLUTIOM: MIN,MAX '',2F7.2)') 
     *  RESMIN,RESMAX
      CALL MSGDOC(MD,LINE)
C ---
      WRITE(LINE,'(''DEL_LIM,RMS :'',2F7.2)') DEL_LIM,DRMS
      CALL MSGDOC(MD,LINE)
      WRITE(LINE,'(''DELA_LIM,RMS:'',2F7.2)') DELA_LIM,DRMS_A
      CALL MSGDOC(MD,LINE)
C ----
      NPOINT  = 20
      NPOINT1 = NPOINT + 1
      RHMIN   = 1./RESMIN-0.00001
      RHMAX   = 1./RESMAX
      ANCR    = (RHMAX-RHMIN)/NPOINT
      ANRH(1) = RESMIN
      DO  I=2,NPOINT+2
        R       = ANCR+1./ANRH(I-1)
        ANRH(I) = 1./R
      ENDDO
      FOMMN2 = FOMMIN*FOMMIN
C ================================================================
C  --- START OF CALC ----     NPASS=2 ONLY FOR SIM-COEF
C
      NPASS = 1
      IF(ISIM.EQ.1) NPASS = 2
      IF(MTDER.GT.0.AND.MSGA.EQ.'Y') NPASS = 2
      IF(MTDER.EQ.0.AND.LAP.EQ.'0' ) NPASS = 2
      NALL = 0
C ==================================
      DO    IPASS=1,NPASS
        IF(IPASS.EQ.2) THEN
          REWIND MTNAT
          IPRINT = 0
          MDOCC  = 99
          ITYP1  = '    '
          CALL OPFILE(MDOCC,MTNAT,NAMEN,ITYP1,NSYM,ISYM,IPRSYM,IERR)
          IF(LAP.EQ.'0') THEN
            DO I=1,NPOINT1
              AKEMP(I) = 0.0
              IF(NGR(I).GT.0) THEN
                AKEMP(I) = SUMDF2(I)/NGR(I)
              ENDIF
            ENDDO
            WRITE(LINE,'(A,F10.3)') ' Kemp =',AKEMP(1)
            CALL MSGDOC(MDOC,LINE)
          ELSE
            REWIND MTDER
            IF(ISIM.EQ.1) THEN
              FSIG = FSIG/NALL
              WRITE(LINE,'(A,F10.3)') ' FSIG=<(Fo-Fc)**2>=',FSIG
              CALL MSGDOC(MDOC,LINE)
              NALL = 0
            ENDIF
            IF(MSGA.EQ.'Y') THEN
              DO I=1,NPOINT1
                IF(SUMDA2(I).GT.0.000001) THEN
                  AKEMP(I) = SQRT(ABS(SUMDF2(I)/SUMDA2(I)))
                ENDIF
              ENDDO
              WRITE(LINE,'(A,F10.3)') ' Kemp =',AKEMP(1)
              CALL MSGDOC(MDOC,LINE)
            ENDIF
          ENDIF
        ELSE
          FSIG = 0.0
          WSIM = 1.0
        ENDIF
C ---------------------------
C       INITIALIZATION
C
        DO I=1,NPOINT+2
          SUMDA2(I)  = 0.0
          SUMDF2(I)  = 0.0
          SUMDA (I)  = 0.0
          IF(IPASS.EQ.1) AKEMP(I) = 0.0
          SMD   (I)  = 0.0
          SMD2  (I)  = 0.0
          SMDA2 (I)  = 0.0
          FSD   (I)  = 0.0
          RFAC  (I)  = 0.0
          SUMFP (I)  = 0.0
          NGR   (I)  = 0
          NGRA  (I)  = 0
          NOUT  (I)  = 0
          NBAD  (I)  = 0
          NDBAD (I)  = 0
        ENDDO

        DEL_MAX   = 0.0
        DEL_AVER  = 0.0
        DEL2_AVER = 0.0
        DEL_RMS   = 0.0
        FP_MAX    = 0.0
        FD_MAX    = 0.0
        NTOT_DEL  = 0

        DELA_MAX   = 0.0
        DELA_AVER  = 0.0
        DELA2_AVER = 0.0
        DELA_RMS   = 0.0
        NTOT_DELA  = 0

        IANOM   = 0
        JANOM   = 0
        NUMB    = 0
        NUMB1   = 0
        NUMB2   = 0
        NUMB3   = 0
        NUMB4   = 0
        NBSD    = 0
        NBFOM   = 0
        NBSLIM  = 0
        NBDLIM  = 0
        NBDLIMA = 0
        NSTAT   = 0
        NNOUT   = 0
        IHH     =-512
        IKK     =-512
        ILL     =-512
        LHH     =-512
        LKK     =-512
        LLL     =-512
        IEND1   =-1
        IEND2   =-1
        IEND3   =-1
        IEND4   =-1
        AD      = 0.0
        SAD     = 0.0
        AP      = 0.0
        SAP     = 0.0
        DEL     = 0.0
        ADEL    = 0.0
C ------
  460   CONTINUE
        JANOM = 0
        IF(IEND1.GT.0) GO TO 560
C ------
C       READ OF ONE REFLS-NATI
        IF(ITYP1.EQ.'F   ') THEN
          CALL RD1(MTNAT,JHH,JKK,JLL,AP,BP,NUMB1,IEND1)
C         SIG-DUMMY
          SAP = 0.04*AP
          SBP = 0.04*BP
        ELSE
          CALL RRD1(MTNAT,JHH,JKK,JLL,AP,BP,SAP,SBP,NUMB1,IEND1)
        ENDIF
C -----------------
C        F(0,0,0)
C
        IF(JHH.EQ.0.AND.JKK.EQ.0.AND.JLL.EQ.0) THEN
          IF(MTDER.EQ.0.AND.MSGA.NE.'Y') THEN
            IF(LAP.EQ.'Y') GO TO 460
            IF(MTPH.NE.0) THEN
              FAA = AP*SCALE
            ELSE
              FAA = AP*AP
              IF(LAP.EQ.'0'.AND.IPASS.EQ.2) THEN
                FAA = FAA - AKEMP(1)
              ELSE
                FAA = FAA*SCALE*SCALE
              ENDIF
            ENDIF
            FBB = 0.
            CALL WRT(MTOUT,JHH,JKK,JLL,FAA,FBB,NUMB3,IEND3)
            GO TO 460
          ELSE
            GO TO 460
          ENDIF
        ENDIF
C ------------------
        IF(MSGA.EQ.'Y'.AND.MTDER.EQ.0) THEN
          IF(AP.LE.1.E-6.OR.BP.LE.1.E-6) GO TO 460
          AD    = AP
          SAD   = SAP
          AP    = BP
          SAP   = SBP
          IANOM = 1
        ELSE
          IF(AP.LE.1.E-6.AND.BP.LE.1.E-6) GO TO 460
          IF(AP.GT.1.E-6.AND.BP.GT.1.E-6) THEN
            IF(SAP.LT.0.000001) SAP = 1.0
            IF(SBP.LT.0.000001) SBP = 1.0
            WT1 = 1./(SAP*SAP)
            WT2 = 1./(SBP*SBP)
            WT  = WT1+WT2
            AP  = AP*WT1+BP*WT2
            AP  = AP/WT
            SAP = 1./SQRT(WT)
          ELSE IF(BP.GT.1.E-6) THEN
            AP  = BP
            SAP = SBP
          ENDIF
        ENDIF
C
C       NOW : F-NATI=AP  OR FOR ANOMAL-SCATT. F(+)=AD  F(-)=AP
C              SIG  =SAP                      SIG =SAD SIG=SAP
C -------------------------------------------------------------
C       READ OF F-DERIV FOR THIS REFL.
C
        FDPLUS  = 0.0
        FDMINUS = 0.0
        JANOM   = 0
  550   IF(IEND1.GT.0.OR.IEND2.GT.0) GO TO 560
        IF(MTDER.EQ.0) GO TO 360

C        IF(ILL-JLL) 370,340,460
C  340   IF(IKK-JKK) 370,350,460
C  350   IF(IHH-JHH) 370,360,460

        IF(ILL.LT.JLL) GO TO 370
        IF(ILL.GT.JLL) GO TO 460
        IF(IKK.LT.JKK) GO TO 370
        IF(IKK.GT.JKK) GO TO 460
        IF(IHH.LT.JHH) GO TO 370
        IF(IHH.GT.JHH) GO TO 460
        GO TO 360

  370   IF(IEND2.GT.0) GO TO 560
        IF(ITYP2.EQ.'F   ') THEN
          CALL RD2(MTDER,IHH,IKK,ILL,AD,BD,NUMB2,IEND2)
C         SIG-DUMMY
          SAD = 0.04*AD
          SBD = 0.04*BD
        ELSE
          CALL RRD2(MTDER,IHH,IKK,ILL,AD,BD,SAD,SBD,NUMB2,IEND2)
        ENDIF
        FDPLUS  = 0.0
        FDMINUS = 0.0
        JANOM   = 0
        IF(AD.LE.1.E-6.AND.BD.LE.1.E-6) GO TO 370
C -------
        IF(AD.GT.1.E-6.AND.BD.GT.1.E-6) THEN
          IF(SAD.LT.0.000001) SAD = 1.0
          IF(SBD.LT.0.000001) SBD = 1.0
          IF(MSGA.EQ.'Y') THEN
            FDPLUS  = AD
            FDMINUS = BD
            IANOM   = 1
            JANOM   = 1
          ENDIF
          WT1 = 1./(SAD*SAD)
          WT2 = 1./(SBD*SBD)
          WT  = WT1+WT2
          AD  = AD*WT1+BD*WT2
          AD  = AD/WT
          SAD = 1./SQRT(WT)
        ELSE IF(BD.GT.1.E-6) THEN
          AD  = BD
          SAD = SBD
        ENDIF
        GO TO 550
C
C       NOW : F-DERIV=AD
C               SIG  =SAD
C --------------------------------------------------
C       READ PHASE FOR THIS REFL.
C
  360   CONTINUE
        IF(MTPH.EQ.0) GO TO 9360

        IF(NPASS.EQ.2) THEN
          IF(IPASS.EQ.1) GO TO 9360
        ENDIF

        IF(IEND4.GT.0) GO TO 560

C        IF(LLL-JLL) 9370,9340, 460
C 9340   IF(LKK-JKK) 9370,9350, 460
C 9350   IF(LHH-JHH) 9370,9360, 460

         IF(LLL.LT.JLL) GO TO 9370
         IF(LLL.GT.JLL) GO TO 460
         IF(LKK.LT.JKK) GO TO 9370
         IF(LKK.GT.JKK) GO TO 460
         IF(LHH.LT.JHH) GO TO 9370
         IF(LHH.GT.JHH) GO TO 460
         GO TO 9360

 9370   IF(IEND4.GT.0) GO TO 560
        CALL RD3(MTPH,LHH,LKK,LLL,COPH,SIPH,NUMB4,IEND4)
        TESTFOM = COPH*COPH + SIPH*SIPH
        IF(TESTFOM.LT.FOMMN2) THEN
          NBFOM = NBFOM + 1
          GO TO 460
        ENDIF
        IF(FOMMIN.LT.0.0) THEN
          TEMP1 = SQRT(TESTFOM)
          IF(TEMP1.GT.0.000001) COPH = COPH/TEMP1
          IF(TEMP1.GT.0.000001) SIPH = SIPH/TEMP1
        ENDIF
        GO TO 360
C
C       NOW : PHASE= COPH,SIPH  
C --------------------------------------
C       CHECK OF RESOLUTION
C
 9360   CONTINUE
        CALL DSTAR(JHH,JKK,JLL,RSQ)
        RH = SQRT(RSQ)
        IF(RH.LT.RHMIN.OR.RH.GT.RHMAX) THEN
          NNOUT = NNOUT+1
          GO TO 460
        ENDIF
        CBOFF = 1.0
        IF(BOFF.GT.0.0) THEN
          BT    = BOFF/4.0
          CBOFF = 1.0-EXP(-BT*RSQ)
          AD    = AD *CBOFF
          SAD   = SAD*CBOFF
          AP    = AP *CBOFF
          SAP   = SAP*CBOFF
        ENDIF
        NALL = NALL + 1
        KK   = (RH-RHMIN)/ANCR+2.5
        IF(KK.GT.NPOINT1)  KK = NPOINT1
C ------------------------------------------
        IOUT  = 0
        IOUTA = 1
        DEL   = 0.0
        DDEL  = 0.0
        ADEL  = 0.0
        AADEL = 0.0
          

        BT   = BTEMP/4.0
        TEMP = EXP(-BT*RSQ)

        IF(MTDER.NE.0.OR.MSGA.EQ.'Y') THEN
C
C         CALC OF DELTA :    DIFF-PATT / DIFF-FOUR / ANOMAL-DIFF
C
          DDEL  = AD - AP
          SSD   = SQRT(SAP*SAP+SAD*SAD)
          DEL   = (AD*SCALE-AP)*TEMP
          SD    = SQRT(ABS(SAP*SAP+SAD*SAD*SCALE*SCALE))*TEMP
          APS   = AP * TEMP
          AADEL = FDPLUS-FDMINUS
          ADEL  = AADEL*CBOFF*TEMP
C
          IF(ISIM.EQ.1) THEN
            IF(IPASS.EQ.1) THEN
              FSIG = FSIG+DDEL*DDEL
              ICHK = MOD(NALL,1000)
              IF(ICHK.EQ.0) THEN
                WRITE(LINE,3331) WSIM,FSIG
                CALL MSGDOC(MDOC,LINE)
              ENDIF
            ELSE
              IF(FSIG.GT.0.0000001) XX = 2.*AD*AP/FSIG
              WSIM = 1.
              IF(XX.LE.6.) WSIM = XX*(.5658-XX*(.1304-.0106*XX))
              ICHK = MOD(NALL,1000)
              IF(ICHK.EQ.0) THEN
                WRITE(LINE,3333) NALL,WSIM,FSIG,XX
                CALL MSGDOC(MDOC,LINE)
              ENDIF
 3333         FORMAT(' ',5X,I5,3F10.3)
 3331         FORMAT(' ',5X,F8.3,E12.4)
              DEL  = DDEL *WSIM
              ADEL = AADEL*WSIM
              SD   = SSD  *WSIM
              APS  = AP   *WSIM
            ENDIF
          ENDIF

          STOR = ABS(DEL)
          IF(SD.GT.0.0000001) THEN
            FSDD = STOR/SD
          ELSE
            FSDD = 0.0
          ENDIF
          AMD = AD + AP

        ELSE
C
C         CALC OF F-MOD :    PATT / FOUR /
C
          DDEL = AP
          SSD  = SAP
C
          IF(LAP.EQ.'0') THEN
            DEL  = AP
            SD   = SAP
          ELSE
            DEL  = AP *SCALE*TEMP
            SD   = SAP*SCALE*TEMP
          ENDIF
          APS  = DEL
          STOR = ABS(DEL)

          IF(SD.GT.0.0000001) THEN
            FSDD = STOR/SD
          ELSE
            FSDD = 0.0
          ENDIF
          AMD = DEL

        ENDIF

        IF(IPASS.EQ.1) THEN
          SUMDF2(1)  = SUMDF2(1)  + DEL *DEL
          SUMDF2(KK) = SUMDF2(KK) + DEL *DEL
          SUMDA2(1)  = SUMDA2(1)  + ADEL*ADEL
          SUMDA2(KK) = SUMDA2(KK) + ADEL*ADEL
          IF(NPASS.EQ.2) THEN
            NGR  (1)  = NGR  (1)  + 1
            NGR  (KK) = NGR  (KK) + 1
          ENDIF
        ENDIF
C -----------------------------------------------
        IF(NPASS.EQ.2.AND.IPASS.EQ.1) GO TO 460
C ------------------------------------------------
C                             PATT  FOUR   ANOM.DIFF.FOUR
C      VALUES FOR WRITE : FAA: F**2  F*COS    [(+)-(-)]*COS
C                         FBB: SIG   F*SIN   -[(+)-(-)]*SIN
C
C    ----   CHECK ----
C        TEST = SLIM * SD
C        IF(ABS(DEL).LT.TEST) THEN
C          NOUT(1) = NOUT(1)  + 1
C          NOUT(KK)= NOUT(KK) + 1
C          NBSLIM  = NBSLIM   + 1
C          IOUT    = 1
C          IOUTA   = 1
C          GO TO 460
C        ENDIF
C --------
C        AFAA = 0.0
C        IF(MTPH.EQ.0) THEN
C          IF(LAP.EQ.'Y') THEN
C            FAA = DEL*DEL*RSQ*FOURPI2
C            FBB = 2.*ABS(DEL)*SD*RSQ*FOURPI2
C          ELSE
C            FAA = DEL*DEL
C            FBB = 2.*ABS(DEL)*SD
C            IF(MSGA.EQ.'Y'.AND.MTDER.GT.0) THEN
C              AFAA  = AKEMP(KK)*AKEMP(KK)*ADEL*ADEL
C              IOUTA = 0
C            ENDIF
C          ENDIF
C        ELSE
C          IF(MSGA.EQ.'Y') THEN
C            FAA = DEL*SIPH
C            FBB =-DEL*COPH
C          ELSE
C            IF(LAP.EQ.'Y') THEN
C              FAA = DEL*COPH*RSQ*FOURPI2
C              FBB = DEL*SIPH*RSQ*FOURPI2
C            ELSE
C              FAA = DEL*COPH
C              FBB = DEL*SIPH
C            ENDIF
C          ENDIF
C        ENDIF
C -------------------------------------
        IF(ABS(DEL) .GT.DEL_MAX) DEL_MAX = ABS(DEL)
        IF(AP       .GT.FP_MAX ) FP_MAX  = AP
        IF(AD       .GT.FD_MAX ) FD_MAX  = AD
        NTOT_DEL   = NTOT_DEL   + 1
        DEL_AVER   = DEL_AVER   + ABS(DEL)
        DEL2_AVER  = DEL2_AVER  + ABS(DEL)*ABS(DEL) 
        IF(MTPH.EQ.0.AND.MSGA.EQ.'Y'.AND.MTDER.GT.0) THEN
          IF(ABS(ADEL).GT.DELA_MAX) DELA_MAX = ABS(ADEL)
          DELA_AVER  = DELA_AVER  + ABS(ADEL)
          DELA2_AVER = DELA2_AVER + ADEL*ADEL
          NTOT_DELA  = NTOT_DELA  + 1
          IOUTA      = 0
        ENDIF
C --------------------------------------
C    ----   CHECK ----
        TEST = SLIM * SD
        IF(ABS(DEL).LT.TEST) THEN
          NOUT(1) = NOUT(1)  + 1
          NOUT(KK)= NOUT(KK) + 1
          NBSLIM  = NBSLIM   + 1
          IOUT    = 1
          IOUTA   = 1
C          GO TO 460
        ENDIF
        IF(ABS(DEL).GT.DEL_LIM.AND.DEL_LIM.GT.0.0000001) THEN
          NDBAD(1)  = NDBAD(1)  + 1
          NDBAD(KK) = NDBAD(KK) + 1
          NBDLIM    = NBDLIM    + 1
          IOUT      = 1
C         GO TO 460
        ENDIF

c        t = 0.0
c        del_o = del
c        IF(DRMS.GT.0.000001.AND.DEL_LIM.GT.0.0000001
c     *                     .AND.IOUT.EQ.0) THEN
c          X   = DEL_LIM-ABS(DEL)
c          T   = EXP(-(X*X)/(2.0*DRMS*DRMS))
c          T   = 1.0 - T
c          IF(T.GT.1.0) T=1.0
c          IF(T.LT.0.0) T=0.0
c          DEL = DEL * T
c        ENDIF
C        WRITE(*,*) DEL,del_o,DEL_LIM,DRMS,T,iout

        IF(IOUTA.EQ.0.AND.ABS(ADEL).GT.DELA_LIM.AND.
     *                    DELA_LIM.GT.0.0000001) THEN
          NBDLIMA   = NBDLIMA   + 1
          IOUTA     = 1
C         GO TO 460
        ENDIF
C ------------------------------------------------
        AFAA = 0.0
        IF(MTPH.EQ.0) THEN
          IF(LAP.EQ.'Y') THEN
            FAA = DEL*DEL*RSQ*FOURPI2
            FBB = 2.*ABS(DEL)*SD*RSQ*FOURPI2
          ELSE IF(MTDER.EQ.0.AND.LAP.EQ.'0') THEN
            FAA = DEL*DEL - AKEMP(KK)*SCALE*TEMP
            FBB = 2.*ABS(DEL)*SD
          ELSE
            FAA = DEL*DEL
            FBB = 2.*ABS(DEL)*SD
            IF(MSGA.EQ.'Y'.AND.MTDER.GT.0) THEN
              AFAA  = AKEMP(KK)*AKEMP(KK)*ADEL*ADEL
            ENDIF
          ENDIF
        ELSE
          IF(MSGA.EQ.'Y') THEN
            FAA = DEL*SIPH
            FBB =-DEL*COPH
          ELSE
            IF(LAP.EQ.'Y') THEN
              FAA = DEL*COPH*RSQ*FOURPI2
              FBB = DEL*SIPH*RSQ*FOURPI2
            ELSE
              FAA = DEL*COPH
              FBB = DEL*SIPH
            ENDIF
          ENDIF
        ENDIF
C --------------------------------------
C       STATISTICS
C
        IF(IOUT.EQ.0) THEN
          SUMFP(1)  = SUMFP(1)  + APS
          SMD  (1)  = SMD  (1)  + ABS(DEL)
          SMD2 (1)  = SMD2 (1)  + ABS(DEL)*ABS(DEL)
          FSD  (1)  = FSD  (1)  + FSDD
          NGR  (1)  = NGR  (1)  + 1
          SUMFP(KK) = SUMFP(KK) + APS
          SMD  (KK) = SMD  (KK) + ABS(DEL)
          SMD2 (KK) = SMD2 (KK) + ABS(DEL)*ABS(DEL)
          FSD  (KK) = FSD  (KK) + FSDD
          NGR  (KK) = NGR  (KK) + 1
        ENDIF
        IF(IOUTA.EQ.0.AND.JANOM.EQ.1) THEN
          SUMDA(1)   = SUMDA(1)  + ABS(ADEL)
          SUMDA(KK)  = SUMDA(KK) + ABS(ADEL)
          SMDA2(1)   = SMDA2(1)  + ABS(ADEL)*ABS(ADEL)
          SMDA2(KK)  = SMDA2(KK) + ABS(ADEL)*ABS(ADEL)
          NGRA (1)   = NGRA (1)  + 1
          NGRA (KK)  = NGRA (KK) + 1
        ENDIF
        IF(FSDD.GT.1.) NSTAT = NSTAT + 1
C------------------------------------------------------------
C       WRITE TO OUTPUT-FILE
C
        IF(IPASS.EQ.NPASS) THEN
          IF(IOUT.EQ.0.OR.IOUTA.EQ.0) THEN
            NUMB = NUMB+1
            IF(MTDER.GT.0.AND.MSGA.EQ.'Y'.AND.MTPH.EQ.0
     *        .AND.IANOM.EQ.1) THEN
              IF(IOUT .EQ.1) FAA  = 0.0
              IF(IOUTA.EQ.1) AFAA = 0.0 
              FAA = FAA + AFAA
            ENDIF
            IF(MTOUT.GT.0) 
     *      CALL WRT(MTOUT,JHH,JKK,JLL,FAA,FBB,NUMB3,IEND3)
          ENDIF
        ENDIF
C------------------------------------------------------------
        GO TO 460
C ==================
  560   CONTINUE
      ENDDO
C =======================================================================
C     WRITE LAST RECORD AND END-OF-FILE
C
      IEND3 = 2
      IF(NUMB.LE.0) THEN
        CALL MSGERR(MDOC,'ERR: number of coefficients = 0.')
        IF(MTOUT.GT.0) CLOSE(MTOUT)
        CLOSE(MTNAT)
        IF(MTDER.GT.0) CLOSE(MTDER)
        IF(MTPH.GT.0)  CLOSE(MTPH)
        IERR=1
        RETURN
      ENDIF
      IF(MTOUT.GT.0) CALL WRT(MTOUT,JHH,JKK,JLL,FAA,FBB,NUMB3,IEND3)
C --------------------------------------------------------------
C     WRITE OF INFORMATION TO FILE-DOCUMENT
C     CALC R-FACTOR
C
      WRITE(LINE,680) NUMB
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,681) NNOUT
      CALL MSGDOC(MDOC,LINE)
  680 FORMAT(' NUMBER OF REFLS=',I6)
  681 FORMAT(' OUT OF RESOLUTION=',I6)
C
      IF(MTPH.NE.0) THEN
        WRITE(LINE,'(A,I8)') ' N-BAD REFLS < FOM-MIN:',NBFOM
        CALL MSGDOC(MDOC,LINE)
      ENDIF
      WRITE(LINE,'(A,I8)') ' N-BAD REFLS for SLIM :',NBSLIM
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,'(A,I8)') ' N  DEL > DEL_LIM     :',NBDLIM
      CALL MSGDOC(MDOC,LINE)

      DO I=1,NPOINT1
        RESULT(I,1) = ANRH(I)  
        IF(NGR(I).GT.0) THEN
          RESULT(I,2) = SMD(I)     /NGR(I)  
          RESULT(I,3) = SUMFP(I)   /NGR(I)  
          RESULT(I,4) = RESULT(I,2)/RESULT(I,3)
          RESULT(I,8) = FSD(I)     /NGR(I)
        ELSE
          RESULT(I,2) = 0.0
          RESULT(I,3) = 0.0
          RESULT(I,4) = 0.0
        ENDIF
        RESULT(I,5) = NGR(I)  
        IF(NGRA(I).GT.0) THEN
          RESULT(I,6) = SUMDA(I)/NGRA(I)  
        ELSE
          RESULT(I,6) = 0.0
        ENDIF
        RESULT(I,7) = NGRA(I)  
      ENDDO

      IF(NTOT_DEL.GT.0) THEN
        DEL_AVER  = DEL_AVER/NTOT_DEL
        DEL2_AVER = DEL2_AVER/NTOT_DEL
        DEL_RMS   = SQRT(ABS(DEL2_AVER-DEL_AVER*DEL_AVER))
      ENDIF
      IF(NTOT_DELA.GT.0) THEN
        DELA_AVER  = DELA_AVER/NTOT_DELA
        DELA2_AVER = DELA2_AVER/NTOT_DELA
        DELA_RMS   = SQRT(ABS(DELA2_AVER-DELA_AVER*DELA_AVER))
      ENDIF

      RESULT( 1,9) = FP_MAX
      RESULT( 2,9) = FD_MAX
      RESULT( 3,9) = DEL_MAX
      RESULT( 4,9) = DEL_AVER
      RESULT( 5,9) = DEL_RMS
      RESULT( 6,9) = NTOT_DEL
      RESULT( 7,9) = DELA_MAX
      RESULT( 8,9) = DELA_AVER
      RESULT( 9,9) = DELA_RMS
      RESULT(10,9) = NTOT_DELA
      RESULT(11,9) = NUMB
      RESULT(12,9) = NNOUT
      RESULT(13,9) = NBSLIM
      RESULT(14,9) = NBDLIM
      RESULT(15,9) = NBDLIMA
      RESULT(16,9) = NBFOM

C     RESULT(I,1) = RESOL
C     RESULT(I,2) = DEL = !FOBS -FDER!
C     RESULT(I,3) = FOBS 
C     RESULT(I,4) = RFAC
C     RESULT(I,5) = N
C     RESULT(I,6) = DEL_ano 
C     RESULT(I,7) = Nano
C     RESULT(I,8) = F/S or D/S
C     RESULT(1,9) = FP_MAX
C     RESULT(2,9) = FD_MAX
C     RESULT(3,9) = DEL_MAX

   
      DO I=2,9
c        I2 = (I-1)*2+1
        I2 = I*2-1
        ANRH (I) = ANRH (I2)
        NGR  (I) = NGR  (I2-1) + NGR  (I2) 
        NGRA (I) = NGRA (I2-1) + NGRA (I2) 
        SUMFP(I) = SUMFP(I2-1) + SUMFP(I2) 
        SMD  (I) = SMD  (I2-1) + SMD  (I2) 
        SUMDA(I) = SUMDA(I2-1) + SUMDA(I2) 
        FSD  (I) = FSD  (I2-1) + FSD  (I2) 
        NOUT (I) = NOUT (I2-1) + NOUT (I2) 
        AKEMP(I) = AKEMP(I2-1) + AKEMP(I2) 
      ENDDO

      NPOINT_PRINT = 9

      DO     I=1,NPOINT_PRINT
        IF(NGR(I).GT.0) THEN
C           < FP >
          SUMFP(I)=SUMFP(I)/NGR(I)
C           < !DEL! >
          SMD(I) =SMD(I)/NGR(I)
C          R-FAC
          RFAC(I) =SMD(I)/SUMFP(I)
C           < FD+DP >
          FSD(I) =FSD(I)/NGR(I)
        ENDIF
        IF(NGRA(I).GT.0) THEN
C           < !DEL_anom! >
          SUMDA(I) =SUMDA(I)/NGRA(I)
        ENDIF
      ENDDO


      WRITE(LINE,700)  (ANRH(I),I=1,8),RESMAX
      CALL MSGDOC(MDOC,LINE)
      IF(MTDER.NE.0.OR.MSGA.EQ.'Y') THEN
        WRITE(LINE,721)  (SMD(I),I=1,9)
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,760)  (SUMFP(I),I=1,9)
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,720)  (RFAC(I),I=1,9)
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,722)  (FSD(I),I=1,9)
        CALL MSGDOC(MDOC,LINE)
      ELSE
        WRITE(LINE,724)  (SMD(I),I=1,9)
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,723)  (FSD(I),I=1,9)
        CALL MSGDOC(MDOC,LINE)
      ENDIF

  
      WRITE(LINE,730)  (NGR(I),I=1,9)
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,731)  (NOUT(I),I=1,9)
      CALL MSGDOC(MDOC,LINE)
      IF(MTDER.GT.0.AND.MSGA.EQ.'Y'
     * .AND.IANOM.EQ.1.AND.MTPH.EQ.0) THEN
        WRITE(LINE,725)  (AKEMP(I),I=1,9)
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,726)  (SUMDA(I),I=1,9)
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,727)  (NGRA(I),I=1,9)
        CALL MSGDOC(MDOC,LINE)
      ENDIF

      IF(NUMB3.GT.0) THEN
        WRITE(LINE,'('' N-REFLS GT SIGMA:'',I6)') NSTAT
        CALL MSGDOC(MDOC,LINE)
        PERS = NSTAT/FLOAT(NUMB3)
        WRITE(LINE,'('' PERCENT > SD    :'',F6.3)') PERS
        CALL MSGDOC(MDOC,LINE)
      ENDIF
      CLOSE(MTNAT)
      IF(MTDER.GT.0) CLOSE(MTDER)
      IF(MTPH.GT.0)  CLOSE(MTPH)
      IF(MSGA.EQ.'Y'.AND.IANOM.EQ.0) MSGA='N'



c      WRITE(LINE,'(''N   :'',3I6,2F10.2)') 
c     * NUMB,NNOUT,NBSLIM,FP_MAX,FD_MAX
c      CALL MSGDOC(MDOC,LINE)
c
c      WRITE(LINE,'(''DEL :'',2I6,3F10.2)') 
c     * NTOT_DEL,NBDLIM,DEL_MAX,DEL_AVER,DEL_RMS
c      CALL MSGDOC(MDOC,LINE)
c
c      WRITE(LINE,'(''DELA:'',2I6,3F10.2)') 
c     * NTOT_DELA,NBDLIMA,DELA_MAX,DELA_AVER,DELA_RMS
c      CALL MSGDOC(MDOC,LINE)



      RETURN

  700 FORMAT('Res : TOT',F7.2,7F8.2,1X,F7.2)
  724 FORMAT('F   :',F7.2,8(1X,F7.2))
  721 FORMAT('DEL :',F7.3,8(1X,F7.3))
  722 FORMAT('D/S :',F7.3,8(1X,F7.3))
  723 FORMAT('F/S :',F7.3,8(1X,F7.3))
  720 FORMAT('Rfac:',F7.3,8(1X,F7.3))
  760 FORMAT('Fn  :',F7.3,8(1X,F7.3))
  730 FORMAT('N   :',I7,  8(1X,I7))
  731 FORMAT('bad :',I7,  8(1X,I7))
  725 FORMAT('Kemp:',F7.1,8(1X,F7.1))
  726 FORMAT('Dano:',F7.3,8(1X,F7.3))
  727 FORMAT('Nano:',I7,  8(1X,I7))
      END

C -I-
      SUBROUTINE COEF_FFT2(MDOC,NAMEN,NAMED,NAMEPH,NAMEC,FOMMIN
     * ,RESMIN,RESMAX,BOFF,SLIM,DEL_LIM,DELA_LIM,DRMS,DRMS_A,LAP
     * ,SCALE,BTEMP,MSGA,ISIM,ISYM,IPRSYM,RESULT,IERR)
C -------------
C -P- COEF - calculation all kinds of the coefficients for FFT.
C            Program COEF calculates coefficients for Fourie transformation 
C            (input file for FFT). Coefficients are calculated for Patterson 
C            function, difference Patterson function, anomalous Patterson 
C            function, conventional Fourie transformation and difference Fourie
C            transformation. Sim's weighting sheme may be applied.  
C            Input files for the programm COEF are type of "F   ",
C            "FS  ", "PH  ", and output files type of "COEF".
C -S-
C  Programm calculates coefficients with phases and two file F:
C    F1 ( F1=Fnat or Fcalc ) means first file of modules SF,
C    F2 ( F2=Fder=Fobs ) - second.
C
C    A=W*FOM*(SCALE*F2-F2)*EXP(-TEMP*RSQ)*SIN(PH)
C    B=W*FOM*(SCALE*F2-F1)*EXP(-TEMP*RSQ)*COS(PH)
C                      where W - Sim''s weight, if you want it.
C                            if Sim'' weight is used SCALE=1 TEMP=0
C
C  With phases and one file which contains F(hkl) and F(-h-k-l):
C  Anomalous Furier function.
C
C    A=FOM*(SCALE * F+ - F-)*EXP(-TEMP*RSQ)*SIN(PH)
C    B=FOM*(SCALE * F+ - F-)*EXP(-TEMP*RSQ)*COS(PH)
C                                    where F+ is F(hkl), F- is F(-h-k-l)
C  With phases but 
C     ( F1 = Fnat = Fobs ) 
C    Fourie transformation
C    A=FOM*(SCALE*F1)*EXP(-TEMP*RSQ)*SIN(PH)
C    B=FOM*(SCALE*F1)*EXP(-TEMP*RSQ)*COS(PH)
C
C  Without phases and without second file F:
C     ( F1 = Fnat = Fobs ) 
C    Patterson function
C    A=(SCALE*F1)**2
C    B=2.0*SCALE*F1*sd(SCALE*F1)
C
C  Without phases and with two files F:
C  Difference Patterson function.
C    F1 ( F1=Fnat or Fcalc ) , F2 ( F2=Fder=Fobs ) 
C    A=(SCALE *F2-F1)**2
C    B=2.0*(SCALE*F2-F1)*sd(SCALE*F2-F1)
C
C  Without phases and one file which contains F(hkl) and F(-h-k-l):
C  Anomalous Patterson function.
C    A=(SCALE * F+ - F- )**2
C    B=2.0*(SCALE * F+ - F-)*sd(SCALE * F+ - F-)
C                                    where F+ is F(hkl), F- is F(-h-k-l)
C
C  With phases and one file which contains F(hkl) and F(-h-k-l):
C  Anomalous Furier function.
C    A=W*FOM*(SCALE*F2-F2)*EXP(-TEMP*RSQ)*SIN(PH)
C    B=W*FOM*(SCALE*F2-F1)*EXP(-TEMP*RSQ)*COS(PH)
C                      where W - Sim''s weight, if you want it.
C                            if Sim'' weight is used SCALE=1 TEMP=0
C
C       where RSQ - distance between planes in reciprocal space.
C             FOM - figure of merit.
C             Sim's weight - W = I1(X)/I0(X), X=(2*F1*F2)/<!F1-F2!**2>
C                                             I1,I2 - bessel functions      
C---------------------------------------------------------------
C  Dialog and Batch: 
C
C   FILE_1:  -   input file-1 of the structure factors.
C   FILE_2:  -   name of FILE-DERIV, if you want it 
C   FILE_PH: -   name of FILE-PHASE, if you want it
C   FILE_O:  -   output file of the coefficients.
C   RESOL:   MIN,MAX <from files> resolution
C   BOFF     <0> , 240 corresponds to RESmin=10 /aprox./
C                For suppressing low resolutin reflections, kind of 
C                modeling desordered solvent: Fnew=(1-exp(-Boff*s**2))*Fold    
C   ANOM:    <N>,Y     Y - if you want to use anomal-scattering,
C   FOM:     <0.0>   limit of fig-of-merit
C                     / -1 means don''t use FOM/
C   SLIM:    <0.0>   limit for F or DEL.
C                     Coefficients will be calculated
C                     only for such structure factors which are: 
C                     !F! > sd(F) * SLIM or !DEL! > sd(DEL) * SLIM
C                             where  sd -standard deviation
C   SIM:     <N>,Y    Y - if you want to use Sim"s scheme
C   LAP:     <N>,Y  - coefficients of the curvature (second derivative)
C                     will be calculated: COEF = 4 * PI**2 * S**2 * F(hkl) 
C   SCALE:   <1.0>
C   BTEMP:   <0.0>
C                     SCALE and BTEMP will be applyed:
C                     DEL = (Fder*SCALE-Fnat)*EXP(-BTEMP*RSQ
C                     or F = ( Fnat*SCALE )*EXP(-BTEMP*RSQ)
C
C      SUBROUTINE COEF(MDOC,NAMEN,NAMED,NAMEPH,NAMEC,FOMMIN
C     * ,RESMIN,RESMAX,BOFF,SLIM,LAP
C     * ,SCALE,BTEMP,MSGA,ISIM,ISYM,IPRSYM,IERR)
C
C  Parameters: 
C
C    MDOC  - mode of writting messages to DOC-file
C            0 - only terminal , < - 0 only file, 0 < < 99 - both
C            >= 99 - don't write  
C    NAMEN  - input file-1 of the structure factors.
C    NAMED  - input file-2 of the structure factors, if you want to calculate
C             difference Pattersomn or Fourie./ if not define = " " /
C    NAMEPH - input file of the phases, if you want to calculate Fourie 
C             transformation. / if not define = " " /
C    NAMEC  - output file of the coefficients.
C    MSGA   = "Y" if you want to calculate anomalous Patterson or Fourie.
C    ISIM   = 1   if you want to use Sim's sheme.
C    FOMMIN - limit of figure of merit. If reflection has FOM < FOMMIN
C             it will not used. Value FOMMIN=-1 means don't use FOM. 
C    RESMIN,RESMAX  - resolution MIN , MAX. Default values will be taken
C                     from files.
C    SCALE,BTEMP - scale and temperature factor. See above.
C    SLIM  -  Coefficients will be calculated for such structure factors 
C              which are:  
C                 !F1! > sd(F1) * SLIM  or  
C                 !(F2-F1)! > sd(F2-F1) * SLIM  or
C                 !(F(h,k,l)-F(-h,-k,-l))! > sd(F(h,k,l)-F(-h,-k,-l)) * SLIM
C    BOFF     <0> , 240 corresponds to RESmin=10 /aprox./
C    LAP     <N>,Y , "y" - coefficients of the curvature will be calculated.
C    ISYM    - integer*2 array for cryst.symmetry operators.
C    IPRSYM  - dimension of integer*2 array ISYM(5,3,IPRSYM),
C              number of cryst. symm. operators.
C    IERR    - output signal of error / =1 -error , =o - OK / 
C -I-
C--------------
      INTEGER*2 ISYM(5,3,IPRSYM)
      INTEGER   NGR(22),NBAD(22),NOUT(22),NGRA(22),NDBAD(22)
      REAL      RLATT(6)
      REAL      SMD2(22),SMDA2(22)
      REAL      SMD(22),FSD(22),ANRH(22),SUMFP(22),RFAC(22)
      REAL      SUMDA(22),AKEMP(22),SUMDF2(22),SUMDA2(22)
      REAL      RESULT(21,10)
      CHARACTER TDP*4,TCP*4,TDD*4,TCD*4
      CHARACTER TTT*80
      CHARACTER ITYP*4,ITYP1*4,ITYP2*4,ITYP3*4
      CHARACTER TARR1*4,TARR2*4
      CHARACTER LINE*80
      CHARACTER MSGA*1,LAP*1
      CHARACTER NAMEN*(*),NAMED*(*),NAMEC*(*),NAMEPH*(*)
C --------------------------------------------------------------
      IERR    = 0
      PI      = 4.0*ATAN(1.0)
      FOURPI2 =-4.0*PI*PI
C --------------------
      MD =-ABS(MDOC)-1

      ITYP1 = 'FF  '
      MTNAT = 20
      CALL LENSTR_BL(NAMEN,LEN)
      IF(LEN.LE.0.OR.NAMEN(1:1).EQ.' '.OR.NAMEN(1:1).EQ.',') THEN
        CALL MSGERR(MDOC,' ERR: FILE-F-NATI')
        IERR = 1
        RETURN
      ENDIF
      CALL ORFILE(MD,MTNAT,NAMEN,ITYP1,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERR: OPEN FILE-1')
        RETURN
      ENDIF
      CALL GET_TITLE(MD,RLATT(1),RLATT(2),RLATT(3),RLATT(4),RLATT(5)
     * ,RLATT(6),CF,BT,RN1,RX1,IDM,IDM,IDM,IDM,IDM,TTT,IERR)
      CALL C_RD_CR
      TDP   = TTT(1:4)
      TCP   = TTT(5:8)
      TARR1 = TDP
C ----
      MTDER = 21
      CALL LENSTR_BL(NAMED,LEN)
      IF(LEN.LE.0.OR.NAMED(1:1).EQ.' '.OR.NAMED(1:1).EQ.',') THEN
        MTDER = 0
      ENDIF
      IF(MTDER.GT.0) THEN
        ITYP2='FF  '
        CALL ORFILE(MD,MTDER,NAMED,ITYP2,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MDOC,' ERR: OPEN FILE-2')
          CLOSE(MTNAT)
          CLOSE(MTDER)
          RETURN
        ENDIF
        CALL GET_TITLE(MD,RLATT(1),RLATT(2),RLATT(3),RLATT(4),RLATT(5)
     *   ,RLATT(6),CF,BT,RN2,RX2,IDM,IDM,IDM,IDM,IDM,TTT,IERR)
        TDD   = TTT(1:4)
        TCD   = TTT(5:8)
        TARR2 = TDD
      ENDIF
C  -----
      MTPH = 23
      CALL LENSTR_BL(NAMEPH,LEN)
      IF(LEN.LE.0.OR.NAMEPH(1:1).EQ.' '.OR.NAMEPH(1:1).EQ.',') THEN
        MTPH = 0
      ENDIF
      IF(MTPH.GT.0) THEN
        ITYP3 = 'PH  '
        CALL ORFILE(MD,MTPH,NAMEPH,ITYP3,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MDOC,' ERR: OPEN FILE-PH')
          CLOSE(MTNAT)
          CLOSE(MTPH)
          IF(MTDER.GT.0) CLOSE(MTDER)
          RETURN
        ENDIF
        CALL GET_TITLE(MD,RLATT(1),RLATT(2),RLATT(3),RLATT(4),RLATT(5)
     *  ,RLATT(6),CF,BT,RN3,RX3,IDM,IDM,IDM,IDM,IDM,TTT,IERR)
        TDD = TTT(1:4)
        TCD = TTT(5:8)
      ENDIF
C ---
      IF(LAP .EQ.'y') LAP  = 'Y'
      IF(LAP .NE.'Y') LAP  = 'N'
      IF(MSGA.EQ.'y') MSGA = 'Y'
      IF(MSGA.NE.'Y') MSGA = 'N'
C ------
C     OPEN OUTPUT-FILE AND WRITE OF TITLES
C
      TTT = ' '
      IF(MTPH.EQ.0) THEN
        IF(MTDER.EQ.0) THEN
          TTT='         PATTERSON -'//TARR1
        ELSE
          TTT='         DIFF.PATT  '//TARR1//' - '//TARR2
        ENDIF
        TTT(1:4)='PATT'
        IF(MSGA.EQ.'Y') THEN
          TTT(5:8)='ANOM'
        ELSE IF(LAP.EQ.'Y') THEN
          TTT(5:8)='LAP '
        ELSE
          TTT(5:8)='    '
        ENDIF
      ELSE
        IF(MTDER.EQ.0) THEN
          TTT='          FOURIE  - '//TARR1
        ELSE
          TTT='         DIFF.FOUR  '//TARR1//' - '//TARR2
        ENDIF
        TTT(1:4)='FOUR'
        IF(MSGA.EQ.'Y') THEN
          TTT(5:8)='ANOM'
        ELSE IF(LAP.EQ.'Y') THEN
          TTT(5:8)='LAP '
        ELSE
          TTT(5:8)='    '
        ENDIF
      ENDIF
C -----------
      ITYP  = 'COEF'
      MTOUT = 30
      CALL LENSTR_BL(NAMEC,LEN)
      IF(LEN.LE.0.OR.NAMEC(1:1).EQ.' '.OR.NAMEC(1:1).EQ.',') THEN
        MTOUT = 0
      ENDIF
      IF(MTOUT.GT.0) THEN
        CALL C_CR_WR
        CALL SET_TITLE(MDOC,RLATT(1),RLATT(2),RLATT(3),RLATT(4)
     *  ,RLATT(5),RLATT(6),SCALE,BTEMP,RESMIN,RESMAX,IDM,IDM,IDM,IDM
     *  ,IDM,TTT,IERR)
        CALL OWFILE(MDOC,MTOUT,NAMEC,ITYP,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MDOC,' ERR: OPEN FILE-COEF')
          CLOSE(MTOUT)
          CLOSE(MTNAT)
          IF(MTDER.GT.0) CLOSE(MTDER)
          IF(MTPH.GT.0)  CLOSE(MTPH)
          RETURN
        ENDIF
      ENDIF
C -----
      IF(MSGA.EQ.'Y')
     *  CALL MSGDOC(MD,'ANOMAL-SCATTERING WILL USED')
      IF(ISIM.EQ.1) 
     *  CALL MSGDOC(MD,'SIM"S WEIGHTING SCHEME WILL BE USED')
      IF(FOMMIN.GE.0.0.AND.MTPH.GT.0) 
     *  CALL MSGDOC(MD,'FOM WILL USED')
      CALL MSGDOC(MD, 
     * ' !F! > sd(F) * SLIM  or !DEL! > sd(DEL) * SLIM')
      WRITE(LINE,'('' SLIM :'',G12.4)') SLIM 
      CALL MSGDOC(MD,LINE)
      IF(ISIM.EQ.0) THEN
        CALL MSGDOC(MD,' SCALE AND BTEMP WILL BE APPLYED :')
        CALL MSGDOC(MD,
     *  '    DEL  = (Fder*SCALE-Fnat)*EXP(-BTEMP*RSQ)')
        CALL MSGDOC(MD,
     *   ' or  F   = ( Fnat *SCALE   )*EXP(-BTEMP*RSQ)')
        WRITE(LINE,'(''SCALE,BTEMP :'',2F8.3)') SCALE,BTEMP
        CALL MSGDOC(MD,LINE)
      ENDIF
C -----
      CALL DSTARF(RLATT,AS,BS,CS,ALS,BES,GAS,VOL)
C -----
      IF(RESMIN.LT.RESMAX) THEN
        T      = RESMIN
        RESMIN = RESMAX
        RESMAX = T
      ENDIF
      IF(RESMIN.LE.0.0) RESMIN=1.0E30
      IF(RESMIN.GT.RN1) RESMIN=RN1
      IF(MTDER.GT.0) THEN
        IF(RESMIN.GT.RN2) RESMIN=RN2
      ENDIF
      IF(MTPH.GT.0) THEN
        IF(RESMIN.GT.RN3) RESMIN=RN3
      ENDIF
      IF(RESMAX.LT.RX1) RESMAX=RX1
      IF(MTDER.GT.0) THEN
        IF(RESMAX.LT.RX2) RESMAX=RX2
      ENDIF
      IF(MTPH.GT.0) THEN
        IF(RESMAX.LT.RX3) RESMAX=RX3
      ENDIF
      WRITE(LINE,'(''RESOLUTIOM: MIN,MAX '',2F7.2)') 
     *  RESMIN,RESMAX
      CALL MSGDOC(MD,LINE)
C ---
      WRITE(LINE,'(''DEL_LIM,RMS :'',2F7.2)') DEL_LIM,DRMS
      CALL MSGDOC(MD,LINE)
      WRITE(LINE,'(''DELA_LIM,RMS:'',2F7.2)') DELA_LIM,DRMS_A
      CALL MSGDOC(MD,LINE)
C ----
      NPOINT  = 20
      NPOINT1 = NPOINT + 1
      RHMIN   = 1./RESMIN-0.00001
      RHMAX   = 1./RESMAX
      ANCR    = (RHMAX-RHMIN)/NPOINT
      ANRH(1) = RESMIN
      DO  I=2,NPOINT+2
        R       = ANCR+1./ANRH(I-1)
        ANRH(I) = 1./R
      ENDDO
      FOMMN2 = FOMMIN*FOMMIN
C ================================================================
C  --- START OF CALC ----     NPASS=2 ONLY FOR SIM-COEF
C
      NPASS = 1
      IF(ISIM.EQ.1) NPASS = 2
      IF(MTDER.GT.0.AND.MSGA.EQ.'Y') NPASS = 2
      NALL = 0
C ==================================
      DO    IPASS=1,NPASS
        IF(IPASS.EQ.2) THEN
          REWIND MTNAT
          REWIND MTDER
          IF(ISIM.EQ.1) THEN
            FSIG = FSIG/NALL
            WRITE(LINE,'(A,F10.3)') ' FSIG=<(Fo-Fc)**2>=',FSIG
            CALL MSGDOC(MDOC,LINE)
            NALL = 0
          ENDIF
          IF(MSGA.EQ.'Y') THEN
            DO I=1,NPOINT1
              IF(SUMDA2(I).GT.0.000001) THEN
                AKEMP(I) = SQRT(ABS(SUMDF2(I)/SUMDA2(I)))
              ENDIF
            ENDDO
            WRITE(LINE,'(A,F10.3)') ' Kemp =',AKEMP(1)
            CALL MSGDOC(MDOC,LINE)
          ENDIF
          IPRINT = 0
          MDOCC  = 99
          ITYP1  = '    '
          CALL OPFILE(MDOCC,MTNAT,NAMEN,ITYP1,NSYM,ISYM,IPRSYM,IERR)
          ITYP2='    '
          CALL OPFILE(MDOCC,MTDER,NAMED,ITYP2,NSYM,ISYM,IPRSYM,IERR)
        ELSE
          FSIG = 0.0
          WSIM = 1.0
        ENDIF
C ---------------------------
C       INITIALIZATION
C
        DO I=1,NPOINT+2
          SUMDA2(I)  = 0.0
          SUMDF2(I)  = 0.0
          SUMDA (I)  = 0.0
          IF(IPASS.EQ.1) AKEMP(I) = 0.0
          SMD   (I)  = 0.0
          SMD2  (I)  = 0.0
          SMDA2 (I)  = 0.0
          FSD   (I)  = 0.0
          RFAC  (I)  = 0.0
          SUMFP (I)  = 0.0
          NGR   (I)  = 0
          NGRA  (I)  = 0
          NOUT  (I)  = 0
          NBAD  (I)  = 0
          NDBAD (I)  = 0
        ENDDO

        DEL_MAX   = 0.0
        DEL_AVER  = 0.0
        DEL2_AVER = 0.0
        DEL_RMS   = 0.0
        FP_MAX    = 0.0
        FD_MAX    = 0.0
        NTOT_DEL  = 0

        DELA_MAX   = 0.0
        DELA_AVER  = 0.0
        DELA2_AVER = 0.0
        DELA_RMS   = 0.0
        NTOT_DELA  = 0

        IANOM   = 0
        JANOM   = 0
        NUMB    = 0
        NUMB1   = 0
        NUMB2   = 0
        NUMB3   = 0
        NUMB4   = 0
        NBSD    = 0
        NBFOM   = 0
        NBSLIM  = 0
        NBDLIM  = 0
        NBDLIMA = 0
        NSTAT   = 0
        NNOUT   = 0
        IHH     =-512
        IKK     =-512
        ILL     =-512
        LHH     =-512
        LKK     =-512
        LLL     =-512
        IEND1   =-1
        IEND2   =-1
        IEND3   =-1
        IEND4   =-1
        AD      = 0.0
        SAD     = 0.0
        AP      = 0.0
        SAP     = 0.0
        DEL     = 0.0
        ADEL    = 0.0
C ------
  460   CONTINUE
        JANOM = 0
        IF(IEND1.GT.0) GO TO 560
C ------
C       READ OF ONE REFLS-NATI
        IF(ITYP1.EQ.'F   ') THEN
          CALL RD1(MTNAT,JHH,JKK,JLL,AP,BP,NUMB1,IEND1)
C         SIG-DUMMY
          SAP = 0.04*AP
          SBP = 0.04*BP
        ELSE
          CALL RRD1(MTNAT,JHH,JKK,JLL,AP,BP,SAP,SBP,NUMB1,IEND1)
        ENDIF
C -----------------
C        F(0,0,0)
C
        IF(JHH.EQ.0.AND.JKK.EQ.0.AND.JLL.EQ.0) THEN
          IF(MTDER.EQ.0.AND.MSGA.NE.'Y') THEN
            IF(LAP.EQ.'Y') GO TO 460
            IF(MTPH.NE.0) THEN
              FAA = AP*SCALE
            ELSE
              FAA = AP*AP*SCALE*SCALE
            ENDIF
            FBB = 0.
            CALL WRT(MTOUT,JHH,JKK,JLL,FAA,FBB,NUMB3,IEND3)
            GO TO 460
          ELSE
            GO TO 460
          ENDIF
        ENDIF
C ------------------
        IF(MSGA.EQ.'Y'.AND.MTDER.EQ.0) THEN
          IF(AP.LE.1.E-6.OR.BP.LE.1.E-6) GO TO 460
          AD    = AP
          SAD   = SAP
          AP    = BP
          SAP   = SBP
          IANOM = 1
        ELSE
          IF(AP.LE.1.E-6.AND.BP.LE.1.E-6) GO TO 460
          IF(AP.GT.1.E-6.AND.BP.GT.1.E-6) THEN
            IF(SAP.LT.0.000001) SAP = 1.0
            IF(SBP.LT.0.000001) SBP = 1.0
            WT1 = 1./(SAP*SAP)
            WT2 = 1./(SBP*SBP)
            WT  = WT1+WT2
            AP  = AP*WT1+BP*WT2
            AP  = AP/WT
            SAP = 1./SQRT(WT)
          ELSE IF(BP.GT.1.E-6) THEN
            AP  = BP
            SAP = SBP
          ENDIF
        ENDIF
C
C       NOW : F-NATI=AP  OR FOR ANOMAL-SCATT. F(+)=AD  F(-)=AP
C              SIG  =SAP                      SIG =SAD SIG=SAP
C -------------------------------------------------------------
C       READ OF F-DERIV FOR THIS REFL.
C
        FDPLUS  = 0.0
        FDMINUS = 0.0
        JANOM   = 0
  550   IF(IEND1.GT.0.OR.IEND2.GT.0) GO TO 560
        IF(MTDER.EQ.0) GO TO 360

C        IF(ILL-JLL) 370,340,460
C  340   IF(IKK-JKK) 370,350,460
C  350   IF(IHH-JHH) 370,360,460

        IF(ILL.LT.JLL) GO TO 370
        IF(ILL.GT.JLL) GO TO 460
        IF(IKK.LT.JKK) GO TO 370
        IF(IKK.GT.JKK) GO TO 460
        IF(IHH.LT.JHH) GO TO 370
        IF(IHH.GT.JHH) GO TO 460
        GO TO 360

  370   IF(IEND2.GT.0) GO TO 560
        IF(ITYP2.EQ.'F   ') THEN
          CALL RD2(MTDER,IHH,IKK,ILL,AD,BD,NUMB2,IEND2)
C         SIG-DUMMY
          SAD = 0.04*AD
          SBD = 0.04*BD
        ELSE
          CALL RRD2(MTDER,IHH,IKK,ILL,AD,BD,SAD,SBD,NUMB2,IEND2)
        ENDIF
        FDPLUS  = 0.0
        FDMINUS = 0.0
        JANOM   = 0
        IF(AD.LE.1.E-6.AND.BD.LE.1.E-6) GO TO 370
C -------
        IF(AD.GT.1.E-6.AND.BD.GT.1.E-6) THEN
          IF(SAD.LT.0.000001) SAD = 1.0
          IF(SBD.LT.0.000001) SBD = 1.0
          IF(MSGA.EQ.'Y') THEN
            FDPLUS  = AD
            FDMINUS = BD
            IANOM   = 1
            JANOM   = 1
          ENDIF
          WT1 = 1./(SAD*SAD)
          WT2 = 1./(SBD*SBD)
          WT  = WT1+WT2
          AD  = AD*WT1+BD*WT2
          AD  = AD/WT
          SAD = 1./SQRT(WT)
        ELSE IF(BD.GT.1.E-6) THEN
          AD  = BD
          SAD = SBD
        ENDIF
        GO TO 550
C
C       NOW : F-DERIV=AD
C               SIG  =SAD
C --------------------------------------------------
C       READ PHASE FOR THIS REFL.
C
  360   CONTINUE
        IF(MTPH.EQ.0) GO TO 9360

        IF(NPASS.EQ.2) THEN
          IF(IPASS.EQ.1) GO TO 9360
        ENDIF

        IF(IEND4.GT.0) GO TO 560

C        IF(LLL-JLL) 9370,9340, 460
C 9340   IF(LKK-JKK) 9370,9350, 460
C 9350   IF(LHH-JHH) 9370,9360, 460

        IF(LLL.LT.JLL) GO TO 9370
        IF(LLL.GT.JLL) GO TO 460
        IF(LKK.LT.JKK) GO TO 9370
        IF(LKK.GT.JKK) GO TO 460
        IF(LHH.LT.JHH) GO TO 9370
        IF(LHH.GT.JHH) GO TO 460
        GO TO 9360

 9370   IF(IEND4.GT.0) GO TO 560
        CALL RD3(MTPH,LHH,LKK,LLL,COPH,SIPH,NUMB4,IEND4)
        TESTFOM = COPH*COPH + SIPH*SIPH
        IF(TESTFOM.LT.FOMMN2) THEN
          NBFOM = NBFOM + 1
          GO TO 460
        ENDIF
        IF(FOMMIN.LT.0.0) THEN
          TEMP1 = SQRT(TESTFOM)
          IF(TEMP1.GT.0.000001) COPH = COPH/TEMP1
          IF(TEMP1.GT.0.000001) SIPH = SIPH/TEMP1
        ENDIF
        GO TO 360
C
C       NOW : PHASE= COPH,SIPH  
C --------------------------------------
C       CHECK OF RESOLUTION
C
 9360   CONTINUE
        CALL DSTAR(JHH,JKK,JLL,RSQ)
        RH = SQRT(RSQ)
        IF(RH.LT.RHMIN.OR.RH.GT.RHMAX) THEN
          NNOUT = NNOUT+1
          GO TO 460
        ENDIF
        CBOFF = 1.0
        IF(BOFF.GT.0.0) THEN
          BT    = BOFF/4.0
          CBOFF = 1.0-EXP(-BT*RSQ)
          AD    = AD *CBOFF
          SAD   = SAD*CBOFF
          AP    = AP *CBOFF
          SAP   = SAP*CBOFF
        ENDIF
        NALL = NALL + 1
        KK   = (RH-RHMIN)/ANCR+2.5
        IF(KK.GT.NPOINT1)  KK = NPOINT1
C ------------------------------------------
        IOUT  = 0
        IOUTA = 1
        DEL   = 0.0
        DDEL  = 0.0
        ADEL  = 0.0
        AADEL = 0.0
          

        BT   = BTEMP/4.0
        TEMP = EXP(-BT*RSQ)

        IF(MTDER.NE.0.OR.MSGA.EQ.'Y') THEN
C
C         CALC OF DELTA :    DIFF-PATT / DIFF-FOUR / ANOMAL-DIFF
C
          DDEL  = AD - AP
          SSD   = SQRT(SAP*SAP+SAD*SAD)
          DEL   = (AD-AP*SCALE)*TEMP
          SD    = SQRT(ABS(SAP*SAP*SCALE*SCALE+SAD*SAD))*TEMP
          APS   = AP * TEMP
          AADEL = FDPLUS-FDMINUS
          ADEL  = AADEL*CBOFF*TEMP
C
          IF(ISIM.EQ.1) THEN
            IF(IPASS.EQ.1) THEN
              FSIG = FSIG+DDEL*DDEL
              ICHK = MOD(NALL,1000)
              IF(ICHK.EQ.0) THEN
                WRITE(LINE,3331) WSIM,FSIG
                CALL MSGDOC(MDOC,LINE)
              ENDIF
            ELSE
              IF(FSIG.GT.0.0000001) XX = 2.*AD*AP/FSIG
              WSIM = 1.
              IF(XX.LE.6.) WSIM = XX*(.5658-XX*(.1304-.0106*XX))
              ICHK = MOD(NALL,1000)
              IF(ICHK.EQ.0) THEN
                WRITE(LINE,3333) NALL,WSIM,FSIG,XX
                CALL MSGDOC(MDOC,LINE)
              ENDIF
 3333         FORMAT(' ',5X,I5,3F10.3)
 3331         FORMAT(' ',5X,F8.3,E12.4)
              DEL  = DDEL *WSIM
              ADEL = AADEL*WSIM
              SD   = SSD  *WSIM
              APS  = AP   *WSIM
            ENDIF
          ENDIF

          STOR = ABS(DEL)
          IF(SD.GT.0.0000001) THEN
            FSDD = STOR/SD
          ELSE
            FSDD = 0.0
          ENDIF
          AMD = AD + AP

        ELSE
C
C         CALC OF F-MOD :    PATT / FOUR /
C
          DDEL = AP
          SSD  = SAP
C
          DEL  = AP*SCALE*TEMP
          APS  = DEL
          SD   = SAP*SCALE*TEMP
          STOR = ABS(DEL)

          IF(SD.GT.0.0000001) THEN
            FSDD = STOR/SD
          ELSE
            FSDD = 0.0
          ENDIF
          AMD = DEL

        ENDIF

        IF(IPASS.EQ.1) THEN
          SUMDF2(1)  = SUMDF2(1)  + DEL *DEL
          SUMDF2(KK) = SUMDF2(KK) + DEL *DEL
          SUMDA2(1)  = SUMDA2(1)  + ADEL*ADEL
          SUMDA2(KK) = SUMDA2(KK) + ADEL*ADEL
        ENDIF
C -----------------------------------------------
        IF(NPASS.EQ.2.AND.IPASS.EQ.1) GO TO 460
C ------------------------------------------------
C                             PATT  FOUR   ANOM.DIFF.FOUR
C      VALUES FOR WRITE : FAA: F**2  F*COS    [(+)-(-)]*COS
C                         FBB: SIG   F*SIN   -[(+)-(-)]*SIN
C
C    ----   CHECK ----
C        TEST = SLIM * SD
C        IF(ABS(DEL).LT.TEST) THEN
C          NOUT(1) = NOUT(1)  + 1
C          NOUT(KK)= NOUT(KK) + 1
C          NBSLIM  = NBSLIM   + 1
C          IOUT    = 1
C          IOUTA   = 1
C          GO TO 460
C        ENDIF
C --------
C        AFAA = 0.0
C        IF(MTPH.EQ.0) THEN
C          IF(LAP.EQ.'Y') THEN
C            FAA = DEL*DEL*RSQ*FOURPI2
C            FBB = 2.*ABS(DEL)*SD*RSQ*FOURPI2
C          ELSE
C            FAA = DEL*DEL
C            FBB = 2.*ABS(DEL)*SD
C            IF(MSGA.EQ.'Y'.AND.MTDER.GT.0) THEN
C              AFAA  = AKEMP(KK)*AKEMP(KK)*ADEL*ADEL
C              IOUTA = 0
C            ENDIF
C          ENDIF
C        ELSE
C          IF(MSGA.EQ.'Y') THEN
C            FAA = DEL*SIPH
C            FBB =-DEL*COPH
C          ELSE
C            IF(LAP.EQ.'Y') THEN
C              FAA = DEL*COPH*RSQ*FOURPI2
C              FBB = DEL*SIPH*RSQ*FOURPI2
C            ELSE
C              FAA = DEL*COPH
C              FBB = DEL*SIPH
C            ENDIF
C          ENDIF
C        ENDIF
C -------------------------------------
        IF(ABS(DEL) .GT.DEL_MAX) DEL_MAX = ABS(DEL)
        IF(AP       .GT.FP_MAX ) FP_MAX  = AP
        IF(AD       .GT.FD_MAX ) FD_MAX  = AD
        NTOT_DEL   = NTOT_DEL   + 1
        DEL_AVER   = DEL_AVER   + ABS(DEL)
        DEL2_AVER  = DEL2_AVER  + ABS(DEL)*ABS(DEL) 
        IF(MTPH.EQ.0.AND.MSGA.EQ.'Y'.AND.MTDER.GT.0) THEN
          IF(ABS(ADEL).GT.DELA_MAX) DELA_MAX = ABS(ADEL)
          DELA_AVER  = DELA_AVER  + ABS(ADEL)
          DELA2_AVER = DELA2_AVER + ADEL*ADEL
          NTOT_DELA  = NTOT_DELA  + 1
          IOUTA      = 0
        ENDIF
C --------------------------------------
C    ----   CHECK ----
        TEST = SLIM * SD
        IF(ABS(DEL).LT.TEST) THEN
          NOUT(1) = NOUT(1)  + 1
          NOUT(KK)= NOUT(KK) + 1
          NBSLIM  = NBSLIM   + 1
          IOUT    = 1
          IOUTA   = 1
C          GO TO 460
        ENDIF
        IF(ABS(DEL).GT.DEL_LIM.AND.DEL_LIM.GT.0.0000001) THEN
          NDBAD(1)  = NDBAD(1)  + 1
          NDBAD(KK) = NDBAD(KK) + 1
          NBDLIM    = NBDLIM    + 1
          IOUT      = 1
C         GO TO 460
        ENDIF

c        t = 0.0
c        del_o = del
c        IF(DRMS.GT.0.000001.AND.DEL_LIM.GT.0.0000001
c     *                     .AND.IOUT.EQ.0) THEN
c          X   = DEL_LIM-ABS(DEL)
c          T   = EXP(-(X*X)/(2.0*DRMS*DRMS))
c          T   = 1.0 - T
c          IF(T.GT.1.0) T=1.0
c          IF(T.LT.0.0) T=0.0
c          DEL = DEL * T
c        ENDIF
C        WRITE(*,*) DEL,del_o,DEL_LIM,DRMS,T,iout

        IF(IOUTA.EQ.0.AND.ABS(ADEL).GT.DELA_LIM.AND.
     *                    DELA_LIM.GT.0.0000001) THEN
          NBDLIMA   = NBDLIMA   + 1
          IOUTA     = 1
C         GO TO 460
        ENDIF
C ------------------------------------------------
        AFAA = 0.0
        IF(MTPH.EQ.0) THEN
          IF(LAP.EQ.'Y') THEN
            FAA = DEL*DEL*RSQ*FOURPI2
            FBB = 2.*ABS(DEL)*SD*RSQ*FOURPI2
          ELSE
            FAA = DEL*DEL
            FBB = 2.*ABS(DEL)*SD
            IF(MSGA.EQ.'Y'.AND.MTDER.GT.0) THEN
              AFAA  = AKEMP(KK)*AKEMP(KK)*ADEL*ADEL
            ENDIF
          ENDIF
        ELSE
          IF(MSGA.EQ.'Y') THEN
            FAA = DEL*SIPH
            FBB =-DEL*COPH
          ELSE
            IF(LAP.EQ.'Y') THEN
              FAA = DEL*COPH*RSQ*FOURPI2
              FBB = DEL*SIPH*RSQ*FOURPI2
            ELSE
              FAA = DEL*COPH
              FBB = DEL*SIPH
            ENDIF
          ENDIF
        ENDIF
C --------------------------------------
C       STATISTICS
C
        IF(IOUT.EQ.0) THEN
          SUMFP(1)  = SUMFP(1)  + APS
          SMD  (1)  = SMD  (1)  + ABS(DEL)
          SMD2 (1)  = SMD2 (1)  + ABS(DEL)*ABS(DEL)
          FSD  (1)  = FSD  (1)  + FSDD
          NGR  (1)  = NGR  (1)  + 1
          SUMFP(KK) = SUMFP(KK) + APS
          SMD  (KK) = SMD  (KK) + ABS(DEL)
          SMD2 (KK) = SMD2 (KK) + ABS(DEL)*ABS(DEL)
          FSD  (KK) = FSD  (KK) + FSDD
          NGR  (KK) = NGR  (KK) + 1
        ENDIF
        IF(IOUTA.EQ.0.AND.JANOM.EQ.1) THEN
          SUMDA(1)   = SUMDA(1)  + ABS(ADEL)
          SUMDA(KK)  = SUMDA(KK) + ABS(ADEL)
          SMDA2(1)   = SMDA2(1)  + ABS(ADEL)*ABS(ADEL)
          SMDA2(KK)  = SMDA2(KK) + ABS(ADEL)*ABS(ADEL)
          NGRA (1)   = NGRA (1)  + 1
          NGRA (KK)  = NGRA (KK) + 1
        ENDIF
        IF(FSDD.GT.1.) NSTAT = NSTAT + 1
C------------------------------------------------------------
C       WRITE TO OUTPUT-FILE
C
        IF(IPASS.EQ.NPASS) THEN
          IF(IOUT.EQ.0.OR.IOUTA.EQ.0) THEN
            NUMB = NUMB+1
            IF(MTDER.GT.0.AND.MSGA.EQ.'Y'.AND.MTPH.EQ.0
     *        .AND.IANOM.EQ.1) THEN
              IF(IOUT .EQ.1) FAA  = 0.0
              IF(IOUTA.EQ.1) AFAA = 0.0 
              FAA = FAA + AFAA
            ENDIF
            IF(MTOUT.GT.0) 
     *      CALL WRT(MTOUT,JHH,JKK,JLL,FAA,FBB,NUMB3,IEND3)
          ENDIF
        ENDIF
C------------------------------------------------------------
        GO TO 460
C ==================
  560   CONTINUE
      ENDDO
C =======================================================================
C     WRITE LAST RECORD AND END-OF-FILE
C
      IEND3 = 2
      IF(NUMB.LE.0) THEN
        CALL MSGERR(MDOC,'ERR: number of coefficients = 0')
        IF(MTOUT.GT.0) CLOSE(MTOUT)
        CLOSE(MTNAT)
        IF(MTDER.GT.0) CLOSE(MTDER)
        IF(MTPH.GT.0)  CLOSE(MTPH)
        IERR=1
        RETURN
      ENDIF
      IF(MTOUT.GT.0) CALL WRT(MTOUT,JHH,JKK,JLL,FAA,FBB,NUMB3,IEND3)
C --------------------------------------------------------------
C     WRITE OF INFORMATION TO FILE-DOCUMENT
C     CALC R-FACTOR
C
      WRITE(LINE,680) NUMB
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,681) NNOUT
      CALL MSGDOC(MDOC,LINE)
  680 FORMAT(' NUMBER OF REFLS=',I6)
  681 FORMAT(' OUT OF RESOLUTION=',I6)
C
      IF(MTPH.NE.0) THEN
        WRITE(LINE,'(A,I8)') ' N-BAD REFLS < FOM-MIN:',NBFOM
        CALL MSGDOC(MDOC,LINE)
      ENDIF
      WRITE(LINE,'(A,I8)') ' N-BAD REFLS for SLIM :',NBSLIM
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,'(A,I8)') ' N  DEL > DEL_LIM     :',NBDLIM
      CALL MSGDOC(MDOC,LINE)

      DO I=1,NPOINT1
        RESULT(I,1) = ANRH(I)  
        IF(NGR(I).GT.0) THEN
          RESULT(I,2) = SMD(I)     /NGR(I)  
          RESULT(I,3) = SUMFP(I)   /NGR(I)  
          RESULT(I,4) = RESULT(I,2)/RESULT(I,3)
          RESULT(I,8) = FSD(I)     /NGR(I)
        ELSE
          RESULT(I,2) = 0.0
          RESULT(I,3) = 0.0
          RESULT(I,4) = 0.0
        ENDIF
        RESULT(I,5) = NGR(I)  
        IF(NGRA(I).GT.0) THEN
          RESULT(I,6) = SUMDA(I)/NGRA(I)  
        ELSE
          RESULT(I,6) = 0.0
        ENDIF
        RESULT(I,7) = NGRA(I)  
      ENDDO

      IF(NTOT_DEL.GT.0) THEN
        DEL_AVER  = DEL_AVER/NTOT_DEL
        DEL2_AVER = DEL2_AVER/NTOT_DEL
        DEL_RMS   = SQRT(ABS(DEL2_AVER-DEL_AVER*DEL_AVER))
      ENDIF
      IF(NTOT_DELA.GT.0) THEN
        DELA_AVER  = DELA_AVER/NTOT_DELA
        DELA2_AVER = DELA2_AVER/NTOT_DELA
        DELA_RMS   = SQRT(ABS(DELA2_AVER-DELA_AVER*DELA_AVER))
      ENDIF

      RESULT( 1,9) = FP_MAX
      RESULT( 2,9) = FD_MAX
      RESULT( 3,9) = DEL_MAX
      RESULT( 4,9) = DEL_AVER
      RESULT( 5,9) = DEL_RMS
      RESULT( 6,9) = NTOT_DEL
      RESULT( 7,9) = DELA_MAX
      RESULT( 8,9) = DELA_AVER
      RESULT( 9,9) = DELA_RMS
      RESULT(10,9) = NTOT_DELA
      RESULT(11,9) = NUMB
      RESULT(12,9) = NNOUT
      RESULT(13,9) = NBSLIM
      RESULT(14,9) = NBDLIM
      RESULT(15,9) = NBDLIMA
      RESULT(16,9) = NBFOM

C     RESULT(I,1) = RESOL
C     RESULT(I,2) = DEL = !FOBS -FDER!
C     RESULT(I,3) = FOBS 
C     RESULT(I,4) = RFAC
C     RESULT(I,5) = N
C     RESULT(I,6) = DEL_ano 
C     RESULT(I,7) = Nano
C     RESULT(I,8) = F/S or D/S
C     RESULT(1,9) = FP_MAX
C     RESULT(2,9) = FD_MAX
C     RESULT(3,9) = DEL_MAX

   
      DO I=2,9
c        I2 = (I-1)*2+1
        I2 = I*2-1
        ANRH (I) = ANRH (I2)
        NGR  (I) = NGR  (I2-1) + NGR  (I2) 
        NGRA (I) = NGRA (I2-1) + NGRA (I2) 
        SUMFP(I) = SUMFP(I2-1) + SUMFP(I2) 
        SMD  (I) = SMD  (I2-1) + SMD  (I2) 
        SUMDA(I) = SUMDA(I2-1) + SUMDA(I2) 
        FSD  (I) = FSD  (I2-1) + FSD  (I2) 
        NOUT (I) = NOUT (I2-1) + NOUT (I2) 
        AKEMP(I) = AKEMP(I2-1) + AKEMP(I2) 
      ENDDO

      NPOINT_PRINT = 9

      DO     I=1,NPOINT_PRINT
        IF(NGR(I).GT.0) THEN
C           < FP >
          SUMFP(I)=SUMFP(I)/NGR(I)
C           < !DEL! >
          SMD(I) =SMD(I)/NGR(I)
C          R-FAC
          RFAC(I) =SMD(I)/SUMFP(I)
C           < FD+DP >
          FSD(I) =FSD(I)/NGR(I)
        ENDIF
        IF(NGRA(I).GT.0) THEN
C           < !DEL_anom! >
          SUMDA(I) =SUMDA(I)/NGRA(I)
        ENDIF
      ENDDO


      WRITE(LINE,700)  (ANRH(I),I=1,8),RESMAX
      CALL MSGDOC(MDOC,LINE)
      IF(MTDER.NE.0.OR.MSGA.EQ.'Y') THEN
        WRITE(LINE,721)  (SMD(I),I=1,9)
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,760)  (SUMFP(I),I=1,9)
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,720)  (RFAC(I),I=1,9)
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,722)  (FSD(I),I=1,9)
        CALL MSGDOC(MDOC,LINE)
      ELSE
        WRITE(LINE,724)  (SMD(I),I=1,9)
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,723)  (FSD(I),I=1,9)
        CALL MSGDOC(MDOC,LINE)
      ENDIF

  
      WRITE(LINE,730)  (NGR(I),I=1,9)
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,731)  (NOUT(I),I=1,9)
      CALL MSGDOC(MDOC,LINE)
      IF(MTDER.GT.0.AND.MSGA.EQ.'Y'
     * .AND.IANOM.EQ.1.AND.MTPH.EQ.0) THEN
        WRITE(LINE,725)  (AKEMP(I),I=1,9)
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,726)  (SUMDA(I),I=1,9)
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,727)  (NGRA(I),I=1,9)
        CALL MSGDOC(MDOC,LINE)
      ENDIF

      IF(NUMB3.GT.0) THEN
        WRITE(LINE,'('' N-REFLS GT SIGMA:'',I6)') NSTAT
        CALL MSGDOC(MDOC,LINE)
        PERS = NSTAT/FLOAT(NUMB3)
        WRITE(LINE,'('' PERCENT > SD    :'',F6.3)') PERS
        CALL MSGDOC(MDOC,LINE)
      ENDIF
      CLOSE(MTNAT)
      IF(MTDER.GT.0) CLOSE(MTDER)
      IF(MTPH.GT.0)  CLOSE(MTPH)
      IF(MSGA.EQ.'Y'.AND.IANOM.EQ.0) MSGA='N'



c      WRITE(LINE,'(''N   :'',3I6,2F10.2)') 
c     * NUMB,NNOUT,NBSLIM,FP_MAX,FD_MAX
c      CALL MSGDOC(MDOC,LINE)
c
c      WRITE(LINE,'(''DEL :'',2I6,3F10.2)') 
c     * NTOT_DEL,NBDLIM,DEL_MAX,DEL_AVER,DEL_RMS
c      CALL MSGDOC(MDOC,LINE)
c
c      WRITE(LINE,'(''DELA:'',2I6,3F10.2)') 
c     * NTOT_DELA,NBDLIMA,DELA_MAX,DELA_AVER,DELA_RMS
c      CALL MSGDOC(MDOC,LINE)



      RETURN

  700 FORMAT('Res : TOT',F7.2,7F8.2,1X,F7.2)
  724 FORMAT('F   :',F7.2,8(1X,F7.2))
  721 FORMAT('DEL :',F7.3,8(1X,F7.3))
  722 FORMAT('D/S :',F7.3,8(1X,F7.3))
  723 FORMAT('F/S :',F7.3,8(1X,F7.3))
  720 FORMAT('Rfac:',F7.3,8(1X,F7.3))
  760 FORMAT('Fn  :',F7.3,8(1X,F7.3))
  730 FORMAT('N   :',I7,  8(1X,I7))
  731 FORMAT('bad :',I7,  8(1X,I7))
  725 FORMAT('Kemp:',F7.1,8(1X,F7.1))
  726 FORMAT('Dano:',F7.3,8(1X,F7.3))
  727 FORMAT('Nano:',I7,  8(1X,I7))
      END

      SUBROUTINE SURFACE_RUN(MDOC,NAMER,NAMEO,RH2O,DEL,BLIM,NMR
     * ,SURF_KEY,NATMX
     * ,XR,YR,ZR,OCCR,TEMPR,SURFR,RADVDW,ELPOT
     * ,IRESR,ICHNR
     * ,RESULT,IPRROW,ISYM,IPRSYM,IERR)   
C ---------------------------------------
c      INTEGER*2 IRESR(NATMX),ICHNR(NATMX)
      INTEGER   IRESR(NATMX),ICHNR(NATMX)
      REAL      XR(NATMX),YR(NATMX),ZR(NATMX)
      REAL      OCCR(NATMX),TEMPR(NATMX),SURFR(NATMX),RADVDW(NATMX)
      REAL      ELPOT(NATMX)
      INTEGER*2 ISYM(5,3,IPRSYM)
      REAL      RESULT(IPRROW)
C ---------------------------------------
      CHARACTER LINE*80,NAMER*(*),NAMEO*(*),SURF_KEY*1
C ---------------------------------------
      IERR = 0

      IF(RH2O.LE.0.0) RH2O = 1.4
      RH2O_2 = RH2O * 0.65

      IF(DEL .LE.0.0) DEL  = 0.1
      IF(BLIM.LE.0.000001) BLIM = 15.0
      ILAST  = 0
      IFIRST = 0
      XSH    = 0.0
      YSH    = 0.0
      ZSH    = 0.0
      XMIN   = 1.E30
      YMIN   = 1.E30
      ZMIN   = 1.E30
      XMAX   =-1.E30
      YMAX   =-1.E30
      ZMAX   =-1.E30
      NTOT   = 0
      NTOT_INSIDE = 0
      NR_TOT = 0
      IOUT   = 11
      IENDW  =-1
      MOD_FIRST = 1
      MOD_LAST  = 10000 
      IF(NMR.LT.0) THEN
        MOD_FIRST = ABS(NMR)
        MOD_LAST  = ABS(NMR)
      ENDIF
      DO IMODEL=MOD_FIRST,MOD_LAST
C -----------
        ITEST = 0
        CALL RDCOOR_SR(MDOC,NAMER,NR,XR,YR,ZR,OCCR,TEMPR,SURFR
     *     ,RADVDW,ELPOT,IRESR,ICHNR,NATMX
     *     ,NSYM,ISYM,IPRSYM,IFIRST,ILAST,IMODEL,NMR,ITEST,IERR)
        IF(IERR.NE.0) RETURN
C -----------
        IF(NR.LE.0) THEN
          CALL MSGERR(MDOC,' ERROR: surface: number of atoms = 0')
          IERR=1
          RETURN
        ENDIF
        WRITE(LINE,'('' Number of atoms :'',I6,'' for model:'',I5)')
     *     NR,IMODEL
        CALL MSGDOC(MDOC,LINE)
        NR_TOT = NR_TOT + NR    
C ------------
        CALL AREA_SR(MDOC,NR,XR,YR,ZR,RADVDW,SURFR,ELPOT
     *    ,IRESR
     *    ,NATMX,RH2O,RH2O_2,DEL
     *    ,SURFA,SURFC,NA_INSIDE,IERR)
C IERR
C  1   - CALL MSGERR(MDOC,' ERROR: surface: area_sr: N_atoms = 0')
C  2   - CALL MSGERR(MDOC,' ERROR: surface: table_sr: STOP NZ < 2')
C  3   - CALL MSGERR(MDOC,' ERROR: surface: table_sr: STOP M < 1')
C  4   - CALL MSGERR(MDOC,' ERROR: surface: table_sr: J > NPMAX')
C  5   - CALL MSGERR(MDOC,' ERROR: surface: area_sr: N-neighbors > LIMIT') 
        IF(IERR.NE.0) THEN
          IF(IERR.EQ.1) CALL MSGERR(MDOC,
     *    ' ERROR: surface: area_sr: N_atoms = 0')
          IF(IERR.EQ.2) CALL MSGERR(MDOC,
     *    ' ERROR: surface: table_sr: STOP NZ < 2')
          IF(IERR.EQ.3) CALL MSGERR(MDOC,
     *    ' ERROR: surface: table_sr: STOP M < 1')
          IF(IERR.EQ.4) CALL MSGERR(MDOC,
     *    ' ERROR: surface: table_sr: J > NPMAX')
          IF(IERR.EQ.5) CALL MSGERR(MDOC,
     *    ' ERROR: surface: area_sr: N-neighbors > LIMIT') 
          RETURN
        ENDIF
        WRITE(LINE,9999) SURFC
        CALL MSGDOC(MDOC,LINE)
        WRITE(LINE,9997) SURFA
        CALL MSGDOC(MDOC,LINE)
 9999   FORMAT(' Total Contact    Surface Area =',F10.3)
 9997   FORMAT(' Total Accessible Surface Area =',F10.3)
        CALL MSGDOC(MDOC,' ')
C ------------------------------------------------------------------
        CALL WRCOOR_SR(MDOC,NAMER,NAMEO,IOUT,IENDW
     *     ,SURF_KEY,BLIM,SURFR,ELPOT,NATMX,NR,NA_INSIDE
     *     ,NTOT,XSH,YSH,ZSH,XMIN,XMAX,YMIN,YMAX,ZMIN,ZMAX
     *     ,NSYM,ISYM,IPRSYM,IFIRST,ILAST,IMODEL,NMR,IERR)
        IF(IERR.NE.0) RETURN
        NTOT_INSIDE = NTOT_INSIDE + NA_INSIDE
C ----
        IF(ILAST.NE.0) GO TO 100
      ENDDO
C ---------------------------------------
 100  CONTINUE
      IF(NTOT.GT.0) THEN
        XSH = XSH/NTOT
        YSH = YSH/NTOT
        ZSH = ZSH/NTOT
      ENDIF

      RESULT(1) = NR_TOT
      RESULT(2) = SURFA
      RESULT(3) = SURFC
      RESULT(4) = XSH
      RESULT(5) = YSH
      RESULT(6) = ZSH
      RESULT(7) = IMODEL-MOD_FIRST+1
      RESULT(8) = NTOT_INSIDE
C --------------------------------
      RETURN
      END

      SUBROUTINE RDCOOR_SR(MDOC,NAMER,NCRDR,X,Y,Z,OCC,TEMP
     *     ,SURF,RADVDW,ELPOT,IRES,ICHAIN,NATMX
     *     ,NSYM,ISYM,IPRSYM,IFIRST,ILAST,IMODEL,NMR,ITEST,IERR)
C ---------------------------------------
      INTEGER*2 ISYM(5,3,IPRSYM)
C     INTEGER*2 IRES(NATMX),ICHAIN(NATMX)
      INTEGER   IRES(NATMX),ICHAIN(NATMX)
      REAL      X(NATMX),Y(NATMX),Z(NATMX)
      REAL      OCC(NATMX),TEMP(NATMX),SURF(NATMX),RADVDW(NATMX)
      REAL      ELPOT(NATMX)
      CHARACTER NAMER*(*)
C ------------------------------------------------------------
      INCLUDE 'mr_crd_com.fh'
C -------------------------------------------------
      CHARACTER LINE*80,CHAR2*2
C ----------------------------------------------
      PARAMETER (N_NAME = 9)
      REAL      TAB_RVDW(N_NAME)
      CHARACTER NAME(N_NAME)*2
      DATA NAME    /'C ','O ','N ','S ','P ','H ','FE','CA','ZN'/
      DATA TAB_RVDW/1.8 ,1.7 ,1.6 ,1.9 ,2.1 ,0.8 ,0.65,1.18,0.88/
C B       10.82000  N     0.650      .
C F       19.00000  N     1.330      .
C NA      22.99000  N      .         .
C MG      24.32000  N     0.820      .
C P       30.97380  N     2.100      .
C PS      30.97380  N     2.100      .
C S       32.06400  A     1.900      .
C SH1     32.06400  B     1.900     1.950
C CL      35.45700  N     1.810      .
C CA      40.08000  N     1.180      .
C V       50.95000  N     0.880      .
C MN      54.94000  N     0.800      .
C FE      55.84700  N     0.650      .
C CO      58.94000  N     0.720      .
C CU      63.54600  N     0.740      .
C ZN      65.37000  N     0.880      .
C BR      79.91600  N     1.960      .
C CD     112.40000  N     1.140      .
C I      126.90450  A     2.200      .
C PB     207.21000  N     1.200      .
C HG     200.61000  N     1.270      .
C -------------------------------------------------------------------
      N     = 0
      IEND  =-1
      IERR  = 0
      ILINE = 0
      MODEL = 0
      M     = 99
      MD    =-ABS(MDOC)-1
      MOD   = 0
      INC   = 10
C -------------------------------------------------------------------
      CALL ORCRD(M,INC,NAMER,NSYM,ISYM
     *           ,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERROR: can not open input file')
        RETURN
      ENDIF
C ---------
 200  CONTINUE

      CALL RDCRD(M,INC,MOD,IEND,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERROR: reading input file')
        RETURN
      ENDIF

      IF(IEND.NE.0) THEN
        ILAST = 1 
        GO TO 300
      ENDIF

      IF(MOD.EQ.0) THEN

        IF(ILINE.EQ.0) THEN
          MODEL = 1
          ILINE = 1
        ENDIF

c        IF(NMR.NE.0) THEN
          IF(MODEL.GT.IMODEL) GO TO 300
          IF(MODEL.LT.IMODEL) GO TO 200
c        ENDIF

        IF((CR_ATYPE .EQ.' '.OR.CR_ATYPE .EQ.'.'.OR.
     *      CR_ATYPE .EQ.'y'.OR.CR_ATYPE .EQ.'Y'.OR.
     *      CR_ATYPE .EQ.'r'.OR.CR_ATYPE .EQ.'R').AND.
     *      CR_OCC .GT.0.0001                        ) THEN
             
          IF(CR_ALT.NE.'.'.AND.CR_ALT.NE.' '.AND.
     *       CR_ALT.NE.'A'.AND.CR_ALT.NE.'1') GO TO 200

          IF(CR_ASYMB(1:2).EQ.'H '.OR.CR_ASYMB(1:2).EQ.'D ') GO TO 200
          IF(CR_RNAME.EQ.'HOH') GO TO 200

          N = N + 1
          IF(ITEST.LE.0) THEN
          IF(N.GT.NATMX) THEN
            WRITE(LINE,*) ' ERROR: surface: too many atoms > ',NATMX
            CALL MSGERR(MDOC,LINE)
            IERR=1
            RETURN
          ENDIF
c          ATOM  (N) = CR_ANAME
c          RES4  (N) = CR_RNAME//' '
          ICHAIN(N) = CR_IGROUP
          IRES  (N) = CR_IRES
          X     (N) = CR_XYZ(1)
          Y     (N) = CR_XYZ(2)
          Z     (N) = CR_XYZ(3)
          OCC   (N) = CR_OCC
          TEMP  (N) = CR_BISO
          SURF  (N) = 0.0
          ELPOT (N) = 0.0
          CHAR2     = CR_ASYMB(1:2)
          RVDW      = 1.4
          DO I=1,N_NAME
            IF(CHAR2.EQ.NAME(I)) THEN
              RVDW = TAB_RVDW(I)
              GO TO 100
            ENDIF
          ENDDO
 100      CONTINUE
          RADVDW(N) = RVDW
          ENDIF
 
        ENDIF
      ELSE
        IF(CR_LINE(1:6).EQ.'#MODEL') THEN
          MODEL = MODEL + 1
          ILINE = 1
        ENDIF
      ENDIF
      GO TO 200
C ---------------------------------
  300 CONTINUE
      NCRDR = N
      CLOSE (INC)
      RETURN
      END

      SUBROUTINE AREA_SR(MDOC,NR,XR,YR,ZR,RADVDW,SURFR,ELPOT
     *       ,IRES,NATMX,RH2O,RH2O_2,DEL
     *       ,SURFA,SURFC,NA_INSIDE,IERR)
C ---------------------------------------
      REAL      XR(NATMX),YR(NATMX),ZR(NATMX)
      REAL      SURFR(NATMX),RADVDW(NATMX)
      REAL      ELPOT(NATMX)
c     INTEGER*2 IRES(NATMX)
      INTEGER   IRES(NATMX)
c      CHARACTER ATOM(NATMX)*4,RES(NATMX)*4
C ---------------------------------------
      PARAMETER (NSMAX=500)
      PARAMETER (NPMAX=20000)
      PARAMETER (MAXPO=10000)
      REAL XPNT(MAXPO),YPNT(MAXPO),ZPNT(MAXPO)
      REAL XSOSED(NSMAX),YSOSED(NSMAX),ZSOSED(NSMAX),RSOSED(NSMAX)
      REAL XKPOIN(NPMAX),YKPOIN(NPMAX),ZKPOIN(NPMAX)
      REAL XPOINT(NPMAX),YPOINT(NPMAX),ZPOINT(NPMAX),ITYPE(NPMAX)
      CHARACTER LINE*80
C ----------------------------------------------------
 
c     DO IPASS=1,2
      DO IPASS=1,1

      NA_INSIDE = 0
      NGLOB = 0
      SURFC = 0.0
      SURFA = 0.0
      RUNIT = 1.0
      CALL TABLE_SR(RUNIT,DEL,NPOINT,XPOINT,YPOINT,ZPOINT,SDELK
     *          ,NPMAX,IERR)
      IF(IERR.NE.0) RETURN

C -------- START OF CYCLE K-ATOM --------------------

      DO     K=1,NR

C        IF( MOD(K,100).EQ.0) THEN
C          WRITE(LINE,'('' I-ATOM,N-POINTS :'',I6,I8)') K,NGLOB
C          CALL MSGDOC(MDOC,LINE)
C        ENDIF

        XK = XR(K)
        YK = YR(K)
        ZK = ZR(K)
        IF(IPASS.EQ.1) THEN
          RK = RADVDW(K)+RH2O
        ELSE
          RK = RADVDW(K)+RH2O_2
        ENDIF
        L  = 0
        DO     I1=1,NPOINT
          XKPOIN(I1) = XK+(XPOINT(I1)*RK)/RUNIT
          YKPOIN(I1) = YK+(YPOINT(I1)*RK)/RUNIT
          ZKPOIN(I1) = ZK+(ZPOINT(I1)*RK)/RUNIT
          ITYPE (I1) = 0
        ENDDO
        SDEL = (SDELK*RK*RK)/(RUNIT*RUNIT)
C ----------- SOSEDI ----------------
        DO     J=1,NR
          IF(J.NE.K) THEN
            XJ    = XR(J)
            YJ    = YR(J)
            ZJ    = ZR(J)
            IF(IPASS.EQ.1) THEN
              RJ    = RADVDW(J)+RH2O
            ELSE
              RJ    = RADVDW(J)+RH2O_2
            ENDIF
            R1    = RK+RJ
            RLIM2 = R1*R1
            S1    = (XJ-XK)*(XJ-XK)
            S2    = (YJ-YK)*(YJ-YK)
            S3    = (ZJ-ZK)*(ZJ-ZK)
            DIS2  = S1+S2+S3
            IF(DIS2.LE.RLIM2) THEN
              L = L+1
              IF(L.GT.NSMAX) THEN
                WRITE(LINE,'('' ERROR: surface: N-neighbors >'',I8)')
     *                                                          NSMAX
                CALL MSGERR(MDOC,LINE)
                IERR=1
                RETURN
              ENDIF
              XSOSED(L) = XJ
              YSOSED(L) = YJ
              ZSOSED(L) = ZJ
              RSOSED(L) = RJ
              NSOSED    = L
            ENDIF
          ENDIF
        ENDDO
C -------------
        IF(NSOSED.GT.0) THEN
          DO     IP=1,NPOINT
            XP = XKPOIN(IP)
            YP = YKPOIN(IP)
            ZP = ZKPOIN(IP)
            DO     IS=1,NSOSED
              XS = XSOSED(IS)
              YS = YSOSED(IS)
              ZS = ZSOSED(IS)
              RS = RSOSED(IS)
              DX = XS-XP
              IF(ABS(DX).GT.RS) GO TO 350
              DY = YS-YP
              IF(ABS(DY).GT.RS) GO TO 350
              DZ = ZS-ZP
              IF(ABS(DZ).GT.RS) GO TO 350
              D2  = DX*DX+DY*DY+DZ*DZ
              RS2 = RS*RS
              IF(D2.LT.RS2) THEN
                ITYPE(IP) = 1
                GO TO 352
              ENDIF
 350          CONTINUE
            ENDDO
 352        CONTINUE
          ENDDO
        ENDIF
C --------------------------------------
        MS=0
C   ---
        DO     IP=1,NPOINT
          IF(ITYPE(IP).EQ.0) THEN
            MS = MS+1
          ENDIF
        ENDDO
C   ---
        NGLOB = NGLOB+MS
        SUA   = MS*SDEL
C  --   SCALE AREA TO VDW SHELL ---
        IF(IPASS.EQ.1) THEN
          SUC      = (SUA*(RK-RH2O)*(RK-RH2O))/(RK*RK)
          SURFR(K) = SUC
          ELPOT(K) = SUC
          IF(SUC.LE.0.0) NA_INSIDE = NA_INSIDE + 1
        ELSE
          SUC      = (SUA*(RK-RH2O_2)*(RK-RH2O_2))/(RK*RK)
          ELPOT(K) = SUC
          IF(SUC.LE.0.0) NA_INSIDE = NA_INSIDE + 1
        ENDIF
        SURFA    = SURFA+SUA
        SURFC    = SURFC+SUC
      ENDDO
C ---------------- END OF CYCLE K-ATOM -----------------

      ENDDO

      RETURN
      END

      SUBROUTINE TABLE_SR(R,DEL,N,XP,YP,ZP,SD,NPMAX,IERR)
C --------------------------------
C IERR
C  2   - CALL MSGERR(MDOC,' ERROR: surface: table_sr: STOP NZ < 2')
C  3   - CALL MSGERR(MDOC,' ERROR: surface: table_sr: STOP M < 1')
C  4   - CALL MSGERR(MDOC,' ERROR: surface: table_sr: J > NPMAX')
C --------------------------------
      REAL XP(NPMAX),YP(NPMAX),ZP(NPMAX)
C --------------------------------
      PI    = 4.0*ATAN(1.0)
      XP(1) = 0.0
      YP(1) = 0.0
      ZP(1) = R
      J     = 1
      NZ    = (PI*R)/DEL
      IF(NZ.LE.2) THEN
        IERR=2
        RETURN
      ENDIF
      ANGLZ = PI/NZ
      DO K=1,NZ-1
        Z1 = K*ANGLZ
        Z  = R*COS(Z1)
        RS = SIN(Z1)*R
        M  = 2*PI*RS/DEL
        IF(M.LE.1) THEN
          IERR=3
          RETURN
        ENDIF
        BANGL = 2*PI/M
        DO I=1,M
          BI = BANGL*I
          X  = RS*COS(BI)
          Y  = RS*SIN(BI)
          J  = J+1
          IF(J.GT.NPMAX) THEN
            IERR=4
            RETURN
          ENDIF
          XP(J) = X
          YP(J) = Y
          ZP(J) = Z
        ENDDO
      ENDDO
      XP(J+1) = 0
      YP(J+1) = 0
      ZP(J+1) =-R
      N       = J+1
      SD      = (4.0*PI*R*R)/FLOAT(N)
      RETURN
      END

      
      SUBROUTINE WRCOOR_SR(MDOC,NAMER,NAMEO,IOUT,IENDW
     *     ,SURF_KEY,BLIM,SURFR,ELPOT,NATMX,NR,NA_INSIDE
     *     ,NTOT,XSH,YSH,ZSH,XMIN,XMAX,YMIN,YMAX,ZMIN,ZMAX
     *     ,NSYM,ISYM,IPRSYM,IFIRST,ILAST,IMODEL,NMR,IERR)
C ----------------------------------------------------------
      INTEGER   MDOC,IERR
      INTEGER*2 ISYM(5,3,IPRSYM)
      REAL      SURFR(NATMX)
      REAL      ELPOT(NATMX)
      CHARACTER NAMER*(*),NAMEO*(*),SURF_KEY*1
C ------------------------------------------------------------
      INCLUDE 'mr_crd_com.fh'
C -----------------------------------------------------------
      MODEL = 0
      ILINE = 0
      INC   = 10
c     IOUT  = 11
      MODE  = 0
      IEND  =-1
C     IENDW =-1
      M     = 99
      MD    =-ABS(MDOC)-1
      IERR  = 0
      I     = 0
      T = FLOAT(NA_INSIDE)/FLOAT(NR)
      ISURF = 0
      BLIM_2 = BLIM
      IF(T.LT.0.09.OR.NA_INSIDE.LT.5) THEN
        ISURF = 1
        BLIM_2 = BLIM*2.0
        N = 0
        DO K=1,NR
          SF_2 = ELPOT(K)*20.0 + BLIM
          IF(SF_2.LE.BLIM_2) N = N + 1
        ENDDO
        T2 = FLOAT(N)/FLOAT(NR)
        IF(T2.LT.0.09.OR.N.LT.5) THEN
          BLIM_2 = 1000.0
          NA_INSIDE = NR
        ELSE
          NA_INSIDE = N
        ENDIF
      ENDIF 
C -------------------------------------------------------------------
      IF(IFIRST.EQ.0) THEN
        CALL LENSTR_BL(NAMEO,LEN)
        IF(LEN.LT.0.OR.NAMEO(1:1).EQ.' '.OR.NAMEO(1:1).EQ.',') THEN
          NAMEO='surface'
        ENDIF
        CALL CORR_NAME_BLC(NAMEO)
        CALL OWCRD(MD,IOUT,NAMEO,NSYM,ISYM
     *             ,IPRSYM,IERR)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MDOC,' ERROR: can not open input file')
          RETURN
        ENDIF
      ENDIF
C--------------------------------------
      CALL ORCRD(MD,INC,NAMER,NSYM,ISYM
     *           ,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERROR: surface: reading input file')
        CLOSE(IOUT) 
        RETURN
      ENDIF
C -------------------------------------
 200  CONTINUE

      CALL RDCRD(M,INC,MODE,IEND,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERROR: reading input file')
        CLOSE(INC) 
        CLOSE(IOUT) 
        RETURN
      ENDIF
      IF(IEND.NE.0) GO TO 300
      IF(MODE.EQ.0) THEN

        IF(ILINE.EQ.0) THEN
          MODEL = 1
          ILINE = 1
        ENDIF

c        IF(NMR.NE.0) THEN
          IF(MODEL.GT.IMODEL) GO TO 300
          IF(MODEL.LT.IMODEL) GO TO 200
c        ENDIF

C       CR_BISO = 0.0
        IF((CR_ATYPE .EQ.' '.OR.CR_ATYPE .EQ.'.'.OR.
     *      CR_ATYPE .EQ.'y'.OR.CR_ATYPE .EQ.'Y'.OR.
     *      CR_ATYPE .EQ.'r'.OR.CR_ATYPE .EQ.'R').AND.
     *      CR_OCC .GT.0.0001                        ) THEN

          IF(CR_ALT.NE.'.'.AND.CR_ALT.NE.' '.AND.
     *       CR_ALT.NE.'A'.AND.CR_ALT.NE.'1') GO TO 400

          IF(CR_ASYMB(1:2).EQ.'H '.OR.CR_ASYMB(1:2).EQ.'D ') GO TO 400
          IF(CR_RNAME.EQ.'HOH') GO TO 400

          I = I + 1

C          SF = SURFR(I)*10.0 + BLIM

          SF   = SURFR(I)*20.0 + BLIM
          SF_2 = ELPOT(I)*20.0 + BLIM

          IF(SF  .GT.999.99) SF   = 999.99
          IF(SF_2.GT.999.99) SF_2 = 999.99
 
          CR_SURF   = SF_2

          IF(ISURF.GT.0) THEN
            IF(CR_SURF.LE.BLIM_2) THEN 
              CR_SURF = BLIM
            ENDIF
          ENDIF

          IF(SURF_KEY.EQ.'Y') THEN
            CR_BISO = SF
          ENDIF

          IF(CR_ALT.EQ.'A'.OR.CR_ALT.EQ.'1') CR_ALT = '.'
C         CR_OCC = 1.0

          CR_BTYPE     = '.'
          CR_FLAG_USER = 'I'

          IF(SF.LE.BLIM) THEN
            NTOT = NTOT + 1
            XSH = XSH + CR_XYZ(1)
            YSH = YSH + CR_XYZ(2)
            ZSH = ZSH + CR_XYZ(3)
            IF(CR_XYZ(1).GT.XMAX) XMAX = CR_XYZ(1)
            IF(CR_XYZ(2).GT.YMAX) YMAX = CR_XYZ(2)
            IF(CR_XYZ(3).GT.ZMAX) ZMAX = CR_XYZ(3)
            IF(CR_XYZ(1).LT.XMIN) XMIN = CR_XYZ(1)
            IF(CR_XYZ(2).LT.YMIN) YMIN = CR_XYZ(2)
            IF(CR_XYZ(3).LT.ZMIN) ZMIN = CR_XYZ(3)
          ENDIF

          GO TO 401

 400      CONTINUE
          GO TO 200

 401      CONTINUE

        ENDIF

      ELSE
            
c        IF(NMR.NE.0) THEN
          IF(CR_LINE(1:6).EQ.'#MODEL') THEN 
            MODEL = MODEL + 1
            ILINE = 1
          ENDIF
          IF(MODEL.NE.IMODEL) GO TO 200
c        ENDIF

      ENDIF

      IF(IFIRST.EQ.0) THEN
        IFIRST = 1
      ELSE
        IENDW = 0
      ENDIF

      CALL WRCRD(M,IOUT,MODE,IENDW,IERR)
      IF(IERR.NE.0) THEN
        CLOSE(INC) 
        RETURN
      ENDIF

      GO TO 200
C -------------------------
 300  CONTINUE
      CLOSE(INC) 
      IF(ILAST.GT.0) THEN
        IENDW = 1
        MODE  = 0
        CALL WRCRD(M,IOUT,MODE,IENDW,IERR)
      ENDIF
      RETURN
      END

      SUBROUTINE SFVSUM(MDOC,MODE,SCALE,INVER
     *    ,F_NAME,PH_NAME,F2_NAME,PH2_NAME,FO_NAME,PHO_NAME 
     *    ,SHIFT
     *    ,BOFF,BADD,RESMINR,RESMAXR,ISYM,IPRSYM,RESULT,IPRROW,IERR)
C ----------------------------------------------------
C -P- 
C SFVSUM   sum two vectors of structure factors: (F1 + scale*F2)
C          or convolution: F1(h)*scale*F2(-h)
C -S-
C      Dialogue and Batch:
C
C     F1:     < >    - input_file_f1
C     PH1:    < >    - input_file phases_1
C     F2:     < >    - input_file_f2
C     PH2:    < >    - input_file_phases_2
C     RESOL: MIN,MAX - resolution <default from files>
C     SCALE: <1.0>   - (F1 + scale*F2)
C     INVER  <N>,Y   - Y inverted phases of F1 will be used
C     MODE:  <A>,C   - A: sum (F1 + scale*F2
C                      C: convolution F1(h)*scale*F2(-h)
C     FILE_F: - input file_1 of the modules of structure factors.
C     FILE_2: - input file_2 of the modules of structure factors.
C     RESOL: MIN,MAX - resolution <default from files>
C     BOFF:  <0> , 256 corresponds to RESmin=8A,/BOFF=4*RESmin^2./
C     BADD:  <0>           BOFF and BADD mean :
C                !F!new = !F!input *EXP(-BADD*RSQ)*(1-EXP(-BOFF*RSQ)
C     FO:         - output_file F
C     PHO:        - output_file PH
C
C       It is possible to use the subroutine SFVSUM by program:
C
C      SUBROUTINE SFVSUM(MDOC,MODE,SCALE,INVER
C     *    ,F_NAME,PH_NAME,F2_NAME,PH2_NAME,FO_NAME,PHO_NAME
C     *    ,BOFF,BADD,RESMINR,RESMAXR,ISYM,IPRSYM,RESULT,IPRROW,IERR)
C
C  Parameters of subroutine: 
C
C    MDOC  - mode of writting messages to DOC-file
C            0 - only terminal , < - 0 only file, 0 < < 99 - both
C            >= 99 - don't write  
C    F_NAME   - input file_1 of the modules of structure factors.
C    F2_NAME  - input file_2 of the modules of structure factors.
C    PH_NAME  - input file_1 of the modules of phases.
C    PH2_NAME - input file_2 of the modules of phases.
C    FO_NAME  - output file F  
C    PHO_NAME - output file PH 
C    RESMINR   MIN,MAX - resolution <default from files>
C    RESMAXR 
C    BOFF:  <0> , 256 corresponds to RESmin=8A,/BOFF=4*RESmin^2./
C    BADD:  <0>           BOFF and BADD mean :
C                !F!new = !F!input *EXP(-BADD*RSQ)*(1-EXP(-BOFF*RSQ)
C    ISYM    - integer*2 array for cryst.symmetry operators.
C    IPRSYM  - dimension of integer*2 array ISYM(5,3,IPRSYM),
C              number of cryst. symm. operators.
C    IERR    - output signal of error / =1 -error , =o - OK / 
C
C    RESULT /real RESULT(IPRROW)/ - array for output information:
C
C      RESULT(1) = NTOT
C      RESULT(2) = RESMIN
C      RESULT(3) = RESMAX
C      RESULT(4) = CORR_I
C -I-
C ------------------------------
      INTEGER*2 ISYM(5,3,IPRSYM)
      REAL      RESULT(IPRROW),SHIFT(3)
      INTEGER*4 MDOC,IERR
      CHARACTER F_NAME *(*),PH_NAME *(*),FO_NAME*(*)
      CHARACTER F2_NAME*(*),PH2_NAME*(*)  
      CHARACTER PHO_NAME*(*)
      CHARACTER MODE*1,INVER*1,F000I*1
C ==============================
      INTEGER*4 MT1,MT2,MP1,MP2,MOUTF,MTOUTP
      CHARACTER ITYPE*4
      CHARACTER ITYP*4
      CHARACTER ITF1*4,ITF2*4,ITP1*4,ITP2*4,ITFW*4,ITPW*4
      CHARACTER LINE*80,TTT*80,TITLE*80
C -----------------------------------------------------------
      TWOPI = 8.0*ATAN(1.0)
      M     = 99
      MD    =-ABS(MDOC)-1
C --------------
      F000I = 'N'

      IF(MODE.EQ.'c') MODE = 'C'
      IF(MODE.EQ.'i') MODE = 'I'
      IF(MODE.NE.'C'.AND.MODE.NE.'I') MODE = 'A'

      IF(INVER.EQ.'y') INVER = 'Y'
      IF(INVER.NE.'Y') INVER = 'N'

      IF(ABS(SCALE).LT.0.00001) SCALE = 1.0
C --------------
C
C     ITYP  ='FF  '  means 'F   ' or 'FS  '
C     ITYP  ='F   '
C     ITYP  ='FS  '
C     ITYP  ='    '  means ALL  
C     ITYP  ='ABCD'
C     ITYP  ='COEF'
C     ITYP  ='PH  '
C     ITYP  ='RI  '
C
C     Subroutine ORFILE returns actual type by ITYP
C

      MT1 = 20
      CALL LENSTR_BL(F_NAME,LEN)
      IF(LEN.LE.0.OR.F_NAME(1:1).EQ.' '.OR.F_NAME(1:1).EQ.',') THEN
        CALL MSGERR(MDOC,' ERR: WRONG NAME OF FILE-F1')
        IERR=1
        RETURN
      ENDIF
      ITYP = 'FF  '
C
C     ORFILE - 1.open file FNAME 
C              2.reads title of file,return file parameters,fill /COMRDF/.
C                copy file_parameters to /COMRDF/.
C
      CALL ORFILE(MD,MT1,F_NAME,ITYP,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MD,' ERR: OPEN FILE-F1')
        RETURN
      ENDIF
C
C     GET_TITLE - gets information from /COMRDF/
C
      CALL GET_TITLE(MD,A,B,C,AL,BE,GA
     *  ,COEF1,BET1,RN,RX,IDM,IDM,IDM,IDM,IDM,TITLE,IERR)
      ITF1 = ITYP
C
C     for 'COEF':   TITLE(1:4)='FOUR' or 'PATT'
C
C -------------------------------------------------------------
C
C     C_RD_CR - copy parameters from common/COMRDF/ to common/CRYSTL/
C               also using CELL parameters from common/CRYSTL/ calculates
C               reciprocal cell parameters and volume and put its 
C               to common/CRYSTL/
C               
      CALL C_RD_CR
C -------------------------------------------------------------
      MT2  = 21
      ITYP = 'FF  '
      CALL LENSTR_BL(F2_NAME,LEN)
      IF(LEN.LE.0.OR.F2_NAME(1:1).EQ.' '.OR.F2_NAME(1:1).EQ.',') THEN
        MT2=0
        CALL MSGERR(MDOC,' ERR: WRONG NAME OF FILE-F2')
        CLOSE(MT1)
        IERR=1
        RETURN
      ELSE
        CALL ORFILE(MD,MT2,F2_NAME,ITYP,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MDOC,' ERR: OPEN FILE-F2')
          CLOSE(MT1)
          RETURN
        ENDIF
        CALL GET_TITLE(MD,A1,B1,C1,AL1,BE1,GA1
     *  ,DM1,DM2,RN1,RX1,IDM,IDM,IDM,IDM,IDM,TTT,IERR)
        ITF2=ITYP
      ENDIF
C -----------------
      MP1  = 22
      ITYP = 'PH  '
      CALL LENSTR_BL(PH_NAME,LEN)
      IF(LEN.LE.0.OR.PH_NAME(1:1).EQ.' '.OR.PH_NAME(1:1).EQ.',') THEN
        MP1=0
        CALL MSGERR(MDOC,' ERR: WRONG NAME OF FILE-PH1')
        CLOSE(MT1)
        CLOSE(MT2)
        IERR=1
        RETURN
      ELSE
        CALL ORFILE(MD,MP1,PH_NAME,ITYP,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MDOC,' ERR: OPEN FILE-PH1')
          CLOSE(MT1)
          CLOSE(MT2)
          RETURN
        ENDIF
        CALL GET_TITLE(MD,A1,B1,C1,AL1,BE1,GA1
     *  ,DM1,DM2,RN1,RX1,IDM,IDM,IDM,IDM,IDM,TTT,IERR)
        ITP1=ITYP
      ENDIF
C -----------------
      MP2  = 23
      ITYP = 'PH  '
      CALL LENSTR_BL(PH2_NAME,LEN)
      IF(LEN.LE.0.OR.PH2_NAME(1:1).EQ.' '.OR.PH2_NAME(1:1).EQ.',') THEN
        MP2=0
        CALL MSGERR(MDOC,' ERR: WRONG NAME OF FILE-PH2')
        CLOSE(MT1)
        CLOSE(MT2)
        CLOSE(MP1)
        IERR=1
        RETURN
      ELSE
        CALL ORFILE(MD,MP2,PH2_NAME,ITYP,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) THEN
          CALL MSGERR(MDOC,' ERR: OPEN FILE-PH2')
          CLOSE(MT1)
          CLOSE(MT2)
          CLOSE(MP1)
          RETURN
        ENDIF
        CALL GET_TITLE(MD,A1,B1,C1,AL1,BE1,GA1
     *  ,DM1,DM2,RN1,RX1,IDM,IDM,IDM,IDM,IDM,TTT,IERR)
        ITP2=ITYP
      ENDIF
C -----------------
c      IF(BOFF.EQ.0.0) BOFF = 0.0
c      IF(BOFF.LT.0.0) BOFF = 0.0
c      IF(BADD.LE.0.0) BADD = 0.0
C ---
      RESMIN = RESMINR
      RESMAX = RESMAXR
      IF(RESMIN.LE.0.0)   RESMIN = RN
      IF(RESMAX.LE.0.0)   RESMAX = RX
      IF(RN .LT.RESMIN)   RESMIN = RN
      IF(RX .GT.RESMAX)   RESMAX = RX
      IF(MT2.GT.0) THEN
        IF(RN1.LT.RESMIN)   RESMIN = RN1
        IF(RX1.GT.RESMAX)   RESMAX = RX1
      ENDIF
      WRITE(LINE,'(''RESOLUTION MIN,MAX '',2F7.2)') RESMIN,RESMAX
      CALL MSGDOC(MD,LINE)
      RHMIN = 1.0/(RESMIN)
      RHMAX = 1.0/(RESMAX)
C ---------------
      MTOUTF = 0
      CALL LENSTR_BL(FO_NAME,LEN)
      IF(LEN.GT.0.AND.FO_NAME(1:1).NE.' '.AND.FO_NAME(1:1).NE.',') THEN
        MTOUTF=30
C ---
C       C_CR_WR - copy parameters from common/CRYSTL/ to common/COMWRF/
C
        CALL C_CR_WR
C ---
C       SET_TITLE - sets information to  /COMWRF/
C 
        CALL SET_TITLE(MD,A,B,C,
     *  AL,BE,GA,COEF1,BET1,RESMIN,RESMAX,
     *  IDM,IDM,IDM,IDM,IDM,TITLE,IERR)
        ITFW = 'F   '
C
C       OWFILE - 1.open file 
C                2.writes title to file, parameters from common /COMRDF/
C
        CALL OWFILE(MD,MTOUTF,FO_NAME,ITFW,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) THEN
          CLOSE (MT1)
          CLOSE (MT2)
          CLOSE (MP1)
          CLOSE (MP2)
          CALL MSGERR(MDOC,' ERR: OPEN FILE-OUTPUT-F')
          IERR=1
          RETURN
        ENDIF
c      ELSE
c        CLOSE (MT1)
c        CLOSE (MT2)
c        CLOSE (MP1)
c        CLOSE (MP2)
c        CALL MSGERR(MDOC,' ERR:  WRONG NAME OF FILE-OUTPUT-F')
c        IERR=1
c        RETURN
      ENDIF
C --------------
      MTOUTP = 0
      CALL LENSTR_BL(PHO_NAME,LEN)
      IF(LEN.GT.0.AND.PHO_NAME(1:1).NE.' '.AND.
     *                PHO_NAME(1:1).NE.',') THEN
        MTOUTP=31
C ---
C       C_CR_WR - copy parameters from common/CRYSTL/ to common/COMWRF/
C
C        CALL C_CR_WR
C ---
C       SET_TITLE - sets information to  /COMWRF/
C 
        CALL SET_TITLE(MD,A,B,C,
     *  AL,BE,GA,COEF1,BET1,RESMIN,RESMAX,
     *  IDM,IDM,IDM,IDM,IDM,TITLE,IERR)
        ITPW = 'PH  '
C
C       OWFILE - 1.open file 
C                2.writes title to file, parameters from common /COMRDF/
C
        CALL OWFILE(MD,MTOUTP,PHO_NAME,ITPW,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) THEN
          CLOSE (MT1)
          CLOSE (MT2)
          CLOSE (MP1)
          CLOSE (MP2)
          CLOSE (MTOUTF)
          CALL MSGERR(MDOC,' ERR: OPEN FILE-OUTPUT-PH')
          IERR=1
          RETURN
        ENDIF
c      ELSE
c        CLOSE (MT1)
c        CLOSE (MT2)
c        CLOSE (MP1)
c        CLOSE (MP2)
c        CALL MSGERR(MDOC,' ERR:  WRONG NAME OF FILE-OUTPUT-PH')
c        IERR=1
c        RETURN
      ENDIF
C ----------------------------------------------------------
C ---
C 
C     initialization for CENTR_BL and ANOMSC
C
      CALL INIT_CENTR(NSYM,ISYM)
      CALL ANOMF(M,NSYM,ISYM)
C
C     calc limits H,k,l and grid for RESMAX
C
      CALL LIMHKL(RESMAX,IHMAX,IKMAX,ILMAX,NXMIN,NYMIN,NZMIN)
C
C     initialization for CENTR_BL
C
      CALL INIT_CENTR(NSYM,ISYM)
C ---
      NTOT   = 0
      FN_000 = 0.0
      FD_000 = 0.0
      SD12   = 0.0
      SD1    = 0.0
      SD2    = 0.0
C ----
      IEND1  =-1
      IEND2  =-1
      IENDP1 =-1
      IENDP2 =-1
      IENDW  =-1
      IENDPW =-1
      JH     =-200
      JK     =-200
      JL     =-200
      KH     =-200
      KK     =-200
      KL     =-200
      JH1    =-200
      JK1    =-200
      JL1    =-200
      KH1    =-200
      KK1    =-200
      KL1    =-200

        Fn  = 1.0
        cs1 = 1.0
        SN1 = 1.0
        FD  = 1.0
        cs2 = 1.0
        SN2 = 1.0
        sn  = 1.0         
C ---
      IF(ITF1.EQ.'FS  ') THEN
        CALL RRD(MT1,JH,JK,JL,FN,FNA,SN,SNA,KEY1,IEND1)
      ELSE
        CALL RD(MT1,JH,JK,JL,FN,FNA,KEY1,IEND1)
        SN  = 0.04*FN
        SNA = 0.04*FNA
      ENDIF
      IF(MT1.LE.0) THEN
        CALL MSGERR(MDOC,' ERR: READ FILE_F1')
        CLOSE (MT2)
        CLOSE (MP1)
        CLOSE (MP2)
        IF(MTOUTF.GT.0) CLOSE (MTOUTF)
        IF(MTOUTP.GT.0) CLOSE (MTOUTP)
        IERR=1
        RETURN
      ENDIF
      IF(IEND1.GT.0)                   GO TO 800

      IF(ITF2.EQ.'FS  ') THEN
        CALL RRD1(MT2,KH,KK,KL,FD,FDA,SF,SFA,KEY2,IEND2)
      ELSE
        CALL RD1(MT2,KH,KK,KL,FD,FDA,KEY2,IEND2)
C       SIG-DUMMY
        SF  = 0.04*FD
        SFA = 0.04*FDA
      ENDIF
      IF(MT2.LE.0) THEN
        CALL MSGERR(MDOC,' ERR: READ FILE_F2')
        CLOSE (MT1)
        CLOSE (MP1)
        CLOSE (MP2)
        IF(MTOUTF.GT.0) CLOSE (MTOUTF)
        IF(MTOUTP.GT.0) CLOSE (MTOUTP)
        IERR=1
        RETURN
      ENDIF
      IF(IEND2.GT.0)                   GO TO 800

      IF(JH.EQ.0.AND.JK.EQ.0.AND.JL.EQ.0.AND.
     *   KH.EQ.0.AND.KK.EQ.0.AND.KL.EQ.0     ) THEN

        FAA = FN + FD*SCALE
        FBB = 0.0
        SA  = SN + SF*SCALE
        SB  = 0.0
        IF(MTOUTF.GT.0) THEN
          IF(ITFW.EQ.'F   ') THEN
            CALL WRT(MTOUTF,JH,JK,JL,FAA,FBB,KEYW,IENDW)
          ELSE
            CALL WWRT(MTOUTF,JH,JK,JL,FAA,FBB,SA,SB,KEYW,IENDW)
          ENDIF
          IF(MTOUTF.LE.0) THEN
            CALL MSGERR(MDOC,' ERR: WRITE FILE_OUT-F')
            CLOSE(MT1)
            CLOSE(MT2)
            CLOSE(MP1)
            CLOSE(MP2)
            IF(MTOUTP.GT.0) CLOSE (MTOUTP)
            IERR=1
            RETURN
          ENDIF
        ENDIF
      ENDIF
      CLOSE (MT1)
      ITYP = 'FF  '
      CALL ORFILE(MD,MT1,F_NAME,ITYP,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CLOSE (MT2)
        CLOSE (MP1)
        CLOSE (MP2)
        IF(MTOUTF.GT.0) CLOSE (MTOUTF)
        IF(MTOUTP.GT.0) CLOSE (MTOUTP)
        CALL MSGERR(MD,' ERR: OPEN FILE-F1')
        RETURN
      ENDIF
      CLOSE (MT2)
      ITYP = 'FF  '
      CALL ORFILE(MD,MT2,F2_NAME,ITYP,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERR: OPEN FILE-F2')
        CLOSE (MT1)
        CLOSE (MP1)
        CLOSE (MP2)
        IF(MTOUTF.GT.0) CLOSE (MTOUTF)
        IF(MTOUTP.GT.0) CLOSE (MTOUTP)
        RETURN
      ENDIF
C ---
      IEND1  =-1
      IEND2  =-1
      IENDP1 =-1
      IENDP2 =-1
C      IENDW  =-1
      IENDPW =-1
      JH     =-200
      JK     =-200
      JL     =-200
      KH     =-200
      KK     =-200
      KL     =-200
      JH1    =-200
      JK1    =-200
      JL1    =-200
      KH1    =-200
      KK1    =-200
      KL1    =-200

        Fn  = 1.0
        cs1 = 1.0
        SN1 = 1.0
        FD  = 1.0
        cs2 = 1.0
        SN2 = 1.0
        sn  = 1.0         
C -----------------------------------------
      DO     IL=0,ILMAX
      DO     IK=-IKMAX,IKMAX
      DO     IH=-IHMAX,IHMAX
        IF(IH.EQ.0.AND.IK.EQ.0.AND.IL.EQ.0) THEN
          GO TO 100
        ENDIF
        IHP = IH
        IKP = IK
        ILP = IL
C
C        ANOMSC - transforms h,k,l to asymmetrycal part of reciprocal space.
C        output : IH,IK,IL -   indices h,k,l from asymmetrycal part
C                 IANOM    - 0   +h,+k,+l
C                            1   -h,-k,-l
C                 JJSYM    - number operator of symmetry :
C                                 in(h,k,l) -- JJSYM --> out(h,k,l)
C
        CALL ANOMSC(IHP,IKP,ILP,IANOM,JJSYM,NSYM,ISYM)
        IF(IANOM.NE.1.OR.JJSYM.NE.1) GO TO 100

        IF(NSYM.GT.1) THEN
C
C         SYSABS - check systematic absent for h,k,l: 1 - absent, 0 - no.
C
          CALL SYSABS_BL(IH,IK,IL,NSYM,ISYM,ICND)
        ELSE
          ICND = 0
        ENDIF
C
C ---   ICND NE 0 systematic absent
C
        IF(ICND.NE.0) GO TO 100
C 
C       DSTAR - gives value of (4pi*sin(theta))/lambda for H,K,L
C
        CALL DSTAR(IH,IK,IL,RSQ)
        RH = SQRT(RSQ)
        IF(RH.LT.RHMIN.OR.RH.GT.RHMAX) GO TO 100
C ---
C       CENTR_BL - Determine whether a reflection (IH,IK,IL) is centric or not

        CALL CENTR_BL(IH,IK,IL,JCENT)
C
C ---   JCENT = 1 centric reflection, JCENT = 0 acentric reflection
C ---
C ------
  200   CONTINUE
        IF(IEND1.GT.0) GO TO 800

C        IF(JL-IL) 240,210,100
C  210   IF(JK-IK) 240,220,100
C  220   IF(JH-IH) 240,230,100

        IF(JL.LT.IL) GO TO 240
        IF(JL.GT.IL) GO TO 100
        IF(JK.LT.IK) GO TO 240
        IF(JK.GT.IK) GO TO 100
        IF(JH.LT.IH) GO TO 240
        IF(JH.GT.IH) GO TO 100
        GO TO 230

C ------
  240   CONTINUE
C
C        RD - read from MT1 ; type of file :"F   ","PH  ","COEF","ALMN"
C        RRD- read from MT1 ; type of file :"FS  "
C 
        IF(ITF1.EQ.'FS  ') THEN
          CALL RRD(MT1,JH,JK,JL,FN,FNA,SN,SNA,KEY1,IEND1)
        ELSE
          CALL RD(MT1,JH,JK,JL,FN,FNA,KEY1,IEND1)
C
C        IF(ITF2.EQ.'COEF') THEN
C          CALL RD1(MT1,JH,JK,JL,FA,FB,KEY1,IEND1)
C        IF(ITF2.EQ.'ABCD') THEN
c          CALL RABCD(MT1,JH,JK,JL,AC,BC,CC,DC,KEY1,IEND1)
C        IF(ITF2.EQ.'PH  ') THEN
c          CALL RD1(MT1,JH,JK,JL,COSFOM,SINFOMC,KEY1,IEND1)
C
C Possible to use:
C          CALL RD(MT1,JH,JK,JL,FN,FNA,KEY1,IEND1)
C          CALL RRD(MT1,JH,JK,JL,FN,FNA,SN,SNA,KEY1,IEND1)
C          CALL RD2(MT1,JH,JK,JL,FN,FNA,KEY1,IEND1)
C          CALL RRD2(MT1,JH,JK,JL,FN,FNA,SN,SNA,KEY1,IEND1)
C          CALL RD3(MT1,JH,JK,JL,FN,FNA,NUMB,IEND)
C          CALL RRD3(MT1,JH,JK,JL,FN,FNA,SN,SNA,KEY1,IEND1)
C          CALL RD4(MT1,JH,JK,JL,FN,FNA,KEY1,IEND1)
C          CALL RRD4(MT1,JH,JK,JL,FN,FNA,SN,SNA,KEY1,IEND1)
C          CALL RABCD1(MT1,JH,JK,JL,AC,BC,CC,DC,KEY1,IEND1)
C

C         SIG-DUMMY
          SN  = 0.04*FN
          SNA = 0.04*FNA
        ENDIF
C       IFLAG_FREE = KEY1/2        
C       IFLAG_FREE = KEY1 - IFLAG_FREE*2 
C       if IFLAG_FREE = 1 - free reflection
C       use program COPYFL to set "free flag".
 
        IF(MT1.LE.0) THEN
          CALL MSGERR(MDOC,' ERR: READ FILE_F1')
          CLOSE (MT2)
          CLOSE (MP1)
          CLOSE (MP2)
          IF(MTOUTF.GT.0) CLOSE (MTOUTF)
          IF(MTOUTP.GT.0) CLOSE (MTOUTP)
          IERR=1
          RETURN
        ENDIF
        IF(IEND1.GT.0)                   GO TO 800
        IF(FN.LE.1.E-6.AND.FNA.LE.1.E-6) GO TO 100
        IF(FN.GT.1.E-6.AND.FNA.GT.1.E-6) THEN
          WT1 = 1./(SN*SN)
          WT2 = 1./(SNA*SNA)
          WT  = WT1+WT2
          FN  = FN*WT1+FNA*WT2
          FN  = FN/WT
          SN  = 1./SQRT(WT)
        ELSE IF(FNA.GT.1.E-6) THEN
          FN = FNA
          SN = SNA
        ENDIF
        IF(JH.EQ.0.AND.JK.EQ.0.AND.JL.EQ.0) THEN
          FN_000 = FN
        ENDIF

        GO TO 200
  230   CONTINUE
C --------------------------------------------
  400   CONTINUE
        IF(IENDP1.GT.0) GO TO 800

C        IF(JL1-IL) 440,410,100
C  410   IF(JK1-IK) 440,420,100
C  420   IF(JH1-IH) 440,430,100

        IF(JL1.LT.IL) GO TO 440
        IF(JL1.GT.IL) GO TO 100
        IF(JK1.LT.IK) GO TO 440
        IF(JK1.GT.IK) GO TO 100
        IF(JH1.LT.IH) GO TO 440
        IF(JH1.GT.IH) GO TO 100
        GO TO 430
C ------
  440   CONTINUE
        CALL RD2(MP1,JH1,JK1,JL1,CS1,SN1,KEY3,IENDP1)
        IF(MP1.LE.0) THEN
          CALL MSGERR(MDOC,' ERR: READ FILE_PH1')
          CLOSE (MT1)
          CLOSE (MT2)
          CLOSE (MP2)
          IF(MTOUTF.GT.0) CLOSE (MTOUTF)
          IF(MTOUTP.GT.0) CLOSE (MTOUTP)
          IERR=1
          RETURN
        ENDIF
        IF(IENDP1.GT.0)                   GO TO 800
        IF(ABS(CS1).LE.1.E-6.AND.ABS(SN1).LE.1.E-6) GO TO 100
        GO TO 400
  430   CONTINUE

C --------------------------------------------
  300   CONTINUE
        IF(IEND2.GT.0) GO TO 800

C        IF(KL-IL) 340,310,100
C  310   IF(KK-IK) 340,320,100
C  320   IF(KH-IH) 340,330,100

        IF(KL.LT.IL) GO TO 340
        IF(KL.GT.IL) GO TO 100
        IF(KK.LT.IK) GO TO 340
        IF(KK.GT.IK) GO TO 100
        IF(KH.LT.IH) GO TO 340
        IF(KH.GT.IH) GO TO 100
        GO TO 330
C ------
  340   CONTINUE
        IF(ITF2.EQ.'FS  ') THEN
          CALL RRD1(MT2,KH,KK,KL,FD,FDA,SF,SFA,KEY2,IEND2)
        ELSE
          CALL RD1(MT2,KH,KK,KL,FD,FDA,KEY2,IEND2)
C         SIG-DUMMY
          SF  = 0.04*FD
          SFA = 0.04*FDA
        ENDIF
        IF(MT2.LE.0) THEN
          CALL MSGERR(MDOC,' ERR: READ FILE_F2')
          CLOSE (MT1)
          CLOSE (MP1)
          CLOSE (MP2)
          IF(MTOUTF.GT.0) CLOSE (MTOUTF)
          IF(MTOUTP.GT.0) CLOSE (MTOUTP)
          IERR=1
          RETURN
        ENDIF
        IF(IEND2.GT.0)                   GO TO 800
        IF(FD.LE.1.E-6.AND.FDA.LE.1.E-6) GO TO 100
        IF(FD.GT.1.E-6.AND.FDA.GT.1.E-6) THEN
          WT1 = 1./(SF*SF)
          WT2 = 1./(SFA*SFA)
          WT  = WT1+WT2
          FD  = FD*WT1+FDA*WT2
          FD  = FD/WT
          SF  = 1./SQRT(WT)
        ELSE IF(FDA.GT.1.E-6) THEN
          FD = FDA
          SF = SFA
        ENDIF
        IF(KH.EQ.0.AND.KK.EQ.0.AND.KL.EQ.0) THEN
          FD_000 = FD*SCALE
        ENDIF
        GO TO 300
  330   CONTINUE

C --------------------------------------------
  500   CONTINUE
        IF(IENDP2.GT.0) GO TO 800

C        IF(KL1-IL) 540,510,100
C  510   IF(KK1-IK) 540,520,100
C  520   IF(KH1-IH) 540,530,100

        IF(KL1.LT.IL) GO TO 540
        IF(KL1.LT.IL) GO TO 100
        IF(KK1.LT.IK) GO TO 540
        IF(KK1.LT.IK) GO TO 100
        IF(KH1.LT.IH) GO TO 540
        IF(KH1.LT.IH) GO TO 100
        GO TO 530 
C ------
  540   CONTINUE
        CALL RD3(MP2,KH1,KK1,KL1,CS2,SN2,KEY4,IENDP2)
        IF(MP2.LE.0) THEN
          CALL MSGERR(MDOC,' ERR: READ FILE_PH2')
          CLOSE (MT1)
          CLOSE (MT2)
          CLOSE (MP1)
          IF(MTOUTF.GT.0) CLOSE (MTOUTF)
          IF(MTOUTP.GT.0) CLOSE (MTOUTP)
          IERR=1
          RETURN
        ENDIF
        IF(IENDP2.GT.0)                   GO TO 800
        IF(ABS(CS2).LE.1.E-6.AND.ABS(SN2).LE.1.E-6) GO TO 100
        GO TO 500
  530   CONTINUE
C --------------------------------------------
        IF(BOFF.GT.0.000001) THEN
          BT    = BOFF/4.0
          CBOFF = 1.0-EXP(-BT*RSQ)
        ELSE
          CBOFF=1.0
        ENDIF
        IF(ABS(BADD).GT.0.000001) THEN
          BT    = BADD/4.0
          CBADD = EXP(-BT*RSQ)
        ELSE
          CBADD=1.0
        ENDIF
        CBOFFADD=CBOFF*CBADD

        FN = FN * CBOFFADD         
        SN = SN * CBOFFADD         
        FD = FD * CBOFFADD         
        SF = SF * CBOFFADD         
C ----

        FA1 = FN*CS1
        FB1 = FN*SN1
        FA2 = FD*CS2
        FB2 = FD*SN2

        ARG  = TWOPI*(IH*SHIFT(1)+IK*SHIFT(2)+IL*SHIFT(3))
        COSD = COS(ARG)
        SIND = SIN(ARG)
        STOR = FA2*COSD-FB2*SIND
        FB2  = FB2*COSD+FA2*SIND
        FA2  = STOR

        IF(INVER.EQ.'Y') FB1 = -FB1 

        IF(MODE.EQ.'C') THEN
          A   =  FA1*FA2 + FB1*FB2
          B   = -FA1*FB2 + FA2*FB1
          A   = A * SCALE
          B   = B * SCALE
        ELSE
          A   =  FA1 + FA2 * SCALE
          B   =  FB1 + FB2 * SCALE
        ENDIF

        FM  = SQRT(A*A+B*B)

        IF(FM.GT.1.0E-7) THEN
          CSO = A/FM
          SNO = B/FM
        ELSE
          CSO = 1.0
          SNO = 0.0
        ENDIF

        IF(MODE.EQ.'I') THEN
          FM =SQRT(ABS(FN*FN + FD*FD*SCALE*SCALE))
        ENDIF

        FAA = FM
        FBB = 0.0
        SA  = SN
        SB  = SN
C ----
        SD12 = SD12 + 2.0*(FA1*FA2 + FB1*FB2)
        SD1  = SD1  + 2.0*(FA1*FA1 + FB1*FB1)
        SD2  = SD2  + 2.0*(FA2*FA2 + FB2*FB2)
C ----
        NTOT = NTOT+1
C ---
        IF(MTOUTF.GT.0) THEN
C         WRT  - write to MT ; type of file :"F   ","PH  ","COEF","ALMN"
C         WWRT - write to MT ; type of file :"FS  "
          IF(ITFW.EQ.'F   ') THEN
            CALL WRT(MTOUTF,IH,IK,IL,FAA,FBB,KEYW,IENDW)
          ELSE
            CALL WWRT(MTOUTF,IH,IK,IL,FAA,FBB,SA,SB,KEYW,IENDW)
          ENDIF
          IF(MTOUTF.LE.0) THEN
            CALL MSGERR(MDOC,' ERR: WRITE FILE_OUT-F')
            CLOSE(MT1)
            CLOSE(MT2)
            CLOSE(MP1)
            CLOSE(MP2)
            IF(MTOUTP.GT.0) CLOSE (MTOUTP)
            IERR=1
            RETURN
          ENDIF
        ENDIF
C ---
        IF(MTOUTP.GT.0) THEN
          CALL WRT1(MTOUTP,IH,IK,IL,CSO,SNO,KEYPW,IENDPW)
          IF(MTOUTP.LE.0) THEN
            CALL MSGERR(MDOC,' ERR: WRITE FILE_OUT-PH')
            CLOSE(MT1)
            CLOSE(MT2)
            CLOSE(MP1)
            CLOSE(MP2)
            IF(MTOUTF.GT.0) CLOSE (MTOUTF)
            IERR=1
            RETURN
          ENDIF
        ENDIF
C
C        IF(ITFW.EQ.'COEF') THEN
C          CALL WRT(MTOUT,IH,IK,IL,FA,FB,KEYW,IENDW)
C        IF(ITFW.EQ.'ABCD') THEN
c          CALL WABCD(MTOUT,IH,IK,IL,AC,BC,CC,DC,KEYW,IENDW)
C        IF(ITFW.EQ.'PH  ') THEN
c          CALL WRT(MTOUT,IH,IK,IL,COSFOM,SINFOMC,KEYW,IENDW)
C
C Possible to use:
C          CALL WRT1(MTOUT,IH,IK,IL,FN,FNA,KEYW,IENDW)
C          CALL WWRT1(MTOUT,IH,IK,IL,FN,FNA,SN,SNA,KEYW,IENDW)
C          CALL WABCD1(MTOUT,IH,IK,IL,AC,BC,CC,DC,KEYW,IENDW)
C
C ----
 100  CONTINUE
      ENDDO
      ENDDO
      ENDDO
C ---------------------------------------
  800 CONTINUE
      CLOSE (MT1)
      CLOSE (MT2)
      CLOSE (MP1)
      CLOSE (MP2)
      IF(MTOUTF.GT.0) THEN
        IF(NTOT.LE.0) THEN
          CALL MSGERR(MDOC,' ERR: number of refls to write = 0')
          IF(MTOUTP.GT.0) CLOSE (MTOUTP)
          CLOSE(MTOUTF)
          IERR=1
          RETURN
        ENDIF
C ---
C       writes last record (  512,512,512,0,0 ) and close file
C                          
        IENDW=2
        CALL WRT(MTOUTF,IH,IK,IL,FAA,FBB,KEYW,IENDW)
C ---
        IF(MTOUTF.LE.0) THEN
          CALL MSGERR(MDOC,' ERR: CLOSE FILE_OUT-F')
          IERR=1
          RETURN
        ENDIF
      ENDIF
C ---
      IF(MTOUTP.GT.0) THEN
        IF(NTOT.LE.0) THEN
          CALL MSGERR(MDOC,' ERR: number of refls to write = 0')
          IF(MTOUTF.GT.0) CLOSE (MTOUTF)
          CLOSE(MTOUTP)
          IERR=1
          RETURN
        ENDIF
C ---
C       writes last record (  512,512,512,0,0 ) and close file
C                          
        IENDPW=2
        CALL WRT(MTOUTP,IH,IK,IL,FAA,FBB,KEYPW,IENDPW)
C ---
        IF(MTOUTP.LE.0) THEN
          CALL MSGERR(MDOC,' ERR: CLOSE FILE_OUT-PH')
          IERR=1
          RETURN
        ENDIF
      ENDIF
      IF(NTOT.GT.0) THEN
          IF(F000I.EQ.'N') THEN
            FN_000 = 0.0
            FD_000 = 0.0
          ENDIF
          T1 = SD1 - FN_000*FN_000
          IF(T1.LT.0.0) T1 = 0.0
          T2 = SD2 - FD_000*FD_000
          IF(T2.LT.0.0) T2 = 0.0
          T1 = T1*T2
          IF(T1.GE.0.000001) THEN
            CORR_I  = (SD12-FN_000*FD_000)/SQRT(T1)
          ELSE
            CORR_I  = -999.0
          ENDIF
      ELSE
        CORR_I  = -999.0
      ENDIF
C ----------------------------------------------------------
      RESULT(1) = NTOT
      RESULT(2) = RESMIN
      RESULT(3) = RESMAX
      RESULT(4) = CORR_I
C -----------------------------------------------------------
      WRITE(LINE,1000) NTOT
 1000 FORMAT('NUMB REFLS = ',I6)
      CALL MSGDOC(MDOC,LINE)
      RETURN
      END

      SUBROUTINE FSCALE(MDOC,F_NAME,FN_NAME,FO_NAME,SCALEI,BOVERI
     * ,BOFF,BADD,RESMNI,RESMXI
     * ,RESMIN_USED,RESMAX_USED
     * ,ISYM,IPRSYM,RESULT,IERR)
C ------------------------------------------------------------------
C    if scale = 0 - scaling by F2 (cell must be the same),
C                   only scale , set BOVER = 0
C    if scalei>0  - scaling by SCALEI,BOVERI without FN file, no info
c      output all or by RESMIN_USED,RESMAX_USED
C ------------------------------------------------------------------
      INTEGER*2 ISYM(5,3,IPRSYM)
      REAL      RESULT(*)
      REAL      RESMNI,RESMXI,BOFF,BADD,SCALEI,BOVERI
      INTEGER*4 MDOC,IERR
      CHARACTER F_NAME*(*),FN_NAME*(*),FO_NAME*(*)
C ==============================
      INTEGER*4 MTIN,MTNAT,MTOUT
      REAL      RLATT(6)
      CHARACTER ITYPE*4,ITYP*4,ITF1*4,ITF2*4
      CHARACTER LINE*80,TTT*80,TITLE*80
C -----------------------------------------------------------
      IERR = 0
      MD   =-ABS(MDOC)-1
      M    = 99
C ------
      DO I=1,11
        RESULT(I) = 0.0
      ENDDO
      SCALE = SCALEI
      BOVER = BOVERI
C ------
      ITYP ='FF  '
      MTIN = 20
      CALL LENSTR_BL(F_NAME,LEN)
      IF(LEN.LE.0.OR.F_NAME(1:1).EQ.' '.OR.F_NAME(1:1).EQ.',') THEN
        IERR=1
        RETURN
      ENDIF
      CALL ORFILE(M,MTIN,F_NAME,ITYP,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MD,' ERR: OPEN FILE-F')
        RETURN
      ENDIF
      CALL GET_TITLE(M,A,B,C,AL,BE,GA
     *  ,COEF1,BET1,RESMIN,RESMAX,IDM,IDM,IDM,IDM,IDM,TITLE,IERR)
      ITF1 = ITYP
C -------------------------------------------------------------
      CALL C_RD_CR
      RLATT(1) = A
      RLATT(2) = B
      RLATT(3) = C
      RLATT(4) = AL
      RLATT(5) = BE
      RLATT(6) = GA
      CALL DSTARF(RLATT,AST,BST,CST,COALST,COBEST,COGAST,VOL)
C -----------------
      IF(SCALE.GT.0.000001) THEN
        NTOT    = 0
        RESN    = RESMIN
        RESX    = RESMAX
        RFAC    = 0.0
        RCORR   = 0.0
        RFAC_I  = 0.0
        RCORR_I = 0.0
        GO TO 100
      ENDIF
C -----------------
      MTNAT = 21
      ITYPE = 'FF  '
      CALL LENSTR_BL(FN_NAME,LEN)
      IF(LEN.LE.0.OR.FN_NAME(1:1).EQ.' '.OR.FN_NAME(1:1).EQ.',') THEN
        CLOSE(MTIN)
        IERR=1
        RETURN
      ENDIF
      CALL ORFILE(M,MTNAT,FN_NAME,ITYPE,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MD,' ERR: OPEN FILE-TEST')
        CLOSE(MTIN)
        RETURN
      ENDIF
      CALL GET_TITLE(M,A1,B1,C1,AL1,BE1,GA1
     *  ,DM1,DM2,RN,RX,IDM,IDM,IDM,IDM,IDM,TTT,IERR)
      ITF2 = ITYPE
C -----------------
      RESN = RESMIN
      RESX = RESMAX
      IF(RN.LT.RESN) RESN=RN
      IF(RX.GT.RESX) RESX=RX
      IF(RESMNI.GT.1.E-5.AND.RESMNI.LT.RESN) RESN = RESMNI
      IF(RESMXI.GT.1.E-5.AND.RESMXI.GT.RESX) RESX = RESMXI

      RHMN = 1.0/RESN
      RHMX = 1.0/RESX
      WRITE(LINE,
     *'(''Resolution (for scaling) :'',2F10.2)') RESN,RESX
      CALL MSGDOC(MDOC,LINE)
      WRITE(LINE,
     *'(''Boff,Badd        :'',2F10.2)') BOFF,BADD
      CALL MSGDOC(MDOC,LINE)
C ------------------------------------------
      SUMAT = 0.0
      SUMBT = 0.0
      NTOT  = 0
      IEND1 =-1
      IEND  =-1
      JH    =-101
      JK    =-101
      JL    =-101
C -----------------------------------------
  200 CONTINUE
        IF(ITF2.EQ.'FS  ') THEN
          CALL RRD1(MTNAT,IH,IK,IL,FN,FNA,SN,SNA,NUMB,IEND)
        ELSE
          CALL RD1(MTNAT,IH,IK,IL,FN,FNA,NUMB,IEND)
C         SIG-DUMMY
          SN =0.04*FN
          SNA=0.04*FNA
        ENDIF
        IF(MTNAT.LE.0) THEN
          CALL MSGERR(MDOC,' ERR: READ FILE_TEST')
          CLOSE (MTIN)
          IERR=1
          RETURN
        ENDIF
        IF(IEND.GT.0.OR.IEND1.GT.0)      GO TO 220
        IF(FN.LE.1.E-6.AND.FNA.LE.1.E-6) GO TO 200
        IF(FN.GT.1.E-6.AND.FNA.GT.1.E-6) THEN
          IF(SN .LT.0.000001) SN =1.0
          IF(SNA.LT.0.000001) SNA=1.0
          WT1=1./(SN*SN)
          WT2=1./(SNA*SNA)
          WT =WT1+WT2
          FN =FN*WT1+FNA*WT2
          FN =FN/WT
          SN =1./SQRT(WT)
        ELSE IF(FNA.GT.1.E-6) THEN
          FN =FNA
          SN =SNA
        ENDIF
        CALL DSTAR(IH,IK,IL,RSQ)
        RHKL = SQRT(RSQ)
        IF(RHKL.LT.RHMN.OR.RHKL.GT.RHMX) GO TO 210
C --------------------------------------------------

C  280   IF(JL-IL) 230,250,210
C  250   IF(JK-IK) 230,260,210
C  260   IF(JH-IH) 230,270,210

  280   CONTINUE
        IF(JL.LT.IL) GO TO 230
        IF(JL.GT.IL) GO TO 210
        IF(JK.LT.IK) GO TO 230
        IF(JK.GT.IK) GO TO 210
        IF(JH.LT.IH) GO TO 230
        IF(JH.GT.IH) GO TO 210
        GO TO 270
C ------
  230   CONTINUE
        IF(ITF1.EQ.'FS  ') THEN
          CALL RRD2(MTIN,JH,JK,JL,FD,FDA,SF,SFA,NUMB1,IEND1)
        ELSE
          CALL RD2(MTIN,JH,JK,JL,FD,FDA,NUMB1,IEND1)
C         SIG-DUMMY
          SF =0.04*FD
          SFA=0.04*FDA
        ENDIF
        IF(MTIN.LE.0) THEN
          CALL MSGERR(MDOC,' ERR: READ FILE_IN')
          IERR=1
          CLOSE (MTNAT)
          RETURN
        ENDIF
        IF(IEND1.GT.0.OR.IEND.GT.0)      GO TO 220
        GO TO 280
C --------------------------------------------
  270   CONTINUE
        IF(FD.LE.1.E-6.AND.FDA.LE.1.E-6) GO TO 200
        IF(FD.GT.1.E-6.AND.FDA.GT.1.E-6) THEN
          IF(SF .LT.0.000001) SF =1.0
          IF(SFA.LT.0.000001) SFA=1.0
          WT1=1./(SF*SF)
          WT2=1./(SFA*SFA)
          WT =WT1+WT2
          FD =FD*WT1+FDA*WT2
          FD =FD/WT
          SF =1./SQRT(WT)
        ELSE IF(FDA.GT.1.E-6) THEN
          FD =FDA
          SF =SFA
        ENDIF
C -----------------------------------------------------
        IF(BOFF.GT.0.0) THEN
          BT=BOFF/4.0
          CBOFF=1.0-EXP(-BT*RSQ)
        ELSE
          CBOFF=1.0
        ENDIF
        IF(ABS(BADD).GT.0.00001) THEN
          BT=BADD/4.0
          CBADD=EXP(-BT*RSQ)
        ELSE
          CBADD=1.0
        ENDIF

        SUMAT = SUMAT+FN*FN*CBOFF*CBOFF*CBADD*CBADD
        SUMBT = SUMBT+FD*FD*CBOFF*CBOFF*CBADD*CBADD
        NTOT  = NTOT+1

  210   CONTINUE
        GO TO 200
C ---------------------------------------
  220 CONTINUE
      IF(NTOT.EQ.0) THEN
        CALL MSGERR(MDOC,' ERROR : NUMBER OF REFLS = 0')
        CLOSE (MTIN)
        CLOSE (MTNAT)
        IERR=1
        RETURN
      ENDIF

      SCALE = SUMAT/SUMBT
      SCALE = SQRT(SCALE)
C ---
      WRITE(LINE,'('' Scale, N  :'',E12.4,I8)') SCALE,NTOT
      CALL MSGDOC(MDOC,LINE)
      CALL MSGDOC(MDOC,'        Fnew = Fold*SCALE')
C ----------------------------------------------
      ITYP  ='    '
      CALL OPFILE(M,MTIN,F_NAME,ITYP,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MD,' ERR: OPEN FILE-F')
        CLOSE(MTNAT)
        RETURN
      ENDIF
      ITYPE = '    '
      CALL OPFILE(M,MTNAT,FN_NAME,ITYPE,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MD,' ERR: OPEN FILE-TEST')
        CLOSE(MTIN)
        RETURN
      ENDIF
C ----
      SUMDEL = 0.0
      SF1    = 0.0
      SF2    = 0.0
      SF12   = 0.0
      SF22   = 0.0
      SF1F2  = 0.0

      SUMDEL_I = 0.0
      SF1_I    = 0.0
      SF2_I    = 0.0
      SF12_I   = 0.0
      SF22_I   = 0.0
      SF1F2_I  = 0.0

      NTOT   = 0
      IEND1  =-1
      IEND   =-1
      JH     =-101
      JK     =-101
      JL     =-101
C ----
  300 CONTINUE
        IF(ITF2.EQ.'FS  ') THEN
          CALL RRD1(MTNAT,IH,IK,IL,FN,FNA,SN,SNA,NUMB,IEND)
        ELSE
          CALL RD1(MTNAT,IH,IK,IL,FN,FNA,NUMB,IEND)
C         SIG-DUMMY
          SN =0.04*FN
          SNA=0.04*FNA
        ENDIF
        IF(MTNAT.LE.0) THEN
          CALL MSGERR(MDOC,' ERR: READ FILE_TEST')
          CLOSE (MTIN)
          IERR=1
          RETURN
        ENDIF
        IF(IEND.GT.0.OR.IEND1.GT.0)      GO TO 320
        IF(FN.LE.1.E-6.AND.FNA.LE.1.E-6) GO TO 300
        IF(FN.GT.1.E-6.AND.FNA.GT.1.E-6) THEN
          IF(SN .LT.0.000001) SN =1.0
          IF(SNA.LT.0.000001) SNA=1.0
          WT1=1./(SN*SN)
          WT2=1./(SNA*SNA)
          WT =WT1+WT2
          FN =FN*WT1+FNA*WT2
          FN =FN/WT
          SN =1./SQRT(WT)
        ELSE IF(FNA.GT.1.E-6) THEN
          FN =FNA
          SN =SNA
        ENDIF
        CALL DSTAR(IH,IK,IL,RSQ)
        RHKL = SQRT(RSQ)
        IF(RHKL.LT.RHMN.OR.RHKL.GT.RHMX) GO TO 310
C --------------------------------------------------

C  380   IF(JL-IL) 330,350,310
C  350   IF(JK-IK) 330,360,310
C  360   IF(JH-IH) 330,370,310

  380   CONTINUE
        IF(JL.LT.IL) GO TO 330
        IF(JL.GT.IL) GO TO 310
        IF(JK.LT.IK) GO TO 330
        IF(JK.GT.IK) GO TO 310
        IF(JH.LT.IH) GO TO 330
        IF(JH.GT.IH) GO TO 310
        GO TO 370
C ------
  330   CONTINUE
        IF(ITF1.EQ.'FS  ') THEN
          CALL RRD2(MTIN,JH,JK,JL,FD,FDA,SF,SFA,NUMB1,IEND1)
        ELSE
          CALL RD2(MTIN,JH,JK,JL,FD,FDA,NUMB1,IEND1)
C         SIG-DUMMY
          SF =0.04*FD
          SFA=0.04*FDA
        ENDIF
        IF(MTIN.LE.0) THEN
          CALL MSGERR(MDOC,' ERR: READ FILE_IN')
          IERR=1
          CLOSE (MTNAT)
          RETURN
        ENDIF
        IF(IEND1.GT.0.OR.IEND.GT.0)      GO TO 320
        GO TO 380
C --------------------------------------------
  370   CONTINUE
        IF(FD.LE.1.E-6.AND.FDA.LE.1.E-6) GO TO 300
        IF(FD.GT.1.E-6.AND.FDA.GT.1.E-6) THEN
          IF(SF .LT.0.000001) SF =1.0
          IF(SFA.LT.0.000001) SFA=1.0
          WT1=1./(SF*SF)
          WT2=1./(SFA*SFA)
          WT =WT1+WT2
          FD =FD*WT1+FDA*WT2
          FD =FD/WT
          SF =1./SQRT(WT)
        ELSE IF(FDA.GT.1.E-6) THEN
          FD =FDA
          SF =SFA
        ENDIF
C -----------------------------------------------------
        IF(BOFF.GT.0.0) THEN
          BT=BOFF/4.0
          CBOFF=1.0-EXP(-BT*RSQ)
        ELSE
          CBOFF=1.0
        ENDIF
        IF(ABS(BADD).GT.0.00001) THEN
          BT=BADD/4.0
          CBADD=EXP(-BT*RSQ)
        ELSE
          CBADD=1.0
        ENDIF

        FN     = FN*CBOFF*CBADD
        FD     = FD*CBOFF*CBADD*SCALE
        DEL    = ABS(FN-FD)

        SUMDEL = SUMDEL + DEL
        SF1    = SF1    + FN     
        SF2    = SF2    + FD    
        SF12   = SF12   + FN * FN 
        SF22   = SF22   + FD * FD
        SF1F2  = SF1F2  + FN * FD

c        SUMDEL_I = SUMDEL_I + DEL*DEL
c        SF1_I    = SF1_I    + FN *FN   
c        SF2_I    = SF2_I    + FD *FD  
c        SF12_I   = SF12_I   + FN * FN * FN * FN  
c        SF22_I   = SF22_I   + FD * FD * FD * FD
c        SF1F2_I  = SF1F2_I  + FN * FD * FN * FD

        NTOT  = NTOT+1
 
  310   CONTINUE
        GO TO 300
C ---------------------------------------
  320 CONTINUE
      IF(NTOT.GT.0) THEN

        RFAC = SUMDEL/SF1
        CALL MSGDOC(MDOC,' ')
        WRITE(LINE,'('' R-factor               :'',F8.4)') RFAC
        CALL MSGDOC(MDOC,LINE)

c       RFAC_I = SUMDEL_I/SF1_I
        RFAC_I =  0.0

        SF1A   = SF1  /NTOT
        SF2A   = SF2  /NTOT
        SF12A  = SF12 /NTOT
        SF22A  = SF22 /NTOT
        SF1F2A = SF1F2/NTOT
        T1 = (SF12A-SF1A*SF1A)
        T2 = (SF22A-SF2A*SF2A)
        T1 = T1*T2
        IF(T1.GE.0.0) THEN
          RCORR = (SF1F2A-SF1A*SF2A)/SQRT(T1)
        ELSE
          RCORR = 0.0
        ENDIF

c        SF1A   = SF1_I   /NTOT
c        SF2A   = SF2_I   /NTOT
c        SF12A  = SF12_I  /NTOT
c        SF22A  = SF22_I  /NTOT
c        SF1F2A = SF1F2_I /NTOT
c        T1 = (SF12A-SF1A*SF1A)
c        T2 = (SF22A-SF2A*SF2A)
c        T1 = T1*T2
c        IF(T1.GE.0.0) THEN
c          RCORR_I  = (SF1F2A-SF1A*SF2A)/SQRT(T1)
c        ELSE
          RCORR_I = 0.0
c        ENDIF

      ELSE
        RFAC    = 0.0
        RCORR   = 0.0
        RFAC_I  = 0.0
        RCORR_I = 0.0
      ENDIF

      WRITE(LINE,'(''Correlation coefficient :'',F8.4)') RCORR
      CALL MSGDOC(MDOC,LINE)
      CALL MSGDOC(MDOC,
     *'CC = <F1*F2>-<F1><F2>/SQRT((<F1^2>-<F1>^2)(<F2^2>-<F2>^2))')
C ----------------------------------
      CLOSE(MTNAT)
      BOVER = 0.0
C ---
      ITYP  ='    '
      CALL OPFILE(M,MTIN,F_NAME,ITYP,NSYM,ISYM,IPRSYM,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MD,' ERR: OPEN FILE-F')
        RETURN
      ENDIF
C -------------------------------
 100  CONTINUE
      IF(RESMIN_USED.GT.0.01) RESN = RESMIN_USED
      IF(RESMAX_USED.GT.0.01) RESX = RESMAX_USED
      RESULT(1) = NTOT
      RESULT(2) = RESN
      RESULT(3) = RESX
      RESULT(4) = SCALE
      RESULT(5) = RFAC
      RESULT(6) = RCORR
      RESULT(7) = BOVER
      RESULT(10) = RFAC_I
      RESULT(11) = RCORR_I
C -------------------------------
      CALL LENSTR_BL(FO_NAME,LEN)
      MTOUT=30
      IF(LEN.LE.0.OR.FO_NAME(1:1).EQ.' '.OR.FO_NAME(1:1).EQ.',') THEN
C        CLOSE (MTIN)
C        RETURN
        MTOUT=0
      ENDIF
      COEF1 = COEF1*SCALE
      BET1  = BET1 + BOVER
      IF(MTOUT.GT.0) THEN
        CALL C_CR_WR
        CALL SET_TITLE(MD,A,B,C,
     *    AL,BE,GA,COEF1,BET1,RESN,RESX,
     *    IDM,IDM,IDM,IDM,IDM,TITLE,IERR)
        CALL OWFILE(MD,MTOUT,FO_NAME,ITF1,NSYM,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) THEN
          CLOSE (MTIN)
          CALL MSGERR(MD,' ERR: OPEN FILE-OUTPUT')
          IERR=1
          RETURN
        ENDIF
      ENDIF
C ----------------------------------------------------------
      CALL C_RD_CR
      RLATT(1) = A
      RLATT(2) = B
      RLATT(3) = C
      RLATT(4) = AL
      RLATT(5) = BE
      RLATT(6) = GA
      CALL DSTARF(RLATT,AST,BST,CST,COALST,COBEST,COGAST,VOL)

      RHMN = 1.0/RESN
      RHMX = 1.0/RESX

      NREF  = 0
      SUMFA = 0.
      SUMF  = 0.
      FAV   = 0.
      FAVA  = 0.
      IEND  =-1
      IEND1 =-1
      NUMB1 = 0
C -------------------------------------------------------------------
  400 CONTINUE
      IF(ITF1.EQ.'FS  ') THEN
        CALL RRD1(MTIN,IH,IK,IL,FNN,FNA,SNN,SNA,NUMB1,IEND)
      ELSE
        CALL RD1(MTIN,IH,IK,IL,FNN,FNA,NUMB1,IEND)
C       SIG-DUMMY
        SNN=0.04*FNN
        SNA=0.04*FNA
      ENDIF
      IF(MTIN.LE.0) THEN
        CALL MSGERR(MDOC,' ERR: READ FILE_IN')
        IF(MTOUT.GT.0) CLOSE (MTOUT)
        IERR=1
        RETURN
      ENDIF
      IF(IEND.GT.0)                     GO TO 420
      IF(FNN.LE.1.E-6.AND.FNA.LE.1.E-6) GO TO 400
      FN=FNN
      SN=SNN
      IF(IH.EQ.0.AND.IK.EQ.0.AND.IL.EQ.0) THEN
        FMOD = FN *SCALE
        SNN  = SN *SCALE
        FAN  = 0.0
        SNA  = 0.0
        NREF = NREF +1
        IF(MTOUT.GT.0) THEN
          IF(ITYP.EQ.'F   ') THEN
            CALL WRT(MTOUT,IH,IK,IL,FMOD,FAN,NUMB1,IEND1)
          ELSE
            CALL WWRT(MTOUT,IH,IK,IL,FMOD,FAN,SNN,SNA,NUMB1,IEND1)
          ENDIF
          IF(MTOUT.LE.0) THEN
            CALL MSGERR(MDOC,' ERR: WRITE FILE_OUT')
            IERR=1
            RETURN
          ENDIF
        ENDIF
        GO TO 400
      ENDIF
      CALL DSTAR(IH,IK,IL,RSQ)
      RHKL = SQRT(RSQ)
      IF(RHKL.LT.RHMN.OR.RHKL.GT.RHMX) GO TO 400
      IF(FNN.GT.1.E-6.AND.FNA.GT.1.E-6) THEN
        IF(SNN .LT.0.000001) SNN =1.0
        IF(SNA.LT.0.000001) SNA=1.0
        WT1=1./(SNN*SNN)
        WT2=1./(SNA*SNA)
        WT =WT1+WT2
        FN =FNN*WT1+FNA*WT2
        FN =FN/WT
        SN =1./SQRT(WT)
      ELSE IF(FNA.GT.1.E-6) THEN
        FN =FNA
        SN =SNA
      ENDIF


      BTT   = BOVER/4.0
      X     = SCALE*EXP(-BTT*RSQ)
      FMOD  = FNN*X
      FAN   = FNA*X
      SNN   = SNN*X
      SNA   = SNA*X
      FN    = FN *X
      SN    = SN *X
      SUMF  = SUMF +FMOD
      SUMFA = SUMFA+FAN
      NREF  = NREF +1

      IF(MTOUT.GT.0) THEN
        IF(ITYP.EQ.'F   ') THEN
          CALL WRT(MTOUT,IH,IK,IL,FMOD,FAN,NUMB1,IEND1)
        ELSE
          CALL WWRT(MTOUT,IH,IK,IL,FMOD,FAN,SNN,SNA,NUMB1,IEND1)
        ENDIF
        IF(MTOUT.LE.0) THEN
          CALL MSGERR(MDOC,' ERR: WRITE FILE_OUT')
          CLOSE (MTIN)
          IERR=1
          RETURN
        ENDIF
      ENDIF
      GO TO 400
C -----------------------------------------------------------
  420 CONTINUE
      IEND1=2
      IF(MTOUT.GT.0) THEN
        CALL WRT(MTOUT,IH,IK,IL,FNN,FNA,NUMB1,IEND1)
        IF(MTOUT.LE.0) THEN
          CALL MSGERR(MDOC,' ERR: WRITE FILE_OUT')
          CLOSE (MTIN)
          IERR=1
          RETURN
        ENDIF
      ENDIF
C ----------------
      IF(NREF.GT.0) THEN
        FAV =SUMF /NREF
        FAVA=SUMFA/NREF
      ENDIF
      CALL MSGDOC(MDOC,' ')
      WRITE(LINE,1060) NREF,FAV,FAVA
 1060 FORMAT('NUMB REFLS=',I6,
     *       ' F(h,k,l)-AVER=',E12.4,' F(-h,-k,-l)-AVER=',E12.4)
      CALL MSGDOC(MDOC,LINE)
      IF(MTIN.GT.0)  CLOSE (MTIN)
      IF(MTOUT.GT.0) CLOSE (MTOUT)
      RETURN
      END

      SUBROUTINE PDB_OR_CIF(MDOC,IN_FILE_PDB,FILE_OUT,PATH_SCR,FLAG_O
     *  ,MODEL,CHAIN,RESULT,IPRROW,ISYM,IPRSYM,IERR)
C -------------------------------------
      INTEGER*4 MDOC,IERR
      CHARACTER IN_FILE_PDB*(*),FILE_OUT*(*),FLAG*1,FLAG_O*1
      CHARACTER PATH_SCR*(*)
C -------------------------------------
      INTEGER*2 ISYM(5,3,IPRSYM)
      REAL      RESULT(IPRROW,51)
C ---
      CHARACTER LINE*80,PATH*80,EXT*3,STR*80
      INTEGER*4 MD,M,IUN,IFIRST,LEN,I,J,K
C ---
      CHARACTER   STR_TITLE*40,STR_DATE*9,PDB*1,CHAIN*1
C ---
      CHARACTER   MODE*1,SETT*1,REST*1,WAT*1,P1*80
      CHARACTER   HATM*1,NUM*1,NOCC*1,ALT*1,CONV*1
C ---
      CHARACTER   FILE_C*256,NAME*256
C ----------------------------------
      MD   = -ABS(MDOC)-1
      M    = 99
      IERR = 0
C ----------------
      CALL CLEAR_LINE(IN_FILE_PDB)
      CALL LENSTR_BL(IN_FILE_PDB,LEN)
      IF(LEN.LE.0.OR.IN_FILE_PDB(1:1).EQ.','.OR.
     *               IN_FILE_PDB(1:1).EQ.' ') THEN
        CALL MSGERR(MDOC,' ERROR: can''t open input_file')
        IERR=1
        RETURN
      ENDIF

      LLL = LEN
      IF(LLL.GT.65) LLL = 65
      LINE = 'Input file : '//IN_FILE_PDB(1:LLL)
      CALL MSGDOC(MDOC,LINE)

C ----
      IUN  = 14

      PATH = ' '
      EXT  = ' '
      CALL OPENFR(IUN,M,PATH,IN_FILE_PDB,EXT,IERR)
      IF(IERR.NE.0) THEN
        CALL MSGERR(MDOC,' ERROR: can''t open input_coord_file')
        RETURN
      ENDIF
C ----
      FLAG = 'S'
      DO I=1,1000

        READ(IUN,'(A)',ERR=100,END=100) LINE

        IF(LINE(1:4).EQ.'HEAD'.OR.LINE(1:4).EQ.'COMP'.OR.
     *     LINE(1:4).EQ.'REMA'.OR.LINE(1:4).EQ.'CRYS'.OR.
     *     LINE(1:4).EQ.'SCAL'.OR.LINE(1:4).EQ.'ATOM'.OR.
     *     LINE(1:4).EQ.'HETA') THEN
          FLAG = 'P'
          GO TO 100
        ENDIF

        CALL LENSTR_BL(LINE,LEN)
        IF(LEN.GT.4.AND.LINE(1:1).NE.'#') THEN
          IFIRST = 0
          K      = 0
          DO J=1,LEN
            IF(LINE(J:J).EQ.' '.AND.IFIRST.EQ.0) THEN
            ELSE
              IFIRST   = 1
              K        = K+1
              STR(K:K) = LINE(J:J)
            ENDIF
          ENDDO
          IF(STR(1:1).EQ.'_'.OR.STR(1:5).EQ.'data_') THEN
            FLAG   = 'C'
            FILE_C = IN_FILE_PDB
            GO TO 100
          ENDIF
        ENDIF

      ENDDO

 100  CONTINUE
      CLOSE(IUN,ERR=110)
 110  CONTINUE
C ------------------------------
      FLAG_O = FLAG
      IF(FLAG.EQ.'P') THEN
        PDB  = CHAIN
        IERR = MODEL       
        CALL READPDB(MDOC,IN_FILE_PDB,PATH_SCR
     *            ,ISYM,IPRSYM,STR_TITLE,STR_DATE
     *            ,RESULT,IPRROW,PDB,IERR)   
        IF(IERR.NE.0) RETURN
        FLAG   = 'C'
        FILE_C = IN_FILE_PDB
        CALL LENSTR_BL(FILE_C,LEN) 
        IF(LEN.GE.5.AND.FILE_C(LEN-3:LEN).EQ.'.pdb') THEN
          FILE_C = IN_FILE_PDB(1:LEN-4)
        ENDIF

        CALL LENSTR_BL(FILE_C,LEN) 
        LLL = LEN
        IF(LLL.GT.65) LLL = 65
        LINE = 'Input file(crd): '//FILE_C(1:LLL)
        CALL MSGDOC(MDOC,LINE)


      ENDIF       

      IF(FLAG.EQ.'S') THEN
        CALL CONSEQ(MDOC,IN_FILE_PDB,FILE_OUT,IERR)
        IF(IERR.NE.0) RETURN
      ELSE IF(FLAG.EQ.'C') THEN
        CALL CORR_NAME_BLC(FILE_C)
        BOV   = 0.0
        A     = 0.0
        B     = 0.0
        C     = 0.0
        ALPHA = 0.0
        BETA  = 0.0
        GAMMA = 0.0      
c       MODE  = 'B'
        MODE  = ' '
        SETT  = 'N'
        REST  = 'N'
        WAT   = 'Y'
        P1    = 'Y'
        NOCC  = 'R'
C        NUM   = 'Y'
        NUM   = 'N'
        ALT   = 'Y'
        CONV  = 'N'
        HATM  = 'Q'  
        NAME  = ' '
        CALL CONCRD(MDOC,MODE,FILE_C,FILE_OUT,NAME,SETT,REST
     *  ,WAT,P1,HATM,NUM,NOCC,ALT,CONV
     *  ,A,B,C,ALPHA,BETA,GAMMA,BOV,ISYM,IPRSYM,IERR)
        IF(IERR.NE.0) RETURN
      ENDIF

      RETURN
      END     

      SUBROUTINE CONSEQ(MDOC,NAME_IN,NAME_OUT,IERR)
C --------------------------------------------------------
C  
C CONSEQ   converts sequence to coordinate file which can be used for ALIGN.
C 
C      File with sequence is ASCII file:
C
C      ! 
C      !# sequence 
C      !SVIGSDDRTRVTNTTAYPYRAIVHISSSIGSCTGWMIGPKTVATAGHCIY
C      !# this is comment
C      !    DTSSG--SFAGTATVSP   GRNGTSYPYG
C      !NRGTRITKEVFDNLTNWKNSAQ
C
C      If first symbol in the line is "#" it means the line is comments
C
C      Output file is BLANC (CIF) coordinate file which contains only CA atoms
C      
C      Dialogue :
C
C   File with sequence :   - input file
C   Output coord file  :   - output file. Program wiil adds extention ".crd"
C                            if you did not do it.
C 
C --------------------------------------------------------
      CHARACTER NAME_IN*(*),NAME_OUT*(*)
C ----
      CHARACTER LINE*256,NAME*256,PATH*80,EXT*80
      CHARACTER ACODE3(25)*3
      CHARACTER AMIN(25)*1
      CHARACTER CH1*1,CH3*3,STR1*80,STR2*80
C --
      DATA ACODE3/'CYS','SER','THR','PRO','ALA','GLY','ASN','ASP' 
     *           ,'GLU','GLN','HIS','ARG','LYS','MET','ILE','LEU' 
     *           ,'VAL','PHE','TYR','TRP','XXX','ASX','GLX','ACD' 
     *           ,'---'/
C  
      DATA AMIN/'C','S','T','P','A','G','N','D','E','Q','H','R','K'
     *       ,'M','I','L','V','F','Y','W','?','B','Z','X','-'/
C -------------------------------------------------------------
      IERR = 0
      MD   =-ABS(MDOC)-1
      M    = 99
C ---------------------------
      CALL LENSTR_BL(NAME_IN,LEN)
      IF(LEN.LE.0.OR.NAME_IN(1:1).EQ.' '.OR.NAME_IN(1:1).EQ.',') THEN
        CALL MSGERR(MDOC,' ERROR: wrong input file name')
        IERR = 1
        RETURN
      ENDIF
      IU   = 10
      EXT  = ' '
      PATH = ' '
c      OPEN(IU,FILE=NAME_IN(1:LEN),ACCESS='SEQUENTIAL',ERR=200
c     *  ,FORM='FORMATTED',STATUS='UNKNOWN')
      CALL OPENFR(IU,M,PATH,NAME_IN,EXT,IERR)
      IF(IERR.NE.0) THEN
        GO TO 200
      ENDIF
C --------------------------------
      CALL LENSTR_BL(NAME_OUT,LEN)
      IF(LEN.LE.0.OR.NAME_OUT(1:1).EQ.' '.OR.NAME_OUT(1:1).EQ.',') THEN
        CALL MSGERR(MDOC,' ERROR: wrong output file name')
        IERR = 1
        RETURN
      ENDIF
      IF(LEN.GE.4.AND.NAME_OUT(LEN-3:LEN).EQ.'.crd') THEN
      ELSE
        NAME_OUT = NAME_OUT(1:LEN)//'.crd'
        CALL LENSTR_BL(NAME_OUT,LEN) 
      ENDIF
      IOUT = 11
      EXT  = ' '
      PATH = ' '
C      OPEN(IOUT,FILE=NAME_OUT(1:LEN),ACCESS='SEQUENTIAL',ERR=200
C     *   ,FORM='FORMATTED',STATUS='UNKNOWN')
      CALL OPENFW(IOUT,M,PATH,NAME_OUT,EXT,IERR)
      IF(IERR.NE.0) THEN
        GO TO 200
      ENDIF
C -----
C        IF((ITEM(1:18).EQ.'_database_PDB_code').OR.
C     *     (ITEM(1:18).EQ.'_database_PDB.code').OR.
C     *     (ITEM(1:20).EQ.'_database_2.code_PDB').OR.
C     *     (ITEM(1:9).EQ.'_entry.id')) THEN
C          CR_CD_PDB = '    '
C          IF(LEND.GT.4) LEND=4
C          CR_CD_PDB = DATA(1:LEND)
C          IF(LEND.LT.4) THEN
C            DO II=LEND+1,4
C              CR_CD_PDB(II:II)=' '
C            ENDDO
C          ENDIF

      LINE = 'data_structure_XXXX'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)

      LINE = '_database_PDB.code  '//'seq'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)

      LINE = '_struct.title           ------------'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
      LINE = '_struct_keywords.text   ------------'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
      LINE = '_cell.length_a      100.000'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
      LINE = '_cell_length_b      100.000'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
      LINE = '_cell.length_c      100.000'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
      LINE = '_cell.angle_alpha    90.000'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
      LINE = '_cell.angle_beta     90.000'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
      LINE = '_cell.angle_gamma    90.000'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
      LINE = '_symmetry.space_group_name_H-M  ''P 1'''
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
      LINE = '_symmetry.Int_Tables_number        1'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
      LINE = 'loop_'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
      LINE = '_symmetry_equiv.id'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
      LINE = '_symmetry_equiv.pos_as_xyz'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
      LINE = '      1  +X,+Y,+Z,'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)

      LINE = 'loop_'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
      LINE = '_struct_asym.id'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
      LINE = '_struct_asym.entity_id'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
      LINE = '_struct_asym.nc_symmetry_id'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
      LINE = '_struct_asym.nc_symmetry_flag'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
      LINE = '_struct_asym.multiplicity'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
      LINE = '_struct_asym.PDB_chain_label'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
      LINE = '     1     1  .   .  .   A'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)

      LINE = 'loop_'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
      LINE = '_atom_site.id'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
      LINE = '_atom_site.label_atom_id'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
      LINE = '_atom_site.type_symbol'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
      LINE = '_atom_site.calc_flag'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
      LINE = '_atom_site.label_alt_id'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
      LINE = '_atom_site.footnote_id'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
      LINE = '_atom_site.label_comp_id'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
      LINE = '_atom_site.label_seq_id'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
      LINE = '_atom_site.label_asym_id'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
      LINE = '_atom_site.cartn_x'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
      LINE = '_atom_site.cartn_y'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
      LINE = '_atom_site.cartn_z'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
      LINE = '_atom_site.occupancy'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
      LINE = '_atom_site.B_iso_or_equiv'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
      LINE = '_atom_site.thermal_displace_type'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
      LINE = '_atom_site.symmetry_multiplicity'
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
C -----------------------------      
      IC = 0
      NC =-1
      I  = 0
      N  = 0 
C ----------------
 400  CONTINUE
      IF(IC.GT.NC) THEN
        READ(IU,'(A)',ERR=500,END=600) LINE
        CALL LENSTR_BL(LINE,LEN)
        IF(LEN.LE.0.OR.LINE(1:1).EQ.'#'.OR.LINE(1:1).EQ.'>') GO TO 400        
        IC = 1
        NC = LEN
      ENDIF
      CH1 = LINE(IC:IC)
      IF(CH1.EQ.' ') THEN
        IC = IC + 1
        GO TO 400
C      ELSE IF(CH1.EQ.'-') THEN
C        I  = I + 1
C        IC = IC + 1
C        GO TO 400
      ENDIF

      DO  J=1,25
        IF(CH1.EQ.AMIN(J)) THEN
          CH3 = ACODE3(J)
          GO TO 700
        ENDIF
      ENDDO
      J   = 26
 700  CONTINUE
      IF(J.LE.25) THEN
        I = I + 1
        N = N + 1
        STR1 = ' CA   C    . . . ' 
        STR2 = '  1    0.0     0.0      0.0      1.00  15.00 . .'
        CALL LENSTR_BL(STR1,L1)
        CALL LENSTR_BL(STR2,L2)
        WRITE(IOUT,'(I5,A,'' '',A,I5,A)',ERR=800) 
     *  I,STR1(1:L1),CH3,I,STR2(1:L2)
C      ELSE IF(J.LE.25) THEN
C        I = I + 1
      ENDIF

      IC = IC + 1
      GO TO 400
C --------------
 600  CONTINUE
      CLOSE(IU)
      END FILE IOUT
      CLOSE (IOUT)
      WRITE(LINE,'('' Number of residues :'',I8)') N
      CALL MSGDOC(MDOC,LINE)
      IF(N.LE.0) THEN
        CALL MSGERR(MDOC,' Number of residues in sequence = 0')
        IERR = 1
      ENDIF
      RETURN
C ----------------
 200  CONTINUE
      LINE = ' ERROR: cannot open file'
      CALL MSGERR(MDOC,LINE)
      GO TO 900
 500  CONTINUE
      LINE = ' ERROR: reading input file'
      CALL MSGERR(MDOC,LINE)
      GO TO 900
 800  CONTINUE
      LINE = ' ERROR: writing output file'
      CALL MSGERR(MDOC,LINE)
      GO TO 900
C ----------------
 900  CONTINUE
      IERR = 1
      RETURN
      END

      SUBROUTINE CHANGE_ATOM(MDOC,IR1,IR2,I1,I2,IOCC,ATOM1,XYZ,OCC,BISO
     *     ,BTEMP,RNAME1,RNAME2,IATOM,IRES,IGROUP,WEIGHT
     *     ,NMAX2,ATOM_NAME,ATOM_INDEX,ATOM_STORE,IOUT,IERR)
C -----------------------------------------
C     N CA CB CG CD CE CZ C O
      CHARACTER ATOM_NAME(9)*2
C      DATA AMIN/'C','S','T','P','A','G','N','D','E','Q','H','R','K'
C     *         ,'M','I','L','V','F','Y','W','B','Z','X','-',' '/
      INTEGER   ATOM_INDEX(4,25)
      REAL      ATOM_STORE(5,9,2,NMAX2)
C -----------------------------------------
      REAL      XYZ(3)
      CHARACTER RNAME1*3,RNAME2*3,ATOM1*4,ATOM2*4,ANAME*4,ATYPE*4
      CHARACTER LINE*80,WEIGHT*1
C -----------------------------------------
C     N CA CB CG CD CE CZ C O
C     CHARACTER ATOM_NAME(9)*2
      IERR = 0
C     -- N --
      IA  = 1
      IAA = 1
      IATOM = IATOM + 1
      ANAME = 'N   '
      ATYPE = 'N   '
      OCC   = 0.0
      IF(IOCC.GT.0.AND.I2.GT.0) OCC = ATOM_STORE(4,IA,IAA,I2)
      IF(I2.EQ.0.OR.OCC.LE.0.00001) THEN
        XYZ(1) = 0.0
        XYZ(2) = 0.0
        XYZ(3) = 0.0
        BTEMP  = 0.0
      ELSE
        XYZ(1) = ATOM_STORE(1,IA,IAA,I2)        
        XYZ(2) = ATOM_STORE(2,IA,IAA,I2)        
        XYZ(3) = ATOM_STORE(3,IA,IAA,I2)
        OCC    = ATOM_STORE(4,IA,IAA,I2)
        BISO   = ATOM_STORE(5,IA,IAA,I2)
        BTEMP  = BISO 
        IF(WEIGHT.EQ.'2') BTEMP = 20.0
        OCC = 1.0
      ENDIF
      WRITE(LINE,200)
     *      IATOM,ANAME,ATYPE,RNAME1,IRES,IGROUP
     *      ,XYZ(1),XYZ(2),XYZ(3),OCC,BTEMP
  200 FORMAT(I5,1X,A4,1X,A4,' . . . ',A3,1X 
     *    ,I4,1X,I2,1X,F8.3,1X,F8.3,1X,F8.3,1X,F6.2,1X,F6.2
     *    ,' . .')
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
C ----
C     -- CA --
      IA  = 2
      IAA = 1
      IATOM = IATOM + 1
      ANAME = 'CA  '
      ATYPE = 'C   '
      OCC   = 0.0
      IF(IOCC.GT.0.AND.I2.GT.0) OCC = ATOM_STORE(4,IA,IAA,I2)
      IF(I2.EQ.0.OR.OCC.LE.0.00001) THEN
        XYZ(1) = 0.0
        XYZ(2) = 0.0
        XYZ(3) = 0.0
        BTEMP  = 0.0
      ELSE
        XYZ(1) = ATOM_STORE(1,IA,IAA,I2)        
        XYZ(2) = ATOM_STORE(2,IA,IAA,I2)        
        XYZ(3) = ATOM_STORE(3,IA,IAA,I2)
        OCC    = ATOM_STORE(4,IA,IAA,I2)
        BISO   = ATOM_STORE(5,IA,IAA,I2)
        BTEMP  = BISO 
        IF(WEIGHT.EQ.'2') BTEMP = 20.0
        OCC = 1.0
      ENDIF
      WRITE(LINE,200)
     *      IATOM,ANAME,ATYPE,RNAME1,IRES,IGROUP
     *      ,XYZ(1),XYZ(2),XYZ(3),OCC,BTEMP
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)

      IF(RNAME1.NE.'GLY'.AND.(RNAME2.NE.'GLY'.AND.I2.NE.0)) THEN
C ----
C     -- CB --
      IA  = 3
      IAA = 1
      IATOM = IATOM + 1
      ANAME = 'CB  '
      ATYPE = 'C   '
      OCC   = 0.0
      IF(IOCC.GT.0.AND.I2.GT.0) OCC = ATOM_STORE(4,IA,IAA,I2)
      IF(I2.EQ.0.OR.OCC.LE.0.00001) THEN
        XYZ(1) = 0.0
        XYZ(2) = 0.0
        XYZ(3) = 0.0
        BTEMP  = 0.0
      ELSE
        XYZ(1) = ATOM_STORE(1,IA,IAA,I2)        
        XYZ(2) = ATOM_STORE(2,IA,IAA,I2)        
        XYZ(3) = ATOM_STORE(3,IA,IAA,I2)
        OCC    = ATOM_STORE(4,IA,IAA,I2)
        BISO   = ATOM_STORE(5,IA,IAA,I2)
        BTEMP  = BISO 
        IF(WEIGHT.EQ.'2') BTEMP = 20.0
        OCC = 1.0
      ENDIF
      WRITE(LINE,200)
     *      IATOM,ANAME,ATYPE,RNAME1,IRES,IGROUP
     *      ,XYZ(1),XYZ(2),XYZ(3),OCC,BTEMP
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
   
      ENDIF
C ---
      IND1 = ATOM_INDEX(1,IR1)
      IND2 = ATOM_INDEX(2,IR1)
      JND1 = ATOM_INDEX(1,IR2)
      JND2 = ATOM_INDEX(2,IR2)

C     -- CG --
      IF(IND1.GT.0.AND.JND1.GT.0) THEN

      ATOM1 = 'CG  '
C                 1   2   3   4   5   6   7   8   9   10  11  12  13
C      DATA AMIN/'C','S','T','P','A','G','N','D','E','Q','H','R','K'
C     *         ,'M','I','L','V','F','Y','W','B','Z','X','-',' '/
C                 14  15  16  17  18  19  20

      IF(IR1 .EQ.1) ATOM1 = 'SG  '
      IF(IR1 .EQ.2) ATOM1 = 'OG  '
      IF(IR1 .EQ.3) ATOM1 = 'OG  '
      IF(IND1.EQ.2) ATOM1(3:3) = '1'

      IA  = 4
      IAA = 1
      IATOM = IATOM + 1
      ANAME = ATOM1
      ATYPE = ANAME(1:1)
      OCC   = 0.0
      IF(IOCC.GT.0.AND.I2.GT.0) OCC = ATOM_STORE(4,IA,IAA,I2)
      IF(I2.EQ.0.OR.OCC.LE.0.00001) THEN
        XYZ(1) = 0.0
        XYZ(2) = 0.0
        XYZ(3) = 0.0
        BTEMP  = 0.0
      ELSE
        XYZ(1) = ATOM_STORE(1,IA,IAA,I2)        
        XYZ(2) = ATOM_STORE(2,IA,IAA,I2)        
        XYZ(3) = ATOM_STORE(3,IA,IAA,I2)
        OCC    = ATOM_STORE(4,IA,IAA,I2)
        BISO   = ATOM_STORE(5,IA,IAA,I2)
        BTEMP  = BISO 
        IF(WEIGHT.EQ.'2') BTEMP = 20.0
        OCC = 1.0
      ENDIF
      WRITE(LINE,200)
     *      IATOM,ANAME,ATYPE,RNAME1,IRES,IGROUP
     *      ,XYZ(1),XYZ(2),XYZ(3),OCC,BTEMP
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)

C     -- CG2 --
      IF(IND1.EQ.2.AND.JND1.EQ.2) THEN

        ATOM1 = 'CG2 '
        IA  = 4
        IAA = 2
        IATOM = IATOM + 1
        ANAME = ATOM1
        ATYPE = ANAME(1:1)
        OCC   = 0.0
        IF(IOCC.GT.0.AND.I2.GT.0) OCC = ATOM_STORE(4,IA,IAA,I2)
        IF(I2.EQ.0.OR.OCC.LE.0.00001) THEN
          XYZ(1) = 0.0
          XYZ(2) = 0.0
          XYZ(3) = 0.0
          BTEMP  = 0.0
        ELSE
          XYZ(1) = ATOM_STORE(1,IA,IAA,I2)        
          XYZ(2) = ATOM_STORE(2,IA,IAA,I2)        
          XYZ(3) = ATOM_STORE(3,IA,IAA,I2)
          OCC    = ATOM_STORE(4,IA,IAA,I2)
          BISO   = ATOM_STORE(5,IA,IAA,I2)
          BTEMP  = BISO 
          IF(WEIGHT.EQ.'2') BTEMP = 20.0
          OCC = 1.0
        ENDIF
        WRITE(LINE,200)
     *        IATOM,ANAME,ATYPE,RNAME1,IRES,IGROUP
     *        ,XYZ(1),XYZ(2),XYZ(3),OCC,BTEMP
        CALL LENSTR_BL(LINE,LEN)
        WRITE(IOUT,'(A)') LINE(1:LEN)


        ENDIF

      ENDIF

C     -- CD --
      IF(IND2.GT.0.AND.JND2.GT.0) THEN

      ATOM1 = 'CD  '
C                 1   2   3   4   5   6   7   8   9   10  11  12  13
C      DATA AMIN/'C','S','T','P','A','G','N','D','E','Q','H','R','K'
C     *         ,'M','I','L','V','F','Y','W','B','Z','X','-',' '/
C                 14  15  16  17  18  19  20

      IF(IR1 .EQ. 7) ATOM1 = 'OD  '
      IF(IR1 .EQ. 8) ATOM1 = 'OD  '
      IF(IR1 .EQ.14) ATOM1 = 'SD  '
      IF(IR1 .EQ.11) ATOM1 = 'ND  '
      IF(IR1 .EQ.16) ATOM1 = 'CD1 '
      IF(IR1 .EQ.15) ATOM1 = 'CD1 '
      IF(IND2.EQ.2) ATOM1(3:3) = '1'

      IA  = 5
      IAA = 1
      IATOM = IATOM + 1
      ANAME = ATOM1
      ATYPE = ANAME(1:1)
      OCC   = 0.0
      IF(IOCC.GT.0.AND.I2.GT.0) OCC = ATOM_STORE(4,IA,IAA,I2)
      IF(IR2.EQ.4.AND.IR1.NE.4) OCC = 0.0
      IF(I2.EQ.0.OR.OCC.LE.0.00001) THEN
        XYZ(1) = 0.0
        XYZ(2) = 0.0
        XYZ(3) = 0.0
        BTEMP  = 0.0
      ELSE
        XYZ(1) = ATOM_STORE(1,IA,IAA,I2)        
        XYZ(2) = ATOM_STORE(2,IA,IAA,I2)        
        XYZ(3) = ATOM_STORE(3,IA,IAA,I2)
        OCC    = ATOM_STORE(4,IA,IAA,I2)
        BISO   = ATOM_STORE(5,IA,IAA,I2)
        BTEMP  = BISO 
        IF(WEIGHT.EQ.'2') BTEMP = 20.0
        OCC = 1.0
      ENDIF
      WRITE(LINE,200)
     *      IATOM,ANAME,ATYPE,RNAME1,IRES,IGROUP
     *      ,XYZ(1),XYZ(2),XYZ(3),OCC,BTEMP
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)

C     -- CD2 --
      IF(IND2.EQ.2.AND.JND2.EQ.2) THEN

        ATOM1 = 'CD2 '
        IF(IR1 .EQ.7) ATOM1 = 'ND2 '
        IF(IR1 .EQ.8) ATOM1 = 'OD2 '
        IA  = 5
        IAA = 2
        IATOM = IATOM + 1
        ANAME = ATOM1
        ATYPE = ANAME(1:1)
        OCC   = 0.0
        IF(IOCC.GT.0.AND.I2.GT.0) OCC = ATOM_STORE(4,IA,IAA,I2)
        IF(I2.EQ.0.OR.OCC.LE.0.00001) THEN
          XYZ(1) = 0.0
          XYZ(2) = 0.0
          XYZ(3) = 0.0
          BTEMP  = 0.0
        ELSE
          XYZ(1) = ATOM_STORE(1,IA,IAA,I2)        
          XYZ(2) = ATOM_STORE(2,IA,IAA,I2)        
          XYZ(3) = ATOM_STORE(3,IA,IAA,I2)
          OCC    = ATOM_STORE(4,IA,IAA,I2)
          BISO   = ATOM_STORE(5,IA,IAA,I2)
          BTEMP  = BISO 
          IF(WEIGHT.EQ.'2') BTEMP = 20.0
          OCC = 1.0
        ENDIF
        WRITE(LINE,200)
     *        IATOM,ANAME,ATYPE,RNAME1,IRES,IGROUP
     *        ,XYZ(1),XYZ(2),XYZ(3),OCC,BTEMP
        CALL LENSTR_BL(LINE,LEN)
        WRITE(IOUT,'(A)') LINE(1:LEN)


        ENDIF

      ENDIF
      IND1 = ATOM_INDEX(3,IR1)
      JND1 = ATOM_INDEX(3,IR2)

C     -- CE --
      IF(IND1.GT.0.AND.JND1.GT.0) THEN
      IF((IR1.EQ.IR2)             .OR.
     *   (IR1.EQ. 9.AND.IR2.EQ.10).OR.
     *   (IR1.EQ.10.AND.IR2.EQ. 9).OR.
     *   (IR1.EQ.12.AND.IR2.EQ.13).OR.
     *   (IR1.EQ.13.AND.IR2.EQ.12).OR.
     *   (IR1.EQ.18.AND.IR2.EQ.19).OR.
     *   (IR1.EQ.19.AND.IR2.EQ.18)    )THEN
      ATOM1 = 'CE  '
C                 1   2   3   4   5   6   7   8   9   10  11  12  13
C      DATA AMIN/'C','S','T','P','A','G','N','D','E','Q','H','R','K'
C     *         ,'M','I','L','V','F','Y','W','B','Z','X','-',' '/
C                 14  15  16  17  18  19  20

      IF(IR1 .EQ. 9) ATOM1 = 'OE  '
      IF(IR1 .EQ.10) ATOM1 = 'OE  '
      IF(IR1 .EQ.12) ATOM1 = 'NE  '
      IF(IR1 .EQ.20) ATOM1 = 'NE  '
      IF(IND1.EQ.2) ATOM1(3:3) = '1'

      IA  = 6
      IAA = 1
      IATOM = IATOM + 1
      ANAME = ATOM1
      ATYPE = ANAME(1:1)
      OCC   = 0.0
      IF(IOCC.GT.0.AND.I2.GT.0) OCC = ATOM_STORE(4,IA,IAA,I2)
      IF(I2.EQ.0.OR.OCC.LE.0.00001) THEN
        XYZ(1) = 0.0
        XYZ(2) = 0.0
        XYZ(3) = 0.0
        BTEMP  = 0.0
      ELSE
        XYZ(1) = ATOM_STORE(1,IA,IAA,I2)        
        XYZ(2) = ATOM_STORE(2,IA,IAA,I2)        
        XYZ(3) = ATOM_STORE(3,IA,IAA,I2)
        OCC    = ATOM_STORE(4,IA,IAA,I2)
        BISO   = ATOM_STORE(5,IA,IAA,I2)
        BTEMP  = BISO 
        IF(WEIGHT.EQ.'2') BTEMP = 20.0
        OCC = 1.0
      ENDIF
      WRITE(LINE,200)
     *      IATOM,ANAME,ATYPE,RNAME1,IRES,IGROUP
     *      ,XYZ(1),XYZ(2),XYZ(3),OCC,BTEMP
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)

      IF(IND2.EQ.2.AND.JND2.EQ.2) THEN

        ATOM1 = 'CE2 '
        IF(IR1 .EQ.10) ATOM1 = 'NE2 '
        IF(IR1 .EQ.11) ATOM1 = 'NE2 '
        IA  = 6
        IAA = 2
        IATOM = IATOM + 1
        ANAME = ATOM1
        ATYPE = ANAME(1:1)
        OCC   = 0.0
        IF(IOCC.GT.0.AND.I2.GT.0) OCC = ATOM_STORE(4,IA,IAA,I2)
        IF(I2.EQ.0.OR.OCC.LE.0.00001) THEN
          XYZ(1) = 0.0
          XYZ(2) = 0.0
          XYZ(3) = 0.0
          BTEMP  = 0.0
        ELSE
          XYZ(1) = ATOM_STORE(1,IA,IAA,I2)        
          XYZ(2) = ATOM_STORE(2,IA,IAA,I2)        
          XYZ(3) = ATOM_STORE(3,IA,IAA,I2)
          OCC    = ATOM_STORE(4,IA,IAA,I2)
          BISO   = ATOM_STORE(5,IA,IAA,I2)
          BTEMP  = BISO 
          IF(WEIGHT.EQ.'2') BTEMP = 20.0
          OCC = 1.0
        ENDIF
        WRITE(LINE,200)
     *        IATOM,ANAME,ATYPE,RNAME1,IRES,IGROUP
     *        ,XYZ(1),XYZ(2),XYZ(3),OCC,BTEMP
        CALL LENSTR_BL(LINE,LEN)
        WRITE(IOUT,'(A)') LINE(1:LEN)

      ENDIF

      ENDIF
      ENDIF

      IND1 = ATOM_INDEX(4,IR1)
      JND1 = ATOM_INDEX(4,IR2)

C     -- CZ --
      IF(IND1.GT.0.AND.JND1.GT.0) THEN
      IF((IR1.EQ.IR2)             .OR.
     *   (IR1.EQ.12.AND.IR2.EQ.13).OR.
     *   (IR1.EQ.13.AND.IR2.EQ.12).OR.
     *   (IR1.EQ.18.AND.IR2.EQ.19).OR.
     *   (IR1.EQ.19.AND.IR2.EQ.18)    )THEN
      ATOM1 = 'CZ  '
C                 1   2   3   4   5   6   7   8   9   10  11  12  13
C      DATA AMIN/'C','S','T','P','A','G','N','D','E','Q','H','R','K'
C     *         ,'M','I','L','V','F','Y','W','B','Z','X','-',' '/
C                 14  15  16  17  18  19  20

      IF(IR1 .EQ.13) ATOM1 = 'NZ  '
      IF(IND1.EQ.2) ATOM1(3:3) = '1'

      IA  = 7
      IAA = 1
      IATOM = IATOM + 1
      ANAME = ATOM1
      ATYPE = ANAME(1:1)
      OCC   = 0.0
      IF(IOCC.GT.0.AND.I2.GT.0) OCC = ATOM_STORE(4,IA,IAA,I2)
      IF(I2.EQ.0.OR.OCC.LE.0.00001) THEN
        XYZ(1) = 0.0
        XYZ(2) = 0.0
        XYZ(3) = 0.0
        BTEMP  = 0.0
      ELSE
        XYZ(1) = ATOM_STORE(1,IA,IAA,I2)        
        XYZ(2) = ATOM_STORE(2,IA,IAA,I2)        
        XYZ(3) = ATOM_STORE(3,IA,IAA,I2)
        OCC    = ATOM_STORE(4,IA,IAA,I2)
        BISO   = ATOM_STORE(5,IA,IAA,I2)
        BTEMP  = BISO 
        IF(WEIGHT.EQ.'2') BTEMP = 20.0
        OCC = 1.0
      ENDIF
      WRITE(LINE,200)
     *      IATOM,ANAME,ATYPE,RNAME1,IRES,IGROUP
     *      ,XYZ(1),XYZ(2),XYZ(3),OCC,BTEMP
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)

      ENDIF
      ENDIF

C     -- C --
      IA  = 8
      IAA = 1
      IATOM = IATOM + 1
      ANAME = 'C   '
      ATYPE = 'C   '
      OCC   = 0.0
      IF(IOCC.GT.0.AND.I2.GT.0) OCC = ATOM_STORE(4,IA,IAA,I2)
      IF(I2.EQ.0.OR.OCC.LE.0.00001) THEN
        XYZ(1) = 0.0
        XYZ(2) = 0.0
        XYZ(3) = 0.0
        BTEMP  = 0.0
      ELSE
        XYZ(1) = ATOM_STORE(1,IA,IAA,I2)        
        XYZ(2) = ATOM_STORE(2,IA,IAA,I2)        
        XYZ(3) = ATOM_STORE(3,IA,IAA,I2)
        OCC    = ATOM_STORE(4,IA,IAA,I2)
        BISO   = ATOM_STORE(5,IA,IAA,I2)
        BTEMP  = BISO 
        IF(WEIGHT.EQ.'2') BTEMP = 20.0
        OCC = 1.0
      ENDIF
      WRITE(LINE,200)
     *      IATOM,ANAME,ATYPE,RNAME1,IRES,IGROUP
     *      ,XYZ(1),XYZ(2),XYZ(3),OCC,BTEMP
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)

C     -- O --
      IA  = 9
      IAA = 1
      IATOM = IATOM + 1
      ANAME = 'O   '
      ATYPE = 'O   '
      OCC   = 0.0
      IF(IOCC.GT.0.AND.I2.GT.0) OCC = ATOM_STORE(4,IA,IAA,I2)
      IF(I2.EQ.0.OR.OCC.LE.0.00001) THEN
        XYZ(1) = 0.0
        XYZ(2) = 0.0
        XYZ(3) = 0.0
        BTEMP  = 0.0
      ELSE
        XYZ(1) = ATOM_STORE(1,IA,IAA,I2)        
        XYZ(2) = ATOM_STORE(2,IA,IAA,I2)        
        XYZ(3) = ATOM_STORE(3,IA,IAA,I2)
        OCC    = ATOM_STORE(4,IA,IAA,I2)
        BISO   = ATOM_STORE(5,IA,IAA,I2)
        BTEMP  = BISO 
        IF(WEIGHT.EQ.'2') BTEMP = 20.0
        OCC = 1.0
      ENDIF
      WRITE(LINE,200)
     *      IATOM,ANAME,ATYPE,RNAME1,IRES,IGROUP
     *      ,XYZ(1),XYZ(2),XYZ(3),OCC,BTEMP
      CALL LENSTR_BL(LINE,LEN)
      WRITE(IOUT,'(A)') LINE(1:LEN)
C ----
      RETURN
      END

